var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => {
  __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
import { reactive, defineComponent, computed, getCurrentInstance, openBlock, createBlock, resolveDynamicComponent, unref, withCtx, renderSlot, normalizeClass, createElementBlock, createCommentVNode, createTextVNode, toDisplayString, ref, watch, Fragment, withDirectives, mergeProps, renderList, createElementVNode, normalizeStyle, withModifiers, createVNode, vShow, onMounted, useSlots, isRef, toHandlers, vModelText, toRaw, nextTick as nextTick$1, inject, provide, onBeforeUnmount, withKeys, onBeforeMount, onUnmounted, TransitionGroup, h, onUpdated, onBeforeUpdate, normalizeProps, guardReactiveProps, resolveComponent } from "vue";
import { useRouter, RouterLink, useRoute } from "vue-router";
import YouTube from "vue3-youtube";
import { required, numeric } from "@vee-validate/rules";
import { useField } from "vee-validate";
import dayjs from "dayjs";
import { directive } from "vue3-click-away";
import { useLoading } from "vue-loading-overlay";
import { vfmPlugin, $vfm } from "vue-final-modal";
const uiComponentConfig = {
  fileUrlPrefix: "",
  blankImageUrl: "",
  errorImageUrl: "",
  alertRequired: "Required",
  alertNumberOnly: "Only numbers are allowed",
  alertMinCharCount: (args) => `Should be longer than ${args[0]}`,
  alertMaxCharCount: (args) => `Should be shorter than ${args[0]}`,
  currencySymbolBefore: "",
  currencySymbolAfter: "",
  pointSymbolAfter: "P",
  inputQtyChangeButtonCaption: "Change",
  loadingOverlayColor: "#3f51b5",
  loadingOverlayStyle: "spinner",
  scrollListDefaultScrollType: "PAGE",
  scrollListMoreCaption: "More",
  scrollListMoreButtonIcon: "plus",
  scrollListMoreButtonDirection: "left",
  periodSearchMonthList: [{ caption: "3M", months: 3 }, { caption: "6M", months: 6 }, { caption: "1Y", months: 12 }],
  periodSearchAllCaption: "All",
  processStepIconClass: "arrow-right",
  imagePreventCopy: false
};
const configureUiComponent = (config) => {
  Object.assign(uiComponentConfig, config);
};
const ScreenSizeArray = ["XS", "SM", "MD", "LG", "XL"];
const BREAKPOINTS = {
  sm: {}.VITE_BREAKPOINT_SM || "576",
  md: {}.VITE_BREAKPOINT_MD || "768",
  lg: {}.VITE_BREAKPOINT_LG || "992",
  xl: {}.VITE_BREAKPOINT_XL || "1140"
};
const MEDIA_QUERIES = {
  sm: `(min-width: ${BREAKPOINTS.sm}px)`,
  md: `(min-width: ${BREAKPOINTS.md}px)`,
  lg: `(min-width: ${BREAKPOINTS.lg}px)`,
  xl: `(min-width: ${BREAKPOINTS.xl}px)`
};
const globalResponsiveConfig = reactive({
  screenSize: "XS"
});
const refreshScreenSize = () => {
  const width = window.innerWidth;
  globalResponsiveConfig.screenSize = width >= Number(BREAKPOINTS.xl) ? "XL" : width >= Number(BREAKPOINTS.lg) ? "LG" : width >= Number(BREAKPOINTS.md) ? "MD" : width >= Number(BREAKPOINTS.sm) ? "SM" : "XS";
};
refreshScreenSize();
window == null ? void 0 : window.addEventListener("resize", refreshScreenSize, { passive: true });
const responsiveUtil = {
  currentScreenSize() {
    return globalResponsiveConfig.screenSize;
  },
  isScreenSizeSmallerThan(size) {
    return ScreenSizeArray.indexOf(globalResponsiveConfig.screenSize) < ScreenSizeArray.indexOf(size);
  },
  isScreenSizeEqualOrSmallerThan(size) {
    return ScreenSizeArray.indexOf(globalResponsiveConfig.screenSize) <= ScreenSizeArray.indexOf(size);
  },
  isScreenSizeEqualOrGreaterThan(size) {
    return ScreenSizeArray.indexOf(globalResponsiveConfig.screenSize) >= ScreenSizeArray.indexOf(size);
  },
  isScreenSizeGreaterThan(size) {
    return ScreenSizeArray.indexOf(globalResponsiveConfig.screenSize) > ScreenSizeArray.indexOf(size);
  }
};
const urlUtil = {
  /**
   * `url` 이 absolute url 인지 확인한다.
   * @param url
   */
  isAbsoluteUrl(url) {
    return !!url && (url.startsWith("http://") || url.startsWith("https://") || url.startsWith("mailto:") || url.startsWith("tel:"));
  },
  isS3ImageUrl(url) {
    return !!url && !url.startsWith("/src") && !url.startsWith("/asset");
  },
  /**
   * `url` 이 relative url 이면 url 앞에 `prefix`를 붙인다.
   * absolute url 이면 url 을 그대로 리턴한다.
   * @param prefix
   * @param url
   */
  prependPrefixIfRelativeUrl(prefix, url) {
    if (!url)
      return void 0;
    if (this.isAbsoluteUrl(url))
      return url;
    return prefix + url;
  },
  /**
   * `url`이 내부 링크인지 확인한다.
   * `true`이면 이유를 리턴하고, `false`이면 `undefined`를 리턴한다.
   *  @param url
   */
  checkInternalLink(url) {
    return !this.isAbsoluteUrl(url) ? "RELATIVE_PATH" : new URL(url).origin === new URL(location.href).origin ? "SAME_ORIGIN" : void 0;
  },
  /**
   *  `targetUrl`과 `withUrl`를 비교하여, 같은 부분까지를 잘라내고 난 나머지를 리턴한다.
   *
   *  @example
   *  targetUrl: https://www.test.com/test
   *  withUrl: https://www.test.com/abc
   *  return "/test"
   *
   *  @param targetUrl
   *  @param withUrl
   *  @return remainedUrl
   */
  extractUrlDifferentPart(targetUrl, withUrl) {
    return "/" + targetUrl.split("/").filter((str, index2) => str !== withUrl.split("/")[index2]).join("/");
  },
  /**
   * url 이 이미지 URL 인지 확인한다.
   */
  isImageUrl(url) {
    const ext = url.substring(url.lastIndexOf(".") + 1).toLowerCase();
    return ["jpg", "jpeg", "png", "ping", "gif", "giff", "webp", "svg"].includes(ext);
  }
};
const _sfc_main$z = /* @__PURE__ */ defineComponent({
  __name: "UiLink",
  props: {
    href: null,
    target: null,
    replace: { type: Boolean }
  },
  setup(__props) {
    const props = __props;
    const isTargetSelf = computed(() => !(props == null ? void 0 : props.target) || props.target.toLowerCase() === "_self");
    const instance = getCurrentInstance();
    const isVueRouterInstalled = !!(instance == null ? void 0 : instance.appContext.config.globalProperties.$router);
    const router = isVueRouterInstalled ? useRouter() : void 0;
    const routerBase = location.origin + ((router == null ? void 0 : router.options.history.base) || "");
    const isInternalLink = computed(() => props.href && router && urlUtil.checkInternalLink(props.href));
    const computedHref = computed(() => props.href && isInternalLink.value === "SAME_ORIGIN" && isTargetSelf.value ? urlUtil.extractUrlDifferentPart(props.href, routerBase) : props.href);
    const component = computed(() => isInternalLink.value ? RouterLink : "a");
    return (_ctx, _cache) => {
      return openBlock(), createBlock(resolveDynamicComponent(unref(component)), {
        href: unref(computedHref),
        to: unref(computedHref),
        target: __props.target,
        replace: __props.replace
      }, {
        default: withCtx(() => [
          renderSlot(_ctx.$slots, "default")
        ]),
        _: 3
      }, 8, ["href", "to", "target", "replace"]);
    };
  }
});
const _sfc_main$y = /* @__PURE__ */ defineComponent({
  __name: "UiButton",
  props: {
    caption: { default: "" },
    href: null,
    replace: { type: Boolean },
    routerTo: null,
    buttonType: { default: "button" },
    icon: null,
    iconDirection: { default: "left" },
    disabled: { type: Boolean }
  },
  setup(__props) {
    const props = __props;
    const iconClass = computed(() => {
      return `${props.icon} icon-${props.iconDirection} ${props.caption ? "with-caption" : ""}`;
    });
    const extraClass = computed(() => {
      return props.icon && props.iconDirection === "top" ? "vertical" : "";
    });
    const isComponentLink = computed(() => !!props.href || !!props.routerTo);
    const checkComponentLinkOrButton = computed(() => isComponentLink.value ? _sfc_main$z : "button");
    return (_ctx, _cache) => {
      return openBlock(), createBlock(resolveDynamicComponent(unref(checkComponentLinkOrButton)), {
        class: normalizeClass(["ui-button", unref(extraClass)]),
        href: __props.href || __props.routerTo,
        replace: __props.replace,
        disabled: __props.disabled,
        type: !unref(isComponentLink) ? __props.buttonType : void 0
      }, {
        default: withCtx(() => [
          __props.icon && (__props.iconDirection === "left" || __props.iconDirection === "top") ? (openBlock(), createElementBlock("i", {
            key: 0,
            class: normalizeClass(["icon-font", unref(iconClass)])
          }, null, 2)) : createCommentVNode("", true),
          createTextVNode(" " + toDisplayString(__props.caption) + " ", 1),
          __props.icon && __props.iconDirection === "right" ? (openBlock(), createElementBlock("i", {
            key: 1,
            class: normalizeClass(["icon-font", unref(iconClass)])
          }, null, 2)) : createCommentVNode("", true)
        ]),
        _: 1
      }, 8, ["class", "href", "replace", "disabled", "type"]);
    };
  }
});
const checkSupportIntersectionObserver = () => {
  var _a;
  return "IntersectionObserver" in window || "IntersectionObserverEntry" in window || "intersectionRatio" in (((_a = window == null ? void 0 : window.IntersectionObserverEntry) == null ? void 0 : _a.prototype) || {});
};
const checkMobileDevice = () => {
  const userAgent = navigator.userAgent.toLowerCase();
  if (userAgent.indexOf("android") > -1)
    return "ANDROID";
  else if (userAgent.indexOf("iphone") > -1 || userAgent.indexOf("ipad") > -1 || userAgent.indexOf("ipod") > -1)
    return "IOS";
  else
    return "ETC";
};
const checkSupportWebp = () => {
  const elem = document.createElement("canvas");
  return elem.getContext && elem.getContext("2d") ? elem.toDataURL("image/webp").indexOf("data:image/webp") === 0 : false;
};
const mobileDeviceType = checkMobileDevice();
const supportWebp = checkSupportWebp();
const supportIntersectionObserver = checkSupportIntersectionObserver();
const defaultIntersectionObserver = !supportIntersectionObserver ? void 0 : new IntersectionObserver((entries, observer) => {
  entries.forEach((entry) => {
    var _a, _b;
    if (entry.isIntersecting) {
      (_b = (_a = entry.target).onIntersect) == null ? void 0 : _b.call(_a);
      if (entry.target.onIntersectOnce) {
        observer.unobserve(entry.target);
        delete entry.target.onIntersect;
      }
    }
  });
});
const vLazy = {
  mounted: (element, { value }, vnode) => {
    const enabled = typeof value === "object" ? !!value.enabled : !!value;
    const onIntersectHandler = typeof value === "object" ? value.onIntersect : null;
    const once = typeof value === "object" && value.once !== void 0 ? value.once : true;
    if (defaultIntersectionObserver && (enabled === void 0 || enabled)) {
      element.onIntersect = () => onIntersectHandler == null ? void 0 : onIntersectHandler(element, vnode);
      element.onIntersectOnce = once;
      defaultIntersectionObserver.observe(element);
    } else {
      onIntersectHandler == null ? void 0 : onIntersectHandler(element, vnode);
    }
  }
};
const preventDefaultHandler = (event2) => event2.preventDefault();
const vPreventCopy = {
  updated: (element, { value }) => {
    if (value == void 0 || value) {
      if (element.getAttribute("prevent-copy-handler-registered") !== "true") {
        element.addEventListener("contextmenu", preventDefaultHandler);
        element.setAttribute("prevent-copy-handler-registered", "true");
      }
      if (!element.classList.contains("user-select-none")) {
        element.classList.add("user-select-none");
      }
    }
  }
};
const _hoisted_1$r = ["src", "srcset", "alt"];
const _hoisted_2$g = ["viewBox"];
const _hoisted_3$e = ["src", "data-file-url"];
const _hoisted_4$8 = ["src", "data-file-url"];
const _hoisted_5$6 = ["data-file-url", "viewBox"];
const _sfc_main$x = /* @__PURE__ */ defineComponent({
  __name: "UiImage",
  props: {
    fileUrl: null,
    alt: null,
    width: null,
    height: null,
    requestWidth: null,
    requestHeight: null,
    loadingWidth: null,
    loadingHeight: null,
    quality: { default: -1 },
    lazy: { type: Boolean, default: true },
    preventCopy: { type: Boolean, default: () => uiComponentConfig.imagePreventCopy },
    useSrcset: { type: Boolean },
    srcsetMaxResolution: { default: 3 },
    hideImageOnError: { type: Boolean },
    imageRatio: { default: 1 },
    errorImage: { default: () => uiComponentConfig.errorImageUrl },
    blankImage: { default: () => uiComponentConfig.blankImageUrl }
  },
  setup(__props) {
    const props = __props;
    const shouldUseDefaultImage = computed(() => !props.fileUrl || !urlUtil.isImageUrl(props.fileUrl));
    const imageResizeAvailable = computed(
      () => {
        var _a;
        return !urlUtil.isAbsoluteUrl(props.fileUrl) && // 외부 이미지로 판단되므로, resize 하지 않음.
        !shouldUseDefaultImage.value && // 디폴트 이미지는 resize 하지 않음.
        !((_a = props.fileUrl) == null ? void 0 : _a.endsWith(".gif"));
      }
      // animated gif 가 resize 되지 않는 문제로, gif 는 resize 하지 않음.
    );
    const createImageUrl = (src, width, height) => {
      if (!src)
        return void 0;
      if (urlUtil.isAbsoluteUrl(src))
        return src;
      const srcUrl = urlUtil.isS3ImageUrl(src) ? uiComponentConfig.fileUrlPrefix + src : src;
      if (imageResizeAvailable.value) {
        const format = supportWebp ? "?f=webp" : "?";
        const quality = props.quality && props.quality > 0 ? `&q=${props.quality}` : "&q=100";
        const widthParam = width ? `&w=${width}` : "";
        const heightParam = height ? `&h=${height}` : "";
        return `${srcUrl}${format}${quality}${widthParam}${heightParam}`;
      } else {
        return srcUrl;
      }
    };
    const imageSrc = computed(() => createImageUrl(props.fileUrl, props.requestWidth, props.requestHeight));
    const imageSrcSet = computed(() => {
      if (props.useSrcset && imageResizeAvailable.value && (props.requestWidth || props.requestHeight)) {
        const max = Math.max(1, Math.min(props.srcsetMaxResolution || 3, 5));
        return [...Array(max).keys()].map((val) => ({
          resolution: val + 1,
          width: props.requestWidth && props.requestWidth * (val + 1),
          height: props.requestHeight && props.requestHeight * (val + 1)
        })).map((size) => `${createImageUrl(props.fileUrl, size.width, size.height)} ${size.resolution}x`).join(", ");
      } else {
        return void 0;
      }
    });
    const shouldLoad = ref(!props.lazy);
    const startLoadImage = () => {
      shouldLoad.value = true;
    };
    const imageLoaded = ref(false);
    const setImageLoaded = () => {
      imageLoaded.value = true;
    };
    const imageWidth = computed(() => imageLoaded.value ? props.width : "0");
    const imageHeight = computed(() => imageLoaded.value ? props.height : "0");
    const loadFailed = ref(false);
    const setLoadFailed = () => {
      loadFailed.value = true;
    };
    const errorImageUrl = computed(() => createImageUrl(props.errorImage));
    const blankImageUrl = computed(() => createImageUrl(props.blankImage));
    const imageDisplay = computed(() => props.hideImageOnError && loadFailed.value ? "none" : void 0);
    watch(() => props.fileUrl, () => {
      loadFailed.value = false;
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock(Fragment, null, [
        unref(imageSrc) && shouldLoad.value && !loadFailed.value ? withDirectives((openBlock(), createElementBlock("img", mergeProps({
          key: 0,
          onLoad: setImageLoaded,
          class: [!imageLoaded.value ? "position-absolute" : ""],
          src: unref(imageSrc),
          srcset: unref(imageSrcSet),
          alt: __props.alt,
          style: { width: unref(imageWidth), height: unref(imageHeight), display: unref(imageDisplay) },
          onError: setLoadFailed
        }, _ctx.$attrs), null, 16, _hoisted_1$r)), [
          [unref(vPreventCopy), __props.preventCopy]
        ]) : createCommentVNode("", true),
        unref(imageSrc) && !imageLoaded.value && !loadFailed.value ? withDirectives((openBlock(), createElementBlock("div", mergeProps({
          key: 1,
          class: "ui-image loading-image",
          style: { width: __props.loadingWidth || __props.width, height: __props.loadingHeight || __props.height, display: unref(imageDisplay), ..._ctx.$attrs.style }
        }, { class: _ctx.$attrs.class }), [
          (openBlock(), createElementBlock("svg", {
            viewBox: `0 0 1 ${__props.imageRatio}`
          }, null, 8, _hoisted_2$g))
        ], 16)), [
          [unref(vLazy), { enabled: __props.lazy, onIntersect: startLoadImage }]
        ]) : loadFailed.value || !unref(imageSrc) ? (openBlock(), createElementBlock(Fragment, { key: 2 }, [
          !unref(imageSrc) && unref(blankImageUrl) ? (openBlock(), createElementBlock("img", mergeProps({
            key: 0,
            src: unref(blankImageUrl),
            class: "ui-image blank-image",
            style: { width: __props.loadingWidth || __props.width, height: __props.loadingHeight || __props.height, display: unref(imageDisplay), aspectRatio: __props.imageRatio, ..._ctx.$attrs.style },
            "data-file-url": unref(imageSrc)
          }, { class: _ctx.$attrs.class }), null, 16, _hoisted_3$e)) : loadFailed.value && unref(errorImageUrl) ? (openBlock(), createElementBlock("img", mergeProps({
            key: 1,
            src: unref(errorImageUrl),
            class: "ui-image failed-load-image",
            style: { width: __props.loadingWidth || __props.width, height: __props.loadingHeight || __props.height, display: unref(imageDisplay), aspectRatio: __props.imageRatio, ..._ctx.$attrs.style },
            "data-file-url": unref(imageSrc)
          }, { class: _ctx.$attrs.class }), null, 16, _hoisted_4$8)) : (openBlock(), createElementBlock("svg", mergeProps({
            key: 2,
            class: "ui-image failed-load-image",
            style: { width: __props.loadingWidth || __props.width, height: __props.loadingHeight || __props.height, display: unref(imageDisplay), ..._ctx.$attrs.style },
            "data-file-url": unref(imageSrc),
            viewBox: `0 0 ${__props.imageRatio} 1`
          }, { class: _ctx.$attrs.class }), null, 16, _hoisted_5$6))
        ], 64)) : createCommentVNode("", true)
      ], 64);
    };
  }
});
const _hoisted_1$q = { key: 0 };
const _hoisted_2$f = ["media", "srcset"];
const _hoisted_3$d = ["src", "alt"];
const _hoisted_4$7 = ["viewBox"];
const _hoisted_5$5 = ["src", "data-src"];
const _hoisted_6$3 = ["src", "data-src"];
const _hoisted_7$3 = ["data-src", "viewBox"];
const _sfc_main$w = /* @__PURE__ */ defineComponent({
  __name: "UiPicture",
  props: {
    src: null,
    smSrc: null,
    mdSrc: null,
    lgSrc: null,
    xlSrc: null,
    alt: null,
    width: null,
    height: null,
    requestWidth: null,
    requestHeight: null,
    loadingWidth: null,
    loadingHeight: null,
    quality: { default: -1 },
    lazy: { type: Boolean, default: true },
    preventCopy: { type: Boolean, default: uiComponentConfig.imagePreventCopy },
    useResolutions: { type: Boolean },
    srcsetMaxResolution: { default: 3 },
    hideImageOnError: { type: Boolean },
    imageRatio: { default: 1 },
    errorImage: { default: () => uiComponentConfig.errorImageUrl },
    blankImage: { default: () => uiComponentConfig.blankImageUrl }
  },
  emits: ["pictureMouseover", "pictureMouseleave"],
  setup(__props) {
    const props = __props;
    const shouldUseDefaultImage = computed(() => !props.src || !urlUtil.isImageUrl(props.src));
    const imageResizeAvailable = computed(
      () => {
        var _a;
        return !urlUtil.isAbsoluteUrl(props.src) && // 외부 이미지로 판단되므로, resize 하지 않음.
        !shouldUseDefaultImage.value && // 디폴트 이미지는 resize 하지 않음.
        !((_a = props.src) == null ? void 0 : _a.endsWith(".gif"));
      }
      // animated gif 가 resize 되지 않는 문제로, gif 는 resize 하지 않음.
    );
    const createImageUrl = (src, width, height) => {
      if (!src)
        return void 0;
      if (urlUtil.isAbsoluteUrl(src))
        return src;
      const _src = urlUtil.isS3ImageUrl(src) ? uiComponentConfig.fileUrlPrefix + src : src;
      if (imageResizeAvailable.value) {
        const format = supportWebp ? "?f=webp" : "?";
        const quality = props.quality > 0 ? `&q=${props.quality}` : "&q=100";
        const widthParam = width ? `&w=${width}` : "";
        const heightParam = height ? `&h=${height}` : "";
        return `${_src}${format}${quality}${widthParam}${heightParam}`;
      } else {
        return _src;
      }
    };
    const createSrcSet = (src) => {
      if (props.useResolutions && imageResizeAvailable.value && (props.requestWidth || props.requestHeight)) {
        const max = Math.max(1, Math.min(props.srcsetMaxResolution, 5));
        return [...Array(max).keys()].map((val) => ({
          resolution: val + 1,
          width: props.requestWidth && props.requestWidth * (val + 1),
          height: props.requestHeight && props.requestHeight * (val + 1)
        })).map((size) => `${createImageUrl(src, size.width, size.height)} ${size.resolution}x`).join(", ");
      } else
        return createImageUrl(src, props.requestWidth, props.requestHeight);
    };
    const responsiveSrc = computed(() => Object.keys({ default: {}, ...MEDIA_QUERIES }).reverse().map((item) => item.toLowerCase()).reduce((acc, current) => {
      const screen = current;
      if (current === "default") {
        acc["default"] = {
          srcset: createSrcSet(props.src),
          src: createImageUrl(props.src, props.requestWidth, props.requestHeight),
          media: "(min-width: 0)"
        };
      }
      for (const propsKey in props) {
        if (propsKey.includes(current)) {
          const receivedSrc = props[propsKey];
          receivedSrc ? acc[screen] = {
            srcset: createSrcSet(receivedSrc),
            src: createImageUrl(receivedSrc, props.requestWidth, props.requestHeight),
            media: MEDIA_QUERIES[screen]
          } : delete acc[screen];
        }
      }
      return acc;
    }, {}));
    const hasImage = computed(() => {
      var _a;
      return !!((_a = responsiveSrc.value.default) == null ? void 0 : _a.src) || // 'src' 가 있거나,
      !!Object.keys(MEDIA_QUERIES).find((key) => responsiveSrc.value[key]);
    });
    const defaultImageSrc = computed(() => {
      var _a, _b, _c, _d;
      const r = responsiveSrc.value;
      return ((_a = r.default) == null ? void 0 : _a.src) || ((_b = r.sm) == null ? void 0 : _b.src) || ((_c = r.md) == null ? void 0 : _c.src) || ((_d = r.lg) == null ? void 0 : _d.src);
    });
    const shouldLoad = ref(!props.lazy);
    const startLoadImage = () => {
      shouldLoad.value = true;
    };
    const imageLoaded = ref(false);
    const setImageLoaded = () => {
      imageLoaded.value = true;
    };
    const imageWidth = computed(() => imageLoaded.value ? props.width : "0");
    const imageHeight = computed(() => imageLoaded.value ? props.height : "0");
    const loadFailed = ref(false);
    const setLoadFailed = () => {
      loadFailed.value = true;
    };
    const errorImageUrl = computed(() => createImageUrl(props.errorImage));
    const blankImageUrl = computed(() => createImageUrl(props.blankImage));
    const imageDisplay = computed(() => props.hideImageOnError && loadFailed.value ? "none" : void 0);
    watch(() => props.src, () => {
      loadFailed.value = false;
    });
    return (_ctx, _cache) => {
      var _a;
      return openBlock(), createElementBlock(Fragment, null, [
        unref(hasImage) && shouldLoad.value && !loadFailed.value ? (openBlock(), createElementBlock("picture", _hoisted_1$q, [
          (openBlock(true), createElementBlock(Fragment, null, renderList(unref(responsiveSrc), (value, key) => {
            return openBlock(), createElementBlock("source", {
              key,
              media: value == null ? void 0 : value.media,
              srcset: value == null ? void 0 : value.srcset
            }, null, 8, _hoisted_2$f);
          }), 128)),
          withDirectives(createElementVNode("img", {
            src: unref(defaultImageSrc),
            alt: __props.alt,
            style: normalizeStyle({ width: unref(imageWidth), height: unref(imageHeight), display: unref(imageDisplay) }),
            class: normalizeClass([!imageLoaded.value ? "position-absolute" : "", (_a = _ctx.$attrs) == null ? void 0 : _a.class]),
            onMouseover: _cache[0] || (_cache[0] = ($event) => _ctx.$emit("pictureMouseover", $event)),
            onMouseleave: _cache[1] || (_cache[1] = ($event) => _ctx.$emit("pictureMouseleave", $event)),
            onError: setLoadFailed,
            onLoad: setImageLoaded
          }, null, 46, _hoisted_3$d), [
            [unref(vPreventCopy), __props.preventCopy]
          ])
        ])) : createCommentVNode("", true),
        unref(defaultImageSrc) && !imageLoaded.value && !loadFailed.value ? withDirectives((openBlock(), createElementBlock("div", mergeProps({
          key: 1,
          class: "ui-image loading-image",
          style: { width: __props.loadingWidth || __props.width, height: __props.loadingHeight || __props.height, display: unref(imageDisplay), ..._ctx.$attrs.style }
        }, { class: _ctx.$attrs.class }), [
          (openBlock(), createElementBlock("svg", {
            viewBox: `0 0 1 ${__props.imageRatio}`
          }, null, 8, _hoisted_4$7))
        ], 16)), [
          [unref(vLazy), { enabled: __props.lazy, onIntersect: startLoadImage }]
        ]) : loadFailed.value || !unref(defaultImageSrc) ? (openBlock(), createElementBlock(Fragment, { key: 2 }, [
          !unref(defaultImageSrc) && unref(blankImageUrl) ? (openBlock(), createElementBlock("img", mergeProps({
            key: 0,
            class: "ui-image blank-image",
            src: unref(blankImageUrl),
            style: { width: __props.loadingWidth || __props.width, height: __props.loadingHeight || __props.height, display: unref(imageDisplay), aspectRatio: __props.imageRatio, ..._ctx.$attrs.style },
            "data-src": unref(responsiveSrc).default.src
          }, { class: _ctx.$attrs.class }), null, 16, _hoisted_5$5)) : loadFailed.value && unref(errorImageUrl) ? (openBlock(), createElementBlock("img", mergeProps({
            key: 1,
            class: "ui-image failed-load-image",
            src: unref(errorImageUrl),
            style: { width: __props.loadingWidth || __props.width, height: __props.loadingHeight || __props.height, display: unref(imageDisplay), aspectRatio: __props.imageRatio, ..._ctx.$attrs.style },
            "data-src": unref(responsiveSrc).default.src
          }, { class: _ctx.$attrs.class }), null, 16, _hoisted_6$3)) : (openBlock(), createElementBlock("svg", mergeProps({
            key: 2,
            class: "ui-image failed-load-image",
            style: { width: __props.loadingWidth || __props.width, height: __props.loadingHeight || __props.height, display: unref(imageDisplay), ..._ctx.$attrs.style },
            "data-src": unref(responsiveSrc).default.src,
            viewBox: `0 0 ${__props.imageRatio} 1`
          }, { class: _ctx.$attrs.class }), null, 16, _hoisted_7$3))
        ], 64)) : createCommentVNode("", true)
      ], 64);
    };
  }
});
const _hoisted_1$p = ["onClick"];
const _hoisted_2$e = ["src"];
const _hoisted_3$c = {
  key: 0,
  class: "position-absolute top-0 left-0 z-index-1 w-full h-full"
};
const _sfc_main$v = /* @__PURE__ */ defineComponent({
  __name: "UiVideo",
  props: {
    fileUrl: null,
    width: null,
    height: null,
    autoplay: { type: Boolean },
    controls: { type: Boolean },
    loop: { type: Boolean },
    muted: { type: Boolean },
    poster: null,
    smPoster: null,
    mdPoster: null,
    lgPoster: null,
    xlPoster: null,
    playsinline: { type: Boolean, default: true },
    lazy: { type: Boolean, default: true },
    cover: { type: Boolean }
  },
  setup(__props) {
    const props = __props;
    const video = ref();
    const videoSrc = computed(() => urlUtil.prependPrefixIfRelativeUrl(uiComponentConfig.fileUrlPrefix, props.fileUrl));
    const playing = ref(false);
    const setPlaying = (value) => {
      playing.value = value;
    };
    const togglePlay = () => {
      if (video.value)
        isVideoPlaying(video.value) ? video.value.pause() : video.value.play();
    };
    const isVideoPlaying = (video2) => video2.currentTime > 0 && !video2.paused && !video2.ended && video2.readyState > 2;
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: normalizeClass(["ui-video", { paused: !playing.value }]),
        style: normalizeStyle({ width: __props.width, height: __props.height })
      }, [
        createElementVNode("video", mergeProps({
          ref_key: "video",
          ref: video
        }, { autoplay: __props.autoplay, controls: __props.controls, loop: __props.loop, muted: __props.muted, playsinline: __props.playsinline }, {
          onClick: withModifiers(togglePlay, ["prevent"]),
          onPlay: _cache[0] || (_cache[0] = ($event) => setPlaying(true)),
          onPause: _cache[1] || (_cache[1] = ($event) => setPlaying(false))
        }), [
          createElementVNode("source", { src: unref(videoSrc) }, null, 8, _hoisted_2$e)
        ], 16, _hoisted_1$p),
        withDirectives(createElementVNode("span", {
          onClick: _cache[2] || (_cache[2] = ($event) => video.value.play())
        }, [
          createVNode(_sfc_main$w, {
            class: "poster",
            src: __props.poster,
            "sm-src": __props.smPoster,
            "md-src": __props.mdPoster,
            "lg-src": __props.lgPoster,
            "xl-src": __props.xlPoster,
            "loading-height": "0",
            "use-resolutions": ""
          }, null, 8, ["src", "sm-src", "md-src", "lg-src", "xl-src"])
        ], 512), [
          [vShow, __props.poster && !playing.value]
        ]),
        __props.cover ? (openBlock(), createElementBlock("div", _hoisted_3$c)) : createCommentVNode("", true)
      ], 6);
    };
  }
});
const parseYoutubeState = (playerState) => {
  if (playerState === -1)
    return "UNSTARTED";
  else if (playerState === 0)
    return "ENDED";
  else if (playerState === 1)
    return "PLAYING";
  else if (playerState === 2)
    return "PAUSED";
  else if (playerState === 3)
    return "BUFFERING";
  else if (playerState === 4)
    return "CUED";
  else
    return "UNSTARTED";
};
let youtubeCreated = 0;
const increaseYoutubeCreated = () => youtubeCreated++;
const youtubeCreatedCount = () => youtubeCreated;
const waitUntil = async (condition, intervalMilliseconds = 200, maxTrial = 15) => {
  return await new Promise((resolve) => {
    let tried = 0;
    const interval = setInterval(() => {
      if (tried > maxTrial || condition()) {
        clearInterval(interval);
        resolve(void 0);
      }
      tried++;
    }, intervalMilliseconds);
  });
};
const _hoisted_1$o = {
  key: 2,
  class: "position-absolute top-0 left-0 z-index-1 w-full h-full"
};
const _sfc_main$u = /* @__PURE__ */ defineComponent({
  __name: "UiYoutubePlayer",
  props: {
    src: null,
    poster: null,
    smPoster: null,
    mdPoster: null,
    lgPoster: null,
    xlPoster: null,
    autoplay: { type: Boolean },
    muted: { type: Boolean },
    controls: { type: Boolean },
    loop: { type: Boolean },
    width: null,
    height: null,
    playsinline: { type: Boolean, default: true },
    play: { type: Boolean },
    cover: { type: Boolean }
  },
  emits: ["change"],
  setup(__props, { expose, emit }) {
    const props = __props;
    const youtube = ref(YouTube);
    const state = ref("UNSTARTED");
    const options = computed(() => ({ controls: props.controls ? 1 : 0 }));
    const enableMountYoutubePlayer = ref(false);
    onMounted(async () => {
      increaseYoutubeCreated();
      if (youtubeCreatedCount() === 1) {
        enableMountYoutubePlayer.value = true;
      } else if (youtubeCreatedCount() > 1) {
        if (window.YT)
          enableMountYoutubePlayer.value = true;
        else {
          await waitUntil(() => !!(window == null ? void 0 : window.YT), 200, 15);
          if (window == null ? void 0 : window.YT)
            enableMountYoutubePlayer.value = true;
        }
      }
    });
    const youtubeSrc = computed(() => props.src && props.playsinline ? `${props.src}${props.src.includes("?") ? "&" : "?"}playsinline=1` : props.src);
    const play = () => {
      var _a, _b, _c;
      if (props.muted)
        (_b = (_a = youtube.value) == null ? void 0 : _a.setVolume) == null ? void 0 : _b.call(_a, 0);
      (_c = youtube.value) == null ? void 0 : _c.playVideo();
    };
    const stop = () => {
      var _a;
      (_a = youtube.value) == null ? void 0 : _a.stopVideo();
    };
    const onStateChange = ({ data }) => {
      var _a, _b;
      state.value = parseYoutubeState(data);
      if (props.muted)
        (_b = (_a = youtube.value) == null ? void 0 : _a.setVolume) == null ? void 0 : _b.call(_a, 0);
      if (state.value === "ENDED")
        props.loop ? play() : youtube.value.stopVideo();
      emit("change", state.value);
    };
    const onReady = () => {
      if (props.autoplay)
        play();
    };
    watch(() => props.play, () => {
      if (props.play)
        play();
      else
        youtube.value.stopVideo();
    });
    expose({
      youtube,
      play,
      stop
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: normalizeClass(["ui-youtube-player", { paused: state.value === "UNSTARTED" || state.value === "PAUSED" }]),
        style: normalizeStyle({ width: __props.width, height: __props.height })
      }, [
        enableMountYoutubePlayer.value && unref(youtubeSrc) ? (openBlock(), createBlock(unref(YouTube), {
          key: 0,
          class: "youtube",
          ref_key: "youtube",
          ref: youtube,
          width: "100%",
          height: "100%",
          src: unref(youtubeSrc),
          vars: unref(options),
          onReady,
          onStateChange
        }, null, 8, ["src", "vars"])) : createCommentVNode("", true),
        __props.poster ? withDirectives((openBlock(), createElementBlock("span", {
          key: 1,
          onClick: play
        }, [
          createVNode(_sfc_main$w, {
            class: "thumbnail",
            src: __props.poster,
            "sm-src": __props.smPoster,
            "md-src": __props.mdPoster,
            "lg-src": __props.lgPoster,
            "xl-src": __props.xlPoster,
            "loading-height": "0",
            "use-resolutions": ""
          }, null, 8, ["src", "sm-src", "md-src", "lg-src", "xl-src"])
        ], 512)), [
          [vShow, state.value !== "PLAYING"]
        ]) : createCommentVNode("", true),
        __props.cover ? (openBlock(), createElementBlock("div", _hoisted_1$o)) : createCommentVNode("", true)
      ], 6);
    };
  }
});
const IMAGE_EXTS = ["jpg", "jpeg", "png", "gif", "giff", "webp"];
const VIDEO_EXTS = ["mp4", "m4p", "m4v", "ogg", "ogv", "avi", "mov", "wmv", "webm"];
const isYoutubeUrl = (url) => {
  return url.startsWith("https://youtu") || url.startsWith("https://www.youtu");
};
const _sfc_main$t = /* @__PURE__ */ defineComponent({
  __name: "UiMedia",
  props: {
    fileUrl: null,
    alt: null,
    width: null,
    height: null,
    requestWidth: null,
    requestHeight: null,
    loadingWidth: null,
    loadingHeight: null,
    quality: null,
    lazy: { type: Boolean },
    preventCopy: { type: Boolean },
    useSrcset: { type: Boolean },
    srcsetMaxResolution: null,
    hideImageOnError: { type: Boolean },
    autoplay: { type: Boolean },
    controls: { type: Boolean },
    loop: { type: Boolean },
    muted: { type: Boolean },
    poster: null,
    smPoster: null,
    mdPoster: null,
    lgPoster: null,
    xlPoster: null,
    youtubeWidth: null,
    youtubeHeight: null,
    imageRatio: { default: 1 },
    errorImage: { default: () => uiComponentConfig.errorImageUrl },
    blankImage: { default: () => uiComponentConfig.blankImageUrl },
    cover: { type: Boolean }
  },
  setup(__props) {
    const props = __props;
    const mediaType = computed(() => {
      if (props.fileUrl) {
        if (isYoutubeUrl(props.fileUrl)) {
          return "YOUTUBE";
        }
        const ext = props.fileUrl.substring(props.fileUrl.lastIndexOf(".") + 1).toLowerCase();
        if (IMAGE_EXTS.includes(ext)) {
          return "IMAGE";
        } else if (VIDEO_EXTS.includes(ext)) {
          return "VIDEO";
        }
      }
      return "IMAGE";
    });
    return (_ctx, _cache) => {
      return unref(mediaType) === "IMAGE" ? (openBlock(), createBlock(_sfc_main$x, {
        key: 0,
        "file-url": __props.fileUrl,
        alt: __props.alt,
        width: __props.width,
        height: __props.height,
        "request-width": __props.requestWidth,
        "request-height": __props.requestHeight,
        "loading-width": __props.loadingWidth,
        "loading-height": __props.loadingHeight,
        quality: __props.quality,
        lazy: __props.lazy,
        "prevent-copy": __props.preventCopy,
        "use-srcset": __props.useSrcset,
        "srcset-max-resolution": __props.srcsetMaxResolution,
        "hide-image-on-error": __props.hideImageOnError,
        "image-ratio": __props.imageRatio,
        "blank-image": __props.blankImage,
        "error-image": __props.errorImage
      }, null, 8, ["file-url", "alt", "width", "height", "request-width", "request-height", "loading-width", "loading-height", "quality", "lazy", "prevent-copy", "use-srcset", "srcset-max-resolution", "hide-image-on-error", "image-ratio", "blank-image", "error-image"])) : unref(mediaType) === "VIDEO" ? (openBlock(), createBlock(_sfc_main$v, {
        key: 1,
        "file-url": __props.fileUrl,
        width: __props.width,
        height: __props.height,
        lazy: __props.lazy,
        autoplay: __props.autoplay,
        controls: __props.controls,
        muted: __props.muted,
        loop: __props.loop,
        poster: __props.poster,
        "sm-poster": __props.smPoster,
        "md-poster": __props.mdPoster,
        "lg-poster": __props.lgPoster,
        "xl-poster": __props.xlPoster,
        cover: __props.cover
      }, null, 8, ["file-url", "width", "height", "lazy", "autoplay", "controls", "muted", "loop", "poster", "sm-poster", "md-poster", "lg-poster", "xl-poster", "cover"])) : unref(mediaType) === "YOUTUBE" ? (openBlock(), createBlock(_sfc_main$u, {
        key: 2,
        src: __props.fileUrl,
        width: __props.youtubeWidth || __props.width,
        height: __props.youtubeHeight || __props.height,
        autoplay: __props.autoplay,
        controls: __props.controls,
        muted: __props.muted,
        loop: __props.loop,
        poster: __props.poster,
        "sm-poster": __props.smPoster,
        "md-poster": __props.mdPoster,
        "lg-poster": __props.lgPoster,
        "xl-poster": __props.xlPoster,
        cover: __props.cover
      }, null, 8, ["src", "width", "height", "autoplay", "controls", "muted", "loop", "poster", "sm-poster", "md-poster", "lg-poster", "xl-poster", "cover"])) : createCommentVNode("", true);
    };
  }
});
const _sfc_main$s = /* @__PURE__ */ defineComponent({
  __name: "UiLayout",
  props: {
    full: { type: Boolean },
    leftAsideWidth: { default: "30%" },
    rightAsideWidth: { default: "30%" }
  },
  setup(__props) {
    const props = __props;
    const slots = useSlots();
    const hasLeftAsideSlot = computed(() => !!(slots == null ? void 0 : slots.leftAside));
    const hasRightAsideSlot = computed(() => !!(slots == null ? void 0 : slots.rightAside));
    const mainMaxWidth = computed(() => {
      const left = hasLeftAsideSlot.value ? props.leftAsideWidth : void 0;
      const right = hasRightAsideSlot.value ? props.rightAsideWidth : void 0;
      if (left || right) {
        return `calc(100% ${left ? `- ${left}` : ""} ${right ? `- ${right}` : ""}`;
      } else {
        return "100%";
      }
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: normalizeClass(["ui-layout", { full: __props.full }])
      }, [
        unref(hasLeftAsideSlot) ? (openBlock(), createElementBlock("aside", {
          key: 0,
          class: "contents-aside",
          style: normalizeStyle({ width: __props.leftAsideWidth })
        }, [
          renderSlot(_ctx.$slots, "leftAside")
        ], 4)) : createCommentVNode("", true),
        createElementVNode("div", {
          class: "contents-main",
          style: normalizeStyle({ maxWidth: unref(mainMaxWidth) })
        }, [
          renderSlot(_ctx.$slots, "default")
        ], 4),
        unref(hasRightAsideSlot) ? (openBlock(), createElementBlock("aside", {
          key: 1,
          class: "contents-aside",
          style: normalizeStyle({ width: __props.rightAsideWidth })
        }, [
          renderSlot(_ctx.$slots, "rightAside")
        ], 4)) : createCommentVNode("", true)
      ], 2);
    };
  }
});
let nextId = 0;
const componentUtil = {
  /**
   * 화면이 SM 인데 placeholder 가 없는 경우, label 을 placeholder 로 리턴한다.
   * @param placeholder ui component 의 placeholder 속성
   * @param label ui component 의 label 속성
   */
  computeResponsivePlaceholder(placeholder, label) {
    if (placeholder) {
      return placeholder;
    } else if (label && responsiveUtil.isScreenSizeEqualOrSmallerThan("SM")) {
      return label;
    } else {
      return "";
    }
  },
  handleExternalErrorMessage(showErrorMessage, errorMessage, elementId) {
    if (elementId) {
      const el = document.getElementById(elementId);
      if (el) {
        if (!showErrorMessage || !errorMessage || errorMessage.length === 0) {
          el.style.display = "none";
        } else {
          el.style.display = "";
          el.innerText = errorMessage || "";
        }
      }
    }
  },
  generateNextId(prefix) {
    return `${prefix}-${++nextId}`;
  }
};
const _hoisted_1$n = ["id", "name", "checked", "disabled", "data-item-value"];
const _hoisted_2$d = ["for"];
const _hoisted_3$b = ["for"];
const _sfc_main$r = /* @__PURE__ */ defineComponent({
  __name: "UiRadioButton",
  props: {
    id: { default: () => componentUtil.generateNextId("radio") },
    label: null,
    name: { default: () => componentUtil.generateNextId("radio") },
    itemValue: null,
    modelValue: null,
    disabled: { type: Boolean }
  },
  emits: ["update:modelValue"],
  setup(__props, { emit }) {
    const props = __props;
    const slots = useSlots();
    const emitValue = (event2) => {
      const radio = event2.target;
      if (radio.checked) {
        emit("update:modelValue", props.itemValue);
      }
    };
    const hasLabelSlot = computed(() => !!(slots == null ? void 0 : slots.default));
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: normalizeClass(["ui-radio-button", { checked: __props.itemValue === __props.modelValue }])
      }, [
        createElementVNode("input", {
          class: "icon-font radio",
          type: "radio",
          id: __props.id,
          name: __props.name,
          checked: __props.itemValue === __props.modelValue,
          disabled: __props.disabled,
          "data-item-value": __props.itemValue,
          onChange: emitValue
        }, null, 40, _hoisted_1$n),
        __props.label ? (openBlock(), createElementBlock("label", {
          key: 0,
          class: "text-label",
          for: __props.id
        }, toDisplayString(__props.label), 9, _hoisted_2$d)) : createCommentVNode("", true),
        unref(hasLabelSlot) ? (openBlock(), createElementBlock("label", {
          key: 1,
          class: "slot-label cursor-pointer",
          for: __props.id
        }, [
          renderSlot(_ctx.$slots, "default", {
            disabled: __props.disabled,
            itemValue: __props.itemValue
          })
        ], 8, _hoisted_3$b)) : createCommentVNode("", true)
      ], 2);
    };
  }
});
const _hoisted_1$m = { class: "ui-checkbox" };
const _hoisted_2$c = ["id", "name", "checked", "disabled"];
const _hoisted_3$a = ["for"];
const _hoisted_4$6 = ["for"];
const _sfc_main$q = /* @__PURE__ */ defineComponent({
  __name: "UiCheckbox",
  props: {
    id: { default: () => componentUtil.generateNextId("checkbox") },
    label: { default: "" },
    name: { default: () => componentUtil.generateNextId("checkbox") },
    modelValue: { type: Boolean },
    disabled: { type: Boolean }
  },
  emits: ["update:modelValue"],
  setup(__props, { emit }) {
    const slots = useSlots();
    const emitValue = (event2) => {
      const checkbox = event2.target;
      emit("update:modelValue", checkbox.checked);
    };
    const hasLabelSlot = computed(() => !!(slots == null ? void 0 : slots.default));
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("span", _hoisted_1$m, [
        createElementVNode("input", {
          class: "icon-font check",
          type: "checkbox",
          id: __props.id,
          name: __props.name,
          checked: __props.modelValue,
          disabled: __props.disabled,
          onChange: emitValue
        }, null, 40, _hoisted_2$c),
        __props.label ? (openBlock(), createElementBlock("label", {
          key: 0,
          class: "text-label",
          for: __props.id
        }, toDisplayString(__props.label), 9, _hoisted_3$a)) : createCommentVNode("", true),
        unref(hasLabelSlot) ? (openBlock(), createElementBlock("label", {
          key: 1,
          class: "slot-label cursor-pointer",
          for: __props.id
        }, [
          renderSlot(_ctx.$slots, "default", { disabled: __props.disabled })
        ], 8, _hoisted_4$6)) : createCommentVNode("", true)
      ]);
    };
  }
});
function doFocus(el) {
  el.focus();
}
const vFocusOnLoad = {
  mounted: (el, binding) => {
    if (binding.value === void 0 || String(binding.value) === "true" || typeof binding.value === "number") {
      if (typeof binding.value === "number") {
        setTimeout(() => doFocus(el), binding.value);
      } else {
        doFocus(el);
      }
    }
  }
};
function doSelect(el) {
  var _a;
  (_a = el.select) == null ? void 0 : _a.call(el);
}
const vSelectOnLoad = {
  mounted: (el, binding) => {
    if (binding.value === void 0 || String(binding.value) === "true" || typeof binding.value === "number") {
      if (typeof binding.value === "number") {
        setTimeout(() => doSelect(el), binding.value);
      } else {
        doSelect(el);
      }
    }
  }
};
const _export_sfc = (sfc, props) => {
  const target = sfc.__vccOpts || sfc;
  for (const [key, val] of props) {
    target[key] = val;
  }
  return target;
};
const _sfc_main$p = {};
const _hoisted_1$l = { class: "ui-field-guide" };
function _sfc_render$2(_ctx, _cache) {
  return openBlock(), createElementBlock("p", _hoisted_1$l, [
    renderSlot(_ctx.$slots, "default")
  ]);
}
const UiFieldGuide = /* @__PURE__ */ _export_sfc(_sfc_main$p, [["render", _sfc_render$2]]);
const _sfc_main$o = {};
const _hoisted_1$k = { class: "ui-field-error" };
function _sfc_render$1(_ctx, _cache) {
  return openBlock(), createElementBlock("p", _hoisted_1$k, [
    renderSlot(_ctx.$slots, "default")
  ]);
}
const UiFieldError = /* @__PURE__ */ _export_sfc(_sfc_main$o, [["render", _sfc_render$1]]);
const _hoisted_1$j = ["pattern", "maxlength", "id", "name", "placeholder", "disabled", "autocomplete"];
const _sfc_main$n = /* @__PURE__ */ defineComponent({
  __name: "UiInputText",
  props: {
    id: { default: () => componentUtil.generateNextId("input-text") },
    inputType: { default: "text" },
    placeholder: null,
    placeholderLabel: null,
    name: { default: () => componentUtil.generateNextId("input-text") },
    modelValue: { default: "" },
    maxlength: null,
    disabled: { type: Boolean },
    required: { type: Boolean },
    guideMessage: null,
    validationMessageRequired: { default: () => uiComponentConfig.alertRequired },
    validationMessageNumber: { default: () => uiComponentConfig.alertNumberOnly },
    focusOnLoad: { type: [Boolean, Number] },
    selectOnLoad: { type: [Boolean, Number] },
    externalErrorMessageId: null,
    autocomplete: null
  },
  emits: ["update:modelValue"],
  setup(__props, { emit }) {
    const props = __props;
    const isNumberType = computed(() => props.inputType === "number");
    const normalizeTextValue = (value2, trim) => {
      if (isNumberType.value) {
        return value2 ? String(value2).replace(/\D/g, "") : "";
      } else {
        return trim ? (String(value2) || "").trim() : String(value2) || "";
      }
    };
    const isValid = (value2) => {
      if (props.required && !required(value2)) {
        return props.validationMessageRequired;
      }
      if (isNumberType.value && !numeric(value2)) {
        return props.validationMessageNumber;
      }
      return true;
    };
    const { meta, errorMessage, value, handleChange, handleBlur } = useField(
      props.name,
      isValid,
      {
        initialValue: normalizeTextValue(props.modelValue, true),
        validateOnMount: true,
        syncVModel: false
      }
    );
    const normalizeValue = (event2) => {
      const input = event2.target;
      input.value = normalizeTextValue(input.value, false);
      handleChange(event2, true);
    };
    const emitValue = () => {
      if (meta.valid) {
        emit("update:modelValue", (value.value || "").trim());
      }
    };
    const validationListeners = computed(() => ({
      blur: handleBlur,
      change: emitValue,
      input: normalizeValue
    }));
    watch(() => props.modelValue, () => value.value = normalizeTextValue(props.modelValue, true));
    const showErrorMessage = computed(() => {
      return meta.touched && !meta.valid;
    });
    const computedPlaceholder = computed(() => componentUtil.computeResponsivePlaceholder(props.placeholder, props.placeholderLabel));
    watch([errorMessage, showErrorMessage], () => componentUtil.handleExternalErrorMessage(showErrorMessage.value, errorMessage.value, props.externalErrorMessageId));
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: normalizeClass(["ui-input ui-input-text", { active: !!unref(value) }])
      }, [
        withDirectives(createElementVNode("input", mergeProps({
          type: "text",
          pattern: __props.inputType === "number" ? "\\d*" : void 0,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => isRef(value) ? value.value = $event : null),
          maxlength: __props.maxlength,
          id: __props.id,
          name: __props.name,
          placeholder: unref(computedPlaceholder),
          disabled: __props.disabled,
          autocomplete: __props.autocomplete
        }, toHandlers(unref(validationListeners), true)), null, 16, _hoisted_1$j), [
          [vModelText, unref(value)],
          [unref(vFocusOnLoad), __props.focusOnLoad],
          [unref(vSelectOnLoad), __props.selectOnLoad]
        ]),
        __props.guideMessage ? (openBlock(), createBlock(UiFieldGuide, {
          key: 0,
          id: `${__props.id}_guide`
        }, {
          default: withCtx(() => [
            createTextVNode(toDisplayString(__props.guideMessage), 1)
          ]),
          _: 1
        }, 8, ["id"])) : createCommentVNode("", true),
        !__props.externalErrorMessageId && unref(showErrorMessage) ? (openBlock(), createBlock(UiFieldError, {
          key: 1,
          id: `${__props.id}_error`
        }, {
          default: withCtx(() => [
            createTextVNode(toDisplayString(unref(errorMessage)), 1)
          ]),
          _: 1
        }, 8, ["id"])) : createCommentVNode("", true)
      ], 2);
    };
  }
});
const DATE_PATTERN = /* @__PURE__ */ new Map([
  ["DATE", "YYYY-MM-DD"],
  ["MINUTE", "YYYY-MM-DD HH:mm"]
]);
const round = (num, decimalPlace = 2) => Math.round(num * Math.pow(10, decimalPlace)) / Math.pow(10, decimalPlace);
const formatUtil = {
  /**
   * 개행 문자('\r', '\n')를 '<br/>' 태그로 변경한다.
   * @param str 변경할 String
   * @return 개행문자가 '<br/>'로 변경된 String
   */
  escapeNewLine(str) {
    return str ? str.replace(/\r\n|\r|\n/g, "<br />") : "";
  },
  /**
   * `str` 안의 `&<>"'` 문자를 escape 처리한다.
   * @param str 변경할 String
   */
  escapeHtml(str) {
    return str ? str.replace(/&/g, "&amp;").replace(/</g, "&lt;").replace(/>/g, "&gt;").replace(/"/g, "&quot;").replace(/'/g, "&#039;") : "";
  },
  /**
   * String 을 개행 문자('\r', '\n') 기준으로 나눈다.
   * @param str
   * @return 개행문자로 나누어진 string 의 array
   */
  splitNewLine(str) {
    return str ? str.split(/\r\n|\r|\n/g) : [];
  },
  /**
   * 날짜를 주어진 형식의 문자열로 변환한다.
   * ````javascript
   *   formatUtil.formatDate('2020-10-04T12:34:56.000') // returns "2020.10.04"
   *   formatUtil.formatDate('2020-10-04T12:34:56.000', 'MINUTE') // returns "2020.10.04 12:34"
   *   formatUtil.formatDate(null, 'DATE') // returns ''
   *   formatUtil.formatDate(undefined, 'DATE') // returns ''
   * ````
   * @param date 날짜. string, Date, Dayjs 타입 중 하나.
   * @param pattern 'DATE', 'MINUTE', 또는 날짜 패턴 (ex: 'YYYY.MM.DD')
   * @returns pattern 형식으로 변환된 문자열. date 나 pattern 이 false 이면 빈 문자열을 리턴한다.
   */
  formatDate(date, pattern = "DATE") {
    if (!date || !pattern) {
      return "";
    }
    if (typeof date === "string") {
      date = dayjs(date);
    }
    const actualPattern = DATE_PATTERN.get(pattern) || pattern;
    return dayjs(date).format(actualPattern);
  },
  /**
   * 가격/금액을 포매팅한다.
   * @param value 포매팅할 가격/금액
   * @param withUnit 화폐단위 포함 여부
   * @return 포맷팅된 가격/금액. value 가 undefined/null 이면 null.
   */
  formatPrice(value, withUnit = false) {
    if (value !== void 0 && value !== null) {
      const regexp = /\B(?=(\d{3})+(?!\d))/g;
      const formatted = String(value).replace(regexp, ",");
      return withUnit ? `${uiComponentConfig.currencySymbolBefore}${formatted}${uiComponentConfig.currencySymbolAfter}` : formatted;
    }
    return null;
  },
  /**
   * 포인트를 포매팅한다.
   * @param value 포매팅할 포인트
   * @param withUnit 포인트단위 포함 여부
   * @return 포맷팅된 포인트. value 가 undefined/null 이면 null.
   */
  formatPoint(value, withUnit = false) {
    if (value !== void 0 && value !== null) {
      const regexp = /\B(?=(\d{3})+(?!\d))/g;
      const formatted = String(value).replace(regexp, ",");
      return withUnit ? `${formatted}${uiComponentConfig.pointSymbolAfter}` : formatted;
    }
    return null;
  },
  /**
   * 숫자에 구분점을 넣는다.
   * @param value
   * @return
   */
  formatNumber(value) {
    if (value || typeof value === "number") {
      const regexp = /\B(?=(\d{3})+(?!\d))/g;
      return String(value).replace(regexp, ",");
    }
    return null;
  },
  /**
   * rate 를 받아 percent 를 출력한다.
   * * 0.1 -> 10%
   * * 0.55 -> 55%
   * * 0.551 -> 55.1%
   * @param value 비율 값
   * @param withUnit true 이면 % 를 붙이고, false 이면 붙이지 않는다.
   * @param decimalPlace 소숫점 n번째에서 반올림한다.
   */
  formatPercent(value, withUnit = true, decimalPlace = 2) {
    return value !== void 0 && value !== null && !isNaN(Number(value)) ? `${round(Number(value) * 100, decimalPlace)}${withUnit ? "%" : ""}` : null;
  },
  /**
   * 신용카드번호를 4자리 단위로 나누어 구분자를 넣는다.
   * @param value
   * @param separator 구분자
   */
  formatCreditCardNo(value, separator = "-") {
    var _a;
    return (_a = value.match(/.{1,4}/g)) == null ? void 0 : _a.join(separator);
  },
  /**
   *  `HTML`태그가 포함된 문자열에서 text만 남긴다.
   *  @param textIncludedHTMLElement HTML 태그를 포함하는 문자열
   *  @return HTML 태그가 제거된 문자열
   */
  toPlainText(textIncludedHTMLElement) {
    const tmp = document.createElement("DIV");
    tmp.innerHTML = textIncludedHTMLElement || "";
    return tmp.textContent || tmp.innerText;
  }
};
const _hoisted_1$i = ["maxlength", "id", "name", "rows", "cols", "placeholder", "disabled"];
const _sfc_main$m = /* @__PURE__ */ defineComponent({
  __name: "UiTextarea",
  props: {
    id: { default: () => componentUtil.generateNextId("textarea") },
    placeholderLabel: null,
    placeholder: null,
    useLabelAsPlaceholder: { type: Boolean, default: true },
    name: { default: () => componentUtil.generateNextId("textarea") },
    modelValue: { default: "" },
    maxlength: null,
    disabled: { type: Boolean },
    required: { type: Boolean },
    rows: { default: 5 },
    cols: { default: 20 },
    showCharCount: { type: Boolean },
    minCharCount: null,
    maxCharCount: null,
    guideMessage: null,
    validationMessageRequired: { default: () => uiComponentConfig.alertRequired },
    validationMessageMinCharCount: { type: [String, Function], default: () => uiComponentConfig.alertMinCharCount },
    validationMessageMaxCharCount: { type: [String, Function], default: () => uiComponentConfig.alertMaxCharCount },
    focusOnLoad: { type: [Boolean, Number] },
    selectOnLoad: { type: [Boolean, Number] },
    externalErrorMessageId: null
  },
  emits: ["update:modelValue"],
  setup(__props, { emit }) {
    const props = __props;
    const normalizeTextValue = (value2, trim) => {
      return trim ? (String(value2) || "").trim() : String(value2) || "";
    };
    const isValid = (value2) => {
      if (props.required && !required(value2)) {
        return props.validationMessageRequired || "";
      }
      if (props.minCharCount && value2.length < props.minCharCount) {
        return typeof props.validationMessageMinCharCount === "function" ? props.validationMessageMinCharCount([formatUtil.formatNumber(props.minCharCount)]) : props.validationMessageMinCharCount || "";
      }
      if (props.maxCharCount && value2.length > props.maxCharCount) {
        return typeof props.validationMessageMaxCharCount === "function" ? props.validationMessageMaxCharCount([formatUtil.formatNumber(props.maxCharCount)]) : props.validationMessageMaxCharCount || "";
      }
      return true;
    };
    const { meta, errorMessage, value, handleChange, handleBlur } = useField(
      props.name,
      isValid,
      {
        initialValue: normalizeTextValue(props.modelValue, true),
        validateOnMount: true,
        syncVModel: false
      }
    );
    const normalizeValue = (event2) => {
      const input = event2.target;
      input.value = normalizeTextValue(input.value, false);
      handleChange(event2, true);
    };
    const emitValue = () => {
      if (meta.valid) {
        emit("update:modelValue", (value.value || "").trim());
      }
    };
    const validationListeners = computed(() => ({
      blur: handleBlur,
      change: emitValue,
      input: normalizeValue
    }));
    watch(() => props.modelValue, () => value.value = normalizeTextValue(props.modelValue, true));
    const showErrorMessage = computed(() => {
      return meta.touched && !meta.valid;
    });
    const computedPlaceholder = computed(() => componentUtil.computeResponsivePlaceholder(props.placeholder, props.placeholderLabel));
    const counts = computed(() => {
      var _a;
      const max = formatUtil.formatNumber(props.maxCharCount);
      const cur = formatUtil.formatNumber((_a = value.value) == null ? void 0 : _a.length) || 0;
      return `${cur}/${max}`;
    });
    const countsStyle = computed(() => {
      var _a;
      const len = (_a = value.value) == null ? void 0 : _a.length;
      return props.maxCharCount && len > props.maxCharCount || props.minCharCount && len < props.minCharCount ? "text-danger" : "";
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: normalizeClass(["ui-textarea", { active: unref(value) }])
      }, [
        withDirectives(createElementVNode("textarea", mergeProps({
          "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => isRef(value) ? value.value = $event : null),
          maxlength: __props.maxlength,
          id: __props.id,
          name: __props.name,
          rows: __props.rows,
          cols: __props.cols,
          placeholder: unref(computedPlaceholder),
          disabled: __props.disabled
        }, toHandlers(unref(validationListeners), true)), null, 16, _hoisted_1$i), [
          [vModelText, unref(value)],
          [unref(vFocusOnLoad), __props.focusOnLoad],
          [unref(vSelectOnLoad), __props.selectOnLoad]
        ]),
        __props.showCharCount && __props.maxCharCount ? (openBlock(), createElementBlock("span", {
          key: 0,
          class: normalizeClass(["count", unref(countsStyle)])
        }, toDisplayString(unref(counts)), 3)) : createCommentVNode("", true),
        __props.guideMessage ? (openBlock(), createBlock(UiFieldGuide, {
          key: 1,
          id: `${__props.id}_guide`
        }, {
          default: withCtx(() => [
            createTextVNode(toDisplayString(__props.guideMessage), 1)
          ]),
          _: 1
        }, 8, ["id"])) : createCommentVNode("", true),
        !__props.externalErrorMessageId && unref(showErrorMessage) ? (openBlock(), createBlock(UiFieldError, {
          key: 2,
          id: `${__props.id}_error`
        }, {
          default: withCtx(() => [
            createTextVNode(toDisplayString(unref(errorMessage)), 1)
          ]),
          _: 1
        }, 8, ["id"])) : createCommentVNode("", true)
      ], 2);
    };
  }
});
const _hoisted_1$h = { class: "position-relative" };
const _hoisted_2$b = ["id", "name", "title", "value", "disabled"];
const _hoisted_3$9 = ["disabled"];
const _hoisted_4$5 = ["value"];
const _hoisted_5$4 = /* @__PURE__ */ createElementVNode("i", { class: "icon-font arrow-down" }, null, -1);
const _sfc_main$l = /* @__PURE__ */ defineComponent({
  __name: "UiSelect",
  props: {
    id: { default: () => componentUtil.generateNextId("select") },
    placeholderLabel: null,
    placeholder: null,
    title: null,
    name: { default: () => componentUtil.generateNextId("select") },
    modelValue: { default: "" },
    disabled: { type: Boolean },
    allowNull: { type: Boolean },
    values: { default: () => [] },
    valueProperty: null,
    captionProperty: null,
    required: { type: Boolean },
    validationMessageRequired: { default: () => uiComponentConfig.alertRequired },
    externalErrorMessageId: null
  },
  emits: ["update:modelValue"],
  setup(__props, { emit }) {
    const props = __props;
    const getItemValue = (value2) => {
      if (props.valueProperty === "_index") {
        return props.values.indexOf(value2);
      } else if (typeof props.valueProperty === "string" && value2 instanceof Object) {
        return value2[String(props.valueProperty)];
      } else if (props.valueProperty instanceof Function) {
        return props.valueProperty.apply(null, [value2]);
      } else {
        return value2;
      }
    };
    const getItemCaption = (value2) => {
      if (props.captionProperty === "_index") {
        return String(props.values.indexOf(value2));
      } else if (typeof props.captionProperty === "string" && value2 instanceof Object) {
        return value2[String(props.captionProperty)];
      } else if (props.captionProperty instanceof Function) {
        return props.captionProperty.apply(null, [value2]);
      } else {
        return String(value2);
      }
    };
    const isValid = (value2) => {
      if (props.required && !required(value2)) {
        return props.validationMessageRequired;
      }
      return true;
    };
    const getSelectedValue = (value2) => {
      const rawValue = toRaw(value2);
      const index2 = props.values.findIndex((item) => toRaw(getItemValue(item)) === rawValue);
      return index2 < 0 ? "" : String(index2);
    };
    const { meta, errorMessage, value, handleBlur } = useField(
      props.name,
      isValid,
      {
        initialValue: getSelectedValue(props.modelValue),
        validateOnMount: true,
        syncVModel: false
      }
    );
    const emitValue = (event2) => {
      const select = event2.target;
      const value2 = select.value === "" ? void 0 : getItemValue(props.values[Number(select.value)]);
      emit("update:modelValue", value2);
    };
    const validationListeners = computed(() => ({
      blur: handleBlur,
      change: emitValue
    }));
    watch(() => props.modelValue, () => value.value = getSelectedValue(props.modelValue));
    const showErrorMessage = computed(() => {
      return meta.touched && !meta.valid;
    });
    const computedPlaceholder = computed(() => componentUtil.computeResponsivePlaceholder(props.placeholder, props.placeholderLabel));
    watch([errorMessage, showErrorMessage], () => componentUtil.handleExternalErrorMessage(showErrorMessage.value, errorMessage.value, props.externalErrorMessageId));
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: normalizeClass(["ui-select", { active: !!unref(value) }])
      }, [
        createElementVNode("div", _hoisted_1$h, [
          createElementVNode("select", mergeProps({
            class: ["icon select", { placeholder: unref(value) === "" }],
            id: __props.id,
            name: __props.name,
            title: __props.title,
            value: unref(value),
            disabled: __props.disabled
          }, toHandlers(unref(validationListeners), true)), [
            __props.allowNull || unref(computedPlaceholder) ? (openBlock(), createElementBlock("option", {
              key: 0,
              disabled: !__props.allowNull,
              value: "",
              class: "placeholder"
            }, toDisplayString(unref(computedPlaceholder)), 9, _hoisted_3$9)) : createCommentVNode("", true),
            (openBlock(true), createElementBlock(Fragment, null, renderList(__props.values, (value2, index2) => {
              return openBlock(), createElementBlock("option", {
                key: `${index2}_${String(getItemValue(value2))}_${getItemCaption(value2)}`,
                value: index2
              }, toDisplayString(getItemCaption(value2)), 9, _hoisted_4$5);
            }), 128))
          ], 16, _hoisted_2$b),
          _hoisted_5$4
        ]),
        !__props.externalErrorMessageId && unref(showErrorMessage) ? (openBlock(), createBlock(UiFieldError, {
          key: 0,
          id: `${__props.id}_error`
        }, {
          default: withCtx(() => [
            createTextVNode(toDisplayString(unref(errorMessage)), 1)
          ]),
          _: 1
        }, 8, ["id"])) : createCommentVNode("", true)
      ], 2);
    };
  }
});
const _sfc_main$k = /* @__PURE__ */ defineComponent({
  __name: "UiDate",
  props: {
    value: null,
    format: { default: "DATE" }
  },
  setup(__props) {
    const props = __props;
    const formattedValue = computed(() => formatUtil.formatDate(props.value, props.format));
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("span", null, toDisplayString(unref(formattedValue)), 1);
    };
  }
});
const _hoisted_1$g = {
  key: 0,
  class: "currency-unit mr-1"
};
const _hoisted_2$a = { class: "amount" };
const _hoisted_3$8 = {
  key: 1,
  class: "currency-unit ml-1"
};
const _hoisted_4$4 = {
  key: 2,
  class: "tilde ml-1"
};
const _sfc_main$j = /* @__PURE__ */ defineComponent({
  __name: "UiPrice",
  props: {
    type: { default: "span" },
    amount: null,
    currencyUnit: { type: Boolean, default: true },
    tilde: { type: Boolean }
  },
  setup(__props) {
    const props = __props;
    const formattedAmount = computed(() => {
      return formatUtil.formatPrice(props.amount);
    });
    const symbolBefore = computed(() => uiComponentConfig.currencySymbolBefore);
    const symbolAfter = computed(() => uiComponentConfig.currencySymbolAfter);
    return (_ctx, _cache) => {
      return openBlock(), createBlock(resolveDynamicComponent(__props.type), { class: "ui-price" }, {
        default: withCtx(() => [
          __props.currencyUnit && unref(symbolBefore) ? (openBlock(), createElementBlock("span", _hoisted_1$g, toDisplayString(unref(symbolBefore)), 1)) : createCommentVNode("", true),
          createElementVNode("span", _hoisted_2$a, toDisplayString(unref(formattedAmount)), 1),
          __props.currencyUnit && unref(symbolAfter) ? (openBlock(), createElementBlock("span", _hoisted_3$8, toDisplayString(unref(symbolAfter)), 1)) : createCommentVNode("", true),
          __props.tilde ? (openBlock(), createElementBlock("span", _hoisted_4$4, "~")) : createCommentVNode("", true)
        ]),
        _: 1
      });
    };
  }
});
const _hoisted_1$f = { class: "amount" };
const _hoisted_2$9 = {
  key: 0,
  class: "point-unit ml-1"
};
const _sfc_main$i = /* @__PURE__ */ defineComponent({
  __name: "UiPoint",
  props: {
    type: { default: "span" },
    amount: null,
    pointUnit: { type: Boolean, default: true }
  },
  setup(__props) {
    const props = __props;
    const formattedAmount = computed(() => {
      return formatUtil.formatPrice(props.amount);
    });
    const symbolAfter = computed(() => uiComponentConfig.pointSymbolAfter);
    return (_ctx, _cache) => {
      return openBlock(), createBlock(resolveDynamicComponent(__props.type), { class: "ui-point" }, {
        default: withCtx(() => [
          createElementVNode("span", _hoisted_1$f, toDisplayString(unref(formattedAmount)), 1),
          __props.pointUnit && unref(symbolAfter) ? (openBlock(), createElementBlock("span", _hoisted_2$9, toDisplayString(unref(symbolAfter)), 1)) : createCommentVNode("", true)
        ]),
        _: 1
      });
    };
  }
});
const _hoisted_1$e = { class: "position-relative" };
const _hoisted_2$8 = ["maxlength", "id", "name", "placeholder", "disabled"];
const _hoisted_3$7 = {
  key: 0,
  class: "currency-unit"
};
const _sfc_main$h = /* @__PURE__ */ defineComponent({
  __name: "UiInputPrice",
  props: {
    id: { default: () => componentUtil.generateNextId("input-price") },
    placeholderLabel: null,
    placeholder: null,
    useLabelAsPlaceholder: { type: Boolean, default: true },
    name: { default: () => componentUtil.generateNextId("input-price") },
    modelValue: null,
    maxlength: null,
    disabled: { type: Boolean },
    hideCurrencyUnit: { type: Boolean },
    required: { type: Boolean },
    guideMessage: null,
    validationMessageRequired: { default: () => uiComponentConfig.alertRequired },
    focusOnLoad: { type: [Boolean, Number] },
    selectOnLoad: { type: [Boolean, Number] },
    externalErrorMessageId: null
  },
  emits: ["update:modelValue"],
  setup(__props, { emit }) {
    const props = __props;
    const normalizePriceValue = (value2, format, numberize = false) => {
      const normalized = value2 === 0 ? "0" : value2 ? String(value2).replace(/[^\d.]/g, "") : "";
      const numberized = numberize ? String(Number(normalized || "0")) : normalized;
      return format ? formatUtil.formatPrice(numberized, false) || "" : numberized;
    };
    const isValid = (value2) => {
      if (props.required && !required(value2)) {
        return props.validationMessageRequired;
      }
      return true;
    };
    const { meta, errorMessage, value, handleChange, handleBlur } = useField(
      props.name,
      isValid,
      {
        initialValue: normalizePriceValue(props.modelValue, true, true),
        validateOnMount: true,
        syncVModel: false
      }
    );
    const normalizeValue = (event2) => {
      const input = event2.target;
      input.value = normalizePriceValue(input.value, false);
      handleChange(event2, true);
    };
    const deleteZero = (event2) => {
      const input = event2.target;
      if (Number(input.value) === 0) {
        input.value = "";
        handleChange(event2, true);
      }
    };
    const emitValue = () => {
      if (meta.valid) {
        const priceValue = normalizePriceValue(value.value, false, true);
        if (props.modelValue !== priceValue) {
          emit("update:modelValue", priceValue);
        }
      }
    };
    const validationListeners = computed(() => ({
      blur: (event2) => {
        handleBlur(event2);
        value.value = normalizePriceValue(value.value, true, true);
      },
      change: emitValue,
      input: normalizeValue,
      focus: (event2) => {
        normalizeValue(event2);
        deleteZero(event2);
      }
    }));
    watch(() => props.modelValue, () => value.value = normalizePriceValue(props.modelValue, true, true));
    const showErrorMessage = computed(() => {
      return meta.touched && !meta.valid;
    });
    const computedPlaceholder = computed(() => componentUtil.computeResponsivePlaceholder(props.placeholder, props.placeholderLabel));
    const currencySymbolAfter = uiComponentConfig.currencySymbolAfter;
    watch([errorMessage, showErrorMessage], () => componentUtil.handleExternalErrorMessage(showErrorMessage.value, errorMessage.value, props.externalErrorMessageId));
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: normalizeClass(["ui-input ui-input-price", { active: !!unref(value) }])
      }, [
        createElementVNode("div", _hoisted_1$e, [
          withDirectives(createElementVNode("input", mergeProps({
            type: "text",
            pattern: "\\d*",
            "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => isRef(value) ? value.value = $event : null),
            maxlength: __props.maxlength,
            id: __props.id,
            name: __props.name,
            placeholder: unref(computedPlaceholder),
            disabled: __props.disabled
          }, toHandlers(unref(validationListeners), true)), null, 16, _hoisted_2$8), [
            [vModelText, unref(value)],
            [unref(vFocusOnLoad), __props.focusOnLoad],
            [unref(vSelectOnLoad), __props.selectOnLoad]
          ]),
          !__props.hideCurrencyUnit ? (openBlock(), createElementBlock("span", _hoisted_3$7, toDisplayString(unref(currencySymbolAfter)), 1)) : createCommentVNode("", true)
        ]),
        __props.guideMessage ? (openBlock(), createBlock(UiFieldGuide, {
          key: 0,
          id: `${__props.id}_guide`
        }, {
          default: withCtx(() => [
            createTextVNode(toDisplayString(__props.guideMessage), 1)
          ]),
          _: 1
        }, 8, ["id"])) : createCommentVNode("", true),
        !__props.externalErrorMessageId && unref(showErrorMessage) ? (openBlock(), createBlock(UiFieldError, {
          key: 1,
          id: `${__props.id}_error`
        }, {
          default: withCtx(() => [
            createTextVNode(toDisplayString(unref(errorMessage)), 1)
          ]),
          _: 1
        }, 8, ["id"])) : createCommentVNode("", true)
      ], 2);
    };
  }
});
const _hoisted_1$d = { class: "position-relative" };
const _hoisted_2$7 = ["maxlength", "id", "name", "placeholder", "disabled"];
const _hoisted_3$6 = {
  key: 0,
  class: "currency-unit"
};
const _sfc_main$g = /* @__PURE__ */ defineComponent({
  __name: "UiInputPoint",
  props: {
    id: { default: () => componentUtil.generateNextId("input-point") },
    placeholderLabel: null,
    placeholder: null,
    useLabelAsPlaceholder: { type: Boolean, default: true },
    name: { default: () => componentUtil.generateNextId("input-point") },
    modelValue: null,
    maxlength: null,
    disabled: { type: Boolean },
    hidePointUnit: { type: Boolean },
    required: { type: Boolean },
    guideMessage: null,
    validationMessageRequired: { default: () => uiComponentConfig.alertRequired },
    focusOnLoad: { type: [Boolean, Number] },
    selectOnLoad: { type: [Boolean, Number] },
    externalErrorMessageId: null
  },
  emits: ["update:modelValue"],
  setup(__props, { emit }) {
    const props = __props;
    const normalizePointValue = (value2, format, numberize = false) => {
      const normalized = value2 === 0 ? "0" : value2 ? String(value2).replace(/[^\d.]/g, "") : "";
      const numberized = numberize ? String(Number(normalized || "0")) : normalized;
      return format ? formatUtil.formatPoint(numberized, false) || "" : numberized;
    };
    const isValid = (value2) => {
      if (props.required && !required(value2)) {
        return props.validationMessageRequired;
      }
      return true;
    };
    const { meta, errorMessage, value, handleChange, handleBlur } = useField(
      props.name,
      isValid,
      {
        initialValue: normalizePointValue(props.modelValue, true, true),
        validateOnMount: true,
        syncVModel: false
      }
    );
    const normalizeValue = (event2) => {
      const input = event2.target;
      input.value = normalizePointValue(input.value, false);
      handleChange(event2, true);
    };
    const deleteZero = (event2) => {
      const input = event2.target;
      if (Number(input.value) === 0) {
        input.value = "";
        handleChange(event2, true);
      }
    };
    const emitValue = () => {
      if (meta.valid) {
        const pointValue = normalizePointValue(value.value, false, true);
        if (props.modelValue !== pointValue) {
          emit("update:modelValue", pointValue);
        }
      }
    };
    const validationListeners = computed(() => ({
      blur: (event2) => {
        handleBlur(event2);
        value.value = normalizePointValue(value.value, true, true);
      },
      change: emitValue,
      input: normalizeValue,
      focus: (event2) => {
        normalizeValue(event2);
        deleteZero(event2);
      }
    }));
    watch(() => props.modelValue, () => value.value = normalizePointValue(props.modelValue, true, true));
    const showErrorMessage = computed(() => {
      return meta.touched && !meta.valid;
    });
    const computedPlaceholder = computed(() => componentUtil.computeResponsivePlaceholder(props.placeholder, props.placeholderLabel));
    const pointSymbolAfter = uiComponentConfig.pointSymbolAfter;
    watch([errorMessage, showErrorMessage], () => componentUtil.handleExternalErrorMessage(showErrorMessage.value, errorMessage.value, props.externalErrorMessageId));
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: normalizeClass(["ui-input ui-input-price", { active: !!unref(value) }])
      }, [
        createElementVNode("div", _hoisted_1$d, [
          withDirectives(createElementVNode("input", mergeProps({
            type: "text",
            pattern: "\\d*",
            "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => isRef(value) ? value.value = $event : null),
            maxlength: __props.maxlength,
            id: __props.id,
            name: __props.name,
            placeholder: unref(computedPlaceholder),
            disabled: __props.disabled
          }, toHandlers(unref(validationListeners), true)), null, 16, _hoisted_2$7), [
            [vModelText, unref(value)],
            [unref(vFocusOnLoad), __props.focusOnLoad],
            [unref(vSelectOnLoad), __props.selectOnLoad]
          ]),
          !__props.hidePointUnit ? (openBlock(), createElementBlock("span", _hoisted_3$6, toDisplayString(unref(pointSymbolAfter)), 1)) : createCommentVNode("", true)
        ]),
        __props.guideMessage ? (openBlock(), createBlock(UiFieldGuide, {
          key: 0,
          id: `${__props.id}_guide`
        }, {
          default: withCtx(() => [
            createTextVNode(toDisplayString(__props.guideMessage), 1)
          ]),
          _: 1
        }, 8, ["id"])) : createCommentVNode("", true),
        !__props.externalErrorMessageId && unref(showErrorMessage) ? (openBlock(), createBlock(UiFieldError, {
          key: 1,
          id: `${__props.id}_error`
        }, {
          default: withCtx(() => [
            createTextVNode(toDisplayString(unref(errorMessage)), 1)
          ]),
          _: 1
        }, 8, ["id"])) : createCommentVNode("", true)
      ], 2);
    };
  }
});
const _hoisted_1$c = { class: "ui-tooltip" };
const _sfc_main$f = /* @__PURE__ */ defineComponent({
  __name: "UiTooltip",
  props: {
    caption: null
  },
  emits: ["toggle"],
  setup(__props, { emit }) {
    const slots = useSlots();
    const showTooltip = ref(false);
    const hasCaptionSlot = computed(() => !!(slots == null ? void 0 : slots.caption));
    const toggleTooltip = () => {
      showTooltip.value = !showTooltip.value;
      emit("toggle", showTooltip.value);
    };
    const closeTooltip = () => {
      showTooltip.value = false;
    };
    return (_ctx, _cache) => {
      return withDirectives((openBlock(), createElementBlock("div", _hoisted_1$c, [
        unref(hasCaptionSlot) ? renderSlot(_ctx.$slots, "caption", {
          key: 0,
          toggle: toggleTooltip
        }) : (openBlock(), createBlock(_sfc_main$y, {
          key: 1,
          class: "link",
          caption: __props.caption,
          onClick: toggleTooltip
        }, null, 8, ["caption"])),
        showTooltip.value ? renderSlot(_ctx.$slots, "default", {
          key: 2,
          close: closeTooltip
        }) : createCommentVNode("", true)
      ])), [
        [unref(directive), closeTooltip]
      ]);
    };
  }
});
const _hoisted_1$b = {
  key: 0,
  class: "d-inline-flex ui-input-qty"
};
const _hoisted_2$6 = { class: "ui-input ui-input-qty flex-grow-1" };
const _hoisted_3$5 = ["id", "name", "title", "disabled", "value"];
const _hoisted_4$3 = {
  key: 1,
  class: "ui-select ui-input-qty"
};
const _hoisted_5$3 = ["id", "name", "title", "value", "disabled"];
const _hoisted_6$2 = ["value"];
const _hoisted_7$2 = ["value"];
const _hoisted_8$2 = ["value"];
const _hoisted_9$2 = /* @__PURE__ */ createElementVNode("i", { class: "icon-font arrow-down" }, null, -1);
const _sfc_main$e = /* @__PURE__ */ defineComponent({
  __name: "UiInputQty",
  props: {
    modelValue: null,
    id: { default: () => componentUtil.generateNextId("input-qty") },
    name: { default: () => componentUtil.generateNextId("input-qty") },
    title: null,
    minQty: { default: 1 },
    maxQty: { default: 999 },
    allowZero: { type: Boolean },
    extraValues: { default: () => [] },
    forceInputMode: { type: Boolean },
    selectQtyCount: { default: 10 },
    useChangeButton: { type: Boolean },
    changeButtonCaption: { default: () => uiComponentConfig.inputQtyChangeButtonCaption },
    disabled: { type: Boolean },
    captionProvider: null
  },
  emits: ["input", "update:modelValue"],
  setup(__props, { emit }) {
    const props = __props;
    const validMinQty = computed(() => Math.max(0, props.minQty || 0));
    const validMaxQty = computed(() => Math.min(isNaN(props.maxQty) ? 999 : props.maxQty, 999));
    const inputThreshold = computed(() => validMinQty.value + props.selectQtyCount);
    const options = computed(() => {
      let result = [];
      if (validMinQty.value < inputThreshold.value) {
        const maxSelect = Math.min(validMaxQty.value + 1, inputThreshold.value);
        result = [...Array(Math.max(0, maxSelect - validMinQty.value)).fill(0)].map((_, idx) => idx + validMinQty.value);
      }
      if (props.allowZero) {
        result.splice(0, 0, 0);
      }
      if (props.extraValues) {
        const belowThreshold = props.extraValues.filter((value) => value < inputThreshold.value);
        result.splice(result.length, 0, ...belowThreshold);
      }
      return result.sort((a, b) => Number(a) - Number(b));
    });
    const extraValuesAboveThreshold = computed(() => props.extraValues.filter((value) => value >= inputThreshold.value));
    const qtyValue = ref(props.modelValue || validMinQty.value);
    const emitChangeEvent = () => emit("update:modelValue", qtyValue.value);
    const needInputMode = computed(() => validMaxQty.value >= inputThreshold.value);
    const inputMode = ref(false);
    const input = ref(null);
    const isExtraValue = (value) => props.extraValues && props.extraValues.includes(value);
    const qtyChanged = (newInputValue, selectInput = false, fireChange = false) => {
      const newValue = Number(newInputValue) || 0;
      if (newInputValue !== "" && !isNaN(Number(newInputValue))) {
        const newInputMode = !isExtraValue(newValue) && (props.forceInputMode || newValue >= inputThreshold.value);
        if (inputMode.value !== newInputMode) {
          inputMode.value = newInputMode;
          if (selectInput && inputMode.value) {
            nextTick$1(() => {
              var _a;
              return (_a = input.value) == null ? void 0 : _a.select();
            });
          }
        }
      }
      qtyValue.value = newValue;
      emit("input", qtyValue.value);
      if (fireChange && (!inputMode.value || !props.useChangeButton)) {
        emitChangeEvent();
      }
    };
    const qtyChangedByUser = (event2) => {
      if (event2.target instanceof HTMLInputElement || event2.target instanceof HTMLSelectElement) {
        qtyChanged(event2.target.value, true, true);
      }
    };
    watch(() => props.modelValue, () => {
      const initial = props.modelValue === void 0 ? props.allowZero ? 0 : validMinQty.value : props.modelValue;
      qtyChanged(initial, false, false);
    }, { immediate: true });
    const getCaption = (value) => props.captionProvider ? props.captionProvider(value) : String(value);
    return (_ctx, _cache) => {
      return inputMode.value ? (openBlock(), createElementBlock("span", _hoisted_1$b, [
        createElementVNode("span", _hoisted_2$6, [
          createElementVNode("input", {
            type: "text",
            inputmode: "numeric",
            ref_key: "input",
            ref: input,
            id: __props.id,
            name: __props.name,
            title: __props.title,
            disabled: __props.disabled,
            value: qtyValue.value,
            onChange: qtyChangedByUser
          }, null, 40, _hoisted_3$5)
        ]),
        __props.useChangeButton ? (openBlock(), createBlock(_sfc_main$y, {
          key: 0,
          class: "outline gray",
          caption: __props.changeButtonCaption,
          onClick: emitChangeEvent
        }, null, 8, ["caption"])) : createCommentVNode("", true)
      ])) : (openBlock(), createElementBlock("span", _hoisted_4$3, [
        createElementVNode("select", {
          class: "icon select",
          id: __props.id,
          name: __props.name,
          title: __props.title,
          value: qtyValue.value,
          disabled: __props.disabled,
          onChange: qtyChangedByUser
        }, [
          (openBlock(true), createElementBlock(Fragment, null, renderList(unref(options), (qty) => {
            return openBlock(), createElementBlock("option", {
              key: qty,
              value: qty
            }, toDisplayString(getCaption(qty)), 9, _hoisted_6$2);
          }), 128)),
          unref(needInputMode) ? (openBlock(), createElementBlock("option", {
            key: 0,
            value: unref(inputThreshold)
          }, toDisplayString(getCaption(unref(inputThreshold))) + "+", 9, _hoisted_7$2)) : createCommentVNode("", true),
          (openBlock(true), createElementBlock(Fragment, null, renderList(unref(extraValuesAboveThreshold), (qty) => {
            return openBlock(), createElementBlock("option", {
              key: qty,
              value: qty
            }, toDisplayString(getCaption(qty)), 9, _hoisted_8$2);
          }), 128))
        ], 40, _hoisted_5$3),
        _hoisted_9$2
      ]));
    };
  }
});
const TAB_HANDLER = Symbol("TabHandler");
const useTabHandler = () => inject(TAB_HANDLER);
const useRouterTab = (router, route, defaultTabId, paramName = "tab") => {
  const selectedTabId = ref(route.query[paramName]);
  const changeRouterTab = (tabId, tabs) => {
    const query = { ...route.query };
    if (tabId === defaultTabId) {
      delete query[paramName];
    } else {
      query[paramName] = tabId;
    }
    router.push({ path: route.path, query });
  };
  watch(
    () => route.fullPath,
    () => selectedTabId.value = route.query[paramName] || defaultTabId
  );
  return {
    selectedTabId,
    changeRouterTab
  };
};
const _hoisted_1$a = { class: "ui-tabs max-w-full" };
const _sfc_main$d = /* @__PURE__ */ defineComponent({
  __name: "UiTabs",
  props: {
    modelValue: null,
    useScrollToTab: { type: [null, Boolean] }
  },
  emits: ["update:modelValue"],
  setup(__props, { emit }) {
    const props = __props;
    const tabs = ref([]);
    const currentTabId = ref(props.modelValue);
    const changeCurrentTabId = (tabId) => {
      if (currentTabId.value !== tabId) {
        currentTabId.value = tabId;
        emit("update:modelValue", tabId, tabs);
      }
    };
    const updateCurrentTabId = () => {
      var _a;
      currentTabId.value = props.modelValue || ((_a = tabs.value[0]) == null ? void 0 : _a.id);
      if (currentTabId.value !== props.modelValue)
        emit("update:modelValue", currentTabId.value, tabs);
    };
    const currentTabIndex = computed(() => tabs.value.findIndex((tab) => tab.id === currentTabId.value));
    const tabHandler = {
      // 현재 선택된 tab id
      currentTabId,
      currentTabIndex,
      appendTab: (entry) => {
        tabs.value.push(entry);
      },
      removeTab: (entry) => {
        const index2 = tabs.value.findIndex((item) => item.id === entry.id);
        if (index2 >= 0) {
          tabs.value.splice(index2, 1);
        }
      },
      selectTab: (event2) => {
        if (!props.useScrollToTab)
          changeCurrentTabId(event2.id);
        tryScrollToTab(event2.scrollDestId);
      }
    };
    provide(TAB_HANDLER, tabHandler);
    const getScrollToTabOffset = () => typeof props.useScrollToTab === "object" ? props.useScrollToTab.offset : 0;
    const selectTabByScroll = () => tabs.value.filter((tab) => tab.scrollDestId).forEach((tab) => {
      const element = document.getElementById(tab.scrollDestId);
      if (element) {
        const offsetY = getScrollToTabOffset();
        const { top, bottom } = element.getBoundingClientRect();
        if (top < offsetY && bottom >= offsetY)
          changeCurrentTabId(tab.id);
      }
    });
    const tryScrollToTab = (scrollDestId) => {
      if (!!props.useScrollToTab && scrollDestId) {
        const element = document.getElementById(scrollDestId);
        if (element) {
          const relativeTop = (element == null ? void 0 : element.getBoundingClientRect().top) || 0;
          const absoluteTop = relativeTop + window.scrollY;
          const top = absoluteTop - (getScrollToTabOffset() - 1);
          window.scrollTo({ top, behavior: "smooth" });
        }
      }
    };
    onMounted(() => {
      updateCurrentTabId();
      if (props.useScrollToTab) {
        window.addEventListener("scroll", selectTabByScroll, { passive: true });
      }
    });
    onBeforeUnmount(() => {
      if (props.useScrollToTab) {
        window.removeEventListener("scroll", selectTabByScroll);
      }
    });
    watch(() => props.modelValue, updateCurrentTabId);
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$a, [
        renderSlot(_ctx.$slots, "default", { currentTabIndex: unref(currentTabIndex) })
      ]);
    };
  }
});
const _hoisted_1$9 = ["onKeyup"];
const _sfc_main$c = /* @__PURE__ */ defineComponent({
  __name: "UiTab",
  props: {
    id: { default: () => componentUtil.generateNextId("tab-id") },
    scrollDestId: null
  },
  setup(__props) {
    const props = __props;
    const tabHandler = useTabHandler();
    onMounted(() => {
      tabHandler == null ? void 0 : tabHandler.appendTab({ id: props.id, scrollDestId: props.scrollDestId });
    });
    onBeforeUnmount(() => {
      tabHandler == null ? void 0 : tabHandler.removeTab({ id: props.id });
    });
    const selectTab = () => tabHandler == null ? void 0 : tabHandler.selectTab({ id: props.id, scrollDestId: props.scrollDestId });
    const selected = computed(() => tabHandler && tabHandler.currentTabId.value === props.id);
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: normalizeClass(["ui-tab", { selected: unref(selected) }]),
        tabindex: "0",
        onClick: selectTab,
        onKeyup: [
          withKeys(withModifiers(selectTab, ["prevent"]), ["enter"]),
          withKeys(withModifiers(selectTab, ["prevent"]), ["space"])
        ]
      }, [
        renderSlot(_ctx.$slots, "default")
      ], 42, _hoisted_1$9);
    };
  }
});
const _hoisted_1$8 = {
  key: 0,
  class: "ui-pagination"
};
const _hoisted_2$5 = {
  key: 0,
  class: "first",
  disabled: ""
};
const _hoisted_3$4 = /* @__PURE__ */ createElementVNode("i", { class: "icon-font arrow-left-double gray" }, null, -1);
const _hoisted_4$2 = [
  _hoisted_3$4
];
const _hoisted_5$2 = /* @__PURE__ */ createElementVNode("span", null, [
  /* @__PURE__ */ createElementVNode("i", { class: "icon-font arrow-left-double" })
], -1);
const _hoisted_6$1 = [
  _hoisted_5$2
];
const _hoisted_7$1 = {
  key: 2,
  class: "prev",
  disabled: ""
};
const _hoisted_8$1 = /* @__PURE__ */ createElementVNode("i", { class: "icon-font arrow-left gray" }, null, -1);
const _hoisted_9$1 = [
  _hoisted_8$1
];
const _hoisted_10$1 = /* @__PURE__ */ createElementVNode("i", { class: "icon-font arrow-left" }, null, -1);
const _hoisted_11 = [
  _hoisted_10$1
];
const _hoisted_12 = ["onClick", "data-page"];
const _hoisted_13 = {
  key: 4,
  class: "next",
  disabled: ""
};
const _hoisted_14 = /* @__PURE__ */ createElementVNode("i", { class: "icon-font arrow-right gray" }, null, -1);
const _hoisted_15 = [
  _hoisted_14
];
const _hoisted_16 = /* @__PURE__ */ createElementVNode("i", { class: "icon-font arrow-right" }, null, -1);
const _hoisted_17 = [
  _hoisted_16
];
const _hoisted_18 = {
  key: 6,
  class: "last",
  disabled: ""
};
const _hoisted_19 = /* @__PURE__ */ createElementVNode("i", { class: "icon-font arrow-right-double gray" }, null, -1);
const _hoisted_20 = [
  _hoisted_19
];
const _hoisted_21 = /* @__PURE__ */ createElementVNode("i", { class: "icon-font arrow-right-double" }, null, -1);
const _hoisted_22 = [
  _hoisted_21
];
const _sfc_main$b = /* @__PURE__ */ defineComponent({
  __name: "UiPagination",
  props: {
    totalCount: { default: 0 },
    offset: { default: 0 },
    limit: { default: 10 },
    visiblePageCount: { default: 10 },
    scrollTo: null,
    scrollBehavior: { default: "auto" },
    maxPage: null
  },
  emits: ["pageChanged"],
  setup(__props, { emit }) {
    const props = __props;
    const totalPage = computed(() => {
      const totalPage2 = Math.floor((props.totalCount - 1) / props.limit) + 1;
      if (props.totalCount < 1)
        return 1;
      const maxPage = props.maxPage;
      if (maxPage && totalPage2 > maxPage)
        return maxPage;
      return totalPage2 || 0;
    });
    const currentPage = computed(() => {
      return Math.min(Math.floor(props.offset / props.limit) + 1, totalPage.value);
    });
    const currentSetFirstPage = computed(() => {
      return Math.floor((currentPage.value - 1) / props.visiblePageCount) * props.visiblePageCount + 1;
    });
    const currentSetLastPage = computed(() => {
      return Math.min(currentSetFirstPage.value + props.visiblePageCount - 1, totalPage.value);
    });
    const visiblePages = computed(() => {
      if (props.totalCount <= 0)
        return [];
      const first = currentSetFirstPage.value;
      const last = currentSetLastPage.value;
      const pages = Array(last - first + 1);
      for (let i = 0; i < pages.length; i++)
        pages[i] = i + first;
      return pages;
    });
    const prevArrowPage = computed(() => {
      return currentSetFirstPage.value - 1;
    });
    const nextArrowPage = computed(() => {
      return currentSetLastPage.value + 1;
    });
    const isFirstSet = computed(() => {
      return currentSetFirstPage.value <= 1;
    });
    const isLastSet = computed(() => {
      return currentSetLastPage.value >= totalPage.value;
    });
    const goToPage = (page) => {
      const normalized = Math.max(1, Math.min(page, totalPage.value));
      if (currentPage.value !== normalized) {
        emit("pageChanged", normalized);
        if (props.scrollTo === "top") {
          window.scroll({ top: 0, left: 0, behavior: props.scrollBehavior });
        } else if (typeof props.scrollTo === "string") {
          const ref2 = document.getElementById(props.scrollTo);
          if (ref2) {
            window.scroll({ top: ref2.offsetTop, left: 0, behavior: props.scrollBehavior });
          }
        } else if (props.scrollTo instanceof HTMLElement) {
          window.scroll({ top: props.scrollTo.offsetTop, left: 0, behavior: props.scrollBehavior });
        }
      }
    };
    return (_ctx, _cache) => {
      return unref(visiblePages).length > 0 ? (openBlock(), createElementBlock("div", _hoisted_1$8, [
        unref(isFirstSet) ? (openBlock(), createElementBlock("button", _hoisted_2$5, _hoisted_4$2)) : (openBlock(), createElementBlock("a", {
          key: 1,
          href: "#",
          class: "first",
          onClick: _cache[0] || (_cache[0] = withModifiers(($event) => goToPage(1), ["prevent"]))
        }, _hoisted_6$1)),
        unref(isFirstSet) ? (openBlock(), createElementBlock("button", _hoisted_7$1, _hoisted_9$1)) : (openBlock(), createElementBlock("a", {
          key: 3,
          href: "#",
          class: "prev",
          onClick: _cache[1] || (_cache[1] = withModifiers(($event) => goToPage(unref(prevArrowPage)), ["prevent"]))
        }, _hoisted_11)),
        (openBlock(true), createElementBlock(Fragment, null, renderList(unref(visiblePages), (page) => {
          return openBlock(), createElementBlock("a", {
            href: "#",
            key: page,
            onClick: withModifiers(($event) => goToPage(page), ["prevent"]),
            "data-page": page,
            class: normalizeClass({ on: page === unref(currentPage) })
          }, toDisplayString(page), 11, _hoisted_12);
        }), 128)),
        unref(isLastSet) ? (openBlock(), createElementBlock("button", _hoisted_13, _hoisted_15)) : (openBlock(), createElementBlock("a", {
          key: 5,
          href: "#",
          class: "next",
          onClick: _cache[2] || (_cache[2] = withModifiers(($event) => goToPage(unref(nextArrowPage)), ["prevent"]))
        }, _hoisted_17)),
        unref(isLastSet) ? (openBlock(), createElementBlock("button", _hoisted_18, _hoisted_20)) : (openBlock(), createElementBlock("a", {
          key: 7,
          href: "#",
          class: "last",
          onClick: _cache[3] || (_cache[3] = withModifiers(($event) => goToPage(unref(totalPage)), ["prevent"]))
        }, _hoisted_22))
      ])) : createCommentVNode("", true);
    };
  }
});
const _sfc_main$a = /* @__PURE__ */ defineComponent({
  __name: "UiScrollListPage",
  props: {
    list: null,
    listKey: null,
    limit: { default: 10 },
    visiblePageCount: { default: 10 },
    useRouter: { type: Boolean },
    skeletonCount: { default: 5 },
    itemContainerClass: null,
    skeletonContainerClass: null,
    paginationClass: null,
    loadExplicitly: { type: Boolean },
    loadOnMount: { type: Boolean }
  },
  emits: ["needList", "listLoaded"],
  setup(__props, { emit }) {
    const props = __props;
    const isListLoading = computed(() => !!props.list && props.list.isLoading());
    const isListLoaded = computed(() => !!props.list && !props.list.isLoading());
    const isListEmpty = computed(() => !!props.list && props.list.isEmpty());
    const route = props.useRouter ? useRoute() : void 0;
    const router = props.useRouter ? useRouter() : void 0;
    let currentPage = 0;
    const loadList = (page) => {
      emit("needList", { offset: (page - 1) * props.limit, limit: props.limit }, "PAGE");
      currentPage = page;
      if (props.useRouter) {
        const query = { ...route == null ? void 0 : route.query, page: page > 1 ? page : void 0 };
        router == null ? void 0 : router.push({ query });
      }
    };
    if (!props.loadExplicitly && props.loadOnMount) {
      onMounted(() => {
        const page = Number(route == null ? void 0 : route.query.page) || 1;
        loadList(page);
      });
    }
    if (props.useRouter) {
      watch(() => route == null ? void 0 : route.query, () => {
        const page = Number(route == null ? void 0 : route.query.page) || 1;
        if (page !== currentPage) {
          loadList(page);
        }
      });
    }
    watch(() => props.list, () => {
      if (props.list && !props.list.isLoading()) {
        emit("listLoaded", {
          totalCount: props.list.totalCount,
          offset: props.list.offset,
          limit: props.list.limit
        }, "PAGE");
      }
    });
    const resetList = () => {
      if (!props.loadExplicitly) {
        loadList(1);
      }
    };
    watch(() => props.listKey, () => resetList());
    return (_ctx, _cache) => {
      var _a, _b, _c, _d;
      return unref(isListLoading) ? (openBlock(), createElementBlock("div", {
        key: 0,
        class: normalizeClass(["ui-scroll-list-skeletons", __props.skeletonContainerClass])
      }, [
        (openBlock(true), createElementBlock(Fragment, null, renderList(__props.skeletonCount, (n) => {
          return renderSlot(_ctx.$slots, "skeleton", { key: n });
        }), 128))
      ], 2)) : unref(isListEmpty) ? renderSlot(_ctx.$slots, "empty", { key: 1 }) : unref(isListLoaded) ? (openBlock(), createElementBlock(Fragment, { key: 2 }, [
        createElementVNode("div", {
          class: normalizeClass(["ui-scroll-list-items", __props.itemContainerClass])
        }, [
          (openBlock(true), createElementBlock(Fragment, null, renderList((_a = __props.list) == null ? void 0 : _a.data, (item) => {
            return renderSlot(_ctx.$slots, "default", { listItem: item });
          }), 256))
        ], 2),
        createVNode(_sfc_main$b, {
          "total-count": (_b = __props.list) == null ? void 0 : _b.totalCount,
          limit: (_c = __props.list) == null ? void 0 : _c.limit,
          offset: (_d = __props.list) == null ? void 0 : _d.offset,
          "visible-page-count": __props.visiblePageCount,
          class: normalizeClass(__props.paginationClass),
          onPageChanged: loadList
        }, null, 8, ["total-count", "limit", "offset", "visible-page-count", "class"])
      ], 64)) : createCommentVNode("", true);
    };
  }
});
class TotalList {
  constructor() {
    __publicField(this, "data", []);
    __publicField(this, "totalCount", -1);
    __publicField(this, "loadedCount", -1);
  }
  /**
   * `TotalList`에 `PaginatedList`를 추가한다.
   * @param list 추가할 `PaginatedList`
   */
  append(list) {
    if (list) {
      this.totalCount = list.totalCount;
      this.loadedCount = Math.max(list.offset + list.data.length, this.loadedCount);
      list.data.forEach((value, idx) => {
        this.data[list.offset + idx] = value;
      });
    }
  }
  /**
   * @return `TotalList`에 `PaginatedList`가 한 번도 추가된 적이 없으면 true, 그렇지 않으면 false
   */
  isBeforeInitialized() {
    return this.totalCount < 0;
  }
  /**
   * @return 데이터가 없으면 true. 초기화 전에는 empty 여부를 판단할 수 없으므로, false 를 리턴한다.
   */
  isEmpty() {
    return this.totalCount === 0;
  }
  /**
   * `TotalList`를 초기화 전 상태로 되돌린다.
   */
  clear() {
    this.data.length = 0;
    this.totalCount = -1;
    this.loadedCount = -1;
  }
  /**
   * @return 더 로드할 데이터가 남아있으면 true, 그렇지 않으면 false. 초기화 전에는 false.
   */
  isMoreDataAvailable() {
    return this.totalCount >= 0 && this.totalCount > this.loadedCount;
  }
  static copyOf(src) {
    const copy = new TotalList();
    copy.data = [...src.data];
    copy.totalCount = src.totalCount;
    copy.loadedCount = src.loadedCount;
    return copy;
  }
}
const _hoisted_1$7 = {
  key: 0,
  class: "mb-16"
};
const _sfc_main$9 = /* @__PURE__ */ defineComponent({
  __name: "UiScrollListAppend",
  props: {
    list: null,
    listKey: null,
    limit: { default: 10 },
    appendType: { default: "MORE" },
    skeletonCount: { default: 3 },
    itemContainerClass: null,
    skeletonContainerClass: null,
    moreButtonContainerClass: null,
    loadExplicitly: { type: Boolean },
    loadOnMount: { type: Boolean, default: true }
  },
  emits: ["needList", "listLoaded"],
  setup(__props, { emit }) {
    const props = __props;
    const totalList = reactive(new TotalList());
    const isListLoading = computed(() => !!props.list && props.list.isLoading());
    const isListLoaded = computed(() => !!props.list && !props.list.isLoading());
    const isListEmpty = computed(() => isListLoaded.value && totalList.isEmpty());
    const isMoreDataAvailable = computed(() => totalList.isMoreDataAvailable());
    const loadList = () => {
      emit("needList", { offset: Math.max(0, totalList.loadedCount), limit: props.limit }, props.appendType);
    };
    if (!props.loadExplicitly && props.loadOnMount) {
      onMounted(() => loadList());
    }
    watch(() => props.list, () => {
      if (props.list && !props.list.isLoading()) {
        totalList.append(props.list);
        emit("listLoaded", {
          totalCount: totalList.totalCount,
          offset: props.list.offset,
          limit: props.list.limit,
          totalLoaded: totalList.loadedCount,
          totalList
        }, props.appendType);
      }
    });
    const resetTotalList = () => {
      totalList.clear();
      if (!props.loadExplicitly) {
        loadList();
      }
    };
    watch(() => props.listKey, () => resetTotalList());
    const moreCaption = uiComponentConfig.scrollListMoreCaption;
    const moreButtonIcon = uiComponentConfig.scrollListMoreButtonIcon;
    const moreButtonDirection = uiComponentConfig.scrollListMoreButtonDirection;
    return (_ctx, _cache) => {
      return unref(isListEmpty) ? renderSlot(_ctx.$slots, "empty", { key: 0 }) : (openBlock(), createElementBlock(Fragment, { key: 1 }, [
        totalList.data.length > 0 ? (openBlock(), createElementBlock("div", {
          key: 0,
          class: normalizeClass(["ui-scroll-list-items", __props.itemContainerClass])
        }, [
          (openBlock(true), createElementBlock(Fragment, null, renderList(totalList.data, (item) => {
            return renderSlot(_ctx.$slots, "default", { listItem: item });
          }), 256))
        ], 2)) : createCommentVNode("", true),
        unref(isListLoading) ? (openBlock(), createElementBlock("div", {
          key: 1,
          class: normalizeClass(["ui-scroll-list-skeletons", __props.skeletonContainerClass])
        }, [
          (openBlock(true), createElementBlock(Fragment, null, renderList(__props.skeletonCount, (n) => {
            return renderSlot(_ctx.$slots, "skeleton", { key: n });
          }), 128))
        ], 2)) : createCommentVNode("", true),
        __props.appendType === "MORE" && unref(isMoreDataAvailable) ? renderSlot(_ctx.$slots, "more", {
          key: 2,
          loadList
        }, () => [
          createElementVNode("div", {
            class: normalizeClass(["ui-scroll-list-buttons", __props.moreButtonContainerClass])
          }, [
            createVNode(_sfc_main$y, {
              class: "more-button",
              disabled: !unref(isListLoaded),
              caption: unref(moreCaption),
              icon: unref(moreButtonIcon),
              "icon-direction": unref(moreButtonDirection),
              onClick: loadList
            }, null, 8, ["disabled", "caption", "icon", "icon-direction"])
          ], 2)
        ]) : createCommentVNode("", true),
        __props.appendType === "INFINITE" && unref(isMoreDataAvailable) ? (openBlock(), createElementBlock(Fragment, { key: 3 }, [
          unref(isListLoaded) ? withDirectives((openBlock(), createElementBlock("div", _hoisted_1$7, null, 512)), [
            [unref(vLazy), { enabled: true, onIntersect: loadList, once: false }]
          ]) : createCommentVNode("", true)
        ], 64)) : createCommentVNode("", true)
      ], 64));
    };
  }
});
const browserUtil = {
  isMobile() {
    return /Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent);
  }
};
const _sfc_main$8 = /* @__PURE__ */ defineComponent({
  __name: "UiScrollList",
  props: {
    list: null,
    listKey: null,
    scrollType: { default: () => {
      return (browserUtil.isMobile() ? uiComponentConfig.scrollListDefaultScrollTypeMobile : uiComponentConfig.scrollListDefaultScrollTypePc) || uiComponentConfig.scrollListDefaultScrollType || "PAGE";
    } },
    limit: null,
    visiblePageCount: null,
    useRouter: { type: Boolean },
    skeletonCount: null,
    itemContainerClass: null,
    skeletonContainerClass: null,
    paginationClass: null,
    moreButtonContainerClass: null,
    loadExplicitly: { type: Boolean, default: false },
    loadOnMount: { type: Boolean, default: true }
  },
  emits: ["needList", "listLoaded"],
  setup(__props, { emit }) {
    const loadList = (request, scrollType) => emit("needList", request, scrollType);
    const listLoaded = (loadInfo, scrollType) => emit("listLoaded", loadInfo, scrollType);
    return (_ctx, _cache) => {
      return __props.scrollType === "PAGE" ? (openBlock(), createBlock(_sfc_main$a, {
        key: 0,
        list: __props.list,
        "list-key": __props.listKey,
        limit: __props.limit,
        "visible-page-count": __props.visiblePageCount,
        "use-router": __props.useRouter,
        "skeleton-count": __props.skeletonCount,
        "item-container-class": __props.itemContainerClass,
        "skeleton-container-class": __props.skeletonContainerClass,
        "pagination-class": __props.paginationClass,
        "load-explicitly": __props.loadExplicitly,
        "load-on-mount": __props.loadOnMount,
        onNeedList: loadList,
        onListLoaded: listLoaded
      }, {
        default: withCtx(({ listItem }) => [
          renderSlot(_ctx.$slots, "default", { listItem })
        ]),
        skeleton: withCtx(() => [
          renderSlot(_ctx.$slots, "skeleton")
        ]),
        empty: withCtx(() => [
          renderSlot(_ctx.$slots, "empty")
        ]),
        _: 3
      }, 8, ["list", "list-key", "limit", "visible-page-count", "use-router", "skeleton-count", "item-container-class", "skeleton-container-class", "pagination-class", "load-explicitly", "load-on-mount"])) : __props.scrollType === "MORE" || __props.scrollType === "INFINITE" ? (openBlock(), createBlock(_sfc_main$9, {
        key: 1,
        list: __props.list,
        "list-key": __props.listKey,
        limit: __props.limit,
        "skeleton-count": __props.skeletonCount,
        "append-type": __props.scrollType === "MORE" ? "MORE" : "INFINITE",
        "item-container-class": __props.itemContainerClass,
        "skeleton-container-class": __props.skeletonContainerClass,
        "more-button-container-class": __props.moreButtonContainerClass,
        "load-explicitly": __props.loadExplicitly,
        "load-on-mount": __props.loadOnMount,
        onNeedList: loadList,
        onListLoaded: listLoaded
      }, {
        default: withCtx(({ listItem }) => [
          renderSlot(_ctx.$slots, "default", { listItem })
        ]),
        skeleton: withCtx(() => [
          renderSlot(_ctx.$slots, "skeleton")
        ]),
        empty: withCtx(() => [
          renderSlot(_ctx.$slots, "empty")
        ]),
        _: 3
      }, 8, ["list", "list-key", "limit", "skeleton-count", "append-type", "item-container-class", "skeleton-container-class", "more-button-container-class", "load-explicitly", "load-on-mount"])) : createCommentVNode("", true);
    };
  }
});
const serializeDate = (date, format = "YYYYMMDD") => {
  return date ? dayjs(date).format(format) : "";
};
const deserializeDate = (str, endOfDate = false, format = "YYYYMMDD") => {
  if (str) {
    const date = dayjs(str, format);
    return endOfDate ? date.endOf("date").toDate() : date.toDate();
  } else {
    return void 0;
  }
};
const enhanceDatePeriodObject = (period) => {
  period.toString = () => `${serializeDate(period.fromDate) || ""}_${serializeDate(period.toDate)}`;
};
const datePeriodConverter = {
  toQueryString(value) {
    const period = value;
    return `${serializeDate(period == null ? void 0 : period.fromDate)}_${serializeDate(period == null ? void 0 : period.toDate)}`;
  },
  fromQueryString(query) {
    const str = String(Array.isArray(query) ? query[0] : query);
    if (str.includes("_")) {
      const dates = str.split("_");
      return {
        fromDate: deserializeDate(dates[0]),
        toDate: deserializeDate(dates[1], true)
      };
    }
    return void 0;
  }
};
const createDatePeriodByMonths = (months) => {
  const fromDate = dayjs().subtract(months, "month").startOf("date").toDate();
  const toDate = dayjs().endOf("date").toDate();
  return { fromDate, toDate };
};
const getPeriodSearchInitialValue = (monthListItem) => {
  var _a;
  const month = monthListItem || ((_a = uiComponentConfig.periodSearchMonthList) == null ? void 0 : _a[0]);
  return month && month.months ? createDatePeriodByMonths(month.months) : void 0;
};
const _hoisted_1$6 = { class: "ui-period-search" };
const _hoisted_2$4 = { class: "ui-button-group months mr-16" };
const _hoisted_3$3 = { class: "date ui-input" };
const _hoisted_4$1 = { class: "date-input" };
const _hoisted_5$1 = ["placeholder", "value"];
const _hoisted_6 = {
  key: 0,
  class: "icon-font calendar"
};
const _hoisted_7 = /* @__PURE__ */ createElementVNode("span", { class: "tilde" }, "~", -1);
const _hoisted_8 = { class: "date-input" };
const _hoisted_9 = ["placeholder", "value"];
const _hoisted_10 = {
  key: 0,
  class: "icon-font calendar"
};
const _sfc_main$7 = /* @__PURE__ */ defineComponent({
  __name: "UiPeriodSearch",
  props: {
    modelValue: null,
    allowNull: { type: Boolean },
    monthList: { default: () => uiComponentConfig.periodSearchMonthList }
  },
  emits: ["update:modelValue"],
  setup(__props, { emit }) {
    const props = __props;
    const DATE_FORMAT = "YYYYMMDD";
    const fromDateField = ref();
    const supportsDate = computed(() => {
      var _a;
      return ((_a = fromDateField.value) == null ? void 0 : _a.type) === "date";
    });
    const monthButtons = computed(() => {
      const items = [...props.monthList];
      if (props.allowNull) {
        items.splice(0, 0, { caption: uiComponentConfig.periodSearchAllCaption });
      }
      return items;
    });
    const setMonth = (month) => {
      selectedMonth.value = month;
      if (month.months) {
        toDate.value = dayjs().format(DATE_FORMAT);
        fromDate.value = dayjs().subtract(month.months, "month").format(DATE_FORMAT);
      } else {
        toDate.value = "";
        fromDate.value = "";
      }
      emitModelValue();
    };
    const selectedMonth = ref();
    const resetSelectedMonth = () => {
      if (!props.modelValue || !props.modelValue.fromDate && !props.modelValue.toDate) {
        selectedMonth.value = monthButtons.value.find((button) => !button.months);
      } else if (props.modelValue && props.modelValue.fromDate && props.modelValue.toDate) {
        const modelValueFrom = dayjs(props.modelValue.fromDate).format(DATE_FORMAT);
        const modelValueTo = dayjs(props.modelValue.toDate).format(DATE_FORMAT);
        selectedMonth.value = monthButtons.value.filter((button) => button.months).find((button) => modelValueFrom === dayjs().subtract(button.months || 0, "month").format(DATE_FORMAT) && modelValueTo === dayjs().format(DATE_FORMAT));
      } else {
        selectedMonth.value = void 0;
      }
    };
    const fromDate = ref();
    const toDate = ref();
    const formatDateTypeValue = (date) => supportsDate.value ? dayjs(date, DATE_FORMAT).format("YYYY-MM-DD") : date;
    const formattedFromDate = computed(() => fromDate.value ? formatDateTypeValue(fromDate.value) : "");
    const formattedToDate = computed(() => toDate.value ? formatDateTypeValue(toDate.value) : "");
    const getDateFromEvent = (event2) => {
      const input = event2.target;
      const value = input.value;
      const date = dayjs(value, DATE_FORMAT);
      if (date.isValid()) {
        return date;
      } else {
        return void 0;
      }
    };
    const changeFromDate = (event2) => {
      const value = getDateFromEvent(event2);
      fromDate.value = value ? dayjs(value).format(DATE_FORMAT) : "";
      emitModelValue();
    };
    const changeToDate = (event2) => {
      const value = getDateFromEvent(event2);
      toDate.value = value ? dayjs(value).format(DATE_FORMAT) : "";
      emitModelValue();
    };
    const dateStringFromDate = (date) => date ? dayjs(date).format(DATE_FORMAT) : void 0;
    const emitModelValue = () => {
      var _a, _b;
      const fromString = dateStringFromDate((_a = props.modelValue) == null ? void 0 : _a.fromDate);
      const toString = dateStringFromDate((_b = props.modelValue) == null ? void 0 : _b.toDate);
      if (fromString !== fromDate.value || toString !== toDate.value) {
        const newValue = {
          fromDate: fromDate.value ? dayjs(fromDate.value, DATE_FORMAT).toDate() : void 0,
          toDate: toDate.value ? dayjs(toDate.value, DATE_FORMAT).add(1, "day").subtract(1, "millisecond").toDate() : void 0
        };
        enhanceDatePeriodObject(newValue);
        const actualValue = newValue.fromDate || newValue.toDate ? newValue : void 0;
        emit("update:modelValue", actualValue);
      }
    };
    watch(() => props.modelValue, () => {
      var _a, _b;
      resetSelectedMonth();
      fromDate.value = dateStringFromDate((_a = props.modelValue) == null ? void 0 : _a.fromDate) || "";
      toDate.value = dateStringFromDate((_b = props.modelValue) == null ? void 0 : _b.toDate) || "";
    }, { immediate: true });
    onBeforeMount(() => {
      var _a;
      if (!props.allowNull && (!props.modelValue || !props.modelValue.fromDate && !props.modelValue.toDate) && ((_a = props.monthList) == null ? void 0 : _a.length) > 0) {
        setMonth(props.monthList[0]);
      }
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$6, [
        createElementVNode("div", _hoisted_2$4, [
          (openBlock(true), createElementBlock(Fragment, null, renderList(unref(monthButtons), (month) => {
            return openBlock(), createBlock(_sfc_main$y, {
              key: month.months,
              class: normalizeClass(["month", { selected: selectedMonth.value && selectedMonth.value.months === month.months }]),
              caption: month.caption,
              onClick: ($event) => setMonth(month)
            }, null, 8, ["class", "caption", "onClick"]);
          }), 128))
        ]),
        createElementVNode("div", _hoisted_3$3, [
          createElementVNode("span", _hoisted_4$1, [
            createElementVNode("input", {
              ref_key: "fromDateField",
              ref: fromDateField,
              type: "date",
              class: "ui-input d-inline",
              placeholder: !unref(supportsDate) ? "YYYYMMDD" : void 0,
              maxlength: "8",
              value: unref(formattedFromDate),
              onChange: changeFromDate
            }, null, 40, _hoisted_5$1),
            !unref(supportsDate) ? (openBlock(), createElementBlock("i", _hoisted_6)) : createCommentVNode("", true)
          ]),
          _hoisted_7,
          createElementVNode("span", _hoisted_8, [
            createElementVNode("input", {
              type: "date",
              class: "ui-input d-inline",
              placeholder: !unref(supportsDate) ? "YYYYMMDD" : void 0,
              maxlength: "8",
              value: unref(formattedToDate),
              onChange: changeToDate
            }, null, 40, _hoisted_9),
            !unref(supportsDate) ? (openBlock(), createElementBlock("i", _hoisted_10)) : createCommentVNode("", true)
          ])
        ])
      ]);
    };
  }
});
const _hoisted_1$5 = { class: "ui-process-step" };
const _hoisted_2$3 = { key: 0 };
const _hoisted_3$2 = { key: 1 };
const _sfc_main$6 = /* @__PURE__ */ defineComponent({
  __name: "UiProcessStep",
  props: {
    steps: { default: () => [] },
    currentStep: null,
    iconClass: { default: () => uiComponentConfig.processStepIconClass }
  },
  setup(__props) {
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("ul", _hoisted_1$5, [
        (openBlock(true), createElementBlock(Fragment, null, renderList(__props.steps, (step, index2) => {
          return openBlock(), createElementBlock("li", {
            key: step.step
          }, [
            step.step === __props.currentStep ? (openBlock(), createElementBlock("strong", _hoisted_2$3, toDisplayString(step.caption), 1)) : (openBlock(), createElementBlock("span", _hoisted_3$2, toDisplayString(step.caption), 1)),
            index2 !== __props.steps.length - 1 ? (openBlock(), createElementBlock("i", {
              key: 2,
              class: normalizeClass(["icon-font", __props.iconClass])
            }, null, 2)) : createCommentVNode("", true)
          ]);
        }), 128))
      ]);
    };
  }
});
const _hoisted_1$4 = ["src", "alt"];
const _hoisted_2$2 = /* @__PURE__ */ createElementVNode("i", { class: "icon-font plus" }, null, -1);
const _hoisted_3$1 = [
  _hoisted_2$2
];
const _sfc_main$5 = /* @__PURE__ */ defineComponent({
  __name: "UiInputImages",
  props: {
    modelValue: { default: () => [] },
    maxCount: { default: 5 },
    requestWidth: { default: 100 },
    requestHeight: { default: 100 }
  },
  emits: ["update:modelValue", "invalidFileSelected"],
  setup(__props, { emit }) {
    const props = __props;
    const deleteFile = (file) => {
      const value = [...props.modelValue];
      const idx = value.indexOf(file);
      if (idx >= 0) {
        value.splice(idx, 1);
        emit("update:modelValue", value);
      }
    };
    const fileInput = ref();
    const clickSelectFile = () => {
      if (props.modelValue.length < props.maxCount) {
        fileInput.value.click();
      }
    };
    const isValidFile = (file) => {
      var _a;
      if (!((_a = file.type) == null ? void 0 : _a.startsWith("image/"))) {
        emit("invalidFileSelected", "InvalidType", file);
        return false;
      }
      if (file.size > 5242880) {
        emit("invalidFileSelected", "SizeOverflow", file);
        return false;
      }
      return true;
    };
    const selectFile = (event2) => {
      var _a;
      const target = event2.target;
      const files = target.files;
      if (files) {
        const newImages = [];
        for (let idx = 0; idx < files.length && ((_a = props.modelValue) == null ? void 0 : _a.length) + newImages.length < props.maxCount; ++idx) {
          const file = files[idx];
          if (isValidFile(file)) {
            const newFile = {
              file,
              fileUrl: createUrl(file),
              fileName: file.name
            };
            newImages.push(newFile);
          }
        }
        if (newImages.length > 0) {
          const value = [...props.modelValue, ...newImages];
          emit("update:modelValue", value);
        }
      }
      target.value = "";
    };
    const objectUrls = [];
    const createUrl = (file) => {
      try {
        const url = window.URL.createObjectURL(file);
        objectUrls.push(url);
        return url;
      } catch (err) {
        console.log(err);
        return 'data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg"/>';
      }
    };
    const clearObjectUrls = () => {
      objectUrls.forEach((url) => {
        try {
          window.URL.revokeObjectURL(url);
        } catch (err) {
          console.log(err);
        }
      });
    };
    onUnmounted(clearObjectUrls);
    return (_ctx, _cache) => {
      return openBlock(), createBlock(TransitionGroup, {
        tag: "div",
        class: "ui-input-images"
      }, {
        default: withCtx(() => [
          (openBlock(true), createElementBlock(Fragment, null, renderList(__props.modelValue, (file) => {
            return openBlock(), createElementBlock("div", {
              class: "image-container position-relative",
              key: file.fileUrl
            }, [
              file.file ? (openBlock(), createElementBlock("img", {
                key: 0,
                class: "image-new",
                src: file.fileUrl,
                alt: file.fileName
              }, null, 8, _hoisted_1$4)) : (openBlock(), createBlock(_sfc_main$x, {
                key: 1,
                class: "image-old",
                "file-url": file.fileUrl,
                alt: file.fileName,
                width: "100%",
                "loading-width": "100px",
                "loading-height": "100%",
                "request-width": __props.requestWidth,
                "request-height": __props.requestHeight,
                lazy: false
              }, null, 8, ["file-url", "alt", "request-width", "request-height"])),
              createVNode(_sfc_main$y, {
                icon: "close",
                class: "sm delete",
                onClick: ($event) => deleteFile(file)
              }, null, 8, ["onClick"])
            ]);
          }), 128)),
          __props.modelValue.length < __props.maxCount ? (openBlock(), createElementBlock("button", {
            type: "button",
            class: "attach-btn",
            onClick: clickSelectFile,
            key: "add-button"
          }, _hoisted_3$1)) : createCommentVNode("", true),
          createElementVNode("input", {
            type: "file",
            key: "file-input",
            ref_key: "fileInput",
            ref: fileInput,
            hidden: "",
            class: "d-none",
            onChange: selectFile
          }, null, 544)
        ]),
        _: 1
      });
    };
  }
});
const _sfc_main$4 = {};
const _hoisted_1$3 = { class: "ui-field" };
function _sfc_render(_ctx, _cache) {
  return openBlock(), createElementBlock("div", _hoisted_1$3, [
    renderSlot(_ctx.$slots, "default")
  ]);
}
const UiField = /* @__PURE__ */ _export_sfc(_sfc_main$4, [["render", _sfc_render]]);
const _hoisted_1$2 = { class: "ui-label" };
const _hoisted_2$1 = {
  key: 0,
  class: "required"
};
const _sfc_main$3 = /* @__PURE__ */ defineComponent({
  __name: "UiLabel",
  props: {
    required: { type: Boolean }
  },
  setup(__props) {
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("label", _hoisted_1$2, [
        renderSlot(_ctx.$slots, "default"),
        __props.required ? (openBlock(), createElementBlock("sup", _hoisted_2$1, "*")) : createCommentVNode("", true)
      ]);
    };
  }
});
function isObject$2(obj) {
  return obj !== null && typeof obj === "object" && "constructor" in obj && obj.constructor === Object;
}
function extend$2(target = {}, src = {}) {
  Object.keys(src).forEach((key) => {
    if (typeof target[key] === "undefined")
      target[key] = src[key];
    else if (isObject$2(src[key]) && isObject$2(target[key]) && Object.keys(src[key]).length > 0) {
      extend$2(target[key], src[key]);
    }
  });
}
const ssrDocument = {
  body: {},
  addEventListener() {
  },
  removeEventListener() {
  },
  activeElement: {
    blur() {
    },
    nodeName: ""
  },
  querySelector() {
    return null;
  },
  querySelectorAll() {
    return [];
  },
  getElementById() {
    return null;
  },
  createEvent() {
    return {
      initEvent() {
      }
    };
  },
  createElement() {
    return {
      children: [],
      childNodes: [],
      style: {},
      setAttribute() {
      },
      getElementsByTagName() {
        return [];
      }
    };
  },
  createElementNS() {
    return {};
  },
  importNode() {
    return null;
  },
  location: {
    hash: "",
    host: "",
    hostname: "",
    href: "",
    origin: "",
    pathname: "",
    protocol: "",
    search: ""
  }
};
function getDocument() {
  const doc = typeof document !== "undefined" ? document : {};
  extend$2(doc, ssrDocument);
  return doc;
}
const ssrWindow = {
  document: ssrDocument,
  navigator: {
    userAgent: ""
  },
  location: {
    hash: "",
    host: "",
    hostname: "",
    href: "",
    origin: "",
    pathname: "",
    protocol: "",
    search: ""
  },
  history: {
    replaceState() {
    },
    pushState() {
    },
    go() {
    },
    back() {
    }
  },
  CustomEvent: function CustomEvent() {
    return this;
  },
  addEventListener() {
  },
  removeEventListener() {
  },
  getComputedStyle() {
    return {
      getPropertyValue() {
        return "";
      }
    };
  },
  Image() {
  },
  Date() {
  },
  screen: {},
  setTimeout() {
  },
  clearTimeout() {
  },
  matchMedia() {
    return {};
  },
  requestAnimationFrame(callback) {
    if (typeof setTimeout === "undefined") {
      callback();
      return null;
    }
    return setTimeout(callback, 0);
  },
  cancelAnimationFrame(id) {
    if (typeof setTimeout === "undefined") {
      return;
    }
    clearTimeout(id);
  }
};
function getWindow() {
  const win = typeof window !== "undefined" ? window : {};
  extend$2(win, ssrWindow);
  return win;
}
function makeReactive(obj) {
  const proto = obj.__proto__;
  Object.defineProperty(obj, "__proto__", {
    get() {
      return proto;
    },
    set(value) {
      proto.__proto__ = value;
    }
  });
}
class Dom7 extends Array {
  constructor(items) {
    if (typeof items === "number") {
      super(items);
    } else {
      super(...items || []);
      makeReactive(this);
    }
  }
}
function arrayFlat(arr = []) {
  const res = [];
  arr.forEach((el) => {
    if (Array.isArray(el)) {
      res.push(...arrayFlat(el));
    } else {
      res.push(el);
    }
  });
  return res;
}
function arrayFilter(arr, callback) {
  return Array.prototype.filter.call(arr, callback);
}
function arrayUnique(arr) {
  const uniqueArray = [];
  for (let i = 0; i < arr.length; i += 1) {
    if (uniqueArray.indexOf(arr[i]) === -1)
      uniqueArray.push(arr[i]);
  }
  return uniqueArray;
}
function qsa(selector, context) {
  if (typeof selector !== "string") {
    return [selector];
  }
  const a = [];
  const res = context.querySelectorAll(selector);
  for (let i = 0; i < res.length; i += 1) {
    a.push(res[i]);
  }
  return a;
}
function $(selector, context) {
  const window2 = getWindow();
  const document2 = getDocument();
  let arr = [];
  if (!context && selector instanceof Dom7) {
    return selector;
  }
  if (!selector) {
    return new Dom7(arr);
  }
  if (typeof selector === "string") {
    const html2 = selector.trim();
    if (html2.indexOf("<") >= 0 && html2.indexOf(">") >= 0) {
      let toCreate = "div";
      if (html2.indexOf("<li") === 0)
        toCreate = "ul";
      if (html2.indexOf("<tr") === 0)
        toCreate = "tbody";
      if (html2.indexOf("<td") === 0 || html2.indexOf("<th") === 0)
        toCreate = "tr";
      if (html2.indexOf("<tbody") === 0)
        toCreate = "table";
      if (html2.indexOf("<option") === 0)
        toCreate = "select";
      const tempParent = document2.createElement(toCreate);
      tempParent.innerHTML = html2;
      for (let i = 0; i < tempParent.childNodes.length; i += 1) {
        arr.push(tempParent.childNodes[i]);
      }
    } else {
      arr = qsa(selector.trim(), context || document2);
    }
  } else if (selector.nodeType || selector === window2 || selector === document2) {
    arr.push(selector);
  } else if (Array.isArray(selector)) {
    if (selector instanceof Dom7)
      return selector;
    arr = selector;
  }
  return new Dom7(arrayUnique(arr));
}
$.fn = Dom7.prototype;
function addClass(...classes2) {
  const classNames = arrayFlat(classes2.map((c) => c.split(" ")));
  this.forEach((el) => {
    el.classList.add(...classNames);
  });
  return this;
}
function removeClass(...classes2) {
  const classNames = arrayFlat(classes2.map((c) => c.split(" ")));
  this.forEach((el) => {
    el.classList.remove(...classNames);
  });
  return this;
}
function toggleClass(...classes2) {
  const classNames = arrayFlat(classes2.map((c) => c.split(" ")));
  this.forEach((el) => {
    classNames.forEach((className) => {
      el.classList.toggle(className);
    });
  });
}
function hasClass(...classes2) {
  const classNames = arrayFlat(classes2.map((c) => c.split(" ")));
  return arrayFilter(this, (el) => {
    return classNames.filter((className) => el.classList.contains(className)).length > 0;
  }).length > 0;
}
function attr(attrs, value) {
  if (arguments.length === 1 && typeof attrs === "string") {
    if (this[0])
      return this[0].getAttribute(attrs);
    return void 0;
  }
  for (let i = 0; i < this.length; i += 1) {
    if (arguments.length === 2) {
      this[i].setAttribute(attrs, value);
    } else {
      for (const attrName in attrs) {
        this[i][attrName] = attrs[attrName];
        this[i].setAttribute(attrName, attrs[attrName]);
      }
    }
  }
  return this;
}
function removeAttr(attr2) {
  for (let i = 0; i < this.length; i += 1) {
    this[i].removeAttribute(attr2);
  }
  return this;
}
function transform(transform2) {
  for (let i = 0; i < this.length; i += 1) {
    this[i].style.transform = transform2;
  }
  return this;
}
function transition$1(duration2) {
  for (let i = 0; i < this.length; i += 1) {
    this[i].style.transitionDuration = typeof duration2 !== "string" ? `${duration2}ms` : duration2;
  }
  return this;
}
function on(...args) {
  let [eventType, targetSelector, listener, capture] = args;
  if (typeof args[1] === "function") {
    [eventType, listener, capture] = args;
    targetSelector = void 0;
  }
  if (!capture)
    capture = false;
  function handleLiveEvent(e) {
    const target = e.target;
    if (!target)
      return;
    const eventData = e.target.dom7EventData || [];
    if (eventData.indexOf(e) < 0) {
      eventData.unshift(e);
    }
    if ($(target).is(targetSelector))
      listener.apply(target, eventData);
    else {
      const parents2 = $(target).parents();
      for (let k = 0; k < parents2.length; k += 1) {
        if ($(parents2[k]).is(targetSelector))
          listener.apply(parents2[k], eventData);
      }
    }
  }
  function handleEvent(e) {
    const eventData = e && e.target ? e.target.dom7EventData || [] : [];
    if (eventData.indexOf(e) < 0) {
      eventData.unshift(e);
    }
    listener.apply(this, eventData);
  }
  const events2 = eventType.split(" ");
  let j;
  for (let i = 0; i < this.length; i += 1) {
    const el = this[i];
    if (!targetSelector) {
      for (j = 0; j < events2.length; j += 1) {
        const event2 = events2[j];
        if (!el.dom7Listeners)
          el.dom7Listeners = {};
        if (!el.dom7Listeners[event2])
          el.dom7Listeners[event2] = [];
        el.dom7Listeners[event2].push({
          listener,
          proxyListener: handleEvent
        });
        el.addEventListener(event2, handleEvent, capture);
      }
    } else {
      for (j = 0; j < events2.length; j += 1) {
        const event2 = events2[j];
        if (!el.dom7LiveListeners)
          el.dom7LiveListeners = {};
        if (!el.dom7LiveListeners[event2])
          el.dom7LiveListeners[event2] = [];
        el.dom7LiveListeners[event2].push({
          listener,
          proxyListener: handleLiveEvent
        });
        el.addEventListener(event2, handleLiveEvent, capture);
      }
    }
  }
  return this;
}
function off(...args) {
  let [eventType, targetSelector, listener, capture] = args;
  if (typeof args[1] === "function") {
    [eventType, listener, capture] = args;
    targetSelector = void 0;
  }
  if (!capture)
    capture = false;
  const events2 = eventType.split(" ");
  for (let i = 0; i < events2.length; i += 1) {
    const event2 = events2[i];
    for (let j = 0; j < this.length; j += 1) {
      const el = this[j];
      let handlers;
      if (!targetSelector && el.dom7Listeners) {
        handlers = el.dom7Listeners[event2];
      } else if (targetSelector && el.dom7LiveListeners) {
        handlers = el.dom7LiveListeners[event2];
      }
      if (handlers && handlers.length) {
        for (let k = handlers.length - 1; k >= 0; k -= 1) {
          const handler = handlers[k];
          if (listener && handler.listener === listener) {
            el.removeEventListener(event2, handler.proxyListener, capture);
            handlers.splice(k, 1);
          } else if (listener && handler.listener && handler.listener.dom7proxy && handler.listener.dom7proxy === listener) {
            el.removeEventListener(event2, handler.proxyListener, capture);
            handlers.splice(k, 1);
          } else if (!listener) {
            el.removeEventListener(event2, handler.proxyListener, capture);
            handlers.splice(k, 1);
          }
        }
      }
    }
  }
  return this;
}
function trigger(...args) {
  const window2 = getWindow();
  const events2 = args[0].split(" ");
  const eventData = args[1];
  for (let i = 0; i < events2.length; i += 1) {
    const event2 = events2[i];
    for (let j = 0; j < this.length; j += 1) {
      const el = this[j];
      if (window2.CustomEvent) {
        const evt = new window2.CustomEvent(event2, {
          detail: eventData,
          bubbles: true,
          cancelable: true
        });
        el.dom7EventData = args.filter((data, dataIndex) => dataIndex > 0);
        el.dispatchEvent(evt);
        el.dom7EventData = [];
        delete el.dom7EventData;
      }
    }
  }
  return this;
}
function transitionEnd$1(callback) {
  const dom = this;
  function fireCallBack(e) {
    if (e.target !== this)
      return;
    callback.call(this, e);
    dom.off("transitionend", fireCallBack);
  }
  if (callback) {
    dom.on("transitionend", fireCallBack);
  }
  return this;
}
function outerWidth(includeMargins) {
  if (this.length > 0) {
    if (includeMargins) {
      const styles2 = this.styles();
      return this[0].offsetWidth + parseFloat(styles2.getPropertyValue("margin-right")) + parseFloat(styles2.getPropertyValue("margin-left"));
    }
    return this[0].offsetWidth;
  }
  return null;
}
function outerHeight(includeMargins) {
  if (this.length > 0) {
    if (includeMargins) {
      const styles2 = this.styles();
      return this[0].offsetHeight + parseFloat(styles2.getPropertyValue("margin-top")) + parseFloat(styles2.getPropertyValue("margin-bottom"));
    }
    return this[0].offsetHeight;
  }
  return null;
}
function offset() {
  if (this.length > 0) {
    const window2 = getWindow();
    const document2 = getDocument();
    const el = this[0];
    const box = el.getBoundingClientRect();
    const body = document2.body;
    const clientTop = el.clientTop || body.clientTop || 0;
    const clientLeft = el.clientLeft || body.clientLeft || 0;
    const scrollTop = el === window2 ? window2.scrollY : el.scrollTop;
    const scrollLeft = el === window2 ? window2.scrollX : el.scrollLeft;
    return {
      top: box.top + scrollTop - clientTop,
      left: box.left + scrollLeft - clientLeft
    };
  }
  return null;
}
function styles() {
  const window2 = getWindow();
  if (this[0])
    return window2.getComputedStyle(this[0], null);
  return {};
}
function css(props, value) {
  const window2 = getWindow();
  let i;
  if (arguments.length === 1) {
    if (typeof props === "string") {
      if (this[0])
        return window2.getComputedStyle(this[0], null).getPropertyValue(props);
    } else {
      for (i = 0; i < this.length; i += 1) {
        for (const prop in props) {
          this[i].style[prop] = props[prop];
        }
      }
      return this;
    }
  }
  if (arguments.length === 2 && typeof props === "string") {
    for (i = 0; i < this.length; i += 1) {
      this[i].style[props] = value;
    }
    return this;
  }
  return this;
}
function each(callback) {
  if (!callback)
    return this;
  this.forEach((el, index2) => {
    callback.apply(el, [el, index2]);
  });
  return this;
}
function filter(callback) {
  const result = arrayFilter(this, callback);
  return $(result);
}
function html(html2) {
  if (typeof html2 === "undefined") {
    return this[0] ? this[0].innerHTML : null;
  }
  for (let i = 0; i < this.length; i += 1) {
    this[i].innerHTML = html2;
  }
  return this;
}
function text(text2) {
  if (typeof text2 === "undefined") {
    return this[0] ? this[0].textContent.trim() : null;
  }
  for (let i = 0; i < this.length; i += 1) {
    this[i].textContent = text2;
  }
  return this;
}
function is(selector) {
  const window2 = getWindow();
  const document2 = getDocument();
  const el = this[0];
  let compareWith;
  let i;
  if (!el || typeof selector === "undefined")
    return false;
  if (typeof selector === "string") {
    if (el.matches)
      return el.matches(selector);
    if (el.webkitMatchesSelector)
      return el.webkitMatchesSelector(selector);
    if (el.msMatchesSelector)
      return el.msMatchesSelector(selector);
    compareWith = $(selector);
    for (i = 0; i < compareWith.length; i += 1) {
      if (compareWith[i] === el)
        return true;
    }
    return false;
  }
  if (selector === document2) {
    return el === document2;
  }
  if (selector === window2) {
    return el === window2;
  }
  if (selector.nodeType || selector instanceof Dom7) {
    compareWith = selector.nodeType ? [selector] : selector;
    for (i = 0; i < compareWith.length; i += 1) {
      if (compareWith[i] === el)
        return true;
    }
    return false;
  }
  return false;
}
function index() {
  let child = this[0];
  let i;
  if (child) {
    i = 0;
    while ((child = child.previousSibling) !== null) {
      if (child.nodeType === 1)
        i += 1;
    }
    return i;
  }
  return void 0;
}
function eq(index2) {
  if (typeof index2 === "undefined")
    return this;
  const length = this.length;
  if (index2 > length - 1) {
    return $([]);
  }
  if (index2 < 0) {
    const returnIndex = length + index2;
    if (returnIndex < 0)
      return $([]);
    return $([this[returnIndex]]);
  }
  return $([this[index2]]);
}
function append(...els) {
  let newChild;
  const document2 = getDocument();
  for (let k = 0; k < els.length; k += 1) {
    newChild = els[k];
    for (let i = 0; i < this.length; i += 1) {
      if (typeof newChild === "string") {
        const tempDiv = document2.createElement("div");
        tempDiv.innerHTML = newChild;
        while (tempDiv.firstChild) {
          this[i].appendChild(tempDiv.firstChild);
        }
      } else if (newChild instanceof Dom7) {
        for (let j = 0; j < newChild.length; j += 1) {
          this[i].appendChild(newChild[j]);
        }
      } else {
        this[i].appendChild(newChild);
      }
    }
  }
  return this;
}
function prepend(newChild) {
  const document2 = getDocument();
  let i;
  let j;
  for (i = 0; i < this.length; i += 1) {
    if (typeof newChild === "string") {
      const tempDiv = document2.createElement("div");
      tempDiv.innerHTML = newChild;
      for (j = tempDiv.childNodes.length - 1; j >= 0; j -= 1) {
        this[i].insertBefore(tempDiv.childNodes[j], this[i].childNodes[0]);
      }
    } else if (newChild instanceof Dom7) {
      for (j = 0; j < newChild.length; j += 1) {
        this[i].insertBefore(newChild[j], this[i].childNodes[0]);
      }
    } else {
      this[i].insertBefore(newChild, this[i].childNodes[0]);
    }
  }
  return this;
}
function next(selector) {
  if (this.length > 0) {
    if (selector) {
      if (this[0].nextElementSibling && $(this[0].nextElementSibling).is(selector)) {
        return $([this[0].nextElementSibling]);
      }
      return $([]);
    }
    if (this[0].nextElementSibling)
      return $([this[0].nextElementSibling]);
    return $([]);
  }
  return $([]);
}
function nextAll(selector) {
  const nextEls = [];
  let el = this[0];
  if (!el)
    return $([]);
  while (el.nextElementSibling) {
    const next2 = el.nextElementSibling;
    if (selector) {
      if ($(next2).is(selector))
        nextEls.push(next2);
    } else
      nextEls.push(next2);
    el = next2;
  }
  return $(nextEls);
}
function prev(selector) {
  if (this.length > 0) {
    const el = this[0];
    if (selector) {
      if (el.previousElementSibling && $(el.previousElementSibling).is(selector)) {
        return $([el.previousElementSibling]);
      }
      return $([]);
    }
    if (el.previousElementSibling)
      return $([el.previousElementSibling]);
    return $([]);
  }
  return $([]);
}
function prevAll(selector) {
  const prevEls = [];
  let el = this[0];
  if (!el)
    return $([]);
  while (el.previousElementSibling) {
    const prev2 = el.previousElementSibling;
    if (selector) {
      if ($(prev2).is(selector))
        prevEls.push(prev2);
    } else
      prevEls.push(prev2);
    el = prev2;
  }
  return $(prevEls);
}
function parent(selector) {
  const parents2 = [];
  for (let i = 0; i < this.length; i += 1) {
    if (this[i].parentNode !== null) {
      if (selector) {
        if ($(this[i].parentNode).is(selector))
          parents2.push(this[i].parentNode);
      } else {
        parents2.push(this[i].parentNode);
      }
    }
  }
  return $(parents2);
}
function parents(selector) {
  const parents2 = [];
  for (let i = 0; i < this.length; i += 1) {
    let parent2 = this[i].parentNode;
    while (parent2) {
      if (selector) {
        if ($(parent2).is(selector))
          parents2.push(parent2);
      } else {
        parents2.push(parent2);
      }
      parent2 = parent2.parentNode;
    }
  }
  return $(parents2);
}
function closest(selector) {
  let closest2 = this;
  if (typeof selector === "undefined") {
    return $([]);
  }
  if (!closest2.is(selector)) {
    closest2 = closest2.parents(selector).eq(0);
  }
  return closest2;
}
function find(selector) {
  const foundElements = [];
  for (let i = 0; i < this.length; i += 1) {
    const found = this[i].querySelectorAll(selector);
    for (let j = 0; j < found.length; j += 1) {
      foundElements.push(found[j]);
    }
  }
  return $(foundElements);
}
function children(selector) {
  const children2 = [];
  for (let i = 0; i < this.length; i += 1) {
    const childNodes = this[i].children;
    for (let j = 0; j < childNodes.length; j += 1) {
      if (!selector || $(childNodes[j]).is(selector)) {
        children2.push(childNodes[j]);
      }
    }
  }
  return $(children2);
}
function remove() {
  for (let i = 0; i < this.length; i += 1) {
    if (this[i].parentNode)
      this[i].parentNode.removeChild(this[i]);
  }
  return this;
}
const Methods = {
  addClass,
  removeClass,
  hasClass,
  toggleClass,
  attr,
  removeAttr,
  transform,
  transition: transition$1,
  on,
  off,
  trigger,
  transitionEnd: transitionEnd$1,
  outerWidth,
  outerHeight,
  styles,
  offset,
  css,
  each,
  html,
  text,
  is,
  index,
  eq,
  append,
  prepend,
  next,
  nextAll,
  prev,
  prevAll,
  parent,
  parents,
  closest,
  find,
  children,
  filter,
  remove
};
Object.keys(Methods).forEach((methodName) => {
  Object.defineProperty($.fn, methodName, {
    value: Methods[methodName],
    writable: true
  });
});
function deleteProps(obj) {
  const object = obj;
  Object.keys(object).forEach((key) => {
    try {
      object[key] = null;
    } catch (e) {
    }
    try {
      delete object[key];
    } catch (e) {
    }
  });
}
function nextTick(callback, delay = 0) {
  return setTimeout(callback, delay);
}
function now() {
  return Date.now();
}
function getComputedStyle$1(el) {
  const window2 = getWindow();
  let style;
  if (window2.getComputedStyle) {
    style = window2.getComputedStyle(el, null);
  }
  if (!style && el.currentStyle) {
    style = el.currentStyle;
  }
  if (!style) {
    style = el.style;
  }
  return style;
}
function getTranslate(el, axis = "x") {
  const window2 = getWindow();
  let matrix;
  let curTransform;
  let transformMatrix;
  const curStyle = getComputedStyle$1(el);
  if (window2.WebKitCSSMatrix) {
    curTransform = curStyle.transform || curStyle.webkitTransform;
    if (curTransform.split(",").length > 6) {
      curTransform = curTransform.split(", ").map((a) => a.replace(",", ".")).join(", ");
    }
    transformMatrix = new window2.WebKitCSSMatrix(curTransform === "none" ? "" : curTransform);
  } else {
    transformMatrix = curStyle.MozTransform || curStyle.OTransform || curStyle.MsTransform || curStyle.msTransform || curStyle.transform || curStyle.getPropertyValue("transform").replace("translate(", "matrix(1, 0, 0, 1,");
    matrix = transformMatrix.toString().split(",");
  }
  if (axis === "x") {
    if (window2.WebKitCSSMatrix)
      curTransform = transformMatrix.m41;
    else if (matrix.length === 16)
      curTransform = parseFloat(matrix[12]);
    else
      curTransform = parseFloat(matrix[4]);
  }
  if (axis === "y") {
    if (window2.WebKitCSSMatrix)
      curTransform = transformMatrix.m42;
    else if (matrix.length === 16)
      curTransform = parseFloat(matrix[13]);
    else
      curTransform = parseFloat(matrix[5]);
  }
  return curTransform || 0;
}
function isObject$1(o) {
  return typeof o === "object" && o !== null && o.constructor && Object.prototype.toString.call(o).slice(8, -1) === "Object";
}
function isNode(node) {
  if (typeof window !== "undefined" && typeof window.HTMLElement !== "undefined") {
    return node instanceof HTMLElement;
  }
  return node && (node.nodeType === 1 || node.nodeType === 11);
}
function extend$1(...args) {
  const to = Object(args[0]);
  const noExtend = ["__proto__", "constructor", "prototype"];
  for (let i = 1; i < args.length; i += 1) {
    const nextSource = args[i];
    if (nextSource !== void 0 && nextSource !== null && !isNode(nextSource)) {
      const keysArray = Object.keys(Object(nextSource)).filter((key) => noExtend.indexOf(key) < 0);
      for (let nextIndex = 0, len = keysArray.length; nextIndex < len; nextIndex += 1) {
        const nextKey = keysArray[nextIndex];
        const desc = Object.getOwnPropertyDescriptor(nextSource, nextKey);
        if (desc !== void 0 && desc.enumerable) {
          if (isObject$1(to[nextKey]) && isObject$1(nextSource[nextKey])) {
            if (nextSource[nextKey].__swiper__) {
              to[nextKey] = nextSource[nextKey];
            } else {
              extend$1(to[nextKey], nextSource[nextKey]);
            }
          } else if (!isObject$1(to[nextKey]) && isObject$1(nextSource[nextKey])) {
            to[nextKey] = {};
            if (nextSource[nextKey].__swiper__) {
              to[nextKey] = nextSource[nextKey];
            } else {
              extend$1(to[nextKey], nextSource[nextKey]);
            }
          } else {
            to[nextKey] = nextSource[nextKey];
          }
        }
      }
    }
  }
  return to;
}
function setCSSProperty(el, varName, varValue) {
  el.style.setProperty(varName, varValue);
}
function animateCSSModeScroll({
  swiper,
  targetPosition,
  side
}) {
  const window2 = getWindow();
  const startPosition = -swiper.translate;
  let startTime = null;
  let time;
  const duration2 = swiper.params.speed;
  swiper.wrapperEl.style.scrollSnapType = "none";
  window2.cancelAnimationFrame(swiper.cssModeFrameID);
  const dir = targetPosition > startPosition ? "next" : "prev";
  const isOutOfBound = (current, target) => {
    return dir === "next" && current >= target || dir === "prev" && current <= target;
  };
  const animate = () => {
    time = new Date().getTime();
    if (startTime === null) {
      startTime = time;
    }
    const progress = Math.max(Math.min((time - startTime) / duration2, 1), 0);
    const easeProgress = 0.5 - Math.cos(progress * Math.PI) / 2;
    let currentPosition = startPosition + easeProgress * (targetPosition - startPosition);
    if (isOutOfBound(currentPosition, targetPosition)) {
      currentPosition = targetPosition;
    }
    swiper.wrapperEl.scrollTo({
      [side]: currentPosition
    });
    if (isOutOfBound(currentPosition, targetPosition)) {
      swiper.wrapperEl.style.overflow = "hidden";
      swiper.wrapperEl.style.scrollSnapType = "";
      setTimeout(() => {
        swiper.wrapperEl.style.overflow = "";
        swiper.wrapperEl.scrollTo({
          [side]: currentPosition
        });
      });
      window2.cancelAnimationFrame(swiper.cssModeFrameID);
      return;
    }
    swiper.cssModeFrameID = window2.requestAnimationFrame(animate);
  };
  animate();
}
let support;
function calcSupport() {
  const window2 = getWindow();
  const document2 = getDocument();
  return {
    smoothScroll: document2.documentElement && "scrollBehavior" in document2.documentElement.style,
    touch: !!("ontouchstart" in window2 || window2.DocumentTouch && document2 instanceof window2.DocumentTouch),
    passiveListener: function checkPassiveListener() {
      let supportsPassive = false;
      try {
        const opts = Object.defineProperty({}, "passive", {
          // eslint-disable-next-line
          get() {
            supportsPassive = true;
          }
        });
        window2.addEventListener("testPassiveListener", null, opts);
      } catch (e) {
      }
      return supportsPassive;
    }(),
    gestures: function checkGestures() {
      return "ongesturestart" in window2;
    }()
  };
}
function getSupport() {
  if (!support) {
    support = calcSupport();
  }
  return support;
}
let deviceCached;
function calcDevice({
  userAgent
} = {}) {
  const support2 = getSupport();
  const window2 = getWindow();
  const platform = window2.navigator.platform;
  const ua = userAgent || window2.navigator.userAgent;
  const device = {
    ios: false,
    android: false
  };
  const screenWidth = window2.screen.width;
  const screenHeight = window2.screen.height;
  const android = ua.match(/(Android);?[\s\/]+([\d.]+)?/);
  let ipad = ua.match(/(iPad).*OS\s([\d_]+)/);
  const ipod = ua.match(/(iPod)(.*OS\s([\d_]+))?/);
  const iphone = !ipad && ua.match(/(iPhone\sOS|iOS)\s([\d_]+)/);
  const windows = platform === "Win32";
  let macos = platform === "MacIntel";
  const iPadScreens = ["1024x1366", "1366x1024", "834x1194", "1194x834", "834x1112", "1112x834", "768x1024", "1024x768", "820x1180", "1180x820", "810x1080", "1080x810"];
  if (!ipad && macos && support2.touch && iPadScreens.indexOf(`${screenWidth}x${screenHeight}`) >= 0) {
    ipad = ua.match(/(Version)\/([\d.]+)/);
    if (!ipad)
      ipad = [0, 1, "13_0_0"];
    macos = false;
  }
  if (android && !windows) {
    device.os = "android";
    device.android = true;
  }
  if (ipad || iphone || ipod) {
    device.os = "ios";
    device.ios = true;
  }
  return device;
}
function getDevice(overrides = {}) {
  if (!deviceCached) {
    deviceCached = calcDevice(overrides);
  }
  return deviceCached;
}
let browser;
function calcBrowser() {
  const window2 = getWindow();
  function isSafari() {
    const ua = window2.navigator.userAgent.toLowerCase();
    return ua.indexOf("safari") >= 0 && ua.indexOf("chrome") < 0 && ua.indexOf("android") < 0;
  }
  return {
    isSafari: isSafari(),
    isWebView: /(iPhone|iPod|iPad).*AppleWebKit(?!.*Safari)/i.test(window2.navigator.userAgent)
  };
}
function getBrowser() {
  if (!browser) {
    browser = calcBrowser();
  }
  return browser;
}
function Resize({
  swiper,
  on: on2,
  emit
}) {
  const window2 = getWindow();
  let observer = null;
  let animationFrame = null;
  const resizeHandler = () => {
    if (!swiper || swiper.destroyed || !swiper.initialized)
      return;
    emit("beforeResize");
    emit("resize");
  };
  const createObserver = () => {
    if (!swiper || swiper.destroyed || !swiper.initialized)
      return;
    observer = new ResizeObserver((entries) => {
      animationFrame = window2.requestAnimationFrame(() => {
        const {
          width,
          height
        } = swiper;
        let newWidth = width;
        let newHeight = height;
        entries.forEach(({
          contentBoxSize,
          contentRect,
          target
        }) => {
          if (target && target !== swiper.el)
            return;
          newWidth = contentRect ? contentRect.width : (contentBoxSize[0] || contentBoxSize).inlineSize;
          newHeight = contentRect ? contentRect.height : (contentBoxSize[0] || contentBoxSize).blockSize;
        });
        if (newWidth !== width || newHeight !== height) {
          resizeHandler();
        }
      });
    });
    observer.observe(swiper.el);
  };
  const removeObserver = () => {
    if (animationFrame) {
      window2.cancelAnimationFrame(animationFrame);
    }
    if (observer && observer.unobserve && swiper.el) {
      observer.unobserve(swiper.el);
      observer = null;
    }
  };
  const orientationChangeHandler = () => {
    if (!swiper || swiper.destroyed || !swiper.initialized)
      return;
    emit("orientationchange");
  };
  on2("init", () => {
    if (swiper.params.resizeObserver && typeof window2.ResizeObserver !== "undefined") {
      createObserver();
      return;
    }
    window2.addEventListener("resize", resizeHandler);
    window2.addEventListener("orientationchange", orientationChangeHandler);
  });
  on2("destroy", () => {
    removeObserver();
    window2.removeEventListener("resize", resizeHandler);
    window2.removeEventListener("orientationchange", orientationChangeHandler);
  });
}
function Observer({
  swiper,
  extendParams,
  on: on2,
  emit
}) {
  const observers = [];
  const window2 = getWindow();
  const attach = (target, options = {}) => {
    const ObserverFunc = window2.MutationObserver || window2.WebkitMutationObserver;
    const observer = new ObserverFunc((mutations) => {
      if (mutations.length === 1) {
        emit("observerUpdate", mutations[0]);
        return;
      }
      const observerUpdate = function observerUpdate2() {
        emit("observerUpdate", mutations[0]);
      };
      if (window2.requestAnimationFrame) {
        window2.requestAnimationFrame(observerUpdate);
      } else {
        window2.setTimeout(observerUpdate, 0);
      }
    });
    observer.observe(target, {
      attributes: typeof options.attributes === "undefined" ? true : options.attributes,
      childList: typeof options.childList === "undefined" ? true : options.childList,
      characterData: typeof options.characterData === "undefined" ? true : options.characterData
    });
    observers.push(observer);
  };
  const init = () => {
    if (!swiper.params.observer)
      return;
    if (swiper.params.observeParents) {
      const containerParents = swiper.$el.parents();
      for (let i = 0; i < containerParents.length; i += 1) {
        attach(containerParents[i]);
      }
    }
    attach(swiper.$el[0], {
      childList: swiper.params.observeSlideChildren
    });
    attach(swiper.$wrapperEl[0], {
      attributes: false
    });
  };
  const destroy = () => {
    observers.forEach((observer) => {
      observer.disconnect();
    });
    observers.splice(0, observers.length);
  };
  extendParams({
    observer: false,
    observeParents: false,
    observeSlideChildren: false
  });
  on2("init", init);
  on2("destroy", destroy);
}
const eventsEmitter = {
  on(events2, handler, priority) {
    const self2 = this;
    if (!self2.eventsListeners || self2.destroyed)
      return self2;
    if (typeof handler !== "function")
      return self2;
    const method = priority ? "unshift" : "push";
    events2.split(" ").forEach((event2) => {
      if (!self2.eventsListeners[event2])
        self2.eventsListeners[event2] = [];
      self2.eventsListeners[event2][method](handler);
    });
    return self2;
  },
  once(events2, handler, priority) {
    const self2 = this;
    if (!self2.eventsListeners || self2.destroyed)
      return self2;
    if (typeof handler !== "function")
      return self2;
    function onceHandler(...args) {
      self2.off(events2, onceHandler);
      if (onceHandler.__emitterProxy) {
        delete onceHandler.__emitterProxy;
      }
      handler.apply(self2, args);
    }
    onceHandler.__emitterProxy = handler;
    return self2.on(events2, onceHandler, priority);
  },
  onAny(handler, priority) {
    const self2 = this;
    if (!self2.eventsListeners || self2.destroyed)
      return self2;
    if (typeof handler !== "function")
      return self2;
    const method = priority ? "unshift" : "push";
    if (self2.eventsAnyListeners.indexOf(handler) < 0) {
      self2.eventsAnyListeners[method](handler);
    }
    return self2;
  },
  offAny(handler) {
    const self2 = this;
    if (!self2.eventsListeners || self2.destroyed)
      return self2;
    if (!self2.eventsAnyListeners)
      return self2;
    const index2 = self2.eventsAnyListeners.indexOf(handler);
    if (index2 >= 0) {
      self2.eventsAnyListeners.splice(index2, 1);
    }
    return self2;
  },
  off(events2, handler) {
    const self2 = this;
    if (!self2.eventsListeners || self2.destroyed)
      return self2;
    if (!self2.eventsListeners)
      return self2;
    events2.split(" ").forEach((event2) => {
      if (typeof handler === "undefined") {
        self2.eventsListeners[event2] = [];
      } else if (self2.eventsListeners[event2]) {
        self2.eventsListeners[event2].forEach((eventHandler, index2) => {
          if (eventHandler === handler || eventHandler.__emitterProxy && eventHandler.__emitterProxy === handler) {
            self2.eventsListeners[event2].splice(index2, 1);
          }
        });
      }
    });
    return self2;
  },
  emit(...args) {
    const self2 = this;
    if (!self2.eventsListeners || self2.destroyed)
      return self2;
    if (!self2.eventsListeners)
      return self2;
    let events2;
    let data;
    let context;
    if (typeof args[0] === "string" || Array.isArray(args[0])) {
      events2 = args[0];
      data = args.slice(1, args.length);
      context = self2;
    } else {
      events2 = args[0].events;
      data = args[0].data;
      context = args[0].context || self2;
    }
    data.unshift(context);
    const eventsArray = Array.isArray(events2) ? events2 : events2.split(" ");
    eventsArray.forEach((event2) => {
      if (self2.eventsAnyListeners && self2.eventsAnyListeners.length) {
        self2.eventsAnyListeners.forEach((eventHandler) => {
          eventHandler.apply(context, [event2, ...data]);
        });
      }
      if (self2.eventsListeners && self2.eventsListeners[event2]) {
        self2.eventsListeners[event2].forEach((eventHandler) => {
          eventHandler.apply(context, data);
        });
      }
    });
    return self2;
  }
};
function updateSize() {
  const swiper = this;
  let width;
  let height;
  const $el = swiper.$el;
  if (typeof swiper.params.width !== "undefined" && swiper.params.width !== null) {
    width = swiper.params.width;
  } else {
    width = $el[0].clientWidth;
  }
  if (typeof swiper.params.height !== "undefined" && swiper.params.height !== null) {
    height = swiper.params.height;
  } else {
    height = $el[0].clientHeight;
  }
  if (width === 0 && swiper.isHorizontal() || height === 0 && swiper.isVertical()) {
    return;
  }
  width = width - parseInt($el.css("padding-left") || 0, 10) - parseInt($el.css("padding-right") || 0, 10);
  height = height - parseInt($el.css("padding-top") || 0, 10) - parseInt($el.css("padding-bottom") || 0, 10);
  if (Number.isNaN(width))
    width = 0;
  if (Number.isNaN(height))
    height = 0;
  Object.assign(swiper, {
    width,
    height,
    size: swiper.isHorizontal() ? width : height
  });
}
function updateSlides() {
  const swiper = this;
  function getDirectionLabel(property) {
    if (swiper.isHorizontal()) {
      return property;
    }
    return {
      "width": "height",
      "margin-top": "margin-left",
      "margin-bottom ": "margin-right",
      "margin-left": "margin-top",
      "margin-right": "margin-bottom",
      "padding-left": "padding-top",
      "padding-right": "padding-bottom",
      "marginRight": "marginBottom"
    }[property];
  }
  function getDirectionPropertyValue(node, label) {
    return parseFloat(node.getPropertyValue(getDirectionLabel(label)) || 0);
  }
  const params = swiper.params;
  const {
    $wrapperEl,
    size: swiperSize,
    rtlTranslate: rtl,
    wrongRTL
  } = swiper;
  const isVirtual = swiper.virtual && params.virtual.enabled;
  const previousSlidesLength = isVirtual ? swiper.virtual.slides.length : swiper.slides.length;
  const slides = $wrapperEl.children(`.${swiper.params.slideClass}`);
  const slidesLength = isVirtual ? swiper.virtual.slides.length : slides.length;
  let snapGrid = [];
  const slidesGrid = [];
  const slidesSizesGrid = [];
  let offsetBefore = params.slidesOffsetBefore;
  if (typeof offsetBefore === "function") {
    offsetBefore = params.slidesOffsetBefore.call(swiper);
  }
  let offsetAfter = params.slidesOffsetAfter;
  if (typeof offsetAfter === "function") {
    offsetAfter = params.slidesOffsetAfter.call(swiper);
  }
  const previousSnapGridLength = swiper.snapGrid.length;
  const previousSlidesGridLength = swiper.slidesGrid.length;
  let spaceBetween = params.spaceBetween;
  let slidePosition = -offsetBefore;
  let prevSlideSize = 0;
  let index2 = 0;
  if (typeof swiperSize === "undefined") {
    return;
  }
  if (typeof spaceBetween === "string" && spaceBetween.indexOf("%") >= 0) {
    spaceBetween = parseFloat(spaceBetween.replace("%", "")) / 100 * swiperSize;
  }
  swiper.virtualSize = -spaceBetween;
  if (rtl)
    slides.css({
      marginLeft: "",
      marginBottom: "",
      marginTop: ""
    });
  else
    slides.css({
      marginRight: "",
      marginBottom: "",
      marginTop: ""
    });
  if (params.centeredSlides && params.cssMode) {
    setCSSProperty(swiper.wrapperEl, "--swiper-centered-offset-before", "");
    setCSSProperty(swiper.wrapperEl, "--swiper-centered-offset-after", "");
  }
  const gridEnabled = params.grid && params.grid.rows > 1 && swiper.grid;
  if (gridEnabled) {
    swiper.grid.initSlides(slidesLength);
  }
  let slideSize;
  const shouldResetSlideSize = params.slidesPerView === "auto" && params.breakpoints && Object.keys(params.breakpoints).filter((key) => {
    return typeof params.breakpoints[key].slidesPerView !== "undefined";
  }).length > 0;
  for (let i = 0; i < slidesLength; i += 1) {
    slideSize = 0;
    const slide2 = slides.eq(i);
    if (gridEnabled) {
      swiper.grid.updateSlide(i, slide2, slidesLength, getDirectionLabel);
    }
    if (slide2.css("display") === "none")
      continue;
    if (params.slidesPerView === "auto") {
      if (shouldResetSlideSize) {
        slides[i].style[getDirectionLabel("width")] = ``;
      }
      const slideStyles = getComputedStyle(slide2[0]);
      const currentTransform = slide2[0].style.transform;
      const currentWebKitTransform = slide2[0].style.webkitTransform;
      if (currentTransform) {
        slide2[0].style.transform = "none";
      }
      if (currentWebKitTransform) {
        slide2[0].style.webkitTransform = "none";
      }
      if (params.roundLengths) {
        slideSize = swiper.isHorizontal() ? slide2.outerWidth(true) : slide2.outerHeight(true);
      } else {
        const width = getDirectionPropertyValue(slideStyles, "width");
        const paddingLeft = getDirectionPropertyValue(slideStyles, "padding-left");
        const paddingRight = getDirectionPropertyValue(slideStyles, "padding-right");
        const marginLeft = getDirectionPropertyValue(slideStyles, "margin-left");
        const marginRight = getDirectionPropertyValue(slideStyles, "margin-right");
        const boxSizing = slideStyles.getPropertyValue("box-sizing");
        if (boxSizing && boxSizing === "border-box") {
          slideSize = width + marginLeft + marginRight;
        } else {
          const {
            clientWidth,
            offsetWidth
          } = slide2[0];
          slideSize = width + paddingLeft + paddingRight + marginLeft + marginRight + (offsetWidth - clientWidth);
        }
      }
      if (currentTransform) {
        slide2[0].style.transform = currentTransform;
      }
      if (currentWebKitTransform) {
        slide2[0].style.webkitTransform = currentWebKitTransform;
      }
      if (params.roundLengths)
        slideSize = Math.floor(slideSize);
    } else {
      slideSize = (swiperSize - (params.slidesPerView - 1) * spaceBetween) / params.slidesPerView;
      if (params.roundLengths)
        slideSize = Math.floor(slideSize);
      if (slides[i]) {
        slides[i].style[getDirectionLabel("width")] = `${slideSize}px`;
      }
    }
    if (slides[i]) {
      slides[i].swiperSlideSize = slideSize;
    }
    slidesSizesGrid.push(slideSize);
    if (params.centeredSlides) {
      slidePosition = slidePosition + slideSize / 2 + prevSlideSize / 2 + spaceBetween;
      if (prevSlideSize === 0 && i !== 0)
        slidePosition = slidePosition - swiperSize / 2 - spaceBetween;
      if (i === 0)
        slidePosition = slidePosition - swiperSize / 2 - spaceBetween;
      if (Math.abs(slidePosition) < 1 / 1e3)
        slidePosition = 0;
      if (params.roundLengths)
        slidePosition = Math.floor(slidePosition);
      if (index2 % params.slidesPerGroup === 0)
        snapGrid.push(slidePosition);
      slidesGrid.push(slidePosition);
    } else {
      if (params.roundLengths)
        slidePosition = Math.floor(slidePosition);
      if ((index2 - Math.min(swiper.params.slidesPerGroupSkip, index2)) % swiper.params.slidesPerGroup === 0)
        snapGrid.push(slidePosition);
      slidesGrid.push(slidePosition);
      slidePosition = slidePosition + slideSize + spaceBetween;
    }
    swiper.virtualSize += slideSize + spaceBetween;
    prevSlideSize = slideSize;
    index2 += 1;
  }
  swiper.virtualSize = Math.max(swiper.virtualSize, swiperSize) + offsetAfter;
  if (rtl && wrongRTL && (params.effect === "slide" || params.effect === "coverflow")) {
    $wrapperEl.css({
      width: `${swiper.virtualSize + params.spaceBetween}px`
    });
  }
  if (params.setWrapperSize) {
    $wrapperEl.css({
      [getDirectionLabel("width")]: `${swiper.virtualSize + params.spaceBetween}px`
    });
  }
  if (gridEnabled) {
    swiper.grid.updateWrapperSize(slideSize, snapGrid, getDirectionLabel);
  }
  if (!params.centeredSlides) {
    const newSlidesGrid = [];
    for (let i = 0; i < snapGrid.length; i += 1) {
      let slidesGridItem = snapGrid[i];
      if (params.roundLengths)
        slidesGridItem = Math.floor(slidesGridItem);
      if (snapGrid[i] <= swiper.virtualSize - swiperSize) {
        newSlidesGrid.push(slidesGridItem);
      }
    }
    snapGrid = newSlidesGrid;
    if (Math.floor(swiper.virtualSize - swiperSize) - Math.floor(snapGrid[snapGrid.length - 1]) > 1) {
      snapGrid.push(swiper.virtualSize - swiperSize);
    }
  }
  if (snapGrid.length === 0)
    snapGrid = [0];
  if (params.spaceBetween !== 0) {
    const key = swiper.isHorizontal() && rtl ? "marginLeft" : getDirectionLabel("marginRight");
    slides.filter((_, slideIndex) => {
      if (!params.cssMode)
        return true;
      if (slideIndex === slides.length - 1) {
        return false;
      }
      return true;
    }).css({
      [key]: `${spaceBetween}px`
    });
  }
  if (params.centeredSlides && params.centeredSlidesBounds) {
    let allSlidesSize = 0;
    slidesSizesGrid.forEach((slideSizeValue) => {
      allSlidesSize += slideSizeValue + (params.spaceBetween ? params.spaceBetween : 0);
    });
    allSlidesSize -= params.spaceBetween;
    const maxSnap = allSlidesSize - swiperSize;
    snapGrid = snapGrid.map((snap) => {
      if (snap < 0)
        return -offsetBefore;
      if (snap > maxSnap)
        return maxSnap + offsetAfter;
      return snap;
    });
  }
  if (params.centerInsufficientSlides) {
    let allSlidesSize = 0;
    slidesSizesGrid.forEach((slideSizeValue) => {
      allSlidesSize += slideSizeValue + (params.spaceBetween ? params.spaceBetween : 0);
    });
    allSlidesSize -= params.spaceBetween;
    if (allSlidesSize < swiperSize) {
      const allSlidesOffset = (swiperSize - allSlidesSize) / 2;
      snapGrid.forEach((snap, snapIndex) => {
        snapGrid[snapIndex] = snap - allSlidesOffset;
      });
      slidesGrid.forEach((snap, snapIndex) => {
        slidesGrid[snapIndex] = snap + allSlidesOffset;
      });
    }
  }
  Object.assign(swiper, {
    slides,
    snapGrid,
    slidesGrid,
    slidesSizesGrid
  });
  if (params.centeredSlides && params.cssMode && !params.centeredSlidesBounds) {
    setCSSProperty(swiper.wrapperEl, "--swiper-centered-offset-before", `${-snapGrid[0]}px`);
    setCSSProperty(swiper.wrapperEl, "--swiper-centered-offset-after", `${swiper.size / 2 - slidesSizesGrid[slidesSizesGrid.length - 1] / 2}px`);
    const addToSnapGrid = -swiper.snapGrid[0];
    const addToSlidesGrid = -swiper.slidesGrid[0];
    swiper.snapGrid = swiper.snapGrid.map((v) => v + addToSnapGrid);
    swiper.slidesGrid = swiper.slidesGrid.map((v) => v + addToSlidesGrid);
  }
  if (slidesLength !== previousSlidesLength) {
    swiper.emit("slidesLengthChange");
  }
  if (snapGrid.length !== previousSnapGridLength) {
    if (swiper.params.watchOverflow)
      swiper.checkOverflow();
    swiper.emit("snapGridLengthChange");
  }
  if (slidesGrid.length !== previousSlidesGridLength) {
    swiper.emit("slidesGridLengthChange");
  }
  if (params.watchSlidesProgress) {
    swiper.updateSlidesOffset();
  }
  if (!isVirtual && !params.cssMode && (params.effect === "slide" || params.effect === "fade")) {
    const backFaceHiddenClass = `${params.containerModifierClass}backface-hidden`;
    const hasClassBackfaceClassAdded = swiper.$el.hasClass(backFaceHiddenClass);
    if (slidesLength <= params.maxBackfaceHiddenSlides) {
      if (!hasClassBackfaceClassAdded)
        swiper.$el.addClass(backFaceHiddenClass);
    } else if (hasClassBackfaceClassAdded) {
      swiper.$el.removeClass(backFaceHiddenClass);
    }
  }
}
function updateAutoHeight(speed) {
  const swiper = this;
  const activeSlides = [];
  const isVirtual = swiper.virtual && swiper.params.virtual.enabled;
  let newHeight = 0;
  let i;
  if (typeof speed === "number") {
    swiper.setTransition(speed);
  } else if (speed === true) {
    swiper.setTransition(swiper.params.speed);
  }
  const getSlideByIndex = (index2) => {
    if (isVirtual) {
      return swiper.slides.filter((el) => parseInt(el.getAttribute("data-swiper-slide-index"), 10) === index2)[0];
    }
    return swiper.slides.eq(index2)[0];
  };
  if (swiper.params.slidesPerView !== "auto" && swiper.params.slidesPerView > 1) {
    if (swiper.params.centeredSlides) {
      (swiper.visibleSlides || $([])).each((slide2) => {
        activeSlides.push(slide2);
      });
    } else {
      for (i = 0; i < Math.ceil(swiper.params.slidesPerView); i += 1) {
        const index2 = swiper.activeIndex + i;
        if (index2 > swiper.slides.length && !isVirtual)
          break;
        activeSlides.push(getSlideByIndex(index2));
      }
    }
  } else {
    activeSlides.push(getSlideByIndex(swiper.activeIndex));
  }
  for (i = 0; i < activeSlides.length; i += 1) {
    if (typeof activeSlides[i] !== "undefined") {
      const height = activeSlides[i].offsetHeight;
      newHeight = height > newHeight ? height : newHeight;
    }
  }
  if (newHeight || newHeight === 0)
    swiper.$wrapperEl.css("height", `${newHeight}px`);
}
function updateSlidesOffset() {
  const swiper = this;
  const slides = swiper.slides;
  for (let i = 0; i < slides.length; i += 1) {
    slides[i].swiperSlideOffset = swiper.isHorizontal() ? slides[i].offsetLeft : slides[i].offsetTop;
  }
}
function updateSlidesProgress(translate2 = this && this.translate || 0) {
  const swiper = this;
  const params = swiper.params;
  const {
    slides,
    rtlTranslate: rtl,
    snapGrid
  } = swiper;
  if (slides.length === 0)
    return;
  if (typeof slides[0].swiperSlideOffset === "undefined")
    swiper.updateSlidesOffset();
  let offsetCenter = -translate2;
  if (rtl)
    offsetCenter = translate2;
  slides.removeClass(params.slideVisibleClass);
  swiper.visibleSlidesIndexes = [];
  swiper.visibleSlides = [];
  for (let i = 0; i < slides.length; i += 1) {
    const slide2 = slides[i];
    let slideOffset = slide2.swiperSlideOffset;
    if (params.cssMode && params.centeredSlides) {
      slideOffset -= slides[0].swiperSlideOffset;
    }
    const slideProgress = (offsetCenter + (params.centeredSlides ? swiper.minTranslate() : 0) - slideOffset) / (slide2.swiperSlideSize + params.spaceBetween);
    const originalSlideProgress = (offsetCenter - snapGrid[0] + (params.centeredSlides ? swiper.minTranslate() : 0) - slideOffset) / (slide2.swiperSlideSize + params.spaceBetween);
    const slideBefore = -(offsetCenter - slideOffset);
    const slideAfter = slideBefore + swiper.slidesSizesGrid[i];
    const isVisible = slideBefore >= 0 && slideBefore < swiper.size - 1 || slideAfter > 1 && slideAfter <= swiper.size || slideBefore <= 0 && slideAfter >= swiper.size;
    if (isVisible) {
      swiper.visibleSlides.push(slide2);
      swiper.visibleSlidesIndexes.push(i);
      slides.eq(i).addClass(params.slideVisibleClass);
    }
    slide2.progress = rtl ? -slideProgress : slideProgress;
    slide2.originalProgress = rtl ? -originalSlideProgress : originalSlideProgress;
  }
  swiper.visibleSlides = $(swiper.visibleSlides);
}
function updateProgress(translate2) {
  const swiper = this;
  if (typeof translate2 === "undefined") {
    const multiplier = swiper.rtlTranslate ? -1 : 1;
    translate2 = swiper && swiper.translate && swiper.translate * multiplier || 0;
  }
  const params = swiper.params;
  const translatesDiff = swiper.maxTranslate() - swiper.minTranslate();
  let {
    progress,
    isBeginning,
    isEnd
  } = swiper;
  const wasBeginning = isBeginning;
  const wasEnd = isEnd;
  if (translatesDiff === 0) {
    progress = 0;
    isBeginning = true;
    isEnd = true;
  } else {
    progress = (translate2 - swiper.minTranslate()) / translatesDiff;
    isBeginning = progress <= 0;
    isEnd = progress >= 1;
  }
  Object.assign(swiper, {
    progress,
    isBeginning,
    isEnd
  });
  if (params.watchSlidesProgress || params.centeredSlides && params.autoHeight)
    swiper.updateSlidesProgress(translate2);
  if (isBeginning && !wasBeginning) {
    swiper.emit("reachBeginning toEdge");
  }
  if (isEnd && !wasEnd) {
    swiper.emit("reachEnd toEdge");
  }
  if (wasBeginning && !isBeginning || wasEnd && !isEnd) {
    swiper.emit("fromEdge");
  }
  swiper.emit("progress", progress);
}
function updateSlidesClasses() {
  const swiper = this;
  const {
    slides,
    params,
    $wrapperEl,
    activeIndex,
    realIndex
  } = swiper;
  const isVirtual = swiper.virtual && params.virtual.enabled;
  slides.removeClass(`${params.slideActiveClass} ${params.slideNextClass} ${params.slidePrevClass} ${params.slideDuplicateActiveClass} ${params.slideDuplicateNextClass} ${params.slideDuplicatePrevClass}`);
  let activeSlide;
  if (isVirtual) {
    activeSlide = swiper.$wrapperEl.find(`.${params.slideClass}[data-swiper-slide-index="${activeIndex}"]`);
  } else {
    activeSlide = slides.eq(activeIndex);
  }
  activeSlide.addClass(params.slideActiveClass);
  if (params.loop) {
    if (activeSlide.hasClass(params.slideDuplicateClass)) {
      $wrapperEl.children(`.${params.slideClass}:not(.${params.slideDuplicateClass})[data-swiper-slide-index="${realIndex}"]`).addClass(params.slideDuplicateActiveClass);
    } else {
      $wrapperEl.children(`.${params.slideClass}.${params.slideDuplicateClass}[data-swiper-slide-index="${realIndex}"]`).addClass(params.slideDuplicateActiveClass);
    }
  }
  let nextSlide = activeSlide.nextAll(`.${params.slideClass}`).eq(0).addClass(params.slideNextClass);
  if (params.loop && nextSlide.length === 0) {
    nextSlide = slides.eq(0);
    nextSlide.addClass(params.slideNextClass);
  }
  let prevSlide = activeSlide.prevAll(`.${params.slideClass}`).eq(0).addClass(params.slidePrevClass);
  if (params.loop && prevSlide.length === 0) {
    prevSlide = slides.eq(-1);
    prevSlide.addClass(params.slidePrevClass);
  }
  if (params.loop) {
    if (nextSlide.hasClass(params.slideDuplicateClass)) {
      $wrapperEl.children(`.${params.slideClass}:not(.${params.slideDuplicateClass})[data-swiper-slide-index="${nextSlide.attr("data-swiper-slide-index")}"]`).addClass(params.slideDuplicateNextClass);
    } else {
      $wrapperEl.children(`.${params.slideClass}.${params.slideDuplicateClass}[data-swiper-slide-index="${nextSlide.attr("data-swiper-slide-index")}"]`).addClass(params.slideDuplicateNextClass);
    }
    if (prevSlide.hasClass(params.slideDuplicateClass)) {
      $wrapperEl.children(`.${params.slideClass}:not(.${params.slideDuplicateClass})[data-swiper-slide-index="${prevSlide.attr("data-swiper-slide-index")}"]`).addClass(params.slideDuplicatePrevClass);
    } else {
      $wrapperEl.children(`.${params.slideClass}.${params.slideDuplicateClass}[data-swiper-slide-index="${prevSlide.attr("data-swiper-slide-index")}"]`).addClass(params.slideDuplicatePrevClass);
    }
  }
  swiper.emitSlidesClasses();
}
function updateActiveIndex(newActiveIndex) {
  const swiper = this;
  const translate2 = swiper.rtlTranslate ? swiper.translate : -swiper.translate;
  const {
    slidesGrid,
    snapGrid,
    params,
    activeIndex: previousIndex,
    realIndex: previousRealIndex,
    snapIndex: previousSnapIndex
  } = swiper;
  let activeIndex = newActiveIndex;
  let snapIndex;
  if (typeof activeIndex === "undefined") {
    for (let i = 0; i < slidesGrid.length; i += 1) {
      if (typeof slidesGrid[i + 1] !== "undefined") {
        if (translate2 >= slidesGrid[i] && translate2 < slidesGrid[i + 1] - (slidesGrid[i + 1] - slidesGrid[i]) / 2) {
          activeIndex = i;
        } else if (translate2 >= slidesGrid[i] && translate2 < slidesGrid[i + 1]) {
          activeIndex = i + 1;
        }
      } else if (translate2 >= slidesGrid[i]) {
        activeIndex = i;
      }
    }
    if (params.normalizeSlideIndex) {
      if (activeIndex < 0 || typeof activeIndex === "undefined")
        activeIndex = 0;
    }
  }
  if (snapGrid.indexOf(translate2) >= 0) {
    snapIndex = snapGrid.indexOf(translate2);
  } else {
    const skip = Math.min(params.slidesPerGroupSkip, activeIndex);
    snapIndex = skip + Math.floor((activeIndex - skip) / params.slidesPerGroup);
  }
  if (snapIndex >= snapGrid.length)
    snapIndex = snapGrid.length - 1;
  if (activeIndex === previousIndex) {
    if (snapIndex !== previousSnapIndex) {
      swiper.snapIndex = snapIndex;
      swiper.emit("snapIndexChange");
    }
    return;
  }
  const realIndex = parseInt(swiper.slides.eq(activeIndex).attr("data-swiper-slide-index") || activeIndex, 10);
  Object.assign(swiper, {
    snapIndex,
    realIndex,
    previousIndex,
    activeIndex
  });
  swiper.emit("activeIndexChange");
  swiper.emit("snapIndexChange");
  if (previousRealIndex !== realIndex) {
    swiper.emit("realIndexChange");
  }
  if (swiper.initialized || swiper.params.runCallbacksOnInit) {
    swiper.emit("slideChange");
  }
}
function updateClickedSlide(e) {
  const swiper = this;
  const params = swiper.params;
  const slide2 = $(e).closest(`.${params.slideClass}`)[0];
  let slideFound = false;
  let slideIndex;
  if (slide2) {
    for (let i = 0; i < swiper.slides.length; i += 1) {
      if (swiper.slides[i] === slide2) {
        slideFound = true;
        slideIndex = i;
        break;
      }
    }
  }
  if (slide2 && slideFound) {
    swiper.clickedSlide = slide2;
    if (swiper.virtual && swiper.params.virtual.enabled) {
      swiper.clickedIndex = parseInt($(slide2).attr("data-swiper-slide-index"), 10);
    } else {
      swiper.clickedIndex = slideIndex;
    }
  } else {
    swiper.clickedSlide = void 0;
    swiper.clickedIndex = void 0;
    return;
  }
  if (params.slideToClickedSlide && swiper.clickedIndex !== void 0 && swiper.clickedIndex !== swiper.activeIndex) {
    swiper.slideToClickedSlide();
  }
}
const update = {
  updateSize,
  updateSlides,
  updateAutoHeight,
  updateSlidesOffset,
  updateSlidesProgress,
  updateProgress,
  updateSlidesClasses,
  updateActiveIndex,
  updateClickedSlide
};
function getSwiperTranslate(axis = this.isHorizontal() ? "x" : "y") {
  const swiper = this;
  const {
    params,
    rtlTranslate: rtl,
    translate: translate2,
    $wrapperEl
  } = swiper;
  if (params.virtualTranslate) {
    return rtl ? -translate2 : translate2;
  }
  if (params.cssMode) {
    return translate2;
  }
  let currentTranslate = getTranslate($wrapperEl[0], axis);
  if (rtl)
    currentTranslate = -currentTranslate;
  return currentTranslate || 0;
}
function setTranslate(translate2, byController) {
  const swiper = this;
  const {
    rtlTranslate: rtl,
    params,
    $wrapperEl,
    wrapperEl,
    progress
  } = swiper;
  let x = 0;
  let y = 0;
  const z = 0;
  if (swiper.isHorizontal()) {
    x = rtl ? -translate2 : translate2;
  } else {
    y = translate2;
  }
  if (params.roundLengths) {
    x = Math.floor(x);
    y = Math.floor(y);
  }
  if (params.cssMode) {
    wrapperEl[swiper.isHorizontal() ? "scrollLeft" : "scrollTop"] = swiper.isHorizontal() ? -x : -y;
  } else if (!params.virtualTranslate) {
    $wrapperEl.transform(`translate3d(${x}px, ${y}px, ${z}px)`);
  }
  swiper.previousTranslate = swiper.translate;
  swiper.translate = swiper.isHorizontal() ? x : y;
  let newProgress;
  const translatesDiff = swiper.maxTranslate() - swiper.minTranslate();
  if (translatesDiff === 0) {
    newProgress = 0;
  } else {
    newProgress = (translate2 - swiper.minTranslate()) / translatesDiff;
  }
  if (newProgress !== progress) {
    swiper.updateProgress(translate2);
  }
  swiper.emit("setTranslate", swiper.translate, byController);
}
function minTranslate() {
  return -this.snapGrid[0];
}
function maxTranslate() {
  return -this.snapGrid[this.snapGrid.length - 1];
}
function translateTo(translate2 = 0, speed = this.params.speed, runCallbacks = true, translateBounds = true, internal) {
  const swiper = this;
  const {
    params,
    wrapperEl
  } = swiper;
  if (swiper.animating && params.preventInteractionOnTransition) {
    return false;
  }
  const minTranslate2 = swiper.minTranslate();
  const maxTranslate2 = swiper.maxTranslate();
  let newTranslate;
  if (translateBounds && translate2 > minTranslate2)
    newTranslate = minTranslate2;
  else if (translateBounds && translate2 < maxTranslate2)
    newTranslate = maxTranslate2;
  else
    newTranslate = translate2;
  swiper.updateProgress(newTranslate);
  if (params.cssMode) {
    const isH = swiper.isHorizontal();
    if (speed === 0) {
      wrapperEl[isH ? "scrollLeft" : "scrollTop"] = -newTranslate;
    } else {
      if (!swiper.support.smoothScroll) {
        animateCSSModeScroll({
          swiper,
          targetPosition: -newTranslate,
          side: isH ? "left" : "top"
        });
        return true;
      }
      wrapperEl.scrollTo({
        [isH ? "left" : "top"]: -newTranslate,
        behavior: "smooth"
      });
    }
    return true;
  }
  if (speed === 0) {
    swiper.setTransition(0);
    swiper.setTranslate(newTranslate);
    if (runCallbacks) {
      swiper.emit("beforeTransitionStart", speed, internal);
      swiper.emit("transitionEnd");
    }
  } else {
    swiper.setTransition(speed);
    swiper.setTranslate(newTranslate);
    if (runCallbacks) {
      swiper.emit("beforeTransitionStart", speed, internal);
      swiper.emit("transitionStart");
    }
    if (!swiper.animating) {
      swiper.animating = true;
      if (!swiper.onTranslateToWrapperTransitionEnd) {
        swiper.onTranslateToWrapperTransitionEnd = function transitionEnd2(e) {
          if (!swiper || swiper.destroyed)
            return;
          if (e.target !== this)
            return;
          swiper.$wrapperEl[0].removeEventListener("transitionend", swiper.onTranslateToWrapperTransitionEnd);
          swiper.$wrapperEl[0].removeEventListener("webkitTransitionEnd", swiper.onTranslateToWrapperTransitionEnd);
          swiper.onTranslateToWrapperTransitionEnd = null;
          delete swiper.onTranslateToWrapperTransitionEnd;
          if (runCallbacks) {
            swiper.emit("transitionEnd");
          }
        };
      }
      swiper.$wrapperEl[0].addEventListener("transitionend", swiper.onTranslateToWrapperTransitionEnd);
      swiper.$wrapperEl[0].addEventListener("webkitTransitionEnd", swiper.onTranslateToWrapperTransitionEnd);
    }
  }
  return true;
}
const translate = {
  getTranslate: getSwiperTranslate,
  setTranslate,
  minTranslate,
  maxTranslate,
  translateTo
};
function setTransition(duration2, byController) {
  const swiper = this;
  if (!swiper.params.cssMode) {
    swiper.$wrapperEl.transition(duration2);
  }
  swiper.emit("setTransition", duration2, byController);
}
function transitionEmit({
  swiper,
  runCallbacks,
  direction,
  step
}) {
  const {
    activeIndex,
    previousIndex
  } = swiper;
  let dir = direction;
  if (!dir) {
    if (activeIndex > previousIndex)
      dir = "next";
    else if (activeIndex < previousIndex)
      dir = "prev";
    else
      dir = "reset";
  }
  swiper.emit(`transition${step}`);
  if (runCallbacks && activeIndex !== previousIndex) {
    if (dir === "reset") {
      swiper.emit(`slideResetTransition${step}`);
      return;
    }
    swiper.emit(`slideChangeTransition${step}`);
    if (dir === "next") {
      swiper.emit(`slideNextTransition${step}`);
    } else {
      swiper.emit(`slidePrevTransition${step}`);
    }
  }
}
function transitionStart(runCallbacks = true, direction) {
  const swiper = this;
  const {
    params
  } = swiper;
  if (params.cssMode)
    return;
  if (params.autoHeight) {
    swiper.updateAutoHeight();
  }
  transitionEmit({
    swiper,
    runCallbacks,
    direction,
    step: "Start"
  });
}
function transitionEnd(runCallbacks = true, direction) {
  const swiper = this;
  const {
    params
  } = swiper;
  swiper.animating = false;
  if (params.cssMode)
    return;
  swiper.setTransition(0);
  transitionEmit({
    swiper,
    runCallbacks,
    direction,
    step: "End"
  });
}
const transition = {
  setTransition,
  transitionStart,
  transitionEnd
};
function slideTo(index2 = 0, speed = this.params.speed, runCallbacks = true, internal, initial) {
  if (typeof index2 !== "number" && typeof index2 !== "string") {
    throw new Error(`The 'index' argument cannot have type other than 'number' or 'string'. [${typeof index2}] given.`);
  }
  if (typeof index2 === "string") {
    const indexAsNumber = parseInt(index2, 10);
    const isValidNumber = isFinite(indexAsNumber);
    if (!isValidNumber) {
      throw new Error(`The passed-in 'index' (string) couldn't be converted to 'number'. [${index2}] given.`);
    }
    index2 = indexAsNumber;
  }
  const swiper = this;
  let slideIndex = index2;
  if (slideIndex < 0)
    slideIndex = 0;
  const {
    params,
    snapGrid,
    slidesGrid,
    previousIndex,
    activeIndex,
    rtlTranslate: rtl,
    wrapperEl,
    enabled
  } = swiper;
  if (swiper.animating && params.preventInteractionOnTransition || !enabled && !internal && !initial) {
    return false;
  }
  const skip = Math.min(swiper.params.slidesPerGroupSkip, slideIndex);
  let snapIndex = skip + Math.floor((slideIndex - skip) / swiper.params.slidesPerGroup);
  if (snapIndex >= snapGrid.length)
    snapIndex = snapGrid.length - 1;
  const translate2 = -snapGrid[snapIndex];
  if (params.normalizeSlideIndex) {
    for (let i = 0; i < slidesGrid.length; i += 1) {
      const normalizedTranslate = -Math.floor(translate2 * 100);
      const normalizedGrid = Math.floor(slidesGrid[i] * 100);
      const normalizedGridNext = Math.floor(slidesGrid[i + 1] * 100);
      if (typeof slidesGrid[i + 1] !== "undefined") {
        if (normalizedTranslate >= normalizedGrid && normalizedTranslate < normalizedGridNext - (normalizedGridNext - normalizedGrid) / 2) {
          slideIndex = i;
        } else if (normalizedTranslate >= normalizedGrid && normalizedTranslate < normalizedGridNext) {
          slideIndex = i + 1;
        }
      } else if (normalizedTranslate >= normalizedGrid) {
        slideIndex = i;
      }
    }
  }
  if (swiper.initialized && slideIndex !== activeIndex) {
    if (!swiper.allowSlideNext && translate2 < swiper.translate && translate2 < swiper.minTranslate()) {
      return false;
    }
    if (!swiper.allowSlidePrev && translate2 > swiper.translate && translate2 > swiper.maxTranslate()) {
      if ((activeIndex || 0) !== slideIndex)
        return false;
    }
  }
  if (slideIndex !== (previousIndex || 0) && runCallbacks) {
    swiper.emit("beforeSlideChangeStart");
  }
  swiper.updateProgress(translate2);
  let direction;
  if (slideIndex > activeIndex)
    direction = "next";
  else if (slideIndex < activeIndex)
    direction = "prev";
  else
    direction = "reset";
  if (rtl && -translate2 === swiper.translate || !rtl && translate2 === swiper.translate) {
    swiper.updateActiveIndex(slideIndex);
    if (params.autoHeight) {
      swiper.updateAutoHeight();
    }
    swiper.updateSlidesClasses();
    if (params.effect !== "slide") {
      swiper.setTranslate(translate2);
    }
    if (direction !== "reset") {
      swiper.transitionStart(runCallbacks, direction);
      swiper.transitionEnd(runCallbacks, direction);
    }
    return false;
  }
  if (params.cssMode) {
    const isH = swiper.isHorizontal();
    const t = rtl ? translate2 : -translate2;
    if (speed === 0) {
      const isVirtual = swiper.virtual && swiper.params.virtual.enabled;
      if (isVirtual) {
        swiper.wrapperEl.style.scrollSnapType = "none";
        swiper._immediateVirtual = true;
      }
      wrapperEl[isH ? "scrollLeft" : "scrollTop"] = t;
      if (isVirtual) {
        requestAnimationFrame(() => {
          swiper.wrapperEl.style.scrollSnapType = "";
          swiper._swiperImmediateVirtual = false;
        });
      }
    } else {
      if (!swiper.support.smoothScroll) {
        animateCSSModeScroll({
          swiper,
          targetPosition: t,
          side: isH ? "left" : "top"
        });
        return true;
      }
      wrapperEl.scrollTo({
        [isH ? "left" : "top"]: t,
        behavior: "smooth"
      });
    }
    return true;
  }
  swiper.setTransition(speed);
  swiper.setTranslate(translate2);
  swiper.updateActiveIndex(slideIndex);
  swiper.updateSlidesClasses();
  swiper.emit("beforeTransitionStart", speed, internal);
  swiper.transitionStart(runCallbacks, direction);
  if (speed === 0) {
    swiper.transitionEnd(runCallbacks, direction);
  } else if (!swiper.animating) {
    swiper.animating = true;
    if (!swiper.onSlideToWrapperTransitionEnd) {
      swiper.onSlideToWrapperTransitionEnd = function transitionEnd2(e) {
        if (!swiper || swiper.destroyed)
          return;
        if (e.target !== this)
          return;
        swiper.$wrapperEl[0].removeEventListener("transitionend", swiper.onSlideToWrapperTransitionEnd);
        swiper.$wrapperEl[0].removeEventListener("webkitTransitionEnd", swiper.onSlideToWrapperTransitionEnd);
        swiper.onSlideToWrapperTransitionEnd = null;
        delete swiper.onSlideToWrapperTransitionEnd;
        swiper.transitionEnd(runCallbacks, direction);
      };
    }
    swiper.$wrapperEl[0].addEventListener("transitionend", swiper.onSlideToWrapperTransitionEnd);
    swiper.$wrapperEl[0].addEventListener("webkitTransitionEnd", swiper.onSlideToWrapperTransitionEnd);
  }
  return true;
}
function slideToLoop(index2 = 0, speed = this.params.speed, runCallbacks = true, internal) {
  if (typeof index2 === "string") {
    const indexAsNumber = parseInt(index2, 10);
    const isValidNumber = isFinite(indexAsNumber);
    if (!isValidNumber) {
      throw new Error(`The passed-in 'index' (string) couldn't be converted to 'number'. [${index2}] given.`);
    }
    index2 = indexAsNumber;
  }
  const swiper = this;
  let newIndex = index2;
  if (swiper.params.loop) {
    newIndex += swiper.loopedSlides;
  }
  return swiper.slideTo(newIndex, speed, runCallbacks, internal);
}
function slideNext(speed = this.params.speed, runCallbacks = true, internal) {
  const swiper = this;
  const {
    animating,
    enabled,
    params
  } = swiper;
  if (!enabled)
    return swiper;
  let perGroup = params.slidesPerGroup;
  if (params.slidesPerView === "auto" && params.slidesPerGroup === 1 && params.slidesPerGroupAuto) {
    perGroup = Math.max(swiper.slidesPerViewDynamic("current", true), 1);
  }
  const increment = swiper.activeIndex < params.slidesPerGroupSkip ? 1 : perGroup;
  if (params.loop) {
    if (animating && params.loopPreventsSlide)
      return false;
    swiper.loopFix();
    swiper._clientLeft = swiper.$wrapperEl[0].clientLeft;
  }
  if (params.rewind && swiper.isEnd) {
    return swiper.slideTo(0, speed, runCallbacks, internal);
  }
  return swiper.slideTo(swiper.activeIndex + increment, speed, runCallbacks, internal);
}
function slidePrev(speed = this.params.speed, runCallbacks = true, internal) {
  const swiper = this;
  const {
    params,
    animating,
    snapGrid,
    slidesGrid,
    rtlTranslate,
    enabled
  } = swiper;
  if (!enabled)
    return swiper;
  if (params.loop) {
    if (animating && params.loopPreventsSlide)
      return false;
    swiper.loopFix();
    swiper._clientLeft = swiper.$wrapperEl[0].clientLeft;
  }
  const translate2 = rtlTranslate ? swiper.translate : -swiper.translate;
  function normalize(val) {
    if (val < 0)
      return -Math.floor(Math.abs(val));
    return Math.floor(val);
  }
  const normalizedTranslate = normalize(translate2);
  const normalizedSnapGrid = snapGrid.map((val) => normalize(val));
  let prevSnap = snapGrid[normalizedSnapGrid.indexOf(normalizedTranslate) - 1];
  if (typeof prevSnap === "undefined" && params.cssMode) {
    let prevSnapIndex;
    snapGrid.forEach((snap, snapIndex) => {
      if (normalizedTranslate >= snap) {
        prevSnapIndex = snapIndex;
      }
    });
    if (typeof prevSnapIndex !== "undefined") {
      prevSnap = snapGrid[prevSnapIndex > 0 ? prevSnapIndex - 1 : prevSnapIndex];
    }
  }
  let prevIndex = 0;
  if (typeof prevSnap !== "undefined") {
    prevIndex = slidesGrid.indexOf(prevSnap);
    if (prevIndex < 0)
      prevIndex = swiper.activeIndex - 1;
    if (params.slidesPerView === "auto" && params.slidesPerGroup === 1 && params.slidesPerGroupAuto) {
      prevIndex = prevIndex - swiper.slidesPerViewDynamic("previous", true) + 1;
      prevIndex = Math.max(prevIndex, 0);
    }
  }
  if (params.rewind && swiper.isBeginning) {
    const lastIndex = swiper.params.virtual && swiper.params.virtual.enabled && swiper.virtual ? swiper.virtual.slides.length - 1 : swiper.slides.length - 1;
    return swiper.slideTo(lastIndex, speed, runCallbacks, internal);
  }
  return swiper.slideTo(prevIndex, speed, runCallbacks, internal);
}
function slideReset(speed = this.params.speed, runCallbacks = true, internal) {
  const swiper = this;
  return swiper.slideTo(swiper.activeIndex, speed, runCallbacks, internal);
}
function slideToClosest(speed = this.params.speed, runCallbacks = true, internal, threshold = 0.5) {
  const swiper = this;
  let index2 = swiper.activeIndex;
  const skip = Math.min(swiper.params.slidesPerGroupSkip, index2);
  const snapIndex = skip + Math.floor((index2 - skip) / swiper.params.slidesPerGroup);
  const translate2 = swiper.rtlTranslate ? swiper.translate : -swiper.translate;
  if (translate2 >= swiper.snapGrid[snapIndex]) {
    const currentSnap = swiper.snapGrid[snapIndex];
    const nextSnap = swiper.snapGrid[snapIndex + 1];
    if (translate2 - currentSnap > (nextSnap - currentSnap) * threshold) {
      index2 += swiper.params.slidesPerGroup;
    }
  } else {
    const prevSnap = swiper.snapGrid[snapIndex - 1];
    const currentSnap = swiper.snapGrid[snapIndex];
    if (translate2 - prevSnap <= (currentSnap - prevSnap) * threshold) {
      index2 -= swiper.params.slidesPerGroup;
    }
  }
  index2 = Math.max(index2, 0);
  index2 = Math.min(index2, swiper.slidesGrid.length - 1);
  return swiper.slideTo(index2, speed, runCallbacks, internal);
}
function slideToClickedSlide() {
  const swiper = this;
  const {
    params,
    $wrapperEl
  } = swiper;
  const slidesPerView = params.slidesPerView === "auto" ? swiper.slidesPerViewDynamic() : params.slidesPerView;
  let slideToIndex = swiper.clickedIndex;
  let realIndex;
  if (params.loop) {
    if (swiper.animating)
      return;
    realIndex = parseInt($(swiper.clickedSlide).attr("data-swiper-slide-index"), 10);
    if (params.centeredSlides) {
      if (slideToIndex < swiper.loopedSlides - slidesPerView / 2 || slideToIndex > swiper.slides.length - swiper.loopedSlides + slidesPerView / 2) {
        swiper.loopFix();
        slideToIndex = $wrapperEl.children(`.${params.slideClass}[data-swiper-slide-index="${realIndex}"]:not(.${params.slideDuplicateClass})`).eq(0).index();
        nextTick(() => {
          swiper.slideTo(slideToIndex);
        });
      } else {
        swiper.slideTo(slideToIndex);
      }
    } else if (slideToIndex > swiper.slides.length - slidesPerView) {
      swiper.loopFix();
      slideToIndex = $wrapperEl.children(`.${params.slideClass}[data-swiper-slide-index="${realIndex}"]:not(.${params.slideDuplicateClass})`).eq(0).index();
      nextTick(() => {
        swiper.slideTo(slideToIndex);
      });
    } else {
      swiper.slideTo(slideToIndex);
    }
  } else {
    swiper.slideTo(slideToIndex);
  }
}
const slide = {
  slideTo,
  slideToLoop,
  slideNext,
  slidePrev,
  slideReset,
  slideToClosest,
  slideToClickedSlide
};
function loopCreate() {
  const swiper = this;
  const document2 = getDocument();
  const {
    params,
    $wrapperEl
  } = swiper;
  const $selector = $wrapperEl.children().length > 0 ? $($wrapperEl.children()[0].parentNode) : $wrapperEl;
  $selector.children(`.${params.slideClass}.${params.slideDuplicateClass}`).remove();
  let slides = $selector.children(`.${params.slideClass}`);
  if (params.loopFillGroupWithBlank) {
    const blankSlidesNum = params.slidesPerGroup - slides.length % params.slidesPerGroup;
    if (blankSlidesNum !== params.slidesPerGroup) {
      for (let i = 0; i < blankSlidesNum; i += 1) {
        const blankNode = $(document2.createElement("div")).addClass(`${params.slideClass} ${params.slideBlankClass}`);
        $selector.append(blankNode);
      }
      slides = $selector.children(`.${params.slideClass}`);
    }
  }
  if (params.slidesPerView === "auto" && !params.loopedSlides)
    params.loopedSlides = slides.length;
  swiper.loopedSlides = Math.ceil(parseFloat(params.loopedSlides || params.slidesPerView, 10));
  swiper.loopedSlides += params.loopAdditionalSlides;
  if (swiper.loopedSlides > slides.length && swiper.params.loopedSlidesLimit) {
    swiper.loopedSlides = slides.length;
  }
  const prependSlides = [];
  const appendSlides = [];
  slides.each((el, index2) => {
    const slide2 = $(el);
    slide2.attr("data-swiper-slide-index", index2);
  });
  for (let i = 0; i < swiper.loopedSlides; i += 1) {
    const index2 = i - Math.floor(i / slides.length) * slides.length;
    appendSlides.push(slides.eq(index2)[0]);
    prependSlides.unshift(slides.eq(slides.length - index2 - 1)[0]);
  }
  for (let i = 0; i < appendSlides.length; i += 1) {
    $selector.append($(appendSlides[i].cloneNode(true)).addClass(params.slideDuplicateClass));
  }
  for (let i = prependSlides.length - 1; i >= 0; i -= 1) {
    $selector.prepend($(prependSlides[i].cloneNode(true)).addClass(params.slideDuplicateClass));
  }
}
function loopFix() {
  const swiper = this;
  swiper.emit("beforeLoopFix");
  const {
    activeIndex,
    slides,
    loopedSlides,
    allowSlidePrev,
    allowSlideNext,
    snapGrid,
    rtlTranslate: rtl
  } = swiper;
  let newIndex;
  swiper.allowSlidePrev = true;
  swiper.allowSlideNext = true;
  const snapTranslate = -snapGrid[activeIndex];
  const diff = snapTranslate - swiper.getTranslate();
  if (activeIndex < loopedSlides) {
    newIndex = slides.length - loopedSlides * 3 + activeIndex;
    newIndex += loopedSlides;
    const slideChanged = swiper.slideTo(newIndex, 0, false, true);
    if (slideChanged && diff !== 0) {
      swiper.setTranslate((rtl ? -swiper.translate : swiper.translate) - diff);
    }
  } else if (activeIndex >= slides.length - loopedSlides) {
    newIndex = -slides.length + activeIndex + loopedSlides;
    newIndex += loopedSlides;
    const slideChanged = swiper.slideTo(newIndex, 0, false, true);
    if (slideChanged && diff !== 0) {
      swiper.setTranslate((rtl ? -swiper.translate : swiper.translate) - diff);
    }
  }
  swiper.allowSlidePrev = allowSlidePrev;
  swiper.allowSlideNext = allowSlideNext;
  swiper.emit("loopFix");
}
function loopDestroy() {
  const swiper = this;
  const {
    $wrapperEl,
    params,
    slides
  } = swiper;
  $wrapperEl.children(`.${params.slideClass}.${params.slideDuplicateClass},.${params.slideClass}.${params.slideBlankClass}`).remove();
  slides.removeAttr("data-swiper-slide-index");
}
const loop = {
  loopCreate,
  loopFix,
  loopDestroy
};
function setGrabCursor(moving) {
  const swiper = this;
  if (swiper.support.touch || !swiper.params.simulateTouch || swiper.params.watchOverflow && swiper.isLocked || swiper.params.cssMode)
    return;
  const el = swiper.params.touchEventsTarget === "container" ? swiper.el : swiper.wrapperEl;
  el.style.cursor = "move";
  el.style.cursor = moving ? "grabbing" : "grab";
}
function unsetGrabCursor() {
  const swiper = this;
  if (swiper.support.touch || swiper.params.watchOverflow && swiper.isLocked || swiper.params.cssMode) {
    return;
  }
  swiper[swiper.params.touchEventsTarget === "container" ? "el" : "wrapperEl"].style.cursor = "";
}
const grabCursor = {
  setGrabCursor,
  unsetGrabCursor
};
function closestElement(selector, base = this) {
  function __closestFrom(el) {
    if (!el || el === getDocument() || el === getWindow())
      return null;
    if (el.assignedSlot)
      el = el.assignedSlot;
    const found = el.closest(selector);
    if (!found && !el.getRootNode) {
      return null;
    }
    return found || __closestFrom(el.getRootNode().host);
  }
  return __closestFrom(base);
}
function onTouchStart(event2) {
  const swiper = this;
  const document2 = getDocument();
  const window2 = getWindow();
  const data = swiper.touchEventsData;
  const {
    params,
    touches,
    enabled
  } = swiper;
  if (!enabled)
    return;
  if (swiper.animating && params.preventInteractionOnTransition) {
    return;
  }
  if (!swiper.animating && params.cssMode && params.loop) {
    swiper.loopFix();
  }
  let e = event2;
  if (e.originalEvent)
    e = e.originalEvent;
  let $targetEl = $(e.target);
  if (params.touchEventsTarget === "wrapper") {
    if (!$targetEl.closest(swiper.wrapperEl).length)
      return;
  }
  data.isTouchEvent = e.type === "touchstart";
  if (!data.isTouchEvent && "which" in e && e.which === 3)
    return;
  if (!data.isTouchEvent && "button" in e && e.button > 0)
    return;
  if (data.isTouched && data.isMoved)
    return;
  const swipingClassHasValue = !!params.noSwipingClass && params.noSwipingClass !== "";
  const eventPath = event2.composedPath ? event2.composedPath() : event2.path;
  if (swipingClassHasValue && e.target && e.target.shadowRoot && eventPath) {
    $targetEl = $(eventPath[0]);
  }
  const noSwipingSelector = params.noSwipingSelector ? params.noSwipingSelector : `.${params.noSwipingClass}`;
  const isTargetShadow = !!(e.target && e.target.shadowRoot);
  if (params.noSwiping && (isTargetShadow ? closestElement(noSwipingSelector, $targetEl[0]) : $targetEl.closest(noSwipingSelector)[0])) {
    swiper.allowClick = true;
    return;
  }
  if (params.swipeHandler) {
    if (!$targetEl.closest(params.swipeHandler)[0])
      return;
  }
  touches.currentX = e.type === "touchstart" ? e.targetTouches[0].pageX : e.pageX;
  touches.currentY = e.type === "touchstart" ? e.targetTouches[0].pageY : e.pageY;
  const startX = touches.currentX;
  const startY = touches.currentY;
  const edgeSwipeDetection = params.edgeSwipeDetection || params.iOSEdgeSwipeDetection;
  const edgeSwipeThreshold = params.edgeSwipeThreshold || params.iOSEdgeSwipeThreshold;
  if (edgeSwipeDetection && (startX <= edgeSwipeThreshold || startX >= window2.innerWidth - edgeSwipeThreshold)) {
    if (edgeSwipeDetection === "prevent") {
      event2.preventDefault();
    } else {
      return;
    }
  }
  Object.assign(data, {
    isTouched: true,
    isMoved: false,
    allowTouchCallbacks: true,
    isScrolling: void 0,
    startMoving: void 0
  });
  touches.startX = startX;
  touches.startY = startY;
  data.touchStartTime = now();
  swiper.allowClick = true;
  swiper.updateSize();
  swiper.swipeDirection = void 0;
  if (params.threshold > 0)
    data.allowThresholdMove = false;
  if (e.type !== "touchstart") {
    let preventDefault = true;
    if ($targetEl.is(data.focusableElements)) {
      preventDefault = false;
      if ($targetEl[0].nodeName === "SELECT") {
        data.isTouched = false;
      }
    }
    if (document2.activeElement && $(document2.activeElement).is(data.focusableElements) && document2.activeElement !== $targetEl[0]) {
      document2.activeElement.blur();
    }
    const shouldPreventDefault = preventDefault && swiper.allowTouchMove && params.touchStartPreventDefault;
    if ((params.touchStartForcePreventDefault || shouldPreventDefault) && !$targetEl[0].isContentEditable) {
      e.preventDefault();
    }
  }
  if (swiper.params.freeMode && swiper.params.freeMode.enabled && swiper.freeMode && swiper.animating && !params.cssMode) {
    swiper.freeMode.onTouchStart();
  }
  swiper.emit("touchStart", e);
}
function onTouchMove(event2) {
  const document2 = getDocument();
  const swiper = this;
  const data = swiper.touchEventsData;
  const {
    params,
    touches,
    rtlTranslate: rtl,
    enabled
  } = swiper;
  if (!enabled)
    return;
  let e = event2;
  if (e.originalEvent)
    e = e.originalEvent;
  if (!data.isTouched) {
    if (data.startMoving && data.isScrolling) {
      swiper.emit("touchMoveOpposite", e);
    }
    return;
  }
  if (data.isTouchEvent && e.type !== "touchmove")
    return;
  const targetTouch = e.type === "touchmove" && e.targetTouches && (e.targetTouches[0] || e.changedTouches[0]);
  const pageX = e.type === "touchmove" ? targetTouch.pageX : e.pageX;
  const pageY = e.type === "touchmove" ? targetTouch.pageY : e.pageY;
  if (e.preventedByNestedSwiper) {
    touches.startX = pageX;
    touches.startY = pageY;
    return;
  }
  if (!swiper.allowTouchMove) {
    if (!$(e.target).is(data.focusableElements)) {
      swiper.allowClick = false;
    }
    if (data.isTouched) {
      Object.assign(touches, {
        startX: pageX,
        startY: pageY,
        currentX: pageX,
        currentY: pageY
      });
      data.touchStartTime = now();
    }
    return;
  }
  if (data.isTouchEvent && params.touchReleaseOnEdges && !params.loop) {
    if (swiper.isVertical()) {
      if (pageY < touches.startY && swiper.translate <= swiper.maxTranslate() || pageY > touches.startY && swiper.translate >= swiper.minTranslate()) {
        data.isTouched = false;
        data.isMoved = false;
        return;
      }
    } else if (pageX < touches.startX && swiper.translate <= swiper.maxTranslate() || pageX > touches.startX && swiper.translate >= swiper.minTranslate()) {
      return;
    }
  }
  if (data.isTouchEvent && document2.activeElement) {
    if (e.target === document2.activeElement && $(e.target).is(data.focusableElements)) {
      data.isMoved = true;
      swiper.allowClick = false;
      return;
    }
  }
  if (data.allowTouchCallbacks) {
    swiper.emit("touchMove", e);
  }
  if (e.targetTouches && e.targetTouches.length > 1)
    return;
  touches.currentX = pageX;
  touches.currentY = pageY;
  const diffX = touches.currentX - touches.startX;
  const diffY = touches.currentY - touches.startY;
  if (swiper.params.threshold && Math.sqrt(diffX ** 2 + diffY ** 2) < swiper.params.threshold)
    return;
  if (typeof data.isScrolling === "undefined") {
    let touchAngle;
    if (swiper.isHorizontal() && touches.currentY === touches.startY || swiper.isVertical() && touches.currentX === touches.startX) {
      data.isScrolling = false;
    } else {
      if (diffX * diffX + diffY * diffY >= 25) {
        touchAngle = Math.atan2(Math.abs(diffY), Math.abs(diffX)) * 180 / Math.PI;
        data.isScrolling = swiper.isHorizontal() ? touchAngle > params.touchAngle : 90 - touchAngle > params.touchAngle;
      }
    }
  }
  if (data.isScrolling) {
    swiper.emit("touchMoveOpposite", e);
  }
  if (typeof data.startMoving === "undefined") {
    if (touches.currentX !== touches.startX || touches.currentY !== touches.startY) {
      data.startMoving = true;
    }
  }
  if (data.isScrolling) {
    data.isTouched = false;
    return;
  }
  if (!data.startMoving) {
    return;
  }
  swiper.allowClick = false;
  if (!params.cssMode && e.cancelable) {
    e.preventDefault();
  }
  if (params.touchMoveStopPropagation && !params.nested) {
    e.stopPropagation();
  }
  if (!data.isMoved) {
    if (params.loop && !params.cssMode) {
      swiper.loopFix();
    }
    data.startTranslate = swiper.getTranslate();
    swiper.setTransition(0);
    if (swiper.animating) {
      swiper.$wrapperEl.trigger("webkitTransitionEnd transitionend");
    }
    data.allowMomentumBounce = false;
    if (params.grabCursor && (swiper.allowSlideNext === true || swiper.allowSlidePrev === true)) {
      swiper.setGrabCursor(true);
    }
    swiper.emit("sliderFirstMove", e);
  }
  swiper.emit("sliderMove", e);
  data.isMoved = true;
  let diff = swiper.isHorizontal() ? diffX : diffY;
  touches.diff = diff;
  diff *= params.touchRatio;
  if (rtl)
    diff = -diff;
  swiper.swipeDirection = diff > 0 ? "prev" : "next";
  data.currentTranslate = diff + data.startTranslate;
  let disableParentSwiper = true;
  let resistanceRatio = params.resistanceRatio;
  if (params.touchReleaseOnEdges) {
    resistanceRatio = 0;
  }
  if (diff > 0 && data.currentTranslate > swiper.minTranslate()) {
    disableParentSwiper = false;
    if (params.resistance)
      data.currentTranslate = swiper.minTranslate() - 1 + (-swiper.minTranslate() + data.startTranslate + diff) ** resistanceRatio;
  } else if (diff < 0 && data.currentTranslate < swiper.maxTranslate()) {
    disableParentSwiper = false;
    if (params.resistance)
      data.currentTranslate = swiper.maxTranslate() + 1 - (swiper.maxTranslate() - data.startTranslate - diff) ** resistanceRatio;
  }
  if (disableParentSwiper) {
    e.preventedByNestedSwiper = true;
  }
  if (!swiper.allowSlideNext && swiper.swipeDirection === "next" && data.currentTranslate < data.startTranslate) {
    data.currentTranslate = data.startTranslate;
  }
  if (!swiper.allowSlidePrev && swiper.swipeDirection === "prev" && data.currentTranslate > data.startTranslate) {
    data.currentTranslate = data.startTranslate;
  }
  if (!swiper.allowSlidePrev && !swiper.allowSlideNext) {
    data.currentTranslate = data.startTranslate;
  }
  if (params.threshold > 0) {
    if (Math.abs(diff) > params.threshold || data.allowThresholdMove) {
      if (!data.allowThresholdMove) {
        data.allowThresholdMove = true;
        touches.startX = touches.currentX;
        touches.startY = touches.currentY;
        data.currentTranslate = data.startTranslate;
        touches.diff = swiper.isHorizontal() ? touches.currentX - touches.startX : touches.currentY - touches.startY;
        return;
      }
    } else {
      data.currentTranslate = data.startTranslate;
      return;
    }
  }
  if (!params.followFinger || params.cssMode)
    return;
  if (params.freeMode && params.freeMode.enabled && swiper.freeMode || params.watchSlidesProgress) {
    swiper.updateActiveIndex();
    swiper.updateSlidesClasses();
  }
  if (swiper.params.freeMode && params.freeMode.enabled && swiper.freeMode) {
    swiper.freeMode.onTouchMove();
  }
  swiper.updateProgress(data.currentTranslate);
  swiper.setTranslate(data.currentTranslate);
}
function onTouchEnd(event2) {
  const swiper = this;
  const data = swiper.touchEventsData;
  const {
    params,
    touches,
    rtlTranslate: rtl,
    slidesGrid,
    enabled
  } = swiper;
  if (!enabled)
    return;
  let e = event2;
  if (e.originalEvent)
    e = e.originalEvent;
  if (data.allowTouchCallbacks) {
    swiper.emit("touchEnd", e);
  }
  data.allowTouchCallbacks = false;
  if (!data.isTouched) {
    if (data.isMoved && params.grabCursor) {
      swiper.setGrabCursor(false);
    }
    data.isMoved = false;
    data.startMoving = false;
    return;
  }
  if (params.grabCursor && data.isMoved && data.isTouched && (swiper.allowSlideNext === true || swiper.allowSlidePrev === true)) {
    swiper.setGrabCursor(false);
  }
  const touchEndTime = now();
  const timeDiff = touchEndTime - data.touchStartTime;
  if (swiper.allowClick) {
    const pathTree = e.path || e.composedPath && e.composedPath();
    swiper.updateClickedSlide(pathTree && pathTree[0] || e.target);
    swiper.emit("tap click", e);
    if (timeDiff < 300 && touchEndTime - data.lastClickTime < 300) {
      swiper.emit("doubleTap doubleClick", e);
    }
  }
  data.lastClickTime = now();
  nextTick(() => {
    if (!swiper.destroyed)
      swiper.allowClick = true;
  });
  if (!data.isTouched || !data.isMoved || !swiper.swipeDirection || touches.diff === 0 || data.currentTranslate === data.startTranslate) {
    data.isTouched = false;
    data.isMoved = false;
    data.startMoving = false;
    return;
  }
  data.isTouched = false;
  data.isMoved = false;
  data.startMoving = false;
  let currentPos;
  if (params.followFinger) {
    currentPos = rtl ? swiper.translate : -swiper.translate;
  } else {
    currentPos = -data.currentTranslate;
  }
  if (params.cssMode) {
    return;
  }
  if (swiper.params.freeMode && params.freeMode.enabled) {
    swiper.freeMode.onTouchEnd({
      currentPos
    });
    return;
  }
  let stopIndex = 0;
  let groupSize = swiper.slidesSizesGrid[0];
  for (let i = 0; i < slidesGrid.length; i += i < params.slidesPerGroupSkip ? 1 : params.slidesPerGroup) {
    const increment2 = i < params.slidesPerGroupSkip - 1 ? 1 : params.slidesPerGroup;
    if (typeof slidesGrid[i + increment2] !== "undefined") {
      if (currentPos >= slidesGrid[i] && currentPos < slidesGrid[i + increment2]) {
        stopIndex = i;
        groupSize = slidesGrid[i + increment2] - slidesGrid[i];
      }
    } else if (currentPos >= slidesGrid[i]) {
      stopIndex = i;
      groupSize = slidesGrid[slidesGrid.length - 1] - slidesGrid[slidesGrid.length - 2];
    }
  }
  let rewindFirstIndex = null;
  let rewindLastIndex = null;
  if (params.rewind) {
    if (swiper.isBeginning) {
      rewindLastIndex = swiper.params.virtual && swiper.params.virtual.enabled && swiper.virtual ? swiper.virtual.slides.length - 1 : swiper.slides.length - 1;
    } else if (swiper.isEnd) {
      rewindFirstIndex = 0;
    }
  }
  const ratio = (currentPos - slidesGrid[stopIndex]) / groupSize;
  const increment = stopIndex < params.slidesPerGroupSkip - 1 ? 1 : params.slidesPerGroup;
  if (timeDiff > params.longSwipesMs) {
    if (!params.longSwipes) {
      swiper.slideTo(swiper.activeIndex);
      return;
    }
    if (swiper.swipeDirection === "next") {
      if (ratio >= params.longSwipesRatio)
        swiper.slideTo(params.rewind && swiper.isEnd ? rewindFirstIndex : stopIndex + increment);
      else
        swiper.slideTo(stopIndex);
    }
    if (swiper.swipeDirection === "prev") {
      if (ratio > 1 - params.longSwipesRatio) {
        swiper.slideTo(stopIndex + increment);
      } else if (rewindLastIndex !== null && ratio < 0 && Math.abs(ratio) > params.longSwipesRatio) {
        swiper.slideTo(rewindLastIndex);
      } else {
        swiper.slideTo(stopIndex);
      }
    }
  } else {
    if (!params.shortSwipes) {
      swiper.slideTo(swiper.activeIndex);
      return;
    }
    const isNavButtonTarget = swiper.navigation && (e.target === swiper.navigation.nextEl || e.target === swiper.navigation.prevEl);
    if (!isNavButtonTarget) {
      if (swiper.swipeDirection === "next") {
        swiper.slideTo(rewindFirstIndex !== null ? rewindFirstIndex : stopIndex + increment);
      }
      if (swiper.swipeDirection === "prev") {
        swiper.slideTo(rewindLastIndex !== null ? rewindLastIndex : stopIndex);
      }
    } else if (e.target === swiper.navigation.nextEl) {
      swiper.slideTo(stopIndex + increment);
    } else {
      swiper.slideTo(stopIndex);
    }
  }
}
function onResize() {
  const swiper = this;
  const {
    params,
    el
  } = swiper;
  if (el && el.offsetWidth === 0)
    return;
  if (params.breakpoints) {
    swiper.setBreakpoint();
  }
  const {
    allowSlideNext,
    allowSlidePrev,
    snapGrid
  } = swiper;
  swiper.allowSlideNext = true;
  swiper.allowSlidePrev = true;
  swiper.updateSize();
  swiper.updateSlides();
  swiper.updateSlidesClasses();
  if ((params.slidesPerView === "auto" || params.slidesPerView > 1) && swiper.isEnd && !swiper.isBeginning && !swiper.params.centeredSlides) {
    swiper.slideTo(swiper.slides.length - 1, 0, false, true);
  } else {
    swiper.slideTo(swiper.activeIndex, 0, false, true);
  }
  if (swiper.autoplay && swiper.autoplay.running && swiper.autoplay.paused) {
    swiper.autoplay.run();
  }
  swiper.allowSlidePrev = allowSlidePrev;
  swiper.allowSlideNext = allowSlideNext;
  if (swiper.params.watchOverflow && snapGrid !== swiper.snapGrid) {
    swiper.checkOverflow();
  }
}
function onClick(e) {
  const swiper = this;
  if (!swiper.enabled)
    return;
  if (!swiper.allowClick) {
    if (swiper.params.preventClicks)
      e.preventDefault();
    if (swiper.params.preventClicksPropagation && swiper.animating) {
      e.stopPropagation();
      e.stopImmediatePropagation();
    }
  }
}
function onScroll() {
  const swiper = this;
  const {
    wrapperEl,
    rtlTranslate,
    enabled
  } = swiper;
  if (!enabled)
    return;
  swiper.previousTranslate = swiper.translate;
  if (swiper.isHorizontal()) {
    swiper.translate = -wrapperEl.scrollLeft;
  } else {
    swiper.translate = -wrapperEl.scrollTop;
  }
  if (swiper.translate === 0)
    swiper.translate = 0;
  swiper.updateActiveIndex();
  swiper.updateSlidesClasses();
  let newProgress;
  const translatesDiff = swiper.maxTranslate() - swiper.minTranslate();
  if (translatesDiff === 0) {
    newProgress = 0;
  } else {
    newProgress = (swiper.translate - swiper.minTranslate()) / translatesDiff;
  }
  if (newProgress !== swiper.progress) {
    swiper.updateProgress(rtlTranslate ? -swiper.translate : swiper.translate);
  }
  swiper.emit("setTranslate", swiper.translate, false);
}
let dummyEventAttached = false;
function dummyEventListener() {
}
const events = (swiper, method) => {
  const document2 = getDocument();
  const {
    params,
    touchEvents,
    el,
    wrapperEl,
    device,
    support: support2
  } = swiper;
  const capture = !!params.nested;
  const domMethod = method === "on" ? "addEventListener" : "removeEventListener";
  const swiperMethod = method;
  if (!support2.touch) {
    el[domMethod](touchEvents.start, swiper.onTouchStart, false);
    document2[domMethod](touchEvents.move, swiper.onTouchMove, capture);
    document2[domMethod](touchEvents.end, swiper.onTouchEnd, false);
  } else {
    const passiveListener = touchEvents.start === "touchstart" && support2.passiveListener && params.passiveListeners ? {
      passive: true,
      capture: false
    } : false;
    el[domMethod](touchEvents.start, swiper.onTouchStart, passiveListener);
    el[domMethod](touchEvents.move, swiper.onTouchMove, support2.passiveListener ? {
      passive: false,
      capture
    } : capture);
    el[domMethod](touchEvents.end, swiper.onTouchEnd, passiveListener);
    if (touchEvents.cancel) {
      el[domMethod](touchEvents.cancel, swiper.onTouchEnd, passiveListener);
    }
  }
  if (params.preventClicks || params.preventClicksPropagation) {
    el[domMethod]("click", swiper.onClick, true);
  }
  if (params.cssMode) {
    wrapperEl[domMethod]("scroll", swiper.onScroll);
  }
  if (params.updateOnWindowResize) {
    swiper[swiperMethod](device.ios || device.android ? "resize orientationchange observerUpdate" : "resize observerUpdate", onResize, true);
  } else {
    swiper[swiperMethod]("observerUpdate", onResize, true);
  }
};
function attachEvents() {
  const swiper = this;
  const document2 = getDocument();
  const {
    params,
    support: support2
  } = swiper;
  swiper.onTouchStart = onTouchStart.bind(swiper);
  swiper.onTouchMove = onTouchMove.bind(swiper);
  swiper.onTouchEnd = onTouchEnd.bind(swiper);
  if (params.cssMode) {
    swiper.onScroll = onScroll.bind(swiper);
  }
  swiper.onClick = onClick.bind(swiper);
  if (support2.touch && !dummyEventAttached) {
    document2.addEventListener("touchstart", dummyEventListener);
    dummyEventAttached = true;
  }
  events(swiper, "on");
}
function detachEvents() {
  const swiper = this;
  events(swiper, "off");
}
const events$1 = {
  attachEvents,
  detachEvents
};
const isGridEnabled = (swiper, params) => {
  return swiper.grid && params.grid && params.grid.rows > 1;
};
function setBreakpoint() {
  const swiper = this;
  const {
    activeIndex,
    initialized,
    loopedSlides = 0,
    params,
    $el
  } = swiper;
  const breakpoints2 = params.breakpoints;
  if (!breakpoints2 || breakpoints2 && Object.keys(breakpoints2).length === 0)
    return;
  const breakpoint = swiper.getBreakpoint(breakpoints2, swiper.params.breakpointsBase, swiper.el);
  if (!breakpoint || swiper.currentBreakpoint === breakpoint)
    return;
  const breakpointOnlyParams = breakpoint in breakpoints2 ? breakpoints2[breakpoint] : void 0;
  const breakpointParams = breakpointOnlyParams || swiper.originalParams;
  const wasMultiRow = isGridEnabled(swiper, params);
  const isMultiRow = isGridEnabled(swiper, breakpointParams);
  const wasEnabled = params.enabled;
  if (wasMultiRow && !isMultiRow) {
    $el.removeClass(`${params.containerModifierClass}grid ${params.containerModifierClass}grid-column`);
    swiper.emitContainerClasses();
  } else if (!wasMultiRow && isMultiRow) {
    $el.addClass(`${params.containerModifierClass}grid`);
    if (breakpointParams.grid.fill && breakpointParams.grid.fill === "column" || !breakpointParams.grid.fill && params.grid.fill === "column") {
      $el.addClass(`${params.containerModifierClass}grid-column`);
    }
    swiper.emitContainerClasses();
  }
  ["navigation", "pagination", "scrollbar"].forEach((prop) => {
    const wasModuleEnabled = params[prop] && params[prop].enabled;
    const isModuleEnabled = breakpointParams[prop] && breakpointParams[prop].enabled;
    if (wasModuleEnabled && !isModuleEnabled) {
      swiper[prop].disable();
    }
    if (!wasModuleEnabled && isModuleEnabled) {
      swiper[prop].enable();
    }
  });
  const directionChanged = breakpointParams.direction && breakpointParams.direction !== params.direction;
  const needsReLoop = params.loop && (breakpointParams.slidesPerView !== params.slidesPerView || directionChanged);
  if (directionChanged && initialized) {
    swiper.changeDirection();
  }
  extend$1(swiper.params, breakpointParams);
  const isEnabled = swiper.params.enabled;
  Object.assign(swiper, {
    allowTouchMove: swiper.params.allowTouchMove,
    allowSlideNext: swiper.params.allowSlideNext,
    allowSlidePrev: swiper.params.allowSlidePrev
  });
  if (wasEnabled && !isEnabled) {
    swiper.disable();
  } else if (!wasEnabled && isEnabled) {
    swiper.enable();
  }
  swiper.currentBreakpoint = breakpoint;
  swiper.emit("_beforeBreakpoint", breakpointParams);
  if (needsReLoop && initialized) {
    swiper.loopDestroy();
    swiper.loopCreate();
    swiper.updateSlides();
    swiper.slideTo(activeIndex - loopedSlides + swiper.loopedSlides, 0, false);
  }
  swiper.emit("breakpoint", breakpointParams);
}
function getBreakpoint(breakpoints2, base = "window", containerEl) {
  if (!breakpoints2 || base === "container" && !containerEl)
    return void 0;
  let breakpoint = false;
  const window2 = getWindow();
  const currentHeight = base === "window" ? window2.innerHeight : containerEl.clientHeight;
  const points = Object.keys(breakpoints2).map((point) => {
    if (typeof point === "string" && point.indexOf("@") === 0) {
      const minRatio = parseFloat(point.substr(1));
      const value = currentHeight * minRatio;
      return {
        value,
        point
      };
    }
    return {
      value: point,
      point
    };
  });
  points.sort((a, b) => parseInt(a.value, 10) - parseInt(b.value, 10));
  for (let i = 0; i < points.length; i += 1) {
    const {
      point,
      value
    } = points[i];
    if (base === "window") {
      if (window2.matchMedia(`(min-width: ${value}px)`).matches) {
        breakpoint = point;
      }
    } else if (value <= containerEl.clientWidth) {
      breakpoint = point;
    }
  }
  return breakpoint || "max";
}
const breakpoints = {
  setBreakpoint,
  getBreakpoint
};
function prepareClasses(entries, prefix) {
  const resultClasses = [];
  entries.forEach((item) => {
    if (typeof item === "object") {
      Object.keys(item).forEach((classNames) => {
        if (item[classNames]) {
          resultClasses.push(prefix + classNames);
        }
      });
    } else if (typeof item === "string") {
      resultClasses.push(prefix + item);
    }
  });
  return resultClasses;
}
function addClasses() {
  const swiper = this;
  const {
    classNames,
    params,
    rtl,
    $el,
    device,
    support: support2
  } = swiper;
  const suffixes = prepareClasses(["initialized", params.direction, {
    "pointer-events": !support2.touch
  }, {
    "free-mode": swiper.params.freeMode && params.freeMode.enabled
  }, {
    "autoheight": params.autoHeight
  }, {
    "rtl": rtl
  }, {
    "grid": params.grid && params.grid.rows > 1
  }, {
    "grid-column": params.grid && params.grid.rows > 1 && params.grid.fill === "column"
  }, {
    "android": device.android
  }, {
    "ios": device.ios
  }, {
    "css-mode": params.cssMode
  }, {
    "centered": params.cssMode && params.centeredSlides
  }, {
    "watch-progress": params.watchSlidesProgress
  }], params.containerModifierClass);
  classNames.push(...suffixes);
  $el.addClass([...classNames].join(" "));
  swiper.emitContainerClasses();
}
function removeClasses() {
  const swiper = this;
  const {
    $el,
    classNames
  } = swiper;
  $el.removeClass(classNames.join(" "));
  swiper.emitContainerClasses();
}
const classes = {
  addClasses,
  removeClasses
};
function loadImage(imageEl, src, srcset, sizes, checkForComplete, callback) {
  const window2 = getWindow();
  let image;
  function onReady() {
    if (callback)
      callback();
  }
  const isPicture = $(imageEl).parent("picture")[0];
  if (!isPicture && (!imageEl.complete || !checkForComplete)) {
    if (src) {
      image = new window2.Image();
      image.onload = onReady;
      image.onerror = onReady;
      if (sizes) {
        image.sizes = sizes;
      }
      if (srcset) {
        image.srcset = srcset;
      }
      if (src) {
        image.src = src;
      }
    } else {
      onReady();
    }
  } else {
    onReady();
  }
}
function preloadImages() {
  const swiper = this;
  swiper.imagesToLoad = swiper.$el.find("img");
  function onReady() {
    if (typeof swiper === "undefined" || swiper === null || !swiper || swiper.destroyed)
      return;
    if (swiper.imagesLoaded !== void 0)
      swiper.imagesLoaded += 1;
    if (swiper.imagesLoaded === swiper.imagesToLoad.length) {
      if (swiper.params.updateOnImagesReady)
        swiper.update();
      swiper.emit("imagesReady");
    }
  }
  for (let i = 0; i < swiper.imagesToLoad.length; i += 1) {
    const imageEl = swiper.imagesToLoad[i];
    swiper.loadImage(imageEl, imageEl.currentSrc || imageEl.getAttribute("src"), imageEl.srcset || imageEl.getAttribute("srcset"), imageEl.sizes || imageEl.getAttribute("sizes"), true, onReady);
  }
}
const images = {
  loadImage,
  preloadImages
};
function checkOverflow() {
  const swiper = this;
  const {
    isLocked: wasLocked,
    params
  } = swiper;
  const {
    slidesOffsetBefore
  } = params;
  if (slidesOffsetBefore) {
    const lastSlideIndex = swiper.slides.length - 1;
    const lastSlideRightEdge = swiper.slidesGrid[lastSlideIndex] + swiper.slidesSizesGrid[lastSlideIndex] + slidesOffsetBefore * 2;
    swiper.isLocked = swiper.size > lastSlideRightEdge;
  } else {
    swiper.isLocked = swiper.snapGrid.length === 1;
  }
  if (params.allowSlideNext === true) {
    swiper.allowSlideNext = !swiper.isLocked;
  }
  if (params.allowSlidePrev === true) {
    swiper.allowSlidePrev = !swiper.isLocked;
  }
  if (wasLocked && wasLocked !== swiper.isLocked) {
    swiper.isEnd = false;
  }
  if (wasLocked !== swiper.isLocked) {
    swiper.emit(swiper.isLocked ? "lock" : "unlock");
  }
}
const checkOverflow$1 = {
  checkOverflow
};
const defaults = {
  init: true,
  direction: "horizontal",
  touchEventsTarget: "wrapper",
  initialSlide: 0,
  speed: 300,
  cssMode: false,
  updateOnWindowResize: true,
  resizeObserver: true,
  nested: false,
  createElements: false,
  enabled: true,
  focusableElements: "input, select, option, textarea, button, video, label",
  // Overrides
  width: null,
  height: null,
  //
  preventInteractionOnTransition: false,
  // ssr
  userAgent: null,
  url: null,
  // To support iOS's swipe-to-go-back gesture (when being used in-app).
  edgeSwipeDetection: false,
  edgeSwipeThreshold: 20,
  // Autoheight
  autoHeight: false,
  // Set wrapper width
  setWrapperSize: false,
  // Virtual Translate
  virtualTranslate: false,
  // Effects
  effect: "slide",
  // 'slide' or 'fade' or 'cube' or 'coverflow' or 'flip'
  // Breakpoints
  breakpoints: void 0,
  breakpointsBase: "window",
  // Slides grid
  spaceBetween: 0,
  slidesPerView: 1,
  slidesPerGroup: 1,
  slidesPerGroupSkip: 0,
  slidesPerGroupAuto: false,
  centeredSlides: false,
  centeredSlidesBounds: false,
  slidesOffsetBefore: 0,
  // in px
  slidesOffsetAfter: 0,
  // in px
  normalizeSlideIndex: true,
  centerInsufficientSlides: false,
  // Disable swiper and hide navigation when container not overflow
  watchOverflow: true,
  // Round length
  roundLengths: false,
  // Touches
  touchRatio: 1,
  touchAngle: 45,
  simulateTouch: true,
  shortSwipes: true,
  longSwipes: true,
  longSwipesRatio: 0.5,
  longSwipesMs: 300,
  followFinger: true,
  allowTouchMove: true,
  threshold: 0,
  touchMoveStopPropagation: false,
  touchStartPreventDefault: true,
  touchStartForcePreventDefault: false,
  touchReleaseOnEdges: false,
  // Unique Navigation Elements
  uniqueNavElements: true,
  // Resistance
  resistance: true,
  resistanceRatio: 0.85,
  // Progress
  watchSlidesProgress: false,
  // Cursor
  grabCursor: false,
  // Clicks
  preventClicks: true,
  preventClicksPropagation: true,
  slideToClickedSlide: false,
  // Images
  preloadImages: true,
  updateOnImagesReady: true,
  // loop
  loop: false,
  loopAdditionalSlides: 0,
  loopedSlides: null,
  loopedSlidesLimit: true,
  loopFillGroupWithBlank: false,
  loopPreventsSlide: true,
  // rewind
  rewind: false,
  // Swiping/no swiping
  allowSlidePrev: true,
  allowSlideNext: true,
  swipeHandler: null,
  // '.swipe-handler',
  noSwiping: true,
  noSwipingClass: "swiper-no-swiping",
  noSwipingSelector: null,
  // Passive Listeners
  passiveListeners: true,
  maxBackfaceHiddenSlides: 10,
  // NS
  containerModifierClass: "swiper-",
  // NEW
  slideClass: "swiper-slide",
  slideBlankClass: "swiper-slide-invisible-blank",
  slideActiveClass: "swiper-slide-active",
  slideDuplicateActiveClass: "swiper-slide-duplicate-active",
  slideVisibleClass: "swiper-slide-visible",
  slideDuplicateClass: "swiper-slide-duplicate",
  slideNextClass: "swiper-slide-next",
  slideDuplicateNextClass: "swiper-slide-duplicate-next",
  slidePrevClass: "swiper-slide-prev",
  slideDuplicatePrevClass: "swiper-slide-duplicate-prev",
  wrapperClass: "swiper-wrapper",
  // Callbacks
  runCallbacksOnInit: true,
  // Internals
  _emitClasses: false
};
function moduleExtendParams(params, allModulesParams) {
  return function extendParams(obj = {}) {
    const moduleParamName = Object.keys(obj)[0];
    const moduleParams = obj[moduleParamName];
    if (typeof moduleParams !== "object" || moduleParams === null) {
      extend$1(allModulesParams, obj);
      return;
    }
    if (["navigation", "pagination", "scrollbar"].indexOf(moduleParamName) >= 0 && params[moduleParamName] === true) {
      params[moduleParamName] = {
        auto: true
      };
    }
    if (!(moduleParamName in params && "enabled" in moduleParams)) {
      extend$1(allModulesParams, obj);
      return;
    }
    if (params[moduleParamName] === true) {
      params[moduleParamName] = {
        enabled: true
      };
    }
    if (typeof params[moduleParamName] === "object" && !("enabled" in params[moduleParamName])) {
      params[moduleParamName].enabled = true;
    }
    if (!params[moduleParamName])
      params[moduleParamName] = {
        enabled: false
      };
    extend$1(allModulesParams, obj);
  };
}
const prototypes = {
  eventsEmitter,
  update,
  translate,
  transition,
  slide,
  loop,
  grabCursor,
  events: events$1,
  breakpoints,
  checkOverflow: checkOverflow$1,
  classes,
  images
};
const extendedDefaults = {};
let Swiper$1 = class Swiper {
  constructor(...args) {
    let el;
    let params;
    if (args.length === 1 && args[0].constructor && Object.prototype.toString.call(args[0]).slice(8, -1) === "Object") {
      params = args[0];
    } else {
      [el, params] = args;
    }
    if (!params)
      params = {};
    params = extend$1({}, params);
    if (el && !params.el)
      params.el = el;
    if (params.el && $(params.el).length > 1) {
      const swipers = [];
      $(params.el).each((containerEl) => {
        const newParams = extend$1({}, params, {
          el: containerEl
        });
        swipers.push(new Swiper(newParams));
      });
      return swipers;
    }
    const swiper = this;
    swiper.__swiper__ = true;
    swiper.support = getSupport();
    swiper.device = getDevice({
      userAgent: params.userAgent
    });
    swiper.browser = getBrowser();
    swiper.eventsListeners = {};
    swiper.eventsAnyListeners = [];
    swiper.modules = [...swiper.__modules__];
    if (params.modules && Array.isArray(params.modules)) {
      swiper.modules.push(...params.modules);
    }
    const allModulesParams = {};
    swiper.modules.forEach((mod) => {
      mod({
        swiper,
        extendParams: moduleExtendParams(params, allModulesParams),
        on: swiper.on.bind(swiper),
        once: swiper.once.bind(swiper),
        off: swiper.off.bind(swiper),
        emit: swiper.emit.bind(swiper)
      });
    });
    const swiperParams = extend$1({}, defaults, allModulesParams);
    swiper.params = extend$1({}, swiperParams, extendedDefaults, params);
    swiper.originalParams = extend$1({}, swiper.params);
    swiper.passedParams = extend$1({}, params);
    if (swiper.params && swiper.params.on) {
      Object.keys(swiper.params.on).forEach((eventName) => {
        swiper.on(eventName, swiper.params.on[eventName]);
      });
    }
    if (swiper.params && swiper.params.onAny) {
      swiper.onAny(swiper.params.onAny);
    }
    swiper.$ = $;
    Object.assign(swiper, {
      enabled: swiper.params.enabled,
      el,
      // Classes
      classNames: [],
      // Slides
      slides: $(),
      slidesGrid: [],
      snapGrid: [],
      slidesSizesGrid: [],
      // isDirection
      isHorizontal() {
        return swiper.params.direction === "horizontal";
      },
      isVertical() {
        return swiper.params.direction === "vertical";
      },
      // Indexes
      activeIndex: 0,
      realIndex: 0,
      //
      isBeginning: true,
      isEnd: false,
      // Props
      translate: 0,
      previousTranslate: 0,
      progress: 0,
      velocity: 0,
      animating: false,
      // Locks
      allowSlideNext: swiper.params.allowSlideNext,
      allowSlidePrev: swiper.params.allowSlidePrev,
      // Touch Events
      touchEvents: function touchEvents() {
        const touch = ["touchstart", "touchmove", "touchend", "touchcancel"];
        const desktop = ["pointerdown", "pointermove", "pointerup"];
        swiper.touchEventsTouch = {
          start: touch[0],
          move: touch[1],
          end: touch[2],
          cancel: touch[3]
        };
        swiper.touchEventsDesktop = {
          start: desktop[0],
          move: desktop[1],
          end: desktop[2]
        };
        return swiper.support.touch || !swiper.params.simulateTouch ? swiper.touchEventsTouch : swiper.touchEventsDesktop;
      }(),
      touchEventsData: {
        isTouched: void 0,
        isMoved: void 0,
        allowTouchCallbacks: void 0,
        touchStartTime: void 0,
        isScrolling: void 0,
        currentTranslate: void 0,
        startTranslate: void 0,
        allowThresholdMove: void 0,
        // Form elements to match
        focusableElements: swiper.params.focusableElements,
        // Last click time
        lastClickTime: now(),
        clickTimeout: void 0,
        // Velocities
        velocities: [],
        allowMomentumBounce: void 0,
        isTouchEvent: void 0,
        startMoving: void 0
      },
      // Clicks
      allowClick: true,
      // Touches
      allowTouchMove: swiper.params.allowTouchMove,
      touches: {
        startX: 0,
        startY: 0,
        currentX: 0,
        currentY: 0,
        diff: 0
      },
      // Images
      imagesToLoad: [],
      imagesLoaded: 0
    });
    swiper.emit("_swiper");
    if (swiper.params.init) {
      swiper.init();
    }
    return swiper;
  }
  enable() {
    const swiper = this;
    if (swiper.enabled)
      return;
    swiper.enabled = true;
    if (swiper.params.grabCursor) {
      swiper.setGrabCursor();
    }
    swiper.emit("enable");
  }
  disable() {
    const swiper = this;
    if (!swiper.enabled)
      return;
    swiper.enabled = false;
    if (swiper.params.grabCursor) {
      swiper.unsetGrabCursor();
    }
    swiper.emit("disable");
  }
  setProgress(progress, speed) {
    const swiper = this;
    progress = Math.min(Math.max(progress, 0), 1);
    const min = swiper.minTranslate();
    const max = swiper.maxTranslate();
    const current = (max - min) * progress + min;
    swiper.translateTo(current, typeof speed === "undefined" ? 0 : speed);
    swiper.updateActiveIndex();
    swiper.updateSlidesClasses();
  }
  emitContainerClasses() {
    const swiper = this;
    if (!swiper.params._emitClasses || !swiper.el)
      return;
    const cls = swiper.el.className.split(" ").filter((className) => {
      return className.indexOf("swiper") === 0 || className.indexOf(swiper.params.containerModifierClass) === 0;
    });
    swiper.emit("_containerClasses", cls.join(" "));
  }
  getSlideClasses(slideEl) {
    const swiper = this;
    if (swiper.destroyed)
      return "";
    return slideEl.className.split(" ").filter((className) => {
      return className.indexOf("swiper-slide") === 0 || className.indexOf(swiper.params.slideClass) === 0;
    }).join(" ");
  }
  emitSlidesClasses() {
    const swiper = this;
    if (!swiper.params._emitClasses || !swiper.el)
      return;
    const updates = [];
    swiper.slides.each((slideEl) => {
      const classNames = swiper.getSlideClasses(slideEl);
      updates.push({
        slideEl,
        classNames
      });
      swiper.emit("_slideClass", slideEl, classNames);
    });
    swiper.emit("_slideClasses", updates);
  }
  slidesPerViewDynamic(view = "current", exact = false) {
    const swiper = this;
    const {
      params,
      slides,
      slidesGrid,
      slidesSizesGrid,
      size: swiperSize,
      activeIndex
    } = swiper;
    let spv = 1;
    if (params.centeredSlides) {
      let slideSize = slides[activeIndex].swiperSlideSize;
      let breakLoop;
      for (let i = activeIndex + 1; i < slides.length; i += 1) {
        if (slides[i] && !breakLoop) {
          slideSize += slides[i].swiperSlideSize;
          spv += 1;
          if (slideSize > swiperSize)
            breakLoop = true;
        }
      }
      for (let i = activeIndex - 1; i >= 0; i -= 1) {
        if (slides[i] && !breakLoop) {
          slideSize += slides[i].swiperSlideSize;
          spv += 1;
          if (slideSize > swiperSize)
            breakLoop = true;
        }
      }
    } else {
      if (view === "current") {
        for (let i = activeIndex + 1; i < slides.length; i += 1) {
          const slideInView = exact ? slidesGrid[i] + slidesSizesGrid[i] - slidesGrid[activeIndex] < swiperSize : slidesGrid[i] - slidesGrid[activeIndex] < swiperSize;
          if (slideInView) {
            spv += 1;
          }
        }
      } else {
        for (let i = activeIndex - 1; i >= 0; i -= 1) {
          const slideInView = slidesGrid[activeIndex] - slidesGrid[i] < swiperSize;
          if (slideInView) {
            spv += 1;
          }
        }
      }
    }
    return spv;
  }
  update() {
    const swiper = this;
    if (!swiper || swiper.destroyed)
      return;
    const {
      snapGrid,
      params
    } = swiper;
    if (params.breakpoints) {
      swiper.setBreakpoint();
    }
    swiper.updateSize();
    swiper.updateSlides();
    swiper.updateProgress();
    swiper.updateSlidesClasses();
    function setTranslate2() {
      const translateValue = swiper.rtlTranslate ? swiper.translate * -1 : swiper.translate;
      const newTranslate = Math.min(Math.max(translateValue, swiper.maxTranslate()), swiper.minTranslate());
      swiper.setTranslate(newTranslate);
      swiper.updateActiveIndex();
      swiper.updateSlidesClasses();
    }
    let translated;
    if (swiper.params.freeMode && swiper.params.freeMode.enabled) {
      setTranslate2();
      if (swiper.params.autoHeight) {
        swiper.updateAutoHeight();
      }
    } else {
      if ((swiper.params.slidesPerView === "auto" || swiper.params.slidesPerView > 1) && swiper.isEnd && !swiper.params.centeredSlides) {
        translated = swiper.slideTo(swiper.slides.length - 1, 0, false, true);
      } else {
        translated = swiper.slideTo(swiper.activeIndex, 0, false, true);
      }
      if (!translated) {
        setTranslate2();
      }
    }
    if (params.watchOverflow && snapGrid !== swiper.snapGrid) {
      swiper.checkOverflow();
    }
    swiper.emit("update");
  }
  changeDirection(newDirection, needUpdate = true) {
    const swiper = this;
    const currentDirection = swiper.params.direction;
    if (!newDirection) {
      newDirection = currentDirection === "horizontal" ? "vertical" : "horizontal";
    }
    if (newDirection === currentDirection || newDirection !== "horizontal" && newDirection !== "vertical") {
      return swiper;
    }
    swiper.$el.removeClass(`${swiper.params.containerModifierClass}${currentDirection}`).addClass(`${swiper.params.containerModifierClass}${newDirection}`);
    swiper.emitContainerClasses();
    swiper.params.direction = newDirection;
    swiper.slides.each((slideEl) => {
      if (newDirection === "vertical") {
        slideEl.style.width = "";
      } else {
        slideEl.style.height = "";
      }
    });
    swiper.emit("changeDirection");
    if (needUpdate)
      swiper.update();
    return swiper;
  }
  changeLanguageDirection(direction) {
    const swiper = this;
    if (swiper.rtl && direction === "rtl" || !swiper.rtl && direction === "ltr")
      return;
    swiper.rtl = direction === "rtl";
    swiper.rtlTranslate = swiper.params.direction === "horizontal" && swiper.rtl;
    if (swiper.rtl) {
      swiper.$el.addClass(`${swiper.params.containerModifierClass}rtl`);
      swiper.el.dir = "rtl";
    } else {
      swiper.$el.removeClass(`${swiper.params.containerModifierClass}rtl`);
      swiper.el.dir = "ltr";
    }
    swiper.update();
  }
  mount(el) {
    const swiper = this;
    if (swiper.mounted)
      return true;
    const $el = $(el || swiper.params.el);
    el = $el[0];
    if (!el) {
      return false;
    }
    el.swiper = swiper;
    const getWrapperSelector = () => {
      return `.${(swiper.params.wrapperClass || "").trim().split(" ").join(".")}`;
    };
    const getWrapper = () => {
      if (el && el.shadowRoot && el.shadowRoot.querySelector) {
        const res = $(el.shadowRoot.querySelector(getWrapperSelector()));
        res.children = (options) => $el.children(options);
        return res;
      }
      if (!$el.children) {
        return $($el).children(getWrapperSelector());
      }
      return $el.children(getWrapperSelector());
    };
    let $wrapperEl = getWrapper();
    if ($wrapperEl.length === 0 && swiper.params.createElements) {
      const document2 = getDocument();
      const wrapper = document2.createElement("div");
      $wrapperEl = $(wrapper);
      wrapper.className = swiper.params.wrapperClass;
      $el.append(wrapper);
      $el.children(`.${swiper.params.slideClass}`).each((slideEl) => {
        $wrapperEl.append(slideEl);
      });
    }
    Object.assign(swiper, {
      $el,
      el,
      $wrapperEl,
      wrapperEl: $wrapperEl[0],
      mounted: true,
      // RTL
      rtl: el.dir.toLowerCase() === "rtl" || $el.css("direction") === "rtl",
      rtlTranslate: swiper.params.direction === "horizontal" && (el.dir.toLowerCase() === "rtl" || $el.css("direction") === "rtl"),
      wrongRTL: $wrapperEl.css("display") === "-webkit-box"
    });
    return true;
  }
  init(el) {
    const swiper = this;
    if (swiper.initialized)
      return swiper;
    const mounted = swiper.mount(el);
    if (mounted === false)
      return swiper;
    swiper.emit("beforeInit");
    if (swiper.params.breakpoints) {
      swiper.setBreakpoint();
    }
    swiper.addClasses();
    if (swiper.params.loop) {
      swiper.loopCreate();
    }
    swiper.updateSize();
    swiper.updateSlides();
    if (swiper.params.watchOverflow) {
      swiper.checkOverflow();
    }
    if (swiper.params.grabCursor && swiper.enabled) {
      swiper.setGrabCursor();
    }
    if (swiper.params.preloadImages) {
      swiper.preloadImages();
    }
    if (swiper.params.loop) {
      swiper.slideTo(swiper.params.initialSlide + swiper.loopedSlides, 0, swiper.params.runCallbacksOnInit, false, true);
    } else {
      swiper.slideTo(swiper.params.initialSlide, 0, swiper.params.runCallbacksOnInit, false, true);
    }
    swiper.attachEvents();
    swiper.initialized = true;
    swiper.emit("init");
    swiper.emit("afterInit");
    return swiper;
  }
  destroy(deleteInstance = true, cleanStyles = true) {
    const swiper = this;
    const {
      params,
      $el,
      $wrapperEl,
      slides
    } = swiper;
    if (typeof swiper.params === "undefined" || swiper.destroyed) {
      return null;
    }
    swiper.emit("beforeDestroy");
    swiper.initialized = false;
    swiper.detachEvents();
    if (params.loop) {
      swiper.loopDestroy();
    }
    if (cleanStyles) {
      swiper.removeClasses();
      $el.removeAttr("style");
      $wrapperEl.removeAttr("style");
      if (slides && slides.length) {
        slides.removeClass([params.slideVisibleClass, params.slideActiveClass, params.slideNextClass, params.slidePrevClass].join(" ")).removeAttr("style").removeAttr("data-swiper-slide-index");
      }
    }
    swiper.emit("destroy");
    Object.keys(swiper.eventsListeners).forEach((eventName) => {
      swiper.off(eventName);
    });
    if (deleteInstance !== false) {
      swiper.$el[0].swiper = null;
      deleteProps(swiper);
    }
    swiper.destroyed = true;
    return null;
  }
  static extendDefaults(newDefaults) {
    extend$1(extendedDefaults, newDefaults);
  }
  static get extendedDefaults() {
    return extendedDefaults;
  }
  static get defaults() {
    return defaults;
  }
  static installModule(mod) {
    if (!Swiper.prototype.__modules__)
      Swiper.prototype.__modules__ = [];
    const modules = Swiper.prototype.__modules__;
    if (typeof mod === "function" && modules.indexOf(mod) < 0) {
      modules.push(mod);
    }
  }
  static use(module) {
    if (Array.isArray(module)) {
      module.forEach((m) => Swiper.installModule(m));
      return Swiper;
    }
    Swiper.installModule(module);
    return Swiper;
  }
};
Object.keys(prototypes).forEach((prototypeGroup) => {
  Object.keys(prototypes[prototypeGroup]).forEach((protoMethod) => {
    Swiper$1.prototype[protoMethod] = prototypes[prototypeGroup][protoMethod];
  });
});
Swiper$1.use([Resize, Observer]);
function Virtual({
  swiper,
  extendParams,
  on: on2,
  emit
}) {
  extendParams({
    virtual: {
      enabled: false,
      slides: [],
      cache: true,
      renderSlide: null,
      renderExternal: null,
      renderExternalUpdate: true,
      addSlidesBefore: 0,
      addSlidesAfter: 0
    }
  });
  let cssModeTimeout;
  swiper.virtual = {
    cache: {},
    from: void 0,
    to: void 0,
    slides: [],
    offset: 0,
    slidesGrid: []
  };
  function renderSlide(slide2, index2) {
    const params = swiper.params.virtual;
    if (params.cache && swiper.virtual.cache[index2]) {
      return swiper.virtual.cache[index2];
    }
    const $slideEl = params.renderSlide ? $(params.renderSlide.call(swiper, slide2, index2)) : $(`<div class="${swiper.params.slideClass}" data-swiper-slide-index="${index2}">${slide2}</div>`);
    if (!$slideEl.attr("data-swiper-slide-index"))
      $slideEl.attr("data-swiper-slide-index", index2);
    if (params.cache)
      swiper.virtual.cache[index2] = $slideEl;
    return $slideEl;
  }
  function update2(force) {
    const {
      slidesPerView,
      slidesPerGroup,
      centeredSlides
    } = swiper.params;
    const {
      addSlidesBefore,
      addSlidesAfter
    } = swiper.params.virtual;
    const {
      from: previousFrom,
      to: previousTo,
      slides,
      slidesGrid: previousSlidesGrid,
      offset: previousOffset
    } = swiper.virtual;
    if (!swiper.params.cssMode) {
      swiper.updateActiveIndex();
    }
    const activeIndex = swiper.activeIndex || 0;
    let offsetProp;
    if (swiper.rtlTranslate)
      offsetProp = "right";
    else
      offsetProp = swiper.isHorizontal() ? "left" : "top";
    let slidesAfter;
    let slidesBefore;
    if (centeredSlides) {
      slidesAfter = Math.floor(slidesPerView / 2) + slidesPerGroup + addSlidesAfter;
      slidesBefore = Math.floor(slidesPerView / 2) + slidesPerGroup + addSlidesBefore;
    } else {
      slidesAfter = slidesPerView + (slidesPerGroup - 1) + addSlidesAfter;
      slidesBefore = slidesPerGroup + addSlidesBefore;
    }
    const from = Math.max((activeIndex || 0) - slidesBefore, 0);
    const to = Math.min((activeIndex || 0) + slidesAfter, slides.length - 1);
    const offset2 = (swiper.slidesGrid[from] || 0) - (swiper.slidesGrid[0] || 0);
    Object.assign(swiper.virtual, {
      from,
      to,
      offset: offset2,
      slidesGrid: swiper.slidesGrid
    });
    function onRendered() {
      swiper.updateSlides();
      swiper.updateProgress();
      swiper.updateSlidesClasses();
      if (swiper.lazy && swiper.params.lazy.enabled) {
        swiper.lazy.load();
      }
      emit("virtualUpdate");
    }
    if (previousFrom === from && previousTo === to && !force) {
      if (swiper.slidesGrid !== previousSlidesGrid && offset2 !== previousOffset) {
        swiper.slides.css(offsetProp, `${offset2}px`);
      }
      swiper.updateProgress();
      emit("virtualUpdate");
      return;
    }
    if (swiper.params.virtual.renderExternal) {
      swiper.params.virtual.renderExternal.call(swiper, {
        offset: offset2,
        from,
        to,
        slides: function getSlides() {
          const slidesToRender = [];
          for (let i = from; i <= to; i += 1) {
            slidesToRender.push(slides[i]);
          }
          return slidesToRender;
        }()
      });
      if (swiper.params.virtual.renderExternalUpdate) {
        onRendered();
      } else {
        emit("virtualUpdate");
      }
      return;
    }
    const prependIndexes = [];
    const appendIndexes = [];
    if (force) {
      swiper.$wrapperEl.find(`.${swiper.params.slideClass}`).remove();
    } else {
      for (let i = previousFrom; i <= previousTo; i += 1) {
        if (i < from || i > to) {
          swiper.$wrapperEl.find(`.${swiper.params.slideClass}[data-swiper-slide-index="${i}"]`).remove();
        }
      }
    }
    for (let i = 0; i < slides.length; i += 1) {
      if (i >= from && i <= to) {
        if (typeof previousTo === "undefined" || force) {
          appendIndexes.push(i);
        } else {
          if (i > previousTo)
            appendIndexes.push(i);
          if (i < previousFrom)
            prependIndexes.push(i);
        }
      }
    }
    appendIndexes.forEach((index2) => {
      swiper.$wrapperEl.append(renderSlide(slides[index2], index2));
    });
    prependIndexes.sort((a, b) => b - a).forEach((index2) => {
      swiper.$wrapperEl.prepend(renderSlide(slides[index2], index2));
    });
    swiper.$wrapperEl.children(".swiper-slide").css(offsetProp, `${offset2}px`);
    onRendered();
  }
  function appendSlide2(slides) {
    if (typeof slides === "object" && "length" in slides) {
      for (let i = 0; i < slides.length; i += 1) {
        if (slides[i])
          swiper.virtual.slides.push(slides[i]);
      }
    } else {
      swiper.virtual.slides.push(slides);
    }
    update2(true);
  }
  function prependSlide2(slides) {
    const activeIndex = swiper.activeIndex;
    let newActiveIndex = activeIndex + 1;
    let numberOfNewSlides = 1;
    if (Array.isArray(slides)) {
      for (let i = 0; i < slides.length; i += 1) {
        if (slides[i])
          swiper.virtual.slides.unshift(slides[i]);
      }
      newActiveIndex = activeIndex + slides.length;
      numberOfNewSlides = slides.length;
    } else {
      swiper.virtual.slides.unshift(slides);
    }
    if (swiper.params.virtual.cache) {
      const cache = swiper.virtual.cache;
      const newCache = {};
      Object.keys(cache).forEach((cachedIndex) => {
        const $cachedEl = cache[cachedIndex];
        const cachedElIndex = $cachedEl.attr("data-swiper-slide-index");
        if (cachedElIndex) {
          $cachedEl.attr("data-swiper-slide-index", parseInt(cachedElIndex, 10) + numberOfNewSlides);
        }
        newCache[parseInt(cachedIndex, 10) + numberOfNewSlides] = $cachedEl;
      });
      swiper.virtual.cache = newCache;
    }
    update2(true);
    swiper.slideTo(newActiveIndex, 0);
  }
  function removeSlide2(slidesIndexes) {
    if (typeof slidesIndexes === "undefined" || slidesIndexes === null)
      return;
    let activeIndex = swiper.activeIndex;
    if (Array.isArray(slidesIndexes)) {
      for (let i = slidesIndexes.length - 1; i >= 0; i -= 1) {
        swiper.virtual.slides.splice(slidesIndexes[i], 1);
        if (swiper.params.virtual.cache) {
          delete swiper.virtual.cache[slidesIndexes[i]];
        }
        if (slidesIndexes[i] < activeIndex)
          activeIndex -= 1;
        activeIndex = Math.max(activeIndex, 0);
      }
    } else {
      swiper.virtual.slides.splice(slidesIndexes, 1);
      if (swiper.params.virtual.cache) {
        delete swiper.virtual.cache[slidesIndexes];
      }
      if (slidesIndexes < activeIndex)
        activeIndex -= 1;
      activeIndex = Math.max(activeIndex, 0);
    }
    update2(true);
    swiper.slideTo(activeIndex, 0);
  }
  function removeAllSlides2() {
    swiper.virtual.slides = [];
    if (swiper.params.virtual.cache) {
      swiper.virtual.cache = {};
    }
    update2(true);
    swiper.slideTo(0, 0);
  }
  on2("beforeInit", () => {
    if (!swiper.params.virtual.enabled)
      return;
    swiper.virtual.slides = swiper.params.virtual.slides;
    swiper.classNames.push(`${swiper.params.containerModifierClass}virtual`);
    swiper.params.watchSlidesProgress = true;
    swiper.originalParams.watchSlidesProgress = true;
    if (!swiper.params.initialSlide) {
      update2();
    }
  });
  on2("setTranslate", () => {
    if (!swiper.params.virtual.enabled)
      return;
    if (swiper.params.cssMode && !swiper._immediateVirtual) {
      clearTimeout(cssModeTimeout);
      cssModeTimeout = setTimeout(() => {
        update2();
      }, 100);
    } else {
      update2();
    }
  });
  on2("init update resize", () => {
    if (!swiper.params.virtual.enabled)
      return;
    if (swiper.params.cssMode) {
      setCSSProperty(swiper.wrapperEl, "--swiper-virtual-size", `${swiper.virtualSize}px`);
    }
  });
  Object.assign(swiper.virtual, {
    appendSlide: appendSlide2,
    prependSlide: prependSlide2,
    removeSlide: removeSlide2,
    removeAllSlides: removeAllSlides2,
    update: update2
  });
}
function Keyboard({
  swiper,
  extendParams,
  on: on2,
  emit
}) {
  const document2 = getDocument();
  const window2 = getWindow();
  swiper.keyboard = {
    enabled: false
  };
  extendParams({
    keyboard: {
      enabled: false,
      onlyInViewport: true,
      pageUpDown: true
    }
  });
  function handle(event2) {
    if (!swiper.enabled)
      return;
    const {
      rtlTranslate: rtl
    } = swiper;
    let e = event2;
    if (e.originalEvent)
      e = e.originalEvent;
    const kc = e.keyCode || e.charCode;
    const pageUpDown = swiper.params.keyboard.pageUpDown;
    const isPageUp = pageUpDown && kc === 33;
    const isPageDown = pageUpDown && kc === 34;
    const isArrowLeft = kc === 37;
    const isArrowRight = kc === 39;
    const isArrowUp = kc === 38;
    const isArrowDown = kc === 40;
    if (!swiper.allowSlideNext && (swiper.isHorizontal() && isArrowRight || swiper.isVertical() && isArrowDown || isPageDown)) {
      return false;
    }
    if (!swiper.allowSlidePrev && (swiper.isHorizontal() && isArrowLeft || swiper.isVertical() && isArrowUp || isPageUp)) {
      return false;
    }
    if (e.shiftKey || e.altKey || e.ctrlKey || e.metaKey) {
      return void 0;
    }
    if (document2.activeElement && document2.activeElement.nodeName && (document2.activeElement.nodeName.toLowerCase() === "input" || document2.activeElement.nodeName.toLowerCase() === "textarea")) {
      return void 0;
    }
    if (swiper.params.keyboard.onlyInViewport && (isPageUp || isPageDown || isArrowLeft || isArrowRight || isArrowUp || isArrowDown)) {
      let inView = false;
      if (swiper.$el.parents(`.${swiper.params.slideClass}`).length > 0 && swiper.$el.parents(`.${swiper.params.slideActiveClass}`).length === 0) {
        return void 0;
      }
      const $el = swiper.$el;
      const swiperWidth = $el[0].clientWidth;
      const swiperHeight = $el[0].clientHeight;
      const windowWidth = window2.innerWidth;
      const windowHeight = window2.innerHeight;
      const swiperOffset = swiper.$el.offset();
      if (rtl)
        swiperOffset.left -= swiper.$el[0].scrollLeft;
      const swiperCoord = [[swiperOffset.left, swiperOffset.top], [swiperOffset.left + swiperWidth, swiperOffset.top], [swiperOffset.left, swiperOffset.top + swiperHeight], [swiperOffset.left + swiperWidth, swiperOffset.top + swiperHeight]];
      for (let i = 0; i < swiperCoord.length; i += 1) {
        const point = swiperCoord[i];
        if (point[0] >= 0 && point[0] <= windowWidth && point[1] >= 0 && point[1] <= windowHeight) {
          if (point[0] === 0 && point[1] === 0)
            continue;
          inView = true;
        }
      }
      if (!inView)
        return void 0;
    }
    if (swiper.isHorizontal()) {
      if (isPageUp || isPageDown || isArrowLeft || isArrowRight) {
        if (e.preventDefault)
          e.preventDefault();
        else
          e.returnValue = false;
      }
      if ((isPageDown || isArrowRight) && !rtl || (isPageUp || isArrowLeft) && rtl)
        swiper.slideNext();
      if ((isPageUp || isArrowLeft) && !rtl || (isPageDown || isArrowRight) && rtl)
        swiper.slidePrev();
    } else {
      if (isPageUp || isPageDown || isArrowUp || isArrowDown) {
        if (e.preventDefault)
          e.preventDefault();
        else
          e.returnValue = false;
      }
      if (isPageDown || isArrowDown)
        swiper.slideNext();
      if (isPageUp || isArrowUp)
        swiper.slidePrev();
    }
    emit("keyPress", kc);
    return void 0;
  }
  function enable() {
    if (swiper.keyboard.enabled)
      return;
    $(document2).on("keydown", handle);
    swiper.keyboard.enabled = true;
  }
  function disable() {
    if (!swiper.keyboard.enabled)
      return;
    $(document2).off("keydown", handle);
    swiper.keyboard.enabled = false;
  }
  on2("init", () => {
    if (swiper.params.keyboard.enabled) {
      enable();
    }
  });
  on2("destroy", () => {
    if (swiper.keyboard.enabled) {
      disable();
    }
  });
  Object.assign(swiper.keyboard, {
    enable,
    disable
  });
}
function Mousewheel({
  swiper,
  extendParams,
  on: on2,
  emit
}) {
  const window2 = getWindow();
  extendParams({
    mousewheel: {
      enabled: false,
      releaseOnEdges: false,
      invert: false,
      forceToAxis: false,
      sensitivity: 1,
      eventsTarget: "container",
      thresholdDelta: null,
      thresholdTime: null
    }
  });
  swiper.mousewheel = {
    enabled: false
  };
  let timeout;
  let lastScrollTime = now();
  let lastEventBeforeSnap;
  const recentWheelEvents = [];
  function normalize(e) {
    const PIXEL_STEP = 10;
    const LINE_HEIGHT = 40;
    const PAGE_HEIGHT = 800;
    let sX = 0;
    let sY = 0;
    let pX = 0;
    let pY = 0;
    if ("detail" in e) {
      sY = e.detail;
    }
    if ("wheelDelta" in e) {
      sY = -e.wheelDelta / 120;
    }
    if ("wheelDeltaY" in e) {
      sY = -e.wheelDeltaY / 120;
    }
    if ("wheelDeltaX" in e) {
      sX = -e.wheelDeltaX / 120;
    }
    if ("axis" in e && e.axis === e.HORIZONTAL_AXIS) {
      sX = sY;
      sY = 0;
    }
    pX = sX * PIXEL_STEP;
    pY = sY * PIXEL_STEP;
    if ("deltaY" in e) {
      pY = e.deltaY;
    }
    if ("deltaX" in e) {
      pX = e.deltaX;
    }
    if (e.shiftKey && !pX) {
      pX = pY;
      pY = 0;
    }
    if ((pX || pY) && e.deltaMode) {
      if (e.deltaMode === 1) {
        pX *= LINE_HEIGHT;
        pY *= LINE_HEIGHT;
      } else {
        pX *= PAGE_HEIGHT;
        pY *= PAGE_HEIGHT;
      }
    }
    if (pX && !sX) {
      sX = pX < 1 ? -1 : 1;
    }
    if (pY && !sY) {
      sY = pY < 1 ? -1 : 1;
    }
    return {
      spinX: sX,
      spinY: sY,
      pixelX: pX,
      pixelY: pY
    };
  }
  function handleMouseEnter() {
    if (!swiper.enabled)
      return;
    swiper.mouseEntered = true;
  }
  function handleMouseLeave() {
    if (!swiper.enabled)
      return;
    swiper.mouseEntered = false;
  }
  function animateSlider(newEvent) {
    if (swiper.params.mousewheel.thresholdDelta && newEvent.delta < swiper.params.mousewheel.thresholdDelta) {
      return false;
    }
    if (swiper.params.mousewheel.thresholdTime && now() - lastScrollTime < swiper.params.mousewheel.thresholdTime) {
      return false;
    }
    if (newEvent.delta >= 6 && now() - lastScrollTime < 60) {
      return true;
    }
    if (newEvent.direction < 0) {
      if ((!swiper.isEnd || swiper.params.loop) && !swiper.animating) {
        swiper.slideNext();
        emit("scroll", newEvent.raw);
      }
    } else if ((!swiper.isBeginning || swiper.params.loop) && !swiper.animating) {
      swiper.slidePrev();
      emit("scroll", newEvent.raw);
    }
    lastScrollTime = new window2.Date().getTime();
    return false;
  }
  function releaseScroll(newEvent) {
    const params = swiper.params.mousewheel;
    if (newEvent.direction < 0) {
      if (swiper.isEnd && !swiper.params.loop && params.releaseOnEdges) {
        return true;
      }
    } else if (swiper.isBeginning && !swiper.params.loop && params.releaseOnEdges) {
      return true;
    }
    return false;
  }
  function handle(event2) {
    let e = event2;
    let disableParentSwiper = true;
    if (!swiper.enabled)
      return;
    const params = swiper.params.mousewheel;
    if (swiper.params.cssMode) {
      e.preventDefault();
    }
    let target = swiper.$el;
    if (swiper.params.mousewheel.eventsTarget !== "container") {
      target = $(swiper.params.mousewheel.eventsTarget);
    }
    if (!swiper.mouseEntered && !target[0].contains(e.target) && !params.releaseOnEdges)
      return true;
    if (e.originalEvent)
      e = e.originalEvent;
    let delta = 0;
    const rtlFactor = swiper.rtlTranslate ? -1 : 1;
    const data = normalize(e);
    if (params.forceToAxis) {
      if (swiper.isHorizontal()) {
        if (Math.abs(data.pixelX) > Math.abs(data.pixelY))
          delta = -data.pixelX * rtlFactor;
        else
          return true;
      } else if (Math.abs(data.pixelY) > Math.abs(data.pixelX))
        delta = -data.pixelY;
      else
        return true;
    } else {
      delta = Math.abs(data.pixelX) > Math.abs(data.pixelY) ? -data.pixelX * rtlFactor : -data.pixelY;
    }
    if (delta === 0)
      return true;
    if (params.invert)
      delta = -delta;
    let positions = swiper.getTranslate() + delta * params.sensitivity;
    if (positions >= swiper.minTranslate())
      positions = swiper.minTranslate();
    if (positions <= swiper.maxTranslate())
      positions = swiper.maxTranslate();
    disableParentSwiper = swiper.params.loop ? true : !(positions === swiper.minTranslate() || positions === swiper.maxTranslate());
    if (disableParentSwiper && swiper.params.nested)
      e.stopPropagation();
    if (!swiper.params.freeMode || !swiper.params.freeMode.enabled) {
      const newEvent = {
        time: now(),
        delta: Math.abs(delta),
        direction: Math.sign(delta),
        raw: event2
      };
      if (recentWheelEvents.length >= 2) {
        recentWheelEvents.shift();
      }
      const prevEvent = recentWheelEvents.length ? recentWheelEvents[recentWheelEvents.length - 1] : void 0;
      recentWheelEvents.push(newEvent);
      if (prevEvent) {
        if (newEvent.direction !== prevEvent.direction || newEvent.delta > prevEvent.delta || newEvent.time > prevEvent.time + 150) {
          animateSlider(newEvent);
        }
      } else {
        animateSlider(newEvent);
      }
      if (releaseScroll(newEvent)) {
        return true;
      }
    } else {
      const newEvent = {
        time: now(),
        delta: Math.abs(delta),
        direction: Math.sign(delta)
      };
      const ignoreWheelEvents = lastEventBeforeSnap && newEvent.time < lastEventBeforeSnap.time + 500 && newEvent.delta <= lastEventBeforeSnap.delta && newEvent.direction === lastEventBeforeSnap.direction;
      if (!ignoreWheelEvents) {
        lastEventBeforeSnap = void 0;
        if (swiper.params.loop) {
          swiper.loopFix();
        }
        let position = swiper.getTranslate() + delta * params.sensitivity;
        const wasBeginning = swiper.isBeginning;
        const wasEnd = swiper.isEnd;
        if (position >= swiper.minTranslate())
          position = swiper.minTranslate();
        if (position <= swiper.maxTranslate())
          position = swiper.maxTranslate();
        swiper.setTransition(0);
        swiper.setTranslate(position);
        swiper.updateProgress();
        swiper.updateActiveIndex();
        swiper.updateSlidesClasses();
        if (!wasBeginning && swiper.isBeginning || !wasEnd && swiper.isEnd) {
          swiper.updateSlidesClasses();
        }
        if (swiper.params.freeMode.sticky) {
          clearTimeout(timeout);
          timeout = void 0;
          if (recentWheelEvents.length >= 15) {
            recentWheelEvents.shift();
          }
          const prevEvent = recentWheelEvents.length ? recentWheelEvents[recentWheelEvents.length - 1] : void 0;
          const firstEvent = recentWheelEvents[0];
          recentWheelEvents.push(newEvent);
          if (prevEvent && (newEvent.delta > prevEvent.delta || newEvent.direction !== prevEvent.direction)) {
            recentWheelEvents.splice(0);
          } else if (recentWheelEvents.length >= 15 && newEvent.time - firstEvent.time < 500 && firstEvent.delta - newEvent.delta >= 1 && newEvent.delta <= 6) {
            const snapToThreshold = delta > 0 ? 0.8 : 0.2;
            lastEventBeforeSnap = newEvent;
            recentWheelEvents.splice(0);
            timeout = nextTick(() => {
              swiper.slideToClosest(swiper.params.speed, true, void 0, snapToThreshold);
            }, 0);
          }
          if (!timeout) {
            timeout = nextTick(() => {
              const snapToThreshold = 0.5;
              lastEventBeforeSnap = newEvent;
              recentWheelEvents.splice(0);
              swiper.slideToClosest(swiper.params.speed, true, void 0, snapToThreshold);
            }, 500);
          }
        }
        if (!ignoreWheelEvents)
          emit("scroll", e);
        if (swiper.params.autoplay && swiper.params.autoplayDisableOnInteraction)
          swiper.autoplay.stop();
        if (position === swiper.minTranslate() || position === swiper.maxTranslate())
          return true;
      }
    }
    if (e.preventDefault)
      e.preventDefault();
    else
      e.returnValue = false;
    return false;
  }
  function events2(method) {
    let target = swiper.$el;
    if (swiper.params.mousewheel.eventsTarget !== "container") {
      target = $(swiper.params.mousewheel.eventsTarget);
    }
    target[method]("mouseenter", handleMouseEnter);
    target[method]("mouseleave", handleMouseLeave);
    target[method]("wheel", handle);
  }
  function enable() {
    if (swiper.params.cssMode) {
      swiper.wrapperEl.removeEventListener("wheel", handle);
      return true;
    }
    if (swiper.mousewheel.enabled)
      return false;
    events2("on");
    swiper.mousewheel.enabled = true;
    return true;
  }
  function disable() {
    if (swiper.params.cssMode) {
      swiper.wrapperEl.addEventListener(event, handle);
      return true;
    }
    if (!swiper.mousewheel.enabled)
      return false;
    events2("off");
    swiper.mousewheel.enabled = false;
    return true;
  }
  on2("init", () => {
    if (!swiper.params.mousewheel.enabled && swiper.params.cssMode) {
      disable();
    }
    if (swiper.params.mousewheel.enabled)
      enable();
  });
  on2("destroy", () => {
    if (swiper.params.cssMode) {
      enable();
    }
    if (swiper.mousewheel.enabled)
      disable();
  });
  Object.assign(swiper.mousewheel, {
    enable,
    disable
  });
}
function createElementIfNotDefined(swiper, originalParams, params, checkProps) {
  const document2 = getDocument();
  if (swiper.params.createElements) {
    Object.keys(checkProps).forEach((key) => {
      if (!params[key] && params.auto === true) {
        let element = swiper.$el.children(`.${checkProps[key]}`)[0];
        if (!element) {
          element = document2.createElement("div");
          element.className = checkProps[key];
          swiper.$el.append(element);
        }
        params[key] = element;
        originalParams[key] = element;
      }
    });
  }
  return params;
}
function Navigation({
  swiper,
  extendParams,
  on: on2,
  emit
}) {
  extendParams({
    navigation: {
      nextEl: null,
      prevEl: null,
      hideOnClick: false,
      disabledClass: "swiper-button-disabled",
      hiddenClass: "swiper-button-hidden",
      lockClass: "swiper-button-lock",
      navigationDisabledClass: "swiper-navigation-disabled"
    }
  });
  swiper.navigation = {
    nextEl: null,
    $nextEl: null,
    prevEl: null,
    $prevEl: null
  };
  function getEl(el) {
    let $el;
    if (el) {
      $el = $(el);
      if (swiper.params.uniqueNavElements && typeof el === "string" && $el.length > 1 && swiper.$el.find(el).length === 1) {
        $el = swiper.$el.find(el);
      }
    }
    return $el;
  }
  function toggleEl($el, disabled) {
    const params = swiper.params.navigation;
    if ($el && $el.length > 0) {
      $el[disabled ? "addClass" : "removeClass"](params.disabledClass);
      if ($el[0] && $el[0].tagName === "BUTTON")
        $el[0].disabled = disabled;
      if (swiper.params.watchOverflow && swiper.enabled) {
        $el[swiper.isLocked ? "addClass" : "removeClass"](params.lockClass);
      }
    }
  }
  function update2() {
    if (swiper.params.loop)
      return;
    const {
      $nextEl,
      $prevEl
    } = swiper.navigation;
    toggleEl($prevEl, swiper.isBeginning && !swiper.params.rewind);
    toggleEl($nextEl, swiper.isEnd && !swiper.params.rewind);
  }
  function onPrevClick(e) {
    e.preventDefault();
    if (swiper.isBeginning && !swiper.params.loop && !swiper.params.rewind)
      return;
    swiper.slidePrev();
    emit("navigationPrev");
  }
  function onNextClick(e) {
    e.preventDefault();
    if (swiper.isEnd && !swiper.params.loop && !swiper.params.rewind)
      return;
    swiper.slideNext();
    emit("navigationNext");
  }
  function init() {
    const params = swiper.params.navigation;
    swiper.params.navigation = createElementIfNotDefined(swiper, swiper.originalParams.navigation, swiper.params.navigation, {
      nextEl: "swiper-button-next",
      prevEl: "swiper-button-prev"
    });
    if (!(params.nextEl || params.prevEl))
      return;
    const $nextEl = getEl(params.nextEl);
    const $prevEl = getEl(params.prevEl);
    if ($nextEl && $nextEl.length > 0) {
      $nextEl.on("click", onNextClick);
    }
    if ($prevEl && $prevEl.length > 0) {
      $prevEl.on("click", onPrevClick);
    }
    Object.assign(swiper.navigation, {
      $nextEl,
      nextEl: $nextEl && $nextEl[0],
      $prevEl,
      prevEl: $prevEl && $prevEl[0]
    });
    if (!swiper.enabled) {
      if ($nextEl)
        $nextEl.addClass(params.lockClass);
      if ($prevEl)
        $prevEl.addClass(params.lockClass);
    }
  }
  function destroy() {
    const {
      $nextEl,
      $prevEl
    } = swiper.navigation;
    if ($nextEl && $nextEl.length) {
      $nextEl.off("click", onNextClick);
      $nextEl.removeClass(swiper.params.navigation.disabledClass);
    }
    if ($prevEl && $prevEl.length) {
      $prevEl.off("click", onPrevClick);
      $prevEl.removeClass(swiper.params.navigation.disabledClass);
    }
  }
  on2("init", () => {
    if (swiper.params.navigation.enabled === false) {
      disable();
    } else {
      init();
      update2();
    }
  });
  on2("toEdge fromEdge lock unlock", () => {
    update2();
  });
  on2("destroy", () => {
    destroy();
  });
  on2("enable disable", () => {
    const {
      $nextEl,
      $prevEl
    } = swiper.navigation;
    if ($nextEl) {
      $nextEl[swiper.enabled ? "removeClass" : "addClass"](swiper.params.navigation.lockClass);
    }
    if ($prevEl) {
      $prevEl[swiper.enabled ? "removeClass" : "addClass"](swiper.params.navigation.lockClass);
    }
  });
  on2("click", (_s, e) => {
    const {
      $nextEl,
      $prevEl
    } = swiper.navigation;
    const targetEl = e.target;
    if (swiper.params.navigation.hideOnClick && !$(targetEl).is($prevEl) && !$(targetEl).is($nextEl)) {
      if (swiper.pagination && swiper.params.pagination && swiper.params.pagination.clickable && (swiper.pagination.el === targetEl || swiper.pagination.el.contains(targetEl)))
        return;
      let isHidden;
      if ($nextEl) {
        isHidden = $nextEl.hasClass(swiper.params.navigation.hiddenClass);
      } else if ($prevEl) {
        isHidden = $prevEl.hasClass(swiper.params.navigation.hiddenClass);
      }
      if (isHidden === true) {
        emit("navigationShow");
      } else {
        emit("navigationHide");
      }
      if ($nextEl) {
        $nextEl.toggleClass(swiper.params.navigation.hiddenClass);
      }
      if ($prevEl) {
        $prevEl.toggleClass(swiper.params.navigation.hiddenClass);
      }
    }
  });
  const enable = () => {
    swiper.$el.removeClass(swiper.params.navigation.navigationDisabledClass);
    init();
    update2();
  };
  const disable = () => {
    swiper.$el.addClass(swiper.params.navigation.navigationDisabledClass);
    destroy();
  };
  Object.assign(swiper.navigation, {
    enable,
    disable,
    update: update2,
    init,
    destroy
  });
}
function classesToSelector(classes2 = "") {
  return `.${classes2.trim().replace(/([\.:!\/])/g, "\\$1").replace(/ /g, ".")}`;
}
function Pagination({
  swiper,
  extendParams,
  on: on2,
  emit
}) {
  const pfx = "swiper-pagination";
  extendParams({
    pagination: {
      el: null,
      bulletElement: "span",
      clickable: false,
      hideOnClick: false,
      renderBullet: null,
      renderProgressbar: null,
      renderFraction: null,
      renderCustom: null,
      progressbarOpposite: false,
      type: "bullets",
      // 'bullets' or 'progressbar' or 'fraction' or 'custom'
      dynamicBullets: false,
      dynamicMainBullets: 1,
      formatFractionCurrent: (number) => number,
      formatFractionTotal: (number) => number,
      bulletClass: `${pfx}-bullet`,
      bulletActiveClass: `${pfx}-bullet-active`,
      modifierClass: `${pfx}-`,
      currentClass: `${pfx}-current`,
      totalClass: `${pfx}-total`,
      hiddenClass: `${pfx}-hidden`,
      progressbarFillClass: `${pfx}-progressbar-fill`,
      progressbarOppositeClass: `${pfx}-progressbar-opposite`,
      clickableClass: `${pfx}-clickable`,
      lockClass: `${pfx}-lock`,
      horizontalClass: `${pfx}-horizontal`,
      verticalClass: `${pfx}-vertical`,
      paginationDisabledClass: `${pfx}-disabled`
    }
  });
  swiper.pagination = {
    el: null,
    $el: null,
    bullets: []
  };
  let bulletSize;
  let dynamicBulletIndex = 0;
  function isPaginationDisabled() {
    return !swiper.params.pagination.el || !swiper.pagination.el || !swiper.pagination.$el || swiper.pagination.$el.length === 0;
  }
  function setSideBullets($bulletEl, position) {
    const {
      bulletActiveClass
    } = swiper.params.pagination;
    $bulletEl[position]().addClass(`${bulletActiveClass}-${position}`)[position]().addClass(`${bulletActiveClass}-${position}-${position}`);
  }
  function update2() {
    const rtl = swiper.rtl;
    const params = swiper.params.pagination;
    if (isPaginationDisabled())
      return;
    const slidesLength = swiper.virtual && swiper.params.virtual.enabled ? swiper.virtual.slides.length : swiper.slides.length;
    const $el = swiper.pagination.$el;
    let current;
    const total = swiper.params.loop ? Math.ceil((slidesLength - swiper.loopedSlides * 2) / swiper.params.slidesPerGroup) : swiper.snapGrid.length;
    if (swiper.params.loop) {
      current = Math.ceil((swiper.activeIndex - swiper.loopedSlides) / swiper.params.slidesPerGroup);
      if (current > slidesLength - 1 - swiper.loopedSlides * 2) {
        current -= slidesLength - swiper.loopedSlides * 2;
      }
      if (current > total - 1)
        current -= total;
      if (current < 0 && swiper.params.paginationType !== "bullets")
        current = total + current;
    } else if (typeof swiper.snapIndex !== "undefined") {
      current = swiper.snapIndex;
    } else {
      current = swiper.activeIndex || 0;
    }
    if (params.type === "bullets" && swiper.pagination.bullets && swiper.pagination.bullets.length > 0) {
      const bullets = swiper.pagination.bullets;
      let firstIndex;
      let lastIndex;
      let midIndex;
      if (params.dynamicBullets) {
        bulletSize = bullets.eq(0)[swiper.isHorizontal() ? "outerWidth" : "outerHeight"](true);
        $el.css(swiper.isHorizontal() ? "width" : "height", `${bulletSize * (params.dynamicMainBullets + 4)}px`);
        if (params.dynamicMainBullets > 1 && swiper.previousIndex !== void 0) {
          dynamicBulletIndex += current - (swiper.previousIndex - swiper.loopedSlides || 0);
          if (dynamicBulletIndex > params.dynamicMainBullets - 1) {
            dynamicBulletIndex = params.dynamicMainBullets - 1;
          } else if (dynamicBulletIndex < 0) {
            dynamicBulletIndex = 0;
          }
        }
        firstIndex = Math.max(current - dynamicBulletIndex, 0);
        lastIndex = firstIndex + (Math.min(bullets.length, params.dynamicMainBullets) - 1);
        midIndex = (lastIndex + firstIndex) / 2;
      }
      bullets.removeClass(["", "-next", "-next-next", "-prev", "-prev-prev", "-main"].map((suffix) => `${params.bulletActiveClass}${suffix}`).join(" "));
      if ($el.length > 1) {
        bullets.each((bullet) => {
          const $bullet = $(bullet);
          const bulletIndex = $bullet.index();
          if (bulletIndex === current) {
            $bullet.addClass(params.bulletActiveClass);
          }
          if (params.dynamicBullets) {
            if (bulletIndex >= firstIndex && bulletIndex <= lastIndex) {
              $bullet.addClass(`${params.bulletActiveClass}-main`);
            }
            if (bulletIndex === firstIndex) {
              setSideBullets($bullet, "prev");
            }
            if (bulletIndex === lastIndex) {
              setSideBullets($bullet, "next");
            }
          }
        });
      } else {
        const $bullet = bullets.eq(current);
        const bulletIndex = $bullet.index();
        $bullet.addClass(params.bulletActiveClass);
        if (params.dynamicBullets) {
          const $firstDisplayedBullet = bullets.eq(firstIndex);
          const $lastDisplayedBullet = bullets.eq(lastIndex);
          for (let i = firstIndex; i <= lastIndex; i += 1) {
            bullets.eq(i).addClass(`${params.bulletActiveClass}-main`);
          }
          if (swiper.params.loop) {
            if (bulletIndex >= bullets.length) {
              for (let i = params.dynamicMainBullets; i >= 0; i -= 1) {
                bullets.eq(bullets.length - i).addClass(`${params.bulletActiveClass}-main`);
              }
              bullets.eq(bullets.length - params.dynamicMainBullets - 1).addClass(`${params.bulletActiveClass}-prev`);
            } else {
              setSideBullets($firstDisplayedBullet, "prev");
              setSideBullets($lastDisplayedBullet, "next");
            }
          } else {
            setSideBullets($firstDisplayedBullet, "prev");
            setSideBullets($lastDisplayedBullet, "next");
          }
        }
      }
      if (params.dynamicBullets) {
        const dynamicBulletsLength = Math.min(bullets.length, params.dynamicMainBullets + 4);
        const bulletsOffset = (bulletSize * dynamicBulletsLength - bulletSize) / 2 - midIndex * bulletSize;
        const offsetProp = rtl ? "right" : "left";
        bullets.css(swiper.isHorizontal() ? offsetProp : "top", `${bulletsOffset}px`);
      }
    }
    if (params.type === "fraction") {
      $el.find(classesToSelector(params.currentClass)).text(params.formatFractionCurrent(current + 1));
      $el.find(classesToSelector(params.totalClass)).text(params.formatFractionTotal(total));
    }
    if (params.type === "progressbar") {
      let progressbarDirection;
      if (params.progressbarOpposite) {
        progressbarDirection = swiper.isHorizontal() ? "vertical" : "horizontal";
      } else {
        progressbarDirection = swiper.isHorizontal() ? "horizontal" : "vertical";
      }
      const scale = (current + 1) / total;
      let scaleX = 1;
      let scaleY = 1;
      if (progressbarDirection === "horizontal") {
        scaleX = scale;
      } else {
        scaleY = scale;
      }
      $el.find(classesToSelector(params.progressbarFillClass)).transform(`translate3d(0,0,0) scaleX(${scaleX}) scaleY(${scaleY})`).transition(swiper.params.speed);
    }
    if (params.type === "custom" && params.renderCustom) {
      $el.html(params.renderCustom(swiper, current + 1, total));
      emit("paginationRender", $el[0]);
    } else {
      emit("paginationUpdate", $el[0]);
    }
    if (swiper.params.watchOverflow && swiper.enabled) {
      $el[swiper.isLocked ? "addClass" : "removeClass"](params.lockClass);
    }
  }
  function render() {
    const params = swiper.params.pagination;
    if (isPaginationDisabled())
      return;
    const slidesLength = swiper.virtual && swiper.params.virtual.enabled ? swiper.virtual.slides.length : swiper.slides.length;
    const $el = swiper.pagination.$el;
    let paginationHTML = "";
    if (params.type === "bullets") {
      let numberOfBullets = swiper.params.loop ? Math.ceil((slidesLength - swiper.loopedSlides * 2) / swiper.params.slidesPerGroup) : swiper.snapGrid.length;
      if (swiper.params.freeMode && swiper.params.freeMode.enabled && !swiper.params.loop && numberOfBullets > slidesLength) {
        numberOfBullets = slidesLength;
      }
      for (let i = 0; i < numberOfBullets; i += 1) {
        if (params.renderBullet) {
          paginationHTML += params.renderBullet.call(swiper, i, params.bulletClass);
        } else {
          paginationHTML += `<${params.bulletElement} class="${params.bulletClass}"></${params.bulletElement}>`;
        }
      }
      $el.html(paginationHTML);
      swiper.pagination.bullets = $el.find(classesToSelector(params.bulletClass));
    }
    if (params.type === "fraction") {
      if (params.renderFraction) {
        paginationHTML = params.renderFraction.call(swiper, params.currentClass, params.totalClass);
      } else {
        paginationHTML = `<span class="${params.currentClass}"></span> / <span class="${params.totalClass}"></span>`;
      }
      $el.html(paginationHTML);
    }
    if (params.type === "progressbar") {
      if (params.renderProgressbar) {
        paginationHTML = params.renderProgressbar.call(swiper, params.progressbarFillClass);
      } else {
        paginationHTML = `<span class="${params.progressbarFillClass}"></span>`;
      }
      $el.html(paginationHTML);
    }
    if (params.type !== "custom") {
      emit("paginationRender", swiper.pagination.$el[0]);
    }
  }
  function init() {
    swiper.params.pagination = createElementIfNotDefined(swiper, swiper.originalParams.pagination, swiper.params.pagination, {
      el: "swiper-pagination"
    });
    const params = swiper.params.pagination;
    if (!params.el)
      return;
    let $el = $(params.el);
    if ($el.length === 0)
      return;
    if (swiper.params.uniqueNavElements && typeof params.el === "string" && $el.length > 1) {
      $el = swiper.$el.find(params.el);
      if ($el.length > 1) {
        $el = $el.filter((el) => {
          if ($(el).parents(".swiper")[0] !== swiper.el)
            return false;
          return true;
        });
      }
    }
    if (params.type === "bullets" && params.clickable) {
      $el.addClass(params.clickableClass);
    }
    $el.addClass(params.modifierClass + params.type);
    $el.addClass(swiper.isHorizontal() ? params.horizontalClass : params.verticalClass);
    if (params.type === "bullets" && params.dynamicBullets) {
      $el.addClass(`${params.modifierClass}${params.type}-dynamic`);
      dynamicBulletIndex = 0;
      if (params.dynamicMainBullets < 1) {
        params.dynamicMainBullets = 1;
      }
    }
    if (params.type === "progressbar" && params.progressbarOpposite) {
      $el.addClass(params.progressbarOppositeClass);
    }
    if (params.clickable) {
      $el.on("click", classesToSelector(params.bulletClass), function onClick2(e) {
        e.preventDefault();
        let index2 = $(this).index() * swiper.params.slidesPerGroup;
        if (swiper.params.loop)
          index2 += swiper.loopedSlides;
        swiper.slideTo(index2);
      });
    }
    Object.assign(swiper.pagination, {
      $el,
      el: $el[0]
    });
    if (!swiper.enabled) {
      $el.addClass(params.lockClass);
    }
  }
  function destroy() {
    const params = swiper.params.pagination;
    if (isPaginationDisabled())
      return;
    const $el = swiper.pagination.$el;
    $el.removeClass(params.hiddenClass);
    $el.removeClass(params.modifierClass + params.type);
    $el.removeClass(swiper.isHorizontal() ? params.horizontalClass : params.verticalClass);
    if (swiper.pagination.bullets && swiper.pagination.bullets.removeClass)
      swiper.pagination.bullets.removeClass(params.bulletActiveClass);
    if (params.clickable) {
      $el.off("click", classesToSelector(params.bulletClass));
    }
  }
  on2("init", () => {
    if (swiper.params.pagination.enabled === false) {
      disable();
    } else {
      init();
      render();
      update2();
    }
  });
  on2("activeIndexChange", () => {
    if (swiper.params.loop) {
      update2();
    } else if (typeof swiper.snapIndex === "undefined") {
      update2();
    }
  });
  on2("snapIndexChange", () => {
    if (!swiper.params.loop) {
      update2();
    }
  });
  on2("slidesLengthChange", () => {
    if (swiper.params.loop) {
      render();
      update2();
    }
  });
  on2("snapGridLengthChange", () => {
    if (!swiper.params.loop) {
      render();
      update2();
    }
  });
  on2("destroy", () => {
    destroy();
  });
  on2("enable disable", () => {
    const {
      $el
    } = swiper.pagination;
    if ($el) {
      $el[swiper.enabled ? "removeClass" : "addClass"](swiper.params.pagination.lockClass);
    }
  });
  on2("lock unlock", () => {
    update2();
  });
  on2("click", (_s, e) => {
    const targetEl = e.target;
    const {
      $el
    } = swiper.pagination;
    if (swiper.params.pagination.el && swiper.params.pagination.hideOnClick && $el && $el.length > 0 && !$(targetEl).hasClass(swiper.params.pagination.bulletClass)) {
      if (swiper.navigation && (swiper.navigation.nextEl && targetEl === swiper.navigation.nextEl || swiper.navigation.prevEl && targetEl === swiper.navigation.prevEl))
        return;
      const isHidden = $el.hasClass(swiper.params.pagination.hiddenClass);
      if (isHidden === true) {
        emit("paginationShow");
      } else {
        emit("paginationHide");
      }
      $el.toggleClass(swiper.params.pagination.hiddenClass);
    }
  });
  const enable = () => {
    swiper.$el.removeClass(swiper.params.pagination.paginationDisabledClass);
    if (swiper.pagination.$el) {
      swiper.pagination.$el.removeClass(swiper.params.pagination.paginationDisabledClass);
    }
    init();
    render();
    update2();
  };
  const disable = () => {
    swiper.$el.addClass(swiper.params.pagination.paginationDisabledClass);
    if (swiper.pagination.$el) {
      swiper.pagination.$el.addClass(swiper.params.pagination.paginationDisabledClass);
    }
    destroy();
  };
  Object.assign(swiper.pagination, {
    enable,
    disable,
    render,
    update: update2,
    init,
    destroy
  });
}
function Scrollbar({
  swiper,
  extendParams,
  on: on2,
  emit
}) {
  const document2 = getDocument();
  let isTouched = false;
  let timeout = null;
  let dragTimeout = null;
  let dragStartPos;
  let dragSize;
  let trackSize;
  let divider;
  extendParams({
    scrollbar: {
      el: null,
      dragSize: "auto",
      hide: false,
      draggable: false,
      snapOnRelease: true,
      lockClass: "swiper-scrollbar-lock",
      dragClass: "swiper-scrollbar-drag",
      scrollbarDisabledClass: "swiper-scrollbar-disabled",
      horizontalClass: `swiper-scrollbar-horizontal`,
      verticalClass: `swiper-scrollbar-vertical`
    }
  });
  swiper.scrollbar = {
    el: null,
    dragEl: null,
    $el: null,
    $dragEl: null
  };
  function setTranslate2() {
    if (!swiper.params.scrollbar.el || !swiper.scrollbar.el)
      return;
    const {
      scrollbar,
      rtlTranslate: rtl,
      progress
    } = swiper;
    const {
      $dragEl,
      $el
    } = scrollbar;
    const params = swiper.params.scrollbar;
    let newSize = dragSize;
    let newPos = (trackSize - dragSize) * progress;
    if (rtl) {
      newPos = -newPos;
      if (newPos > 0) {
        newSize = dragSize - newPos;
        newPos = 0;
      } else if (-newPos + dragSize > trackSize) {
        newSize = trackSize + newPos;
      }
    } else if (newPos < 0) {
      newSize = dragSize + newPos;
      newPos = 0;
    } else if (newPos + dragSize > trackSize) {
      newSize = trackSize - newPos;
    }
    if (swiper.isHorizontal()) {
      $dragEl.transform(`translate3d(${newPos}px, 0, 0)`);
      $dragEl[0].style.width = `${newSize}px`;
    } else {
      $dragEl.transform(`translate3d(0px, ${newPos}px, 0)`);
      $dragEl[0].style.height = `${newSize}px`;
    }
    if (params.hide) {
      clearTimeout(timeout);
      $el[0].style.opacity = 1;
      timeout = setTimeout(() => {
        $el[0].style.opacity = 0;
        $el.transition(400);
      }, 1e3);
    }
  }
  function setTransition2(duration2) {
    if (!swiper.params.scrollbar.el || !swiper.scrollbar.el)
      return;
    swiper.scrollbar.$dragEl.transition(duration2);
  }
  function updateSize2() {
    if (!swiper.params.scrollbar.el || !swiper.scrollbar.el)
      return;
    const {
      scrollbar
    } = swiper;
    const {
      $dragEl,
      $el
    } = scrollbar;
    $dragEl[0].style.width = "";
    $dragEl[0].style.height = "";
    trackSize = swiper.isHorizontal() ? $el[0].offsetWidth : $el[0].offsetHeight;
    divider = swiper.size / (swiper.virtualSize + swiper.params.slidesOffsetBefore - (swiper.params.centeredSlides ? swiper.snapGrid[0] : 0));
    if (swiper.params.scrollbar.dragSize === "auto") {
      dragSize = trackSize * divider;
    } else {
      dragSize = parseInt(swiper.params.scrollbar.dragSize, 10);
    }
    if (swiper.isHorizontal()) {
      $dragEl[0].style.width = `${dragSize}px`;
    } else {
      $dragEl[0].style.height = `${dragSize}px`;
    }
    if (divider >= 1) {
      $el[0].style.display = "none";
    } else {
      $el[0].style.display = "";
    }
    if (swiper.params.scrollbar.hide) {
      $el[0].style.opacity = 0;
    }
    if (swiper.params.watchOverflow && swiper.enabled) {
      scrollbar.$el[swiper.isLocked ? "addClass" : "removeClass"](swiper.params.scrollbar.lockClass);
    }
  }
  function getPointerPosition(e) {
    if (swiper.isHorizontal()) {
      return e.type === "touchstart" || e.type === "touchmove" ? e.targetTouches[0].clientX : e.clientX;
    }
    return e.type === "touchstart" || e.type === "touchmove" ? e.targetTouches[0].clientY : e.clientY;
  }
  function setDragPosition(e) {
    const {
      scrollbar,
      rtlTranslate: rtl
    } = swiper;
    const {
      $el
    } = scrollbar;
    let positionRatio;
    positionRatio = (getPointerPosition(e) - $el.offset()[swiper.isHorizontal() ? "left" : "top"] - (dragStartPos !== null ? dragStartPos : dragSize / 2)) / (trackSize - dragSize);
    positionRatio = Math.max(Math.min(positionRatio, 1), 0);
    if (rtl) {
      positionRatio = 1 - positionRatio;
    }
    const position = swiper.minTranslate() + (swiper.maxTranslate() - swiper.minTranslate()) * positionRatio;
    swiper.updateProgress(position);
    swiper.setTranslate(position);
    swiper.updateActiveIndex();
    swiper.updateSlidesClasses();
  }
  function onDragStart(e) {
    const params = swiper.params.scrollbar;
    const {
      scrollbar,
      $wrapperEl
    } = swiper;
    const {
      $el,
      $dragEl
    } = scrollbar;
    isTouched = true;
    dragStartPos = e.target === $dragEl[0] || e.target === $dragEl ? getPointerPosition(e) - e.target.getBoundingClientRect()[swiper.isHorizontal() ? "left" : "top"] : null;
    e.preventDefault();
    e.stopPropagation();
    $wrapperEl.transition(100);
    $dragEl.transition(100);
    setDragPosition(e);
    clearTimeout(dragTimeout);
    $el.transition(0);
    if (params.hide) {
      $el.css("opacity", 1);
    }
    if (swiper.params.cssMode) {
      swiper.$wrapperEl.css("scroll-snap-type", "none");
    }
    emit("scrollbarDragStart", e);
  }
  function onDragMove(e) {
    const {
      scrollbar,
      $wrapperEl
    } = swiper;
    const {
      $el,
      $dragEl
    } = scrollbar;
    if (!isTouched)
      return;
    if (e.preventDefault)
      e.preventDefault();
    else
      e.returnValue = false;
    setDragPosition(e);
    $wrapperEl.transition(0);
    $el.transition(0);
    $dragEl.transition(0);
    emit("scrollbarDragMove", e);
  }
  function onDragEnd(e) {
    const params = swiper.params.scrollbar;
    const {
      scrollbar,
      $wrapperEl
    } = swiper;
    const {
      $el
    } = scrollbar;
    if (!isTouched)
      return;
    isTouched = false;
    if (swiper.params.cssMode) {
      swiper.$wrapperEl.css("scroll-snap-type", "");
      $wrapperEl.transition("");
    }
    if (params.hide) {
      clearTimeout(dragTimeout);
      dragTimeout = nextTick(() => {
        $el.css("opacity", 0);
        $el.transition(400);
      }, 1e3);
    }
    emit("scrollbarDragEnd", e);
    if (params.snapOnRelease) {
      swiper.slideToClosest();
    }
  }
  function events2(method) {
    const {
      scrollbar,
      touchEventsTouch,
      touchEventsDesktop,
      params,
      support: support2
    } = swiper;
    const $el = scrollbar.$el;
    if (!$el)
      return;
    const target = $el[0];
    const activeListener = support2.passiveListener && params.passiveListeners ? {
      passive: false,
      capture: false
    } : false;
    const passiveListener = support2.passiveListener && params.passiveListeners ? {
      passive: true,
      capture: false
    } : false;
    if (!target)
      return;
    const eventMethod = method === "on" ? "addEventListener" : "removeEventListener";
    if (!support2.touch) {
      target[eventMethod](touchEventsDesktop.start, onDragStart, activeListener);
      document2[eventMethod](touchEventsDesktop.move, onDragMove, activeListener);
      document2[eventMethod](touchEventsDesktop.end, onDragEnd, passiveListener);
    } else {
      target[eventMethod](touchEventsTouch.start, onDragStart, activeListener);
      target[eventMethod](touchEventsTouch.move, onDragMove, activeListener);
      target[eventMethod](touchEventsTouch.end, onDragEnd, passiveListener);
    }
  }
  function enableDraggable() {
    if (!swiper.params.scrollbar.el || !swiper.scrollbar.el)
      return;
    events2("on");
  }
  function disableDraggable() {
    if (!swiper.params.scrollbar.el || !swiper.scrollbar.el)
      return;
    events2("off");
  }
  function init() {
    const {
      scrollbar,
      $el: $swiperEl
    } = swiper;
    swiper.params.scrollbar = createElementIfNotDefined(swiper, swiper.originalParams.scrollbar, swiper.params.scrollbar, {
      el: "swiper-scrollbar"
    });
    const params = swiper.params.scrollbar;
    if (!params.el)
      return;
    let $el = $(params.el);
    if (swiper.params.uniqueNavElements && typeof params.el === "string" && $el.length > 1 && $swiperEl.find(params.el).length === 1) {
      $el = $swiperEl.find(params.el);
    }
    $el.addClass(swiper.isHorizontal() ? params.horizontalClass : params.verticalClass);
    let $dragEl = $el.find(`.${swiper.params.scrollbar.dragClass}`);
    if ($dragEl.length === 0) {
      $dragEl = $(`<div class="${swiper.params.scrollbar.dragClass}"></div>`);
      $el.append($dragEl);
    }
    Object.assign(scrollbar, {
      $el,
      el: $el[0],
      $dragEl,
      dragEl: $dragEl[0]
    });
    if (params.draggable) {
      enableDraggable();
    }
    if ($el) {
      $el[swiper.enabled ? "removeClass" : "addClass"](swiper.params.scrollbar.lockClass);
    }
  }
  function destroy() {
    const params = swiper.params.scrollbar;
    const $el = swiper.scrollbar.$el;
    if ($el) {
      $el.removeClass(swiper.isHorizontal() ? params.horizontalClass : params.verticalClass);
    }
    disableDraggable();
  }
  on2("init", () => {
    if (swiper.params.scrollbar.enabled === false) {
      disable();
    } else {
      init();
      updateSize2();
      setTranslate2();
    }
  });
  on2("update resize observerUpdate lock unlock", () => {
    updateSize2();
  });
  on2("setTranslate", () => {
    setTranslate2();
  });
  on2("setTransition", (_s, duration2) => {
    setTransition2(duration2);
  });
  on2("enable disable", () => {
    const {
      $el
    } = swiper.scrollbar;
    if ($el) {
      $el[swiper.enabled ? "removeClass" : "addClass"](swiper.params.scrollbar.lockClass);
    }
  });
  on2("destroy", () => {
    destroy();
  });
  const enable = () => {
    swiper.$el.removeClass(swiper.params.scrollbar.scrollbarDisabledClass);
    if (swiper.scrollbar.$el) {
      swiper.scrollbar.$el.removeClass(swiper.params.scrollbar.scrollbarDisabledClass);
    }
    init();
    updateSize2();
    setTranslate2();
  };
  const disable = () => {
    swiper.$el.addClass(swiper.params.scrollbar.scrollbarDisabledClass);
    if (swiper.scrollbar.$el) {
      swiper.scrollbar.$el.addClass(swiper.params.scrollbar.scrollbarDisabledClass);
    }
    destroy();
  };
  Object.assign(swiper.scrollbar, {
    enable,
    disable,
    updateSize: updateSize2,
    setTranslate: setTranslate2,
    init,
    destroy
  });
}
function Parallax({
  swiper,
  extendParams,
  on: on2
}) {
  extendParams({
    parallax: {
      enabled: false
    }
  });
  const setTransform = (el, progress) => {
    const {
      rtl
    } = swiper;
    const $el = $(el);
    const rtlFactor = rtl ? -1 : 1;
    const p = $el.attr("data-swiper-parallax") || "0";
    let x = $el.attr("data-swiper-parallax-x");
    let y = $el.attr("data-swiper-parallax-y");
    const scale = $el.attr("data-swiper-parallax-scale");
    const opacity = $el.attr("data-swiper-parallax-opacity");
    if (x || y) {
      x = x || "0";
      y = y || "0";
    } else if (swiper.isHorizontal()) {
      x = p;
      y = "0";
    } else {
      y = p;
      x = "0";
    }
    if (x.indexOf("%") >= 0) {
      x = `${parseInt(x, 10) * progress * rtlFactor}%`;
    } else {
      x = `${x * progress * rtlFactor}px`;
    }
    if (y.indexOf("%") >= 0) {
      y = `${parseInt(y, 10) * progress}%`;
    } else {
      y = `${y * progress}px`;
    }
    if (typeof opacity !== "undefined" && opacity !== null) {
      const currentOpacity = opacity - (opacity - 1) * (1 - Math.abs(progress));
      $el[0].style.opacity = currentOpacity;
    }
    if (typeof scale === "undefined" || scale === null) {
      $el.transform(`translate3d(${x}, ${y}, 0px)`);
    } else {
      const currentScale = scale - (scale - 1) * (1 - Math.abs(progress));
      $el.transform(`translate3d(${x}, ${y}, 0px) scale(${currentScale})`);
    }
  };
  const setTranslate2 = () => {
    const {
      $el,
      slides,
      progress,
      snapGrid
    } = swiper;
    $el.children("[data-swiper-parallax], [data-swiper-parallax-x], [data-swiper-parallax-y], [data-swiper-parallax-opacity], [data-swiper-parallax-scale]").each((el) => {
      setTransform(el, progress);
    });
    slides.each((slideEl, slideIndex) => {
      let slideProgress = slideEl.progress;
      if (swiper.params.slidesPerGroup > 1 && swiper.params.slidesPerView !== "auto") {
        slideProgress += Math.ceil(slideIndex / 2) - progress * (snapGrid.length - 1);
      }
      slideProgress = Math.min(Math.max(slideProgress, -1), 1);
      $(slideEl).find("[data-swiper-parallax], [data-swiper-parallax-x], [data-swiper-parallax-y], [data-swiper-parallax-opacity], [data-swiper-parallax-scale]").each((el) => {
        setTransform(el, slideProgress);
      });
    });
  };
  const setTransition2 = (duration2 = swiper.params.speed) => {
    const {
      $el
    } = swiper;
    $el.find("[data-swiper-parallax], [data-swiper-parallax-x], [data-swiper-parallax-y], [data-swiper-parallax-opacity], [data-swiper-parallax-scale]").each((parallaxEl) => {
      const $parallaxEl = $(parallaxEl);
      let parallaxDuration = parseInt($parallaxEl.attr("data-swiper-parallax-duration"), 10) || duration2;
      if (duration2 === 0)
        parallaxDuration = 0;
      $parallaxEl.transition(parallaxDuration);
    });
  };
  on2("beforeInit", () => {
    if (!swiper.params.parallax.enabled)
      return;
    swiper.params.watchSlidesProgress = true;
    swiper.originalParams.watchSlidesProgress = true;
  });
  on2("init", () => {
    if (!swiper.params.parallax.enabled)
      return;
    setTranslate2();
  });
  on2("setTranslate", () => {
    if (!swiper.params.parallax.enabled)
      return;
    setTranslate2();
  });
  on2("setTransition", (_swiper, duration2) => {
    if (!swiper.params.parallax.enabled)
      return;
    setTransition2(duration2);
  });
}
function Zoom({
  swiper,
  extendParams,
  on: on2,
  emit
}) {
  const window2 = getWindow();
  extendParams({
    zoom: {
      enabled: false,
      maxRatio: 3,
      minRatio: 1,
      toggle: true,
      containerClass: "swiper-zoom-container",
      zoomedSlideClass: "swiper-slide-zoomed"
    }
  });
  swiper.zoom = {
    enabled: false
  };
  let currentScale = 1;
  let isScaling = false;
  let gesturesEnabled;
  let fakeGestureTouched;
  let fakeGestureMoved;
  const gesture = {
    $slideEl: void 0,
    slideWidth: void 0,
    slideHeight: void 0,
    $imageEl: void 0,
    $imageWrapEl: void 0,
    maxRatio: 3
  };
  const image = {
    isTouched: void 0,
    isMoved: void 0,
    currentX: void 0,
    currentY: void 0,
    minX: void 0,
    minY: void 0,
    maxX: void 0,
    maxY: void 0,
    width: void 0,
    height: void 0,
    startX: void 0,
    startY: void 0,
    touchesStart: {},
    touchesCurrent: {}
  };
  const velocity = {
    x: void 0,
    y: void 0,
    prevPositionX: void 0,
    prevPositionY: void 0,
    prevTime: void 0
  };
  let scale = 1;
  Object.defineProperty(swiper.zoom, "scale", {
    get() {
      return scale;
    },
    set(value) {
      if (scale !== value) {
        const imageEl = gesture.$imageEl ? gesture.$imageEl[0] : void 0;
        const slideEl = gesture.$slideEl ? gesture.$slideEl[0] : void 0;
        emit("zoomChange", value, imageEl, slideEl);
      }
      scale = value;
    }
  });
  function getDistanceBetweenTouches(e) {
    if (e.targetTouches.length < 2)
      return 1;
    const x1 = e.targetTouches[0].pageX;
    const y1 = e.targetTouches[0].pageY;
    const x2 = e.targetTouches[1].pageX;
    const y2 = e.targetTouches[1].pageY;
    const distance = Math.sqrt((x2 - x1) ** 2 + (y2 - y1) ** 2);
    return distance;
  }
  function onGestureStart(e) {
    const support2 = swiper.support;
    const params = swiper.params.zoom;
    fakeGestureTouched = false;
    fakeGestureMoved = false;
    if (!support2.gestures) {
      if (e.type !== "touchstart" || e.type === "touchstart" && e.targetTouches.length < 2) {
        return;
      }
      fakeGestureTouched = true;
      gesture.scaleStart = getDistanceBetweenTouches(e);
    }
    if (!gesture.$slideEl || !gesture.$slideEl.length) {
      gesture.$slideEl = $(e.target).closest(`.${swiper.params.slideClass}`);
      if (gesture.$slideEl.length === 0)
        gesture.$slideEl = swiper.slides.eq(swiper.activeIndex);
      gesture.$imageEl = gesture.$slideEl.find(`.${params.containerClass}`).eq(0).find("picture, img, svg, canvas, .swiper-zoom-target").eq(0);
      gesture.$imageWrapEl = gesture.$imageEl.parent(`.${params.containerClass}`);
      gesture.maxRatio = gesture.$imageWrapEl.attr("data-swiper-zoom") || params.maxRatio;
      if (gesture.$imageWrapEl.length === 0) {
        gesture.$imageEl = void 0;
        return;
      }
    }
    if (gesture.$imageEl) {
      gesture.$imageEl.transition(0);
    }
    isScaling = true;
  }
  function onGestureChange(e) {
    const support2 = swiper.support;
    const params = swiper.params.zoom;
    const zoom = swiper.zoom;
    if (!support2.gestures) {
      if (e.type !== "touchmove" || e.type === "touchmove" && e.targetTouches.length < 2) {
        return;
      }
      fakeGestureMoved = true;
      gesture.scaleMove = getDistanceBetweenTouches(e);
    }
    if (!gesture.$imageEl || gesture.$imageEl.length === 0) {
      if (e.type === "gesturechange")
        onGestureStart(e);
      return;
    }
    if (support2.gestures) {
      zoom.scale = e.scale * currentScale;
    } else {
      zoom.scale = gesture.scaleMove / gesture.scaleStart * currentScale;
    }
    if (zoom.scale > gesture.maxRatio) {
      zoom.scale = gesture.maxRatio - 1 + (zoom.scale - gesture.maxRatio + 1) ** 0.5;
    }
    if (zoom.scale < params.minRatio) {
      zoom.scale = params.minRatio + 1 - (params.minRatio - zoom.scale + 1) ** 0.5;
    }
    gesture.$imageEl.transform(`translate3d(0,0,0) scale(${zoom.scale})`);
  }
  function onGestureEnd(e) {
    const device = swiper.device;
    const support2 = swiper.support;
    const params = swiper.params.zoom;
    const zoom = swiper.zoom;
    if (!support2.gestures) {
      if (!fakeGestureTouched || !fakeGestureMoved) {
        return;
      }
      if (e.type !== "touchend" || e.type === "touchend" && e.changedTouches.length < 2 && !device.android) {
        return;
      }
      fakeGestureTouched = false;
      fakeGestureMoved = false;
    }
    if (!gesture.$imageEl || gesture.$imageEl.length === 0)
      return;
    zoom.scale = Math.max(Math.min(zoom.scale, gesture.maxRatio), params.minRatio);
    gesture.$imageEl.transition(swiper.params.speed).transform(`translate3d(0,0,0) scale(${zoom.scale})`);
    currentScale = zoom.scale;
    isScaling = false;
    if (zoom.scale === 1)
      gesture.$slideEl = void 0;
  }
  function onTouchStart2(e) {
    const device = swiper.device;
    if (!gesture.$imageEl || gesture.$imageEl.length === 0)
      return;
    if (image.isTouched)
      return;
    if (device.android && e.cancelable)
      e.preventDefault();
    image.isTouched = true;
    image.touchesStart.x = e.type === "touchstart" ? e.targetTouches[0].pageX : e.pageX;
    image.touchesStart.y = e.type === "touchstart" ? e.targetTouches[0].pageY : e.pageY;
  }
  function onTouchMove2(e) {
    const zoom = swiper.zoom;
    if (!gesture.$imageEl || gesture.$imageEl.length === 0)
      return;
    swiper.allowClick = false;
    if (!image.isTouched || !gesture.$slideEl)
      return;
    if (!image.isMoved) {
      image.width = gesture.$imageEl[0].offsetWidth;
      image.height = gesture.$imageEl[0].offsetHeight;
      image.startX = getTranslate(gesture.$imageWrapEl[0], "x") || 0;
      image.startY = getTranslate(gesture.$imageWrapEl[0], "y") || 0;
      gesture.slideWidth = gesture.$slideEl[0].offsetWidth;
      gesture.slideHeight = gesture.$slideEl[0].offsetHeight;
      gesture.$imageWrapEl.transition(0);
    }
    const scaledWidth = image.width * zoom.scale;
    const scaledHeight = image.height * zoom.scale;
    if (scaledWidth < gesture.slideWidth && scaledHeight < gesture.slideHeight)
      return;
    image.minX = Math.min(gesture.slideWidth / 2 - scaledWidth / 2, 0);
    image.maxX = -image.minX;
    image.minY = Math.min(gesture.slideHeight / 2 - scaledHeight / 2, 0);
    image.maxY = -image.minY;
    image.touchesCurrent.x = e.type === "touchmove" ? e.targetTouches[0].pageX : e.pageX;
    image.touchesCurrent.y = e.type === "touchmove" ? e.targetTouches[0].pageY : e.pageY;
    if (!image.isMoved && !isScaling) {
      if (swiper.isHorizontal() && (Math.floor(image.minX) === Math.floor(image.startX) && image.touchesCurrent.x < image.touchesStart.x || Math.floor(image.maxX) === Math.floor(image.startX) && image.touchesCurrent.x > image.touchesStart.x)) {
        image.isTouched = false;
        return;
      }
      if (!swiper.isHorizontal() && (Math.floor(image.minY) === Math.floor(image.startY) && image.touchesCurrent.y < image.touchesStart.y || Math.floor(image.maxY) === Math.floor(image.startY) && image.touchesCurrent.y > image.touchesStart.y)) {
        image.isTouched = false;
        return;
      }
    }
    if (e.cancelable) {
      e.preventDefault();
    }
    e.stopPropagation();
    image.isMoved = true;
    image.currentX = image.touchesCurrent.x - image.touchesStart.x + image.startX;
    image.currentY = image.touchesCurrent.y - image.touchesStart.y + image.startY;
    if (image.currentX < image.minX) {
      image.currentX = image.minX + 1 - (image.minX - image.currentX + 1) ** 0.8;
    }
    if (image.currentX > image.maxX) {
      image.currentX = image.maxX - 1 + (image.currentX - image.maxX + 1) ** 0.8;
    }
    if (image.currentY < image.minY) {
      image.currentY = image.minY + 1 - (image.minY - image.currentY + 1) ** 0.8;
    }
    if (image.currentY > image.maxY) {
      image.currentY = image.maxY - 1 + (image.currentY - image.maxY + 1) ** 0.8;
    }
    if (!velocity.prevPositionX)
      velocity.prevPositionX = image.touchesCurrent.x;
    if (!velocity.prevPositionY)
      velocity.prevPositionY = image.touchesCurrent.y;
    if (!velocity.prevTime)
      velocity.prevTime = Date.now();
    velocity.x = (image.touchesCurrent.x - velocity.prevPositionX) / (Date.now() - velocity.prevTime) / 2;
    velocity.y = (image.touchesCurrent.y - velocity.prevPositionY) / (Date.now() - velocity.prevTime) / 2;
    if (Math.abs(image.touchesCurrent.x - velocity.prevPositionX) < 2)
      velocity.x = 0;
    if (Math.abs(image.touchesCurrent.y - velocity.prevPositionY) < 2)
      velocity.y = 0;
    velocity.prevPositionX = image.touchesCurrent.x;
    velocity.prevPositionY = image.touchesCurrent.y;
    velocity.prevTime = Date.now();
    gesture.$imageWrapEl.transform(`translate3d(${image.currentX}px, ${image.currentY}px,0)`);
  }
  function onTouchEnd2() {
    const zoom = swiper.zoom;
    if (!gesture.$imageEl || gesture.$imageEl.length === 0)
      return;
    if (!image.isTouched || !image.isMoved) {
      image.isTouched = false;
      image.isMoved = false;
      return;
    }
    image.isTouched = false;
    image.isMoved = false;
    let momentumDurationX = 300;
    let momentumDurationY = 300;
    const momentumDistanceX = velocity.x * momentumDurationX;
    const newPositionX = image.currentX + momentumDistanceX;
    const momentumDistanceY = velocity.y * momentumDurationY;
    const newPositionY = image.currentY + momentumDistanceY;
    if (velocity.x !== 0)
      momentumDurationX = Math.abs((newPositionX - image.currentX) / velocity.x);
    if (velocity.y !== 0)
      momentumDurationY = Math.abs((newPositionY - image.currentY) / velocity.y);
    const momentumDuration = Math.max(momentumDurationX, momentumDurationY);
    image.currentX = newPositionX;
    image.currentY = newPositionY;
    const scaledWidth = image.width * zoom.scale;
    const scaledHeight = image.height * zoom.scale;
    image.minX = Math.min(gesture.slideWidth / 2 - scaledWidth / 2, 0);
    image.maxX = -image.minX;
    image.minY = Math.min(gesture.slideHeight / 2 - scaledHeight / 2, 0);
    image.maxY = -image.minY;
    image.currentX = Math.max(Math.min(image.currentX, image.maxX), image.minX);
    image.currentY = Math.max(Math.min(image.currentY, image.maxY), image.minY);
    gesture.$imageWrapEl.transition(momentumDuration).transform(`translate3d(${image.currentX}px, ${image.currentY}px,0)`);
  }
  function onTransitionEnd() {
    const zoom = swiper.zoom;
    if (gesture.$slideEl && swiper.previousIndex !== swiper.activeIndex) {
      if (gesture.$imageEl) {
        gesture.$imageEl.transform("translate3d(0,0,0) scale(1)");
      }
      if (gesture.$imageWrapEl) {
        gesture.$imageWrapEl.transform("translate3d(0,0,0)");
      }
      zoom.scale = 1;
      currentScale = 1;
      gesture.$slideEl = void 0;
      gesture.$imageEl = void 0;
      gesture.$imageWrapEl = void 0;
    }
  }
  function zoomIn(e) {
    const zoom = swiper.zoom;
    const params = swiper.params.zoom;
    if (!gesture.$slideEl) {
      if (e && e.target) {
        gesture.$slideEl = $(e.target).closest(`.${swiper.params.slideClass}`);
      }
      if (!gesture.$slideEl) {
        if (swiper.params.virtual && swiper.params.virtual.enabled && swiper.virtual) {
          gesture.$slideEl = swiper.$wrapperEl.children(`.${swiper.params.slideActiveClass}`);
        } else {
          gesture.$slideEl = swiper.slides.eq(swiper.activeIndex);
        }
      }
      gesture.$imageEl = gesture.$slideEl.find(`.${params.containerClass}`).eq(0).find("picture, img, svg, canvas, .swiper-zoom-target").eq(0);
      gesture.$imageWrapEl = gesture.$imageEl.parent(`.${params.containerClass}`);
    }
    if (!gesture.$imageEl || gesture.$imageEl.length === 0 || !gesture.$imageWrapEl || gesture.$imageWrapEl.length === 0)
      return;
    if (swiper.params.cssMode) {
      swiper.wrapperEl.style.overflow = "hidden";
      swiper.wrapperEl.style.touchAction = "none";
    }
    gesture.$slideEl.addClass(`${params.zoomedSlideClass}`);
    let touchX;
    let touchY;
    let offsetX;
    let offsetY;
    let diffX;
    let diffY;
    let translateX;
    let translateY;
    let imageWidth;
    let imageHeight;
    let scaledWidth;
    let scaledHeight;
    let translateMinX;
    let translateMinY;
    let translateMaxX;
    let translateMaxY;
    let slideWidth;
    let slideHeight;
    if (typeof image.touchesStart.x === "undefined" && e) {
      touchX = e.type === "touchend" ? e.changedTouches[0].pageX : e.pageX;
      touchY = e.type === "touchend" ? e.changedTouches[0].pageY : e.pageY;
    } else {
      touchX = image.touchesStart.x;
      touchY = image.touchesStart.y;
    }
    zoom.scale = gesture.$imageWrapEl.attr("data-swiper-zoom") || params.maxRatio;
    currentScale = gesture.$imageWrapEl.attr("data-swiper-zoom") || params.maxRatio;
    if (e) {
      slideWidth = gesture.$slideEl[0].offsetWidth;
      slideHeight = gesture.$slideEl[0].offsetHeight;
      offsetX = gesture.$slideEl.offset().left + window2.scrollX;
      offsetY = gesture.$slideEl.offset().top + window2.scrollY;
      diffX = offsetX + slideWidth / 2 - touchX;
      diffY = offsetY + slideHeight / 2 - touchY;
      imageWidth = gesture.$imageEl[0].offsetWidth;
      imageHeight = gesture.$imageEl[0].offsetHeight;
      scaledWidth = imageWidth * zoom.scale;
      scaledHeight = imageHeight * zoom.scale;
      translateMinX = Math.min(slideWidth / 2 - scaledWidth / 2, 0);
      translateMinY = Math.min(slideHeight / 2 - scaledHeight / 2, 0);
      translateMaxX = -translateMinX;
      translateMaxY = -translateMinY;
      translateX = diffX * zoom.scale;
      translateY = diffY * zoom.scale;
      if (translateX < translateMinX) {
        translateX = translateMinX;
      }
      if (translateX > translateMaxX) {
        translateX = translateMaxX;
      }
      if (translateY < translateMinY) {
        translateY = translateMinY;
      }
      if (translateY > translateMaxY) {
        translateY = translateMaxY;
      }
    } else {
      translateX = 0;
      translateY = 0;
    }
    gesture.$imageWrapEl.transition(300).transform(`translate3d(${translateX}px, ${translateY}px,0)`);
    gesture.$imageEl.transition(300).transform(`translate3d(0,0,0) scale(${zoom.scale})`);
  }
  function zoomOut() {
    const zoom = swiper.zoom;
    const params = swiper.params.zoom;
    if (!gesture.$slideEl) {
      if (swiper.params.virtual && swiper.params.virtual.enabled && swiper.virtual) {
        gesture.$slideEl = swiper.$wrapperEl.children(`.${swiper.params.slideActiveClass}`);
      } else {
        gesture.$slideEl = swiper.slides.eq(swiper.activeIndex);
      }
      gesture.$imageEl = gesture.$slideEl.find(`.${params.containerClass}`).eq(0).find("picture, img, svg, canvas, .swiper-zoom-target").eq(0);
      gesture.$imageWrapEl = gesture.$imageEl.parent(`.${params.containerClass}`);
    }
    if (!gesture.$imageEl || gesture.$imageEl.length === 0 || !gesture.$imageWrapEl || gesture.$imageWrapEl.length === 0)
      return;
    if (swiper.params.cssMode) {
      swiper.wrapperEl.style.overflow = "";
      swiper.wrapperEl.style.touchAction = "";
    }
    zoom.scale = 1;
    currentScale = 1;
    gesture.$imageWrapEl.transition(300).transform("translate3d(0,0,0)");
    gesture.$imageEl.transition(300).transform("translate3d(0,0,0) scale(1)");
    gesture.$slideEl.removeClass(`${params.zoomedSlideClass}`);
    gesture.$slideEl = void 0;
  }
  function zoomToggle(e) {
    const zoom = swiper.zoom;
    if (zoom.scale && zoom.scale !== 1) {
      zoomOut();
    } else {
      zoomIn(e);
    }
  }
  function getListeners() {
    const support2 = swiper.support;
    const passiveListener = swiper.touchEvents.start === "touchstart" && support2.passiveListener && swiper.params.passiveListeners ? {
      passive: true,
      capture: false
    } : false;
    const activeListenerWithCapture = support2.passiveListener ? {
      passive: false,
      capture: true
    } : true;
    return {
      passiveListener,
      activeListenerWithCapture
    };
  }
  function getSlideSelector() {
    return `.${swiper.params.slideClass}`;
  }
  function toggleGestures(method) {
    const {
      passiveListener
    } = getListeners();
    const slideSelector = getSlideSelector();
    swiper.$wrapperEl[method]("gesturestart", slideSelector, onGestureStart, passiveListener);
    swiper.$wrapperEl[method]("gesturechange", slideSelector, onGestureChange, passiveListener);
    swiper.$wrapperEl[method]("gestureend", slideSelector, onGestureEnd, passiveListener);
  }
  function enableGestures() {
    if (gesturesEnabled)
      return;
    gesturesEnabled = true;
    toggleGestures("on");
  }
  function disableGestures() {
    if (!gesturesEnabled)
      return;
    gesturesEnabled = false;
    toggleGestures("off");
  }
  function enable() {
    const zoom = swiper.zoom;
    if (zoom.enabled)
      return;
    zoom.enabled = true;
    const support2 = swiper.support;
    const {
      passiveListener,
      activeListenerWithCapture
    } = getListeners();
    const slideSelector = getSlideSelector();
    if (support2.gestures) {
      swiper.$wrapperEl.on(swiper.touchEvents.start, enableGestures, passiveListener);
      swiper.$wrapperEl.on(swiper.touchEvents.end, disableGestures, passiveListener);
    } else if (swiper.touchEvents.start === "touchstart") {
      swiper.$wrapperEl.on(swiper.touchEvents.start, slideSelector, onGestureStart, passiveListener);
      swiper.$wrapperEl.on(swiper.touchEvents.move, slideSelector, onGestureChange, activeListenerWithCapture);
      swiper.$wrapperEl.on(swiper.touchEvents.end, slideSelector, onGestureEnd, passiveListener);
      if (swiper.touchEvents.cancel) {
        swiper.$wrapperEl.on(swiper.touchEvents.cancel, slideSelector, onGestureEnd, passiveListener);
      }
    }
    swiper.$wrapperEl.on(swiper.touchEvents.move, `.${swiper.params.zoom.containerClass}`, onTouchMove2, activeListenerWithCapture);
  }
  function disable() {
    const zoom = swiper.zoom;
    if (!zoom.enabled)
      return;
    const support2 = swiper.support;
    zoom.enabled = false;
    const {
      passiveListener,
      activeListenerWithCapture
    } = getListeners();
    const slideSelector = getSlideSelector();
    if (support2.gestures) {
      swiper.$wrapperEl.off(swiper.touchEvents.start, enableGestures, passiveListener);
      swiper.$wrapperEl.off(swiper.touchEvents.end, disableGestures, passiveListener);
    } else if (swiper.touchEvents.start === "touchstart") {
      swiper.$wrapperEl.off(swiper.touchEvents.start, slideSelector, onGestureStart, passiveListener);
      swiper.$wrapperEl.off(swiper.touchEvents.move, slideSelector, onGestureChange, activeListenerWithCapture);
      swiper.$wrapperEl.off(swiper.touchEvents.end, slideSelector, onGestureEnd, passiveListener);
      if (swiper.touchEvents.cancel) {
        swiper.$wrapperEl.off(swiper.touchEvents.cancel, slideSelector, onGestureEnd, passiveListener);
      }
    }
    swiper.$wrapperEl.off(swiper.touchEvents.move, `.${swiper.params.zoom.containerClass}`, onTouchMove2, activeListenerWithCapture);
  }
  on2("init", () => {
    if (swiper.params.zoom.enabled) {
      enable();
    }
  });
  on2("destroy", () => {
    disable();
  });
  on2("touchStart", (_s, e) => {
    if (!swiper.zoom.enabled)
      return;
    onTouchStart2(e);
  });
  on2("touchEnd", (_s, e) => {
    if (!swiper.zoom.enabled)
      return;
    onTouchEnd2();
  });
  on2("doubleTap", (_s, e) => {
    if (!swiper.animating && swiper.params.zoom.enabled && swiper.zoom.enabled && swiper.params.zoom.toggle) {
      zoomToggle(e);
    }
  });
  on2("transitionEnd", () => {
    if (swiper.zoom.enabled && swiper.params.zoom.enabled) {
      onTransitionEnd();
    }
  });
  on2("slideChange", () => {
    if (swiper.zoom.enabled && swiper.params.zoom.enabled && swiper.params.cssMode) {
      onTransitionEnd();
    }
  });
  Object.assign(swiper.zoom, {
    enable,
    disable,
    in: zoomIn,
    out: zoomOut,
    toggle: zoomToggle
  });
}
function Lazy({
  swiper,
  extendParams,
  on: on2,
  emit
}) {
  extendParams({
    lazy: {
      checkInView: false,
      enabled: false,
      loadPrevNext: false,
      loadPrevNextAmount: 1,
      loadOnTransitionStart: false,
      scrollingElement: "",
      elementClass: "swiper-lazy",
      loadingClass: "swiper-lazy-loading",
      loadedClass: "swiper-lazy-loaded",
      preloaderClass: "swiper-lazy-preloader"
    }
  });
  swiper.lazy = {};
  let scrollHandlerAttached = false;
  let initialImageLoaded = false;
  function loadInSlide(index2, loadInDuplicate = true) {
    const params = swiper.params.lazy;
    if (typeof index2 === "undefined")
      return;
    if (swiper.slides.length === 0)
      return;
    const isVirtual = swiper.virtual && swiper.params.virtual.enabled;
    const $slideEl = isVirtual ? swiper.$wrapperEl.children(`.${swiper.params.slideClass}[data-swiper-slide-index="${index2}"]`) : swiper.slides.eq(index2);
    const $images = $slideEl.find(`.${params.elementClass}:not(.${params.loadedClass}):not(.${params.loadingClass})`);
    if ($slideEl.hasClass(params.elementClass) && !$slideEl.hasClass(params.loadedClass) && !$slideEl.hasClass(params.loadingClass)) {
      $images.push($slideEl[0]);
    }
    if ($images.length === 0)
      return;
    $images.each((imageEl) => {
      const $imageEl = $(imageEl);
      $imageEl.addClass(params.loadingClass);
      const background = $imageEl.attr("data-background");
      const src = $imageEl.attr("data-src");
      const srcset = $imageEl.attr("data-srcset");
      const sizes = $imageEl.attr("data-sizes");
      const $pictureEl = $imageEl.parent("picture");
      swiper.loadImage($imageEl[0], src || background, srcset, sizes, false, () => {
        if (typeof swiper === "undefined" || swiper === null || !swiper || swiper && !swiper.params || swiper.destroyed)
          return;
        if (background) {
          $imageEl.css("background-image", `url("${background}")`);
          $imageEl.removeAttr("data-background");
        } else {
          if (srcset) {
            $imageEl.attr("srcset", srcset);
            $imageEl.removeAttr("data-srcset");
          }
          if (sizes) {
            $imageEl.attr("sizes", sizes);
            $imageEl.removeAttr("data-sizes");
          }
          if ($pictureEl.length) {
            $pictureEl.children("source").each((sourceEl) => {
              const $source = $(sourceEl);
              if ($source.attr("data-srcset")) {
                $source.attr("srcset", $source.attr("data-srcset"));
                $source.removeAttr("data-srcset");
              }
            });
          }
          if (src) {
            $imageEl.attr("src", src);
            $imageEl.removeAttr("data-src");
          }
        }
        $imageEl.addClass(params.loadedClass).removeClass(params.loadingClass);
        $slideEl.find(`.${params.preloaderClass}`).remove();
        if (swiper.params.loop && loadInDuplicate) {
          const slideOriginalIndex = $slideEl.attr("data-swiper-slide-index");
          if ($slideEl.hasClass(swiper.params.slideDuplicateClass)) {
            const originalSlide = swiper.$wrapperEl.children(`[data-swiper-slide-index="${slideOriginalIndex}"]:not(.${swiper.params.slideDuplicateClass})`);
            loadInSlide(originalSlide.index(), false);
          } else {
            const duplicatedSlide = swiper.$wrapperEl.children(`.${swiper.params.slideDuplicateClass}[data-swiper-slide-index="${slideOriginalIndex}"]`);
            loadInSlide(duplicatedSlide.index(), false);
          }
        }
        emit("lazyImageReady", $slideEl[0], $imageEl[0]);
        if (swiper.params.autoHeight) {
          swiper.updateAutoHeight();
        }
      });
      emit("lazyImageLoad", $slideEl[0], $imageEl[0]);
    });
  }
  function load() {
    const {
      $wrapperEl,
      params: swiperParams,
      slides,
      activeIndex
    } = swiper;
    const isVirtual = swiper.virtual && swiperParams.virtual.enabled;
    const params = swiperParams.lazy;
    let slidesPerView = swiperParams.slidesPerView;
    if (slidesPerView === "auto") {
      slidesPerView = 0;
    }
    function slideExist(index2) {
      if (isVirtual) {
        if ($wrapperEl.children(`.${swiperParams.slideClass}[data-swiper-slide-index="${index2}"]`).length) {
          return true;
        }
      } else if (slides[index2])
        return true;
      return false;
    }
    function slideIndex(slideEl) {
      if (isVirtual) {
        return $(slideEl).attr("data-swiper-slide-index");
      }
      return $(slideEl).index();
    }
    if (!initialImageLoaded)
      initialImageLoaded = true;
    if (swiper.params.watchSlidesProgress) {
      $wrapperEl.children(`.${swiperParams.slideVisibleClass}`).each((slideEl) => {
        const index2 = isVirtual ? $(slideEl).attr("data-swiper-slide-index") : $(slideEl).index();
        loadInSlide(index2);
      });
    } else if (slidesPerView > 1) {
      for (let i = activeIndex; i < activeIndex + slidesPerView; i += 1) {
        if (slideExist(i))
          loadInSlide(i);
      }
    } else {
      loadInSlide(activeIndex);
    }
    if (params.loadPrevNext) {
      if (slidesPerView > 1 || params.loadPrevNextAmount && params.loadPrevNextAmount > 1) {
        const amount = params.loadPrevNextAmount;
        const spv = Math.ceil(slidesPerView);
        const maxIndex = Math.min(activeIndex + spv + Math.max(amount, spv), slides.length);
        const minIndex = Math.max(activeIndex - Math.max(spv, amount), 0);
        for (let i = activeIndex + spv; i < maxIndex; i += 1) {
          if (slideExist(i))
            loadInSlide(i);
        }
        for (let i = minIndex; i < activeIndex; i += 1) {
          if (slideExist(i))
            loadInSlide(i);
        }
      } else {
        const nextSlide = $wrapperEl.children(`.${swiperParams.slideNextClass}`);
        if (nextSlide.length > 0)
          loadInSlide(slideIndex(nextSlide));
        const prevSlide = $wrapperEl.children(`.${swiperParams.slidePrevClass}`);
        if (prevSlide.length > 0)
          loadInSlide(slideIndex(prevSlide));
      }
    }
  }
  function checkInViewOnLoad() {
    const window2 = getWindow();
    if (!swiper || swiper.destroyed)
      return;
    const $scrollElement = swiper.params.lazy.scrollingElement ? $(swiper.params.lazy.scrollingElement) : $(window2);
    const isWindow = $scrollElement[0] === window2;
    const scrollElementWidth = isWindow ? window2.innerWidth : $scrollElement[0].offsetWidth;
    const scrollElementHeight = isWindow ? window2.innerHeight : $scrollElement[0].offsetHeight;
    const swiperOffset = swiper.$el.offset();
    const {
      rtlTranslate: rtl
    } = swiper;
    let inView = false;
    if (rtl)
      swiperOffset.left -= swiper.$el[0].scrollLeft;
    const swiperCoord = [[swiperOffset.left, swiperOffset.top], [swiperOffset.left + swiper.width, swiperOffset.top], [swiperOffset.left, swiperOffset.top + swiper.height], [swiperOffset.left + swiper.width, swiperOffset.top + swiper.height]];
    for (let i = 0; i < swiperCoord.length; i += 1) {
      const point = swiperCoord[i];
      if (point[0] >= 0 && point[0] <= scrollElementWidth && point[1] >= 0 && point[1] <= scrollElementHeight) {
        if (point[0] === 0 && point[1] === 0)
          continue;
        inView = true;
      }
    }
    const passiveListener = swiper.touchEvents.start === "touchstart" && swiper.support.passiveListener && swiper.params.passiveListeners ? {
      passive: true,
      capture: false
    } : false;
    if (inView) {
      load();
      $scrollElement.off("scroll", checkInViewOnLoad, passiveListener);
    } else if (!scrollHandlerAttached) {
      scrollHandlerAttached = true;
      $scrollElement.on("scroll", checkInViewOnLoad, passiveListener);
    }
  }
  on2("beforeInit", () => {
    if (swiper.params.lazy.enabled && swiper.params.preloadImages) {
      swiper.params.preloadImages = false;
    }
  });
  on2("init", () => {
    if (swiper.params.lazy.enabled) {
      if (swiper.params.lazy.checkInView) {
        checkInViewOnLoad();
      } else {
        load();
      }
    }
  });
  on2("scroll", () => {
    if (swiper.params.freeMode && swiper.params.freeMode.enabled && !swiper.params.freeMode.sticky) {
      load();
    }
  });
  on2("scrollbarDragMove resize _freeModeNoMomentumRelease", () => {
    if (swiper.params.lazy.enabled) {
      if (swiper.params.lazy.checkInView) {
        checkInViewOnLoad();
      } else {
        load();
      }
    }
  });
  on2("transitionStart", () => {
    if (swiper.params.lazy.enabled) {
      if (swiper.params.lazy.loadOnTransitionStart || !swiper.params.lazy.loadOnTransitionStart && !initialImageLoaded) {
        if (swiper.params.lazy.checkInView) {
          checkInViewOnLoad();
        } else {
          load();
        }
      }
    }
  });
  on2("transitionEnd", () => {
    if (swiper.params.lazy.enabled && !swiper.params.lazy.loadOnTransitionStart) {
      if (swiper.params.lazy.checkInView) {
        checkInViewOnLoad();
      } else {
        load();
      }
    }
  });
  on2("slideChange", () => {
    const {
      lazy,
      cssMode,
      watchSlidesProgress,
      touchReleaseOnEdges,
      resistanceRatio
    } = swiper.params;
    if (lazy.enabled && (cssMode || watchSlidesProgress && (touchReleaseOnEdges || resistanceRatio === 0))) {
      load();
    }
  });
  on2("destroy", () => {
    if (!swiper.$el)
      return;
    swiper.$el.find(`.${swiper.params.lazy.loadingClass}`).removeClass(swiper.params.lazy.loadingClass);
  });
  Object.assign(swiper.lazy, {
    load,
    loadInSlide
  });
}
function Controller({
  swiper,
  extendParams,
  on: on2
}) {
  extendParams({
    controller: {
      control: void 0,
      inverse: false,
      by: "slide"
      // or 'container'
    }
  });
  swiper.controller = {
    control: void 0
  };
  function LinearSpline(x, y) {
    const binarySearch = function search() {
      let maxIndex;
      let minIndex;
      let guess;
      return (array, val) => {
        minIndex = -1;
        maxIndex = array.length;
        while (maxIndex - minIndex > 1) {
          guess = maxIndex + minIndex >> 1;
          if (array[guess] <= val) {
            minIndex = guess;
          } else {
            maxIndex = guess;
          }
        }
        return maxIndex;
      };
    }();
    this.x = x;
    this.y = y;
    this.lastIndex = x.length - 1;
    let i1;
    let i3;
    this.interpolate = function interpolate(x2) {
      if (!x2)
        return 0;
      i3 = binarySearch(this.x, x2);
      i1 = i3 - 1;
      return (x2 - this.x[i1]) * (this.y[i3] - this.y[i1]) / (this.x[i3] - this.x[i1]) + this.y[i1];
    };
    return this;
  }
  function getInterpolateFunction(c) {
    if (!swiper.controller.spline) {
      swiper.controller.spline = swiper.params.loop ? new LinearSpline(swiper.slidesGrid, c.slidesGrid) : new LinearSpline(swiper.snapGrid, c.snapGrid);
    }
  }
  function setTranslate2(_t, byController) {
    const controlled = swiper.controller.control;
    let multiplier;
    let controlledTranslate;
    const Swiper3 = swiper.constructor;
    function setControlledTranslate(c) {
      const translate2 = swiper.rtlTranslate ? -swiper.translate : swiper.translate;
      if (swiper.params.controller.by === "slide") {
        getInterpolateFunction(c);
        controlledTranslate = -swiper.controller.spline.interpolate(-translate2);
      }
      if (!controlledTranslate || swiper.params.controller.by === "container") {
        multiplier = (c.maxTranslate() - c.minTranslate()) / (swiper.maxTranslate() - swiper.minTranslate());
        controlledTranslate = (translate2 - swiper.minTranslate()) * multiplier + c.minTranslate();
      }
      if (swiper.params.controller.inverse) {
        controlledTranslate = c.maxTranslate() - controlledTranslate;
      }
      c.updateProgress(controlledTranslate);
      c.setTranslate(controlledTranslate, swiper);
      c.updateActiveIndex();
      c.updateSlidesClasses();
    }
    if (Array.isArray(controlled)) {
      for (let i = 0; i < controlled.length; i += 1) {
        if (controlled[i] !== byController && controlled[i] instanceof Swiper3) {
          setControlledTranslate(controlled[i]);
        }
      }
    } else if (controlled instanceof Swiper3 && byController !== controlled) {
      setControlledTranslate(controlled);
    }
  }
  function setTransition2(duration2, byController) {
    const Swiper3 = swiper.constructor;
    const controlled = swiper.controller.control;
    let i;
    function setControlledTransition(c) {
      c.setTransition(duration2, swiper);
      if (duration2 !== 0) {
        c.transitionStart();
        if (c.params.autoHeight) {
          nextTick(() => {
            c.updateAutoHeight();
          });
        }
        c.$wrapperEl.transitionEnd(() => {
          if (!controlled)
            return;
          if (c.params.loop && swiper.params.controller.by === "slide") {
            c.loopFix();
          }
          c.transitionEnd();
        });
      }
    }
    if (Array.isArray(controlled)) {
      for (i = 0; i < controlled.length; i += 1) {
        if (controlled[i] !== byController && controlled[i] instanceof Swiper3) {
          setControlledTransition(controlled[i]);
        }
      }
    } else if (controlled instanceof Swiper3 && byController !== controlled) {
      setControlledTransition(controlled);
    }
  }
  function removeSpline() {
    if (!swiper.controller.control)
      return;
    if (swiper.controller.spline) {
      swiper.controller.spline = void 0;
      delete swiper.controller.spline;
    }
  }
  on2("beforeInit", () => {
    swiper.controller.control = swiper.params.controller.control;
  });
  on2("update", () => {
    removeSpline();
  });
  on2("resize", () => {
    removeSpline();
  });
  on2("observerUpdate", () => {
    removeSpline();
  });
  on2("setTranslate", (_s, translate2, byController) => {
    if (!swiper.controller.control)
      return;
    swiper.controller.setTranslate(translate2, byController);
  });
  on2("setTransition", (_s, duration2, byController) => {
    if (!swiper.controller.control)
      return;
    swiper.controller.setTransition(duration2, byController);
  });
  Object.assign(swiper.controller, {
    setTranslate: setTranslate2,
    setTransition: setTransition2
  });
}
function A11y({
  swiper,
  extendParams,
  on: on2
}) {
  extendParams({
    a11y: {
      enabled: true,
      notificationClass: "swiper-notification",
      prevSlideMessage: "Previous slide",
      nextSlideMessage: "Next slide",
      firstSlideMessage: "This is the first slide",
      lastSlideMessage: "This is the last slide",
      paginationBulletMessage: "Go to slide {{index}}",
      slideLabelMessage: "{{index}} / {{slidesLength}}",
      containerMessage: null,
      containerRoleDescriptionMessage: null,
      itemRoleDescriptionMessage: null,
      slideRole: "group",
      id: null
    }
  });
  swiper.a11y = {
    clicked: false
  };
  let liveRegion = null;
  function notify(message) {
    const notification = liveRegion;
    if (notification.length === 0)
      return;
    notification.html("");
    notification.html(message);
  }
  function getRandomNumber(size = 16) {
    const randomChar = () => Math.round(16 * Math.random()).toString(16);
    return "x".repeat(size).replace(/x/g, randomChar);
  }
  function makeElFocusable($el) {
    $el.attr("tabIndex", "0");
  }
  function makeElNotFocusable($el) {
    $el.attr("tabIndex", "-1");
  }
  function addElRole($el, role) {
    $el.attr("role", role);
  }
  function addElRoleDescription($el, description) {
    $el.attr("aria-roledescription", description);
  }
  function addElControls($el, controls) {
    $el.attr("aria-controls", controls);
  }
  function addElLabel($el, label) {
    $el.attr("aria-label", label);
  }
  function addElId($el, id) {
    $el.attr("id", id);
  }
  function addElLive($el, live) {
    $el.attr("aria-live", live);
  }
  function disableEl($el) {
    $el.attr("aria-disabled", true);
  }
  function enableEl($el) {
    $el.attr("aria-disabled", false);
  }
  function onEnterOrSpaceKey(e) {
    if (e.keyCode !== 13 && e.keyCode !== 32)
      return;
    const params = swiper.params.a11y;
    const $targetEl = $(e.target);
    if (swiper.navigation && swiper.navigation.$nextEl && $targetEl.is(swiper.navigation.$nextEl)) {
      if (!(swiper.isEnd && !swiper.params.loop)) {
        swiper.slideNext();
      }
      if (swiper.isEnd) {
        notify(params.lastSlideMessage);
      } else {
        notify(params.nextSlideMessage);
      }
    }
    if (swiper.navigation && swiper.navigation.$prevEl && $targetEl.is(swiper.navigation.$prevEl)) {
      if (!(swiper.isBeginning && !swiper.params.loop)) {
        swiper.slidePrev();
      }
      if (swiper.isBeginning) {
        notify(params.firstSlideMessage);
      } else {
        notify(params.prevSlideMessage);
      }
    }
    if (swiper.pagination && $targetEl.is(classesToSelector(swiper.params.pagination.bulletClass))) {
      $targetEl[0].click();
    }
  }
  function updateNavigation() {
    if (swiper.params.loop || swiper.params.rewind || !swiper.navigation)
      return;
    const {
      $nextEl,
      $prevEl
    } = swiper.navigation;
    if ($prevEl && $prevEl.length > 0) {
      if (swiper.isBeginning) {
        disableEl($prevEl);
        makeElNotFocusable($prevEl);
      } else {
        enableEl($prevEl);
        makeElFocusable($prevEl);
      }
    }
    if ($nextEl && $nextEl.length > 0) {
      if (swiper.isEnd) {
        disableEl($nextEl);
        makeElNotFocusable($nextEl);
      } else {
        enableEl($nextEl);
        makeElFocusable($nextEl);
      }
    }
  }
  function hasPagination() {
    return swiper.pagination && swiper.pagination.bullets && swiper.pagination.bullets.length;
  }
  function hasClickablePagination() {
    return hasPagination() && swiper.params.pagination.clickable;
  }
  function updatePagination() {
    const params = swiper.params.a11y;
    if (!hasPagination())
      return;
    swiper.pagination.bullets.each((bulletEl) => {
      const $bulletEl = $(bulletEl);
      if (swiper.params.pagination.clickable) {
        makeElFocusable($bulletEl);
        if (!swiper.params.pagination.renderBullet) {
          addElRole($bulletEl, "button");
          addElLabel($bulletEl, params.paginationBulletMessage.replace(/\{\{index\}\}/, $bulletEl.index() + 1));
        }
      }
      if ($bulletEl.is(`.${swiper.params.pagination.bulletActiveClass}`)) {
        $bulletEl.attr("aria-current", "true");
      } else {
        $bulletEl.removeAttr("aria-current");
      }
    });
  }
  const initNavEl = ($el, wrapperId, message) => {
    makeElFocusable($el);
    if ($el[0].tagName !== "BUTTON") {
      addElRole($el, "button");
      $el.on("keydown", onEnterOrSpaceKey);
    }
    addElLabel($el, message);
    addElControls($el, wrapperId);
  };
  const handlePointerDown = () => {
    swiper.a11y.clicked = true;
  };
  const handlePointerUp = () => {
    requestAnimationFrame(() => {
      requestAnimationFrame(() => {
        if (!swiper.destroyed) {
          swiper.a11y.clicked = false;
        }
      });
    });
  };
  const handleFocus = (e) => {
    if (swiper.a11y.clicked)
      return;
    const slideEl = e.target.closest(`.${swiper.params.slideClass}`);
    if (!slideEl || !swiper.slides.includes(slideEl))
      return;
    const isActive = swiper.slides.indexOf(slideEl) === swiper.activeIndex;
    const isVisible = swiper.params.watchSlidesProgress && swiper.visibleSlides && swiper.visibleSlides.includes(slideEl);
    if (isActive || isVisible)
      return;
    if (e.sourceCapabilities && e.sourceCapabilities.firesTouchEvents)
      return;
    if (swiper.isHorizontal()) {
      swiper.el.scrollLeft = 0;
    } else {
      swiper.el.scrollTop = 0;
    }
    swiper.slideTo(swiper.slides.indexOf(slideEl), 0);
  };
  const initSlides = () => {
    const params = swiper.params.a11y;
    if (params.itemRoleDescriptionMessage) {
      addElRoleDescription($(swiper.slides), params.itemRoleDescriptionMessage);
    }
    if (params.slideRole) {
      addElRole($(swiper.slides), params.slideRole);
    }
    const slidesLength = swiper.params.loop ? swiper.slides.filter((el) => !el.classList.contains(swiper.params.slideDuplicateClass)).length : swiper.slides.length;
    if (params.slideLabelMessage) {
      swiper.slides.each((slideEl, index2) => {
        const $slideEl = $(slideEl);
        const slideIndex = swiper.params.loop ? parseInt($slideEl.attr("data-swiper-slide-index"), 10) : index2;
        const ariaLabelMessage = params.slideLabelMessage.replace(/\{\{index\}\}/, slideIndex + 1).replace(/\{\{slidesLength\}\}/, slidesLength);
        addElLabel($slideEl, ariaLabelMessage);
      });
    }
  };
  const init = () => {
    const params = swiper.params.a11y;
    swiper.$el.append(liveRegion);
    const $containerEl = swiper.$el;
    if (params.containerRoleDescriptionMessage) {
      addElRoleDescription($containerEl, params.containerRoleDescriptionMessage);
    }
    if (params.containerMessage) {
      addElLabel($containerEl, params.containerMessage);
    }
    const $wrapperEl = swiper.$wrapperEl;
    const wrapperId = params.id || $wrapperEl.attr("id") || `swiper-wrapper-${getRandomNumber(16)}`;
    const live = swiper.params.autoplay && swiper.params.autoplay.enabled ? "off" : "polite";
    addElId($wrapperEl, wrapperId);
    addElLive($wrapperEl, live);
    initSlides();
    let $nextEl;
    let $prevEl;
    if (swiper.navigation && swiper.navigation.$nextEl) {
      $nextEl = swiper.navigation.$nextEl;
    }
    if (swiper.navigation && swiper.navigation.$prevEl) {
      $prevEl = swiper.navigation.$prevEl;
    }
    if ($nextEl && $nextEl.length) {
      initNavEl($nextEl, wrapperId, params.nextSlideMessage);
    }
    if ($prevEl && $prevEl.length) {
      initNavEl($prevEl, wrapperId, params.prevSlideMessage);
    }
    if (hasClickablePagination()) {
      swiper.pagination.$el.on("keydown", classesToSelector(swiper.params.pagination.bulletClass), onEnterOrSpaceKey);
    }
    swiper.$el.on("focus", handleFocus, true);
    swiper.$el.on("pointerdown", handlePointerDown, true);
    swiper.$el.on("pointerup", handlePointerUp, true);
  };
  function destroy() {
    if (liveRegion && liveRegion.length > 0)
      liveRegion.remove();
    let $nextEl;
    let $prevEl;
    if (swiper.navigation && swiper.navigation.$nextEl) {
      $nextEl = swiper.navigation.$nextEl;
    }
    if (swiper.navigation && swiper.navigation.$prevEl) {
      $prevEl = swiper.navigation.$prevEl;
    }
    if ($nextEl) {
      $nextEl.off("keydown", onEnterOrSpaceKey);
    }
    if ($prevEl) {
      $prevEl.off("keydown", onEnterOrSpaceKey);
    }
    if (hasClickablePagination()) {
      swiper.pagination.$el.off("keydown", classesToSelector(swiper.params.pagination.bulletClass), onEnterOrSpaceKey);
    }
    swiper.$el.off("focus", handleFocus, true);
    swiper.$el.off("pointerdown", handlePointerDown, true);
    swiper.$el.off("pointerup", handlePointerUp, true);
  }
  on2("beforeInit", () => {
    liveRegion = $(`<span class="${swiper.params.a11y.notificationClass}" aria-live="assertive" aria-atomic="true"></span>`);
  });
  on2("afterInit", () => {
    if (!swiper.params.a11y.enabled)
      return;
    init();
  });
  on2("slidesLengthChange snapGridLengthChange slidesGridLengthChange", () => {
    if (!swiper.params.a11y.enabled)
      return;
    initSlides();
  });
  on2("fromEdge toEdge afterInit lock unlock", () => {
    if (!swiper.params.a11y.enabled)
      return;
    updateNavigation();
  });
  on2("paginationUpdate", () => {
    if (!swiper.params.a11y.enabled)
      return;
    updatePagination();
  });
  on2("destroy", () => {
    if (!swiper.params.a11y.enabled)
      return;
    destroy();
  });
}
function History({
  swiper,
  extendParams,
  on: on2
}) {
  extendParams({
    history: {
      enabled: false,
      root: "",
      replaceState: false,
      key: "slides",
      keepQuery: false
    }
  });
  let initialized = false;
  let paths = {};
  const slugify = (text2) => {
    return text2.toString().replace(/\s+/g, "-").replace(/[^\w-]+/g, "").replace(/--+/g, "-").replace(/^-+/, "").replace(/-+$/, "");
  };
  const getPathValues = (urlOverride) => {
    const window2 = getWindow();
    let location2;
    if (urlOverride) {
      location2 = new URL(urlOverride);
    } else {
      location2 = window2.location;
    }
    const pathArray = location2.pathname.slice(1).split("/").filter((part) => part !== "");
    const total = pathArray.length;
    const key = pathArray[total - 2];
    const value = pathArray[total - 1];
    return {
      key,
      value
    };
  };
  const setHistory = (key, index2) => {
    const window2 = getWindow();
    if (!initialized || !swiper.params.history.enabled)
      return;
    let location2;
    if (swiper.params.url) {
      location2 = new URL(swiper.params.url);
    } else {
      location2 = window2.location;
    }
    const slide2 = swiper.slides.eq(index2);
    let value = slugify(slide2.attr("data-history"));
    if (swiper.params.history.root.length > 0) {
      let root = swiper.params.history.root;
      if (root[root.length - 1] === "/")
        root = root.slice(0, root.length - 1);
      value = `${root}/${key}/${value}`;
    } else if (!location2.pathname.includes(key)) {
      value = `${key}/${value}`;
    }
    if (swiper.params.history.keepQuery) {
      value += location2.search;
    }
    const currentState = window2.history.state;
    if (currentState && currentState.value === value) {
      return;
    }
    if (swiper.params.history.replaceState) {
      window2.history.replaceState({
        value
      }, null, value);
    } else {
      window2.history.pushState({
        value
      }, null, value);
    }
  };
  const scrollToSlide = (speed, value, runCallbacks) => {
    if (value) {
      for (let i = 0, length = swiper.slides.length; i < length; i += 1) {
        const slide2 = swiper.slides.eq(i);
        const slideHistory = slugify(slide2.attr("data-history"));
        if (slideHistory === value && !slide2.hasClass(swiper.params.slideDuplicateClass)) {
          const index2 = slide2.index();
          swiper.slideTo(index2, speed, runCallbacks);
        }
      }
    } else {
      swiper.slideTo(0, speed, runCallbacks);
    }
  };
  const setHistoryPopState = () => {
    paths = getPathValues(swiper.params.url);
    scrollToSlide(swiper.params.speed, paths.value, false);
  };
  const init = () => {
    const window2 = getWindow();
    if (!swiper.params.history)
      return;
    if (!window2.history || !window2.history.pushState) {
      swiper.params.history.enabled = false;
      swiper.params.hashNavigation.enabled = true;
      return;
    }
    initialized = true;
    paths = getPathValues(swiper.params.url);
    if (!paths.key && !paths.value)
      return;
    scrollToSlide(0, paths.value, swiper.params.runCallbacksOnInit);
    if (!swiper.params.history.replaceState) {
      window2.addEventListener("popstate", setHistoryPopState);
    }
  };
  const destroy = () => {
    const window2 = getWindow();
    if (!swiper.params.history.replaceState) {
      window2.removeEventListener("popstate", setHistoryPopState);
    }
  };
  on2("init", () => {
    if (swiper.params.history.enabled) {
      init();
    }
  });
  on2("destroy", () => {
    if (swiper.params.history.enabled) {
      destroy();
    }
  });
  on2("transitionEnd _freeModeNoMomentumRelease", () => {
    if (initialized) {
      setHistory(swiper.params.history.key, swiper.activeIndex);
    }
  });
  on2("slideChange", () => {
    if (initialized && swiper.params.cssMode) {
      setHistory(swiper.params.history.key, swiper.activeIndex);
    }
  });
}
function HashNavigation({
  swiper,
  extendParams,
  emit,
  on: on2
}) {
  let initialized = false;
  const document2 = getDocument();
  const window2 = getWindow();
  extendParams({
    hashNavigation: {
      enabled: false,
      replaceState: false,
      watchState: false
    }
  });
  const onHashChange = () => {
    emit("hashChange");
    const newHash = document2.location.hash.replace("#", "");
    const activeSlideHash = swiper.slides.eq(swiper.activeIndex).attr("data-hash");
    if (newHash !== activeSlideHash) {
      const newIndex = swiper.$wrapperEl.children(`.${swiper.params.slideClass}[data-hash="${newHash}"]`).index();
      if (typeof newIndex === "undefined")
        return;
      swiper.slideTo(newIndex);
    }
  };
  const setHash = () => {
    if (!initialized || !swiper.params.hashNavigation.enabled)
      return;
    if (swiper.params.hashNavigation.replaceState && window2.history && window2.history.replaceState) {
      window2.history.replaceState(null, null, `#${swiper.slides.eq(swiper.activeIndex).attr("data-hash")}` || "");
      emit("hashSet");
    } else {
      const slide2 = swiper.slides.eq(swiper.activeIndex);
      const hash = slide2.attr("data-hash") || slide2.attr("data-history");
      document2.location.hash = hash || "";
      emit("hashSet");
    }
  };
  const init = () => {
    if (!swiper.params.hashNavigation.enabled || swiper.params.history && swiper.params.history.enabled)
      return;
    initialized = true;
    const hash = document2.location.hash.replace("#", "");
    if (hash) {
      const speed = 0;
      for (let i = 0, length = swiper.slides.length; i < length; i += 1) {
        const slide2 = swiper.slides.eq(i);
        const slideHash = slide2.attr("data-hash") || slide2.attr("data-history");
        if (slideHash === hash && !slide2.hasClass(swiper.params.slideDuplicateClass)) {
          const index2 = slide2.index();
          swiper.slideTo(index2, speed, swiper.params.runCallbacksOnInit, true);
        }
      }
    }
    if (swiper.params.hashNavigation.watchState) {
      $(window2).on("hashchange", onHashChange);
    }
  };
  const destroy = () => {
    if (swiper.params.hashNavigation.watchState) {
      $(window2).off("hashchange", onHashChange);
    }
  };
  on2("init", () => {
    if (swiper.params.hashNavigation.enabled) {
      init();
    }
  });
  on2("destroy", () => {
    if (swiper.params.hashNavigation.enabled) {
      destroy();
    }
  });
  on2("transitionEnd _freeModeNoMomentumRelease", () => {
    if (initialized) {
      setHash();
    }
  });
  on2("slideChange", () => {
    if (initialized && swiper.params.cssMode) {
      setHash();
    }
  });
}
function Autoplay({
  swiper,
  extendParams,
  on: on2,
  emit
}) {
  let timeout;
  swiper.autoplay = {
    running: false,
    paused: false
  };
  extendParams({
    autoplay: {
      enabled: false,
      delay: 3e3,
      waitForTransition: true,
      disableOnInteraction: true,
      stopOnLastSlide: false,
      reverseDirection: false,
      pauseOnMouseEnter: false
    }
  });
  function run() {
    if (!swiper.size) {
      swiper.autoplay.running = false;
      swiper.autoplay.paused = false;
      return;
    }
    const $activeSlideEl = swiper.slides.eq(swiper.activeIndex);
    let delay = swiper.params.autoplay.delay;
    if ($activeSlideEl.attr("data-swiper-autoplay")) {
      delay = $activeSlideEl.attr("data-swiper-autoplay") || swiper.params.autoplay.delay;
    }
    clearTimeout(timeout);
    timeout = nextTick(() => {
      let autoplayResult;
      if (swiper.params.autoplay.reverseDirection) {
        if (swiper.params.loop) {
          swiper.loopFix();
          autoplayResult = swiper.slidePrev(swiper.params.speed, true, true);
          emit("autoplay");
        } else if (!swiper.isBeginning) {
          autoplayResult = swiper.slidePrev(swiper.params.speed, true, true);
          emit("autoplay");
        } else if (!swiper.params.autoplay.stopOnLastSlide) {
          autoplayResult = swiper.slideTo(swiper.slides.length - 1, swiper.params.speed, true, true);
          emit("autoplay");
        } else {
          stop();
        }
      } else if (swiper.params.loop) {
        swiper.loopFix();
        autoplayResult = swiper.slideNext(swiper.params.speed, true, true);
        emit("autoplay");
      } else if (!swiper.isEnd) {
        autoplayResult = swiper.slideNext(swiper.params.speed, true, true);
        emit("autoplay");
      } else if (!swiper.params.autoplay.stopOnLastSlide) {
        autoplayResult = swiper.slideTo(0, swiper.params.speed, true, true);
        emit("autoplay");
      } else {
        stop();
      }
      if (swiper.params.cssMode && swiper.autoplay.running)
        run();
      else if (autoplayResult === false) {
        run();
      }
    }, delay);
  }
  function start() {
    if (typeof timeout !== "undefined")
      return false;
    if (swiper.autoplay.running)
      return false;
    swiper.autoplay.running = true;
    emit("autoplayStart");
    run();
    return true;
  }
  function stop() {
    if (!swiper.autoplay.running)
      return false;
    if (typeof timeout === "undefined")
      return false;
    if (timeout) {
      clearTimeout(timeout);
      timeout = void 0;
    }
    swiper.autoplay.running = false;
    emit("autoplayStop");
    return true;
  }
  function pause(speed) {
    if (!swiper.autoplay.running)
      return;
    if (swiper.autoplay.paused)
      return;
    if (timeout)
      clearTimeout(timeout);
    swiper.autoplay.paused = true;
    if (speed === 0 || !swiper.params.autoplay.waitForTransition) {
      swiper.autoplay.paused = false;
      run();
    } else {
      ["transitionend", "webkitTransitionEnd"].forEach((event2) => {
        swiper.$wrapperEl[0].addEventListener(event2, onTransitionEnd);
      });
    }
  }
  function onVisibilityChange() {
    const document2 = getDocument();
    if (document2.visibilityState === "hidden" && swiper.autoplay.running) {
      pause();
    }
    if (document2.visibilityState === "visible" && swiper.autoplay.paused) {
      run();
      swiper.autoplay.paused = false;
    }
  }
  function onTransitionEnd(e) {
    if (!swiper || swiper.destroyed || !swiper.$wrapperEl)
      return;
    if (e.target !== swiper.$wrapperEl[0])
      return;
    ["transitionend", "webkitTransitionEnd"].forEach((event2) => {
      swiper.$wrapperEl[0].removeEventListener(event2, onTransitionEnd);
    });
    swiper.autoplay.paused = false;
    if (!swiper.autoplay.running) {
      stop();
    } else {
      run();
    }
  }
  function onMouseEnter() {
    if (swiper.params.autoplay.disableOnInteraction) {
      stop();
    } else {
      emit("autoplayPause");
      pause();
    }
    ["transitionend", "webkitTransitionEnd"].forEach((event2) => {
      swiper.$wrapperEl[0].removeEventListener(event2, onTransitionEnd);
    });
  }
  function onMouseLeave() {
    if (swiper.params.autoplay.disableOnInteraction) {
      return;
    }
    swiper.autoplay.paused = false;
    emit("autoplayResume");
    run();
  }
  function attachMouseEvents() {
    if (swiper.params.autoplay.pauseOnMouseEnter) {
      swiper.$el.on("mouseenter", onMouseEnter);
      swiper.$el.on("mouseleave", onMouseLeave);
    }
  }
  function detachMouseEvents() {
    swiper.$el.off("mouseenter", onMouseEnter);
    swiper.$el.off("mouseleave", onMouseLeave);
  }
  on2("init", () => {
    if (swiper.params.autoplay.enabled) {
      start();
      const document2 = getDocument();
      document2.addEventListener("visibilitychange", onVisibilityChange);
      attachMouseEvents();
    }
  });
  on2("beforeTransitionStart", (_s, speed, internal) => {
    if (swiper.autoplay.running) {
      if (internal || !swiper.params.autoplay.disableOnInteraction) {
        swiper.autoplay.pause(speed);
      } else {
        stop();
      }
    }
  });
  on2("sliderFirstMove", () => {
    if (swiper.autoplay.running) {
      if (swiper.params.autoplay.disableOnInteraction) {
        stop();
      } else {
        pause();
      }
    }
  });
  on2("touchEnd", () => {
    if (swiper.params.cssMode && swiper.autoplay.paused && !swiper.params.autoplay.disableOnInteraction) {
      run();
    }
  });
  on2("destroy", () => {
    detachMouseEvents();
    if (swiper.autoplay.running) {
      stop();
    }
    const document2 = getDocument();
    document2.removeEventListener("visibilitychange", onVisibilityChange);
  });
  Object.assign(swiper.autoplay, {
    pause,
    run,
    start,
    stop
  });
}
function Thumb({
  swiper,
  extendParams,
  on: on2
}) {
  extendParams({
    thumbs: {
      swiper: null,
      multipleActiveThumbs: true,
      autoScrollOffset: 0,
      slideThumbActiveClass: "swiper-slide-thumb-active",
      thumbsContainerClass: "swiper-thumbs"
    }
  });
  let initialized = false;
  let swiperCreated = false;
  swiper.thumbs = {
    swiper: null
  };
  function onThumbClick() {
    const thumbsSwiper = swiper.thumbs.swiper;
    if (!thumbsSwiper || thumbsSwiper.destroyed)
      return;
    const clickedIndex = thumbsSwiper.clickedIndex;
    const clickedSlide = thumbsSwiper.clickedSlide;
    if (clickedSlide && $(clickedSlide).hasClass(swiper.params.thumbs.slideThumbActiveClass))
      return;
    if (typeof clickedIndex === "undefined" || clickedIndex === null)
      return;
    let slideToIndex;
    if (thumbsSwiper.params.loop) {
      slideToIndex = parseInt($(thumbsSwiper.clickedSlide).attr("data-swiper-slide-index"), 10);
    } else {
      slideToIndex = clickedIndex;
    }
    if (swiper.params.loop) {
      let currentIndex = swiper.activeIndex;
      if (swiper.slides.eq(currentIndex).hasClass(swiper.params.slideDuplicateClass)) {
        swiper.loopFix();
        swiper._clientLeft = swiper.$wrapperEl[0].clientLeft;
        currentIndex = swiper.activeIndex;
      }
      const prevIndex = swiper.slides.eq(currentIndex).prevAll(`[data-swiper-slide-index="${slideToIndex}"]`).eq(0).index();
      const nextIndex = swiper.slides.eq(currentIndex).nextAll(`[data-swiper-slide-index="${slideToIndex}"]`).eq(0).index();
      if (typeof prevIndex === "undefined")
        slideToIndex = nextIndex;
      else if (typeof nextIndex === "undefined")
        slideToIndex = prevIndex;
      else if (nextIndex - currentIndex < currentIndex - prevIndex)
        slideToIndex = nextIndex;
      else
        slideToIndex = prevIndex;
    }
    swiper.slideTo(slideToIndex);
  }
  function init() {
    const {
      thumbs: thumbsParams
    } = swiper.params;
    if (initialized)
      return false;
    initialized = true;
    const SwiperClass = swiper.constructor;
    if (thumbsParams.swiper instanceof SwiperClass) {
      swiper.thumbs.swiper = thumbsParams.swiper;
      Object.assign(swiper.thumbs.swiper.originalParams, {
        watchSlidesProgress: true,
        slideToClickedSlide: false
      });
      Object.assign(swiper.thumbs.swiper.params, {
        watchSlidesProgress: true,
        slideToClickedSlide: false
      });
    } else if (isObject$1(thumbsParams.swiper)) {
      const thumbsSwiperParams = Object.assign({}, thumbsParams.swiper);
      Object.assign(thumbsSwiperParams, {
        watchSlidesProgress: true,
        slideToClickedSlide: false
      });
      swiper.thumbs.swiper = new SwiperClass(thumbsSwiperParams);
      swiperCreated = true;
    }
    swiper.thumbs.swiper.$el.addClass(swiper.params.thumbs.thumbsContainerClass);
    swiper.thumbs.swiper.on("tap", onThumbClick);
    return true;
  }
  function update2(initial) {
    const thumbsSwiper = swiper.thumbs.swiper;
    if (!thumbsSwiper || thumbsSwiper.destroyed)
      return;
    const slidesPerView = thumbsSwiper.params.slidesPerView === "auto" ? thumbsSwiper.slidesPerViewDynamic() : thumbsSwiper.params.slidesPerView;
    let thumbsToActivate = 1;
    const thumbActiveClass = swiper.params.thumbs.slideThumbActiveClass;
    if (swiper.params.slidesPerView > 1 && !swiper.params.centeredSlides) {
      thumbsToActivate = swiper.params.slidesPerView;
    }
    if (!swiper.params.thumbs.multipleActiveThumbs) {
      thumbsToActivate = 1;
    }
    thumbsToActivate = Math.floor(thumbsToActivate);
    thumbsSwiper.slides.removeClass(thumbActiveClass);
    if (thumbsSwiper.params.loop || thumbsSwiper.params.virtual && thumbsSwiper.params.virtual.enabled) {
      for (let i = 0; i < thumbsToActivate; i += 1) {
        thumbsSwiper.$wrapperEl.children(`[data-swiper-slide-index="${swiper.realIndex + i}"]`).addClass(thumbActiveClass);
      }
    } else {
      for (let i = 0; i < thumbsToActivate; i += 1) {
        thumbsSwiper.slides.eq(swiper.realIndex + i).addClass(thumbActiveClass);
      }
    }
    const autoScrollOffset = swiper.params.thumbs.autoScrollOffset;
    const useOffset = autoScrollOffset && !thumbsSwiper.params.loop;
    if (swiper.realIndex !== thumbsSwiper.realIndex || useOffset) {
      let currentThumbsIndex = thumbsSwiper.activeIndex;
      let newThumbsIndex;
      let direction;
      if (thumbsSwiper.params.loop) {
        if (thumbsSwiper.slides.eq(currentThumbsIndex).hasClass(thumbsSwiper.params.slideDuplicateClass)) {
          thumbsSwiper.loopFix();
          thumbsSwiper._clientLeft = thumbsSwiper.$wrapperEl[0].clientLeft;
          currentThumbsIndex = thumbsSwiper.activeIndex;
        }
        const prevThumbsIndex = thumbsSwiper.slides.eq(currentThumbsIndex).prevAll(`[data-swiper-slide-index="${swiper.realIndex}"]`).eq(0).index();
        const nextThumbsIndex = thumbsSwiper.slides.eq(currentThumbsIndex).nextAll(`[data-swiper-slide-index="${swiper.realIndex}"]`).eq(0).index();
        if (typeof prevThumbsIndex === "undefined") {
          newThumbsIndex = nextThumbsIndex;
        } else if (typeof nextThumbsIndex === "undefined") {
          newThumbsIndex = prevThumbsIndex;
        } else if (nextThumbsIndex - currentThumbsIndex === currentThumbsIndex - prevThumbsIndex) {
          newThumbsIndex = thumbsSwiper.params.slidesPerGroup > 1 ? nextThumbsIndex : currentThumbsIndex;
        } else if (nextThumbsIndex - currentThumbsIndex < currentThumbsIndex - prevThumbsIndex) {
          newThumbsIndex = nextThumbsIndex;
        } else {
          newThumbsIndex = prevThumbsIndex;
        }
        direction = swiper.activeIndex > swiper.previousIndex ? "next" : "prev";
      } else {
        newThumbsIndex = swiper.realIndex;
        direction = newThumbsIndex > swiper.previousIndex ? "next" : "prev";
      }
      if (useOffset) {
        newThumbsIndex += direction === "next" ? autoScrollOffset : -1 * autoScrollOffset;
      }
      if (thumbsSwiper.visibleSlidesIndexes && thumbsSwiper.visibleSlidesIndexes.indexOf(newThumbsIndex) < 0) {
        if (thumbsSwiper.params.centeredSlides) {
          if (newThumbsIndex > currentThumbsIndex) {
            newThumbsIndex = newThumbsIndex - Math.floor(slidesPerView / 2) + 1;
          } else {
            newThumbsIndex = newThumbsIndex + Math.floor(slidesPerView / 2) - 1;
          }
        } else if (newThumbsIndex > currentThumbsIndex && thumbsSwiper.params.slidesPerGroup === 1)
          ;
        thumbsSwiper.slideTo(newThumbsIndex, initial ? 0 : void 0);
      }
    }
  }
  on2("beforeInit", () => {
    const {
      thumbs
    } = swiper.params;
    if (!thumbs || !thumbs.swiper)
      return;
    init();
    update2(true);
  });
  on2("slideChange update resize observerUpdate", () => {
    update2();
  });
  on2("setTransition", (_s, duration2) => {
    const thumbsSwiper = swiper.thumbs.swiper;
    if (!thumbsSwiper || thumbsSwiper.destroyed)
      return;
    thumbsSwiper.setTransition(duration2);
  });
  on2("beforeDestroy", () => {
    const thumbsSwiper = swiper.thumbs.swiper;
    if (!thumbsSwiper || thumbsSwiper.destroyed)
      return;
    if (swiperCreated) {
      thumbsSwiper.destroy();
    }
  });
  Object.assign(swiper.thumbs, {
    init,
    update: update2
  });
}
function freeMode({
  swiper,
  extendParams,
  emit,
  once
}) {
  extendParams({
    freeMode: {
      enabled: false,
      momentum: true,
      momentumRatio: 1,
      momentumBounce: true,
      momentumBounceRatio: 1,
      momentumVelocityRatio: 1,
      sticky: false,
      minimumVelocity: 0.02
    }
  });
  function onTouchStart2() {
    const translate2 = swiper.getTranslate();
    swiper.setTranslate(translate2);
    swiper.setTransition(0);
    swiper.touchEventsData.velocities.length = 0;
    swiper.freeMode.onTouchEnd({
      currentPos: swiper.rtl ? swiper.translate : -swiper.translate
    });
  }
  function onTouchMove2() {
    const {
      touchEventsData: data,
      touches
    } = swiper;
    if (data.velocities.length === 0) {
      data.velocities.push({
        position: touches[swiper.isHorizontal() ? "startX" : "startY"],
        time: data.touchStartTime
      });
    }
    data.velocities.push({
      position: touches[swiper.isHorizontal() ? "currentX" : "currentY"],
      time: now()
    });
  }
  function onTouchEnd2({
    currentPos
  }) {
    const {
      params,
      $wrapperEl,
      rtlTranslate: rtl,
      snapGrid,
      touchEventsData: data
    } = swiper;
    const touchEndTime = now();
    const timeDiff = touchEndTime - data.touchStartTime;
    if (currentPos < -swiper.minTranslate()) {
      swiper.slideTo(swiper.activeIndex);
      return;
    }
    if (currentPos > -swiper.maxTranslate()) {
      if (swiper.slides.length < snapGrid.length) {
        swiper.slideTo(snapGrid.length - 1);
      } else {
        swiper.slideTo(swiper.slides.length - 1);
      }
      return;
    }
    if (params.freeMode.momentum) {
      if (data.velocities.length > 1) {
        const lastMoveEvent = data.velocities.pop();
        const velocityEvent = data.velocities.pop();
        const distance = lastMoveEvent.position - velocityEvent.position;
        const time = lastMoveEvent.time - velocityEvent.time;
        swiper.velocity = distance / time;
        swiper.velocity /= 2;
        if (Math.abs(swiper.velocity) < params.freeMode.minimumVelocity) {
          swiper.velocity = 0;
        }
        if (time > 150 || now() - lastMoveEvent.time > 300) {
          swiper.velocity = 0;
        }
      } else {
        swiper.velocity = 0;
      }
      swiper.velocity *= params.freeMode.momentumVelocityRatio;
      data.velocities.length = 0;
      let momentumDuration = 1e3 * params.freeMode.momentumRatio;
      const momentumDistance = swiper.velocity * momentumDuration;
      let newPosition = swiper.translate + momentumDistance;
      if (rtl)
        newPosition = -newPosition;
      let doBounce = false;
      let afterBouncePosition;
      const bounceAmount = Math.abs(swiper.velocity) * 20 * params.freeMode.momentumBounceRatio;
      let needsLoopFix;
      if (newPosition < swiper.maxTranslate()) {
        if (params.freeMode.momentumBounce) {
          if (newPosition + swiper.maxTranslate() < -bounceAmount) {
            newPosition = swiper.maxTranslate() - bounceAmount;
          }
          afterBouncePosition = swiper.maxTranslate();
          doBounce = true;
          data.allowMomentumBounce = true;
        } else {
          newPosition = swiper.maxTranslate();
        }
        if (params.loop && params.centeredSlides)
          needsLoopFix = true;
      } else if (newPosition > swiper.minTranslate()) {
        if (params.freeMode.momentumBounce) {
          if (newPosition - swiper.minTranslate() > bounceAmount) {
            newPosition = swiper.minTranslate() + bounceAmount;
          }
          afterBouncePosition = swiper.minTranslate();
          doBounce = true;
          data.allowMomentumBounce = true;
        } else {
          newPosition = swiper.minTranslate();
        }
        if (params.loop && params.centeredSlides)
          needsLoopFix = true;
      } else if (params.freeMode.sticky) {
        let nextSlide;
        for (let j = 0; j < snapGrid.length; j += 1) {
          if (snapGrid[j] > -newPosition) {
            nextSlide = j;
            break;
          }
        }
        if (Math.abs(snapGrid[nextSlide] - newPosition) < Math.abs(snapGrid[nextSlide - 1] - newPosition) || swiper.swipeDirection === "next") {
          newPosition = snapGrid[nextSlide];
        } else {
          newPosition = snapGrid[nextSlide - 1];
        }
        newPosition = -newPosition;
      }
      if (needsLoopFix) {
        once("transitionEnd", () => {
          swiper.loopFix();
        });
      }
      if (swiper.velocity !== 0) {
        if (rtl) {
          momentumDuration = Math.abs((-newPosition - swiper.translate) / swiper.velocity);
        } else {
          momentumDuration = Math.abs((newPosition - swiper.translate) / swiper.velocity);
        }
        if (params.freeMode.sticky) {
          const moveDistance = Math.abs((rtl ? -newPosition : newPosition) - swiper.translate);
          const currentSlideSize = swiper.slidesSizesGrid[swiper.activeIndex];
          if (moveDistance < currentSlideSize) {
            momentumDuration = params.speed;
          } else if (moveDistance < 2 * currentSlideSize) {
            momentumDuration = params.speed * 1.5;
          } else {
            momentumDuration = params.speed * 2.5;
          }
        }
      } else if (params.freeMode.sticky) {
        swiper.slideToClosest();
        return;
      }
      if (params.freeMode.momentumBounce && doBounce) {
        swiper.updateProgress(afterBouncePosition);
        swiper.setTransition(momentumDuration);
        swiper.setTranslate(newPosition);
        swiper.transitionStart(true, swiper.swipeDirection);
        swiper.animating = true;
        $wrapperEl.transitionEnd(() => {
          if (!swiper || swiper.destroyed || !data.allowMomentumBounce)
            return;
          emit("momentumBounce");
          swiper.setTransition(params.speed);
          setTimeout(() => {
            swiper.setTranslate(afterBouncePosition);
            $wrapperEl.transitionEnd(() => {
              if (!swiper || swiper.destroyed)
                return;
              swiper.transitionEnd();
            });
          }, 0);
        });
      } else if (swiper.velocity) {
        emit("_freeModeNoMomentumRelease");
        swiper.updateProgress(newPosition);
        swiper.setTransition(momentumDuration);
        swiper.setTranslate(newPosition);
        swiper.transitionStart(true, swiper.swipeDirection);
        if (!swiper.animating) {
          swiper.animating = true;
          $wrapperEl.transitionEnd(() => {
            if (!swiper || swiper.destroyed)
              return;
            swiper.transitionEnd();
          });
        }
      } else {
        swiper.updateProgress(newPosition);
      }
      swiper.updateActiveIndex();
      swiper.updateSlidesClasses();
    } else if (params.freeMode.sticky) {
      swiper.slideToClosest();
      return;
    } else if (params.freeMode) {
      emit("_freeModeNoMomentumRelease");
    }
    if (!params.freeMode.momentum || timeDiff >= params.longSwipesMs) {
      swiper.updateProgress();
      swiper.updateActiveIndex();
      swiper.updateSlidesClasses();
    }
  }
  Object.assign(swiper, {
    freeMode: {
      onTouchStart: onTouchStart2,
      onTouchMove: onTouchMove2,
      onTouchEnd: onTouchEnd2
    }
  });
}
function Grid({
  swiper,
  extendParams
}) {
  extendParams({
    grid: {
      rows: 1,
      fill: "column"
    }
  });
  let slidesNumberEvenToRows;
  let slidesPerRow;
  let numFullColumns;
  const initSlides = (slidesLength) => {
    const {
      slidesPerView
    } = swiper.params;
    const {
      rows,
      fill
    } = swiper.params.grid;
    slidesPerRow = slidesNumberEvenToRows / rows;
    numFullColumns = Math.floor(slidesLength / rows);
    if (Math.floor(slidesLength / rows) === slidesLength / rows) {
      slidesNumberEvenToRows = slidesLength;
    } else {
      slidesNumberEvenToRows = Math.ceil(slidesLength / rows) * rows;
    }
    if (slidesPerView !== "auto" && fill === "row") {
      slidesNumberEvenToRows = Math.max(slidesNumberEvenToRows, slidesPerView * rows);
    }
  };
  const updateSlide = (i, slide2, slidesLength, getDirectionLabel) => {
    const {
      slidesPerGroup,
      spaceBetween
    } = swiper.params;
    const {
      rows,
      fill
    } = swiper.params.grid;
    let newSlideOrderIndex;
    let column;
    let row;
    if (fill === "row" && slidesPerGroup > 1) {
      const groupIndex = Math.floor(i / (slidesPerGroup * rows));
      const slideIndexInGroup = i - rows * slidesPerGroup * groupIndex;
      const columnsInGroup = groupIndex === 0 ? slidesPerGroup : Math.min(Math.ceil((slidesLength - groupIndex * rows * slidesPerGroup) / rows), slidesPerGroup);
      row = Math.floor(slideIndexInGroup / columnsInGroup);
      column = slideIndexInGroup - row * columnsInGroup + groupIndex * slidesPerGroup;
      newSlideOrderIndex = column + row * slidesNumberEvenToRows / rows;
      slide2.css({
        "-webkit-order": newSlideOrderIndex,
        order: newSlideOrderIndex
      });
    } else if (fill === "column") {
      column = Math.floor(i / rows);
      row = i - column * rows;
      if (column > numFullColumns || column === numFullColumns && row === rows - 1) {
        row += 1;
        if (row >= rows) {
          row = 0;
          column += 1;
        }
      }
    } else {
      row = Math.floor(i / slidesPerRow);
      column = i - row * slidesPerRow;
    }
    slide2.css(getDirectionLabel("margin-top"), row !== 0 ? spaceBetween && `${spaceBetween}px` : "");
  };
  const updateWrapperSize = (slideSize, snapGrid, getDirectionLabel) => {
    const {
      spaceBetween,
      centeredSlides,
      roundLengths
    } = swiper.params;
    const {
      rows
    } = swiper.params.grid;
    swiper.virtualSize = (slideSize + spaceBetween) * slidesNumberEvenToRows;
    swiper.virtualSize = Math.ceil(swiper.virtualSize / rows) - spaceBetween;
    swiper.$wrapperEl.css({
      [getDirectionLabel("width")]: `${swiper.virtualSize + spaceBetween}px`
    });
    if (centeredSlides) {
      snapGrid.splice(0, snapGrid.length);
      const newSlidesGrid = [];
      for (let i = 0; i < snapGrid.length; i += 1) {
        let slidesGridItem = snapGrid[i];
        if (roundLengths)
          slidesGridItem = Math.floor(slidesGridItem);
        if (snapGrid[i] < swiper.virtualSize + snapGrid[0])
          newSlidesGrid.push(slidesGridItem);
      }
      snapGrid.push(...newSlidesGrid);
    }
  };
  swiper.grid = {
    initSlides,
    updateSlide,
    updateWrapperSize
  };
}
function appendSlide(slides) {
  const swiper = this;
  const {
    $wrapperEl,
    params
  } = swiper;
  if (params.loop) {
    swiper.loopDestroy();
  }
  if (typeof slides === "object" && "length" in slides) {
    for (let i = 0; i < slides.length; i += 1) {
      if (slides[i])
        $wrapperEl.append(slides[i]);
    }
  } else {
    $wrapperEl.append(slides);
  }
  if (params.loop) {
    swiper.loopCreate();
  }
  if (!params.observer) {
    swiper.update();
  }
}
function prependSlide(slides) {
  const swiper = this;
  const {
    params,
    $wrapperEl,
    activeIndex
  } = swiper;
  if (params.loop) {
    swiper.loopDestroy();
  }
  let newActiveIndex = activeIndex + 1;
  if (typeof slides === "object" && "length" in slides) {
    for (let i = 0; i < slides.length; i += 1) {
      if (slides[i])
        $wrapperEl.prepend(slides[i]);
    }
    newActiveIndex = activeIndex + slides.length;
  } else {
    $wrapperEl.prepend(slides);
  }
  if (params.loop) {
    swiper.loopCreate();
  }
  if (!params.observer) {
    swiper.update();
  }
  swiper.slideTo(newActiveIndex, 0, false);
}
function addSlide(index2, slides) {
  const swiper = this;
  const {
    $wrapperEl,
    params,
    activeIndex
  } = swiper;
  let activeIndexBuffer = activeIndex;
  if (params.loop) {
    activeIndexBuffer -= swiper.loopedSlides;
    swiper.loopDestroy();
    swiper.slides = $wrapperEl.children(`.${params.slideClass}`);
  }
  const baseLength = swiper.slides.length;
  if (index2 <= 0) {
    swiper.prependSlide(slides);
    return;
  }
  if (index2 >= baseLength) {
    swiper.appendSlide(slides);
    return;
  }
  let newActiveIndex = activeIndexBuffer > index2 ? activeIndexBuffer + 1 : activeIndexBuffer;
  const slidesBuffer = [];
  for (let i = baseLength - 1; i >= index2; i -= 1) {
    const currentSlide = swiper.slides.eq(i);
    currentSlide.remove();
    slidesBuffer.unshift(currentSlide);
  }
  if (typeof slides === "object" && "length" in slides) {
    for (let i = 0; i < slides.length; i += 1) {
      if (slides[i])
        $wrapperEl.append(slides[i]);
    }
    newActiveIndex = activeIndexBuffer > index2 ? activeIndexBuffer + slides.length : activeIndexBuffer;
  } else {
    $wrapperEl.append(slides);
  }
  for (let i = 0; i < slidesBuffer.length; i += 1) {
    $wrapperEl.append(slidesBuffer[i]);
  }
  if (params.loop) {
    swiper.loopCreate();
  }
  if (!params.observer) {
    swiper.update();
  }
  if (params.loop) {
    swiper.slideTo(newActiveIndex + swiper.loopedSlides, 0, false);
  } else {
    swiper.slideTo(newActiveIndex, 0, false);
  }
}
function removeSlide(slidesIndexes) {
  const swiper = this;
  const {
    params,
    $wrapperEl,
    activeIndex
  } = swiper;
  let activeIndexBuffer = activeIndex;
  if (params.loop) {
    activeIndexBuffer -= swiper.loopedSlides;
    swiper.loopDestroy();
    swiper.slides = $wrapperEl.children(`.${params.slideClass}`);
  }
  let newActiveIndex = activeIndexBuffer;
  let indexToRemove;
  if (typeof slidesIndexes === "object" && "length" in slidesIndexes) {
    for (let i = 0; i < slidesIndexes.length; i += 1) {
      indexToRemove = slidesIndexes[i];
      if (swiper.slides[indexToRemove])
        swiper.slides.eq(indexToRemove).remove();
      if (indexToRemove < newActiveIndex)
        newActiveIndex -= 1;
    }
    newActiveIndex = Math.max(newActiveIndex, 0);
  } else {
    indexToRemove = slidesIndexes;
    if (swiper.slides[indexToRemove])
      swiper.slides.eq(indexToRemove).remove();
    if (indexToRemove < newActiveIndex)
      newActiveIndex -= 1;
    newActiveIndex = Math.max(newActiveIndex, 0);
  }
  if (params.loop) {
    swiper.loopCreate();
  }
  if (!params.observer) {
    swiper.update();
  }
  if (params.loop) {
    swiper.slideTo(newActiveIndex + swiper.loopedSlides, 0, false);
  } else {
    swiper.slideTo(newActiveIndex, 0, false);
  }
}
function removeAllSlides() {
  const swiper = this;
  const slidesIndexes = [];
  for (let i = 0; i < swiper.slides.length; i += 1) {
    slidesIndexes.push(i);
  }
  swiper.removeSlide(slidesIndexes);
}
function Manipulation({
  swiper
}) {
  Object.assign(swiper, {
    appendSlide: appendSlide.bind(swiper),
    prependSlide: prependSlide.bind(swiper),
    addSlide: addSlide.bind(swiper),
    removeSlide: removeSlide.bind(swiper),
    removeAllSlides: removeAllSlides.bind(swiper)
  });
}
function effectInit(params) {
  const {
    effect,
    swiper,
    on: on2,
    setTranslate: setTranslate2,
    setTransition: setTransition2,
    overwriteParams,
    perspective,
    recreateShadows,
    getEffectParams
  } = params;
  on2("beforeInit", () => {
    if (swiper.params.effect !== effect)
      return;
    swiper.classNames.push(`${swiper.params.containerModifierClass}${effect}`);
    if (perspective && perspective()) {
      swiper.classNames.push(`${swiper.params.containerModifierClass}3d`);
    }
    const overwriteParamsResult = overwriteParams ? overwriteParams() : {};
    Object.assign(swiper.params, overwriteParamsResult);
    Object.assign(swiper.originalParams, overwriteParamsResult);
  });
  on2("setTranslate", () => {
    if (swiper.params.effect !== effect)
      return;
    setTranslate2();
  });
  on2("setTransition", (_s, duration2) => {
    if (swiper.params.effect !== effect)
      return;
    setTransition2(duration2);
  });
  on2("transitionEnd", () => {
    if (swiper.params.effect !== effect)
      return;
    if (recreateShadows) {
      if (!getEffectParams || !getEffectParams().slideShadows)
        return;
      swiper.slides.each((slideEl) => {
        const $slideEl = swiper.$(slideEl);
        $slideEl.find(".swiper-slide-shadow-top, .swiper-slide-shadow-right, .swiper-slide-shadow-bottom, .swiper-slide-shadow-left").remove();
      });
      recreateShadows();
    }
  });
  let requireUpdateOnVirtual;
  on2("virtualUpdate", () => {
    if (swiper.params.effect !== effect)
      return;
    if (!swiper.slides.length) {
      requireUpdateOnVirtual = true;
    }
    requestAnimationFrame(() => {
      if (requireUpdateOnVirtual && swiper.slides && swiper.slides.length) {
        setTranslate2();
        requireUpdateOnVirtual = false;
      }
    });
  });
}
function effectTarget(effectParams, $slideEl) {
  if (effectParams.transformEl) {
    return $slideEl.find(effectParams.transformEl).css({
      "backface-visibility": "hidden",
      "-webkit-backface-visibility": "hidden"
    });
  }
  return $slideEl;
}
function effectVirtualTransitionEnd({
  swiper,
  duration: duration2,
  transformEl,
  allSlides
}) {
  const {
    slides,
    activeIndex,
    $wrapperEl
  } = swiper;
  if (swiper.params.virtualTranslate && duration2 !== 0) {
    let eventTriggered = false;
    let $transitionEndTarget;
    if (allSlides) {
      $transitionEndTarget = transformEl ? slides.find(transformEl) : slides;
    } else {
      $transitionEndTarget = transformEl ? slides.eq(activeIndex).find(transformEl) : slides.eq(activeIndex);
    }
    $transitionEndTarget.transitionEnd(() => {
      if (eventTriggered)
        return;
      if (!swiper || swiper.destroyed)
        return;
      eventTriggered = true;
      swiper.animating = false;
      const triggerEvents = ["webkitTransitionEnd", "transitionend"];
      for (let i = 0; i < triggerEvents.length; i += 1) {
        $wrapperEl.trigger(triggerEvents[i]);
      }
    });
  }
}
function EffectFade({
  swiper,
  extendParams,
  on: on2
}) {
  extendParams({
    fadeEffect: {
      crossFade: false,
      transformEl: null
    }
  });
  const setTranslate2 = () => {
    const {
      slides
    } = swiper;
    const params = swiper.params.fadeEffect;
    for (let i = 0; i < slides.length; i += 1) {
      const $slideEl = swiper.slides.eq(i);
      const offset2 = $slideEl[0].swiperSlideOffset;
      let tx = -offset2;
      if (!swiper.params.virtualTranslate)
        tx -= swiper.translate;
      let ty = 0;
      if (!swiper.isHorizontal()) {
        ty = tx;
        tx = 0;
      }
      const slideOpacity = swiper.params.fadeEffect.crossFade ? Math.max(1 - Math.abs($slideEl[0].progress), 0) : 1 + Math.min(Math.max($slideEl[0].progress, -1), 0);
      const $targetEl = effectTarget(params, $slideEl);
      $targetEl.css({
        opacity: slideOpacity
      }).transform(`translate3d(${tx}px, ${ty}px, 0px)`);
    }
  };
  const setTransition2 = (duration2) => {
    const {
      transformEl
    } = swiper.params.fadeEffect;
    const $transitionElements = transformEl ? swiper.slides.find(transformEl) : swiper.slides;
    $transitionElements.transition(duration2);
    effectVirtualTransitionEnd({
      swiper,
      duration: duration2,
      transformEl,
      allSlides: true
    });
  };
  effectInit({
    effect: "fade",
    swiper,
    on: on2,
    setTranslate: setTranslate2,
    setTransition: setTransition2,
    overwriteParams: () => ({
      slidesPerView: 1,
      slidesPerGroup: 1,
      watchSlidesProgress: true,
      spaceBetween: 0,
      virtualTranslate: !swiper.params.cssMode
    })
  });
}
function EffectCube({
  swiper,
  extendParams,
  on: on2
}) {
  extendParams({
    cubeEffect: {
      slideShadows: true,
      shadow: true,
      shadowOffset: 20,
      shadowScale: 0.94
    }
  });
  const createSlideShadows = ($slideEl, progress, isHorizontal) => {
    let shadowBefore = isHorizontal ? $slideEl.find(".swiper-slide-shadow-left") : $slideEl.find(".swiper-slide-shadow-top");
    let shadowAfter = isHorizontal ? $slideEl.find(".swiper-slide-shadow-right") : $slideEl.find(".swiper-slide-shadow-bottom");
    if (shadowBefore.length === 0) {
      shadowBefore = $(`<div class="swiper-slide-shadow-${isHorizontal ? "left" : "top"}"></div>`);
      $slideEl.append(shadowBefore);
    }
    if (shadowAfter.length === 0) {
      shadowAfter = $(`<div class="swiper-slide-shadow-${isHorizontal ? "right" : "bottom"}"></div>`);
      $slideEl.append(shadowAfter);
    }
    if (shadowBefore.length)
      shadowBefore[0].style.opacity = Math.max(-progress, 0);
    if (shadowAfter.length)
      shadowAfter[0].style.opacity = Math.max(progress, 0);
  };
  const recreateShadows = () => {
    const isHorizontal = swiper.isHorizontal();
    swiper.slides.each((slideEl) => {
      const progress = Math.max(Math.min(slideEl.progress, 1), -1);
      createSlideShadows($(slideEl), progress, isHorizontal);
    });
  };
  const setTranslate2 = () => {
    const {
      $el,
      $wrapperEl,
      slides,
      width: swiperWidth,
      height: swiperHeight,
      rtlTranslate: rtl,
      size: swiperSize,
      browser: browser2
    } = swiper;
    const params = swiper.params.cubeEffect;
    const isHorizontal = swiper.isHorizontal();
    const isVirtual = swiper.virtual && swiper.params.virtual.enabled;
    let wrapperRotate = 0;
    let $cubeShadowEl;
    if (params.shadow) {
      if (isHorizontal) {
        $cubeShadowEl = $wrapperEl.find(".swiper-cube-shadow");
        if ($cubeShadowEl.length === 0) {
          $cubeShadowEl = $('<div class="swiper-cube-shadow"></div>');
          $wrapperEl.append($cubeShadowEl);
        }
        $cubeShadowEl.css({
          height: `${swiperWidth}px`
        });
      } else {
        $cubeShadowEl = $el.find(".swiper-cube-shadow");
        if ($cubeShadowEl.length === 0) {
          $cubeShadowEl = $('<div class="swiper-cube-shadow"></div>');
          $el.append($cubeShadowEl);
        }
      }
    }
    for (let i = 0; i < slides.length; i += 1) {
      const $slideEl = slides.eq(i);
      let slideIndex = i;
      if (isVirtual) {
        slideIndex = parseInt($slideEl.attr("data-swiper-slide-index"), 10);
      }
      let slideAngle = slideIndex * 90;
      let round2 = Math.floor(slideAngle / 360);
      if (rtl) {
        slideAngle = -slideAngle;
        round2 = Math.floor(-slideAngle / 360);
      }
      const progress = Math.max(Math.min($slideEl[0].progress, 1), -1);
      let tx = 0;
      let ty = 0;
      let tz = 0;
      if (slideIndex % 4 === 0) {
        tx = -round2 * 4 * swiperSize;
        tz = 0;
      } else if ((slideIndex - 1) % 4 === 0) {
        tx = 0;
        tz = -round2 * 4 * swiperSize;
      } else if ((slideIndex - 2) % 4 === 0) {
        tx = swiperSize + round2 * 4 * swiperSize;
        tz = swiperSize;
      } else if ((slideIndex - 3) % 4 === 0) {
        tx = -swiperSize;
        tz = 3 * swiperSize + swiperSize * 4 * round2;
      }
      if (rtl) {
        tx = -tx;
      }
      if (!isHorizontal) {
        ty = tx;
        tx = 0;
      }
      const transform2 = `rotateX(${isHorizontal ? 0 : -slideAngle}deg) rotateY(${isHorizontal ? slideAngle : 0}deg) translate3d(${tx}px, ${ty}px, ${tz}px)`;
      if (progress <= 1 && progress > -1) {
        wrapperRotate = slideIndex * 90 + progress * 90;
        if (rtl)
          wrapperRotate = -slideIndex * 90 - progress * 90;
      }
      $slideEl.transform(transform2);
      if (params.slideShadows) {
        createSlideShadows($slideEl, progress, isHorizontal);
      }
    }
    $wrapperEl.css({
      "-webkit-transform-origin": `50% 50% -${swiperSize / 2}px`,
      "transform-origin": `50% 50% -${swiperSize / 2}px`
    });
    if (params.shadow) {
      if (isHorizontal) {
        $cubeShadowEl.transform(`translate3d(0px, ${swiperWidth / 2 + params.shadowOffset}px, ${-swiperWidth / 2}px) rotateX(90deg) rotateZ(0deg) scale(${params.shadowScale})`);
      } else {
        const shadowAngle = Math.abs(wrapperRotate) - Math.floor(Math.abs(wrapperRotate) / 90) * 90;
        const multiplier = 1.5 - (Math.sin(shadowAngle * 2 * Math.PI / 360) / 2 + Math.cos(shadowAngle * 2 * Math.PI / 360) / 2);
        const scale1 = params.shadowScale;
        const scale2 = params.shadowScale / multiplier;
        const offset2 = params.shadowOffset;
        $cubeShadowEl.transform(`scale3d(${scale1}, 1, ${scale2}) translate3d(0px, ${swiperHeight / 2 + offset2}px, ${-swiperHeight / 2 / scale2}px) rotateX(-90deg)`);
      }
    }
    const zFactor = browser2.isSafari || browser2.isWebView ? -swiperSize / 2 : 0;
    $wrapperEl.transform(`translate3d(0px,0,${zFactor}px) rotateX(${swiper.isHorizontal() ? 0 : wrapperRotate}deg) rotateY(${swiper.isHorizontal() ? -wrapperRotate : 0}deg)`);
    $wrapperEl[0].style.setProperty("--swiper-cube-translate-z", `${zFactor}px`);
  };
  const setTransition2 = (duration2) => {
    const {
      $el,
      slides
    } = swiper;
    slides.transition(duration2).find(".swiper-slide-shadow-top, .swiper-slide-shadow-right, .swiper-slide-shadow-bottom, .swiper-slide-shadow-left").transition(duration2);
    if (swiper.params.cubeEffect.shadow && !swiper.isHorizontal()) {
      $el.find(".swiper-cube-shadow").transition(duration2);
    }
  };
  effectInit({
    effect: "cube",
    swiper,
    on: on2,
    setTranslate: setTranslate2,
    setTransition: setTransition2,
    recreateShadows,
    getEffectParams: () => swiper.params.cubeEffect,
    perspective: () => true,
    overwriteParams: () => ({
      slidesPerView: 1,
      slidesPerGroup: 1,
      watchSlidesProgress: true,
      resistanceRatio: 0,
      spaceBetween: 0,
      centeredSlides: false,
      virtualTranslate: true
    })
  });
}
function createShadow(params, $slideEl, side) {
  const shadowClass = `swiper-slide-shadow${side ? `-${side}` : ""}`;
  const $shadowContainer = params.transformEl ? $slideEl.find(params.transformEl) : $slideEl;
  let $shadowEl = $shadowContainer.children(`.${shadowClass}`);
  if (!$shadowEl.length) {
    $shadowEl = $(`<div class="swiper-slide-shadow${side ? `-${side}` : ""}"></div>`);
    $shadowContainer.append($shadowEl);
  }
  return $shadowEl;
}
function EffectFlip({
  swiper,
  extendParams,
  on: on2
}) {
  extendParams({
    flipEffect: {
      slideShadows: true,
      limitRotation: true,
      transformEl: null
    }
  });
  const createSlideShadows = ($slideEl, progress, params) => {
    let shadowBefore = swiper.isHorizontal() ? $slideEl.find(".swiper-slide-shadow-left") : $slideEl.find(".swiper-slide-shadow-top");
    let shadowAfter = swiper.isHorizontal() ? $slideEl.find(".swiper-slide-shadow-right") : $slideEl.find(".swiper-slide-shadow-bottom");
    if (shadowBefore.length === 0) {
      shadowBefore = createShadow(params, $slideEl, swiper.isHorizontal() ? "left" : "top");
    }
    if (shadowAfter.length === 0) {
      shadowAfter = createShadow(params, $slideEl, swiper.isHorizontal() ? "right" : "bottom");
    }
    if (shadowBefore.length)
      shadowBefore[0].style.opacity = Math.max(-progress, 0);
    if (shadowAfter.length)
      shadowAfter[0].style.opacity = Math.max(progress, 0);
  };
  const recreateShadows = () => {
    const params = swiper.params.flipEffect;
    swiper.slides.each((slideEl) => {
      const $slideEl = $(slideEl);
      let progress = $slideEl[0].progress;
      if (swiper.params.flipEffect.limitRotation) {
        progress = Math.max(Math.min(slideEl.progress, 1), -1);
      }
      createSlideShadows($slideEl, progress, params);
    });
  };
  const setTranslate2 = () => {
    const {
      slides,
      rtlTranslate: rtl
    } = swiper;
    const params = swiper.params.flipEffect;
    for (let i = 0; i < slides.length; i += 1) {
      const $slideEl = slides.eq(i);
      let progress = $slideEl[0].progress;
      if (swiper.params.flipEffect.limitRotation) {
        progress = Math.max(Math.min($slideEl[0].progress, 1), -1);
      }
      const offset2 = $slideEl[0].swiperSlideOffset;
      const rotate = -180 * progress;
      let rotateY = rotate;
      let rotateX = 0;
      let tx = swiper.params.cssMode ? -offset2 - swiper.translate : -offset2;
      let ty = 0;
      if (!swiper.isHorizontal()) {
        ty = tx;
        tx = 0;
        rotateX = -rotateY;
        rotateY = 0;
      } else if (rtl) {
        rotateY = -rotateY;
      }
      $slideEl[0].style.zIndex = -Math.abs(Math.round(progress)) + slides.length;
      if (params.slideShadows) {
        createSlideShadows($slideEl, progress, params);
      }
      const transform2 = `translate3d(${tx}px, ${ty}px, 0px) rotateX(${rotateX}deg) rotateY(${rotateY}deg)`;
      const $targetEl = effectTarget(params, $slideEl);
      $targetEl.transform(transform2);
    }
  };
  const setTransition2 = (duration2) => {
    const {
      transformEl
    } = swiper.params.flipEffect;
    const $transitionElements = transformEl ? swiper.slides.find(transformEl) : swiper.slides;
    $transitionElements.transition(duration2).find(".swiper-slide-shadow-top, .swiper-slide-shadow-right, .swiper-slide-shadow-bottom, .swiper-slide-shadow-left").transition(duration2);
    effectVirtualTransitionEnd({
      swiper,
      duration: duration2,
      transformEl
    });
  };
  effectInit({
    effect: "flip",
    swiper,
    on: on2,
    setTranslate: setTranslate2,
    setTransition: setTransition2,
    recreateShadows,
    getEffectParams: () => swiper.params.flipEffect,
    perspective: () => true,
    overwriteParams: () => ({
      slidesPerView: 1,
      slidesPerGroup: 1,
      watchSlidesProgress: true,
      spaceBetween: 0,
      virtualTranslate: !swiper.params.cssMode
    })
  });
}
function EffectCoverflow({
  swiper,
  extendParams,
  on: on2
}) {
  extendParams({
    coverflowEffect: {
      rotate: 50,
      stretch: 0,
      depth: 100,
      scale: 1,
      modifier: 1,
      slideShadows: true,
      transformEl: null
    }
  });
  const setTranslate2 = () => {
    const {
      width: swiperWidth,
      height: swiperHeight,
      slides,
      slidesSizesGrid
    } = swiper;
    const params = swiper.params.coverflowEffect;
    const isHorizontal = swiper.isHorizontal();
    const transform2 = swiper.translate;
    const center = isHorizontal ? -transform2 + swiperWidth / 2 : -transform2 + swiperHeight / 2;
    const rotate = isHorizontal ? params.rotate : -params.rotate;
    const translate2 = params.depth;
    for (let i = 0, length = slides.length; i < length; i += 1) {
      const $slideEl = slides.eq(i);
      const slideSize = slidesSizesGrid[i];
      const slideOffset = $slideEl[0].swiperSlideOffset;
      const centerOffset = (center - slideOffset - slideSize / 2) / slideSize;
      const offsetMultiplier = typeof params.modifier === "function" ? params.modifier(centerOffset) : centerOffset * params.modifier;
      let rotateY = isHorizontal ? rotate * offsetMultiplier : 0;
      let rotateX = isHorizontal ? 0 : rotate * offsetMultiplier;
      let translateZ = -translate2 * Math.abs(offsetMultiplier);
      let stretch = params.stretch;
      if (typeof stretch === "string" && stretch.indexOf("%") !== -1) {
        stretch = parseFloat(params.stretch) / 100 * slideSize;
      }
      let translateY = isHorizontal ? 0 : stretch * offsetMultiplier;
      let translateX = isHorizontal ? stretch * offsetMultiplier : 0;
      let scale = 1 - (1 - params.scale) * Math.abs(offsetMultiplier);
      if (Math.abs(translateX) < 1e-3)
        translateX = 0;
      if (Math.abs(translateY) < 1e-3)
        translateY = 0;
      if (Math.abs(translateZ) < 1e-3)
        translateZ = 0;
      if (Math.abs(rotateY) < 1e-3)
        rotateY = 0;
      if (Math.abs(rotateX) < 1e-3)
        rotateX = 0;
      if (Math.abs(scale) < 1e-3)
        scale = 0;
      const slideTransform = `translate3d(${translateX}px,${translateY}px,${translateZ}px)  rotateX(${rotateX}deg) rotateY(${rotateY}deg) scale(${scale})`;
      const $targetEl = effectTarget(params, $slideEl);
      $targetEl.transform(slideTransform);
      $slideEl[0].style.zIndex = -Math.abs(Math.round(offsetMultiplier)) + 1;
      if (params.slideShadows) {
        let $shadowBeforeEl = isHorizontal ? $slideEl.find(".swiper-slide-shadow-left") : $slideEl.find(".swiper-slide-shadow-top");
        let $shadowAfterEl = isHorizontal ? $slideEl.find(".swiper-slide-shadow-right") : $slideEl.find(".swiper-slide-shadow-bottom");
        if ($shadowBeforeEl.length === 0) {
          $shadowBeforeEl = createShadow(params, $slideEl, isHorizontal ? "left" : "top");
        }
        if ($shadowAfterEl.length === 0) {
          $shadowAfterEl = createShadow(params, $slideEl, isHorizontal ? "right" : "bottom");
        }
        if ($shadowBeforeEl.length)
          $shadowBeforeEl[0].style.opacity = offsetMultiplier > 0 ? offsetMultiplier : 0;
        if ($shadowAfterEl.length)
          $shadowAfterEl[0].style.opacity = -offsetMultiplier > 0 ? -offsetMultiplier : 0;
      }
    }
  };
  const setTransition2 = (duration2) => {
    const {
      transformEl
    } = swiper.params.coverflowEffect;
    const $transitionElements = transformEl ? swiper.slides.find(transformEl) : swiper.slides;
    $transitionElements.transition(duration2).find(".swiper-slide-shadow-top, .swiper-slide-shadow-right, .swiper-slide-shadow-bottom, .swiper-slide-shadow-left").transition(duration2);
  };
  effectInit({
    effect: "coverflow",
    swiper,
    on: on2,
    setTranslate: setTranslate2,
    setTransition: setTransition2,
    perspective: () => true,
    overwriteParams: () => ({
      watchSlidesProgress: true
    })
  });
}
function EffectCreative({
  swiper,
  extendParams,
  on: on2
}) {
  extendParams({
    creativeEffect: {
      transformEl: null,
      limitProgress: 1,
      shadowPerProgress: false,
      progressMultiplier: 1,
      perspective: true,
      prev: {
        translate: [0, 0, 0],
        rotate: [0, 0, 0],
        opacity: 1,
        scale: 1
      },
      next: {
        translate: [0, 0, 0],
        rotate: [0, 0, 0],
        opacity: 1,
        scale: 1
      }
    }
  });
  const getTranslateValue = (value) => {
    if (typeof value === "string")
      return value;
    return `${value}px`;
  };
  const setTranslate2 = () => {
    const {
      slides,
      $wrapperEl,
      slidesSizesGrid
    } = swiper;
    const params = swiper.params.creativeEffect;
    const {
      progressMultiplier: multiplier
    } = params;
    const isCenteredSlides = swiper.params.centeredSlides;
    if (isCenteredSlides) {
      const margin = slidesSizesGrid[0] / 2 - swiper.params.slidesOffsetBefore || 0;
      $wrapperEl.transform(`translateX(calc(50% - ${margin}px))`);
    }
    for (let i = 0; i < slides.length; i += 1) {
      const $slideEl = slides.eq(i);
      const slideProgress = $slideEl[0].progress;
      const progress = Math.min(Math.max($slideEl[0].progress, -params.limitProgress), params.limitProgress);
      let originalProgress = progress;
      if (!isCenteredSlides) {
        originalProgress = Math.min(Math.max($slideEl[0].originalProgress, -params.limitProgress), params.limitProgress);
      }
      const offset2 = $slideEl[0].swiperSlideOffset;
      const t = [swiper.params.cssMode ? -offset2 - swiper.translate : -offset2, 0, 0];
      const r = [0, 0, 0];
      let custom = false;
      if (!swiper.isHorizontal()) {
        t[1] = t[0];
        t[0] = 0;
      }
      let data = {
        translate: [0, 0, 0],
        rotate: [0, 0, 0],
        scale: 1,
        opacity: 1
      };
      if (progress < 0) {
        data = params.next;
        custom = true;
      } else if (progress > 0) {
        data = params.prev;
        custom = true;
      }
      t.forEach((value, index2) => {
        t[index2] = `calc(${value}px + (${getTranslateValue(data.translate[index2])} * ${Math.abs(progress * multiplier)}))`;
      });
      r.forEach((value, index2) => {
        r[index2] = data.rotate[index2] * Math.abs(progress * multiplier);
      });
      $slideEl[0].style.zIndex = -Math.abs(Math.round(slideProgress)) + slides.length;
      const translateString = t.join(", ");
      const rotateString = `rotateX(${r[0]}deg) rotateY(${r[1]}deg) rotateZ(${r[2]}deg)`;
      const scaleString = originalProgress < 0 ? `scale(${1 + (1 - data.scale) * originalProgress * multiplier})` : `scale(${1 - (1 - data.scale) * originalProgress * multiplier})`;
      const opacityString = originalProgress < 0 ? 1 + (1 - data.opacity) * originalProgress * multiplier : 1 - (1 - data.opacity) * originalProgress * multiplier;
      const transform2 = `translate3d(${translateString}) ${rotateString} ${scaleString}`;
      if (custom && data.shadow || !custom) {
        let $shadowEl = $slideEl.children(".swiper-slide-shadow");
        if ($shadowEl.length === 0 && data.shadow) {
          $shadowEl = createShadow(params, $slideEl);
        }
        if ($shadowEl.length) {
          const shadowOpacity = params.shadowPerProgress ? progress * (1 / params.limitProgress) : progress;
          $shadowEl[0].style.opacity = Math.min(Math.max(Math.abs(shadowOpacity), 0), 1);
        }
      }
      const $targetEl = effectTarget(params, $slideEl);
      $targetEl.transform(transform2).css({
        opacity: opacityString
      });
      if (data.origin) {
        $targetEl.css("transform-origin", data.origin);
      }
    }
  };
  const setTransition2 = (duration2) => {
    const {
      transformEl
    } = swiper.params.creativeEffect;
    const $transitionElements = transformEl ? swiper.slides.find(transformEl) : swiper.slides;
    $transitionElements.transition(duration2).find(".swiper-slide-shadow").transition(duration2);
    effectVirtualTransitionEnd({
      swiper,
      duration: duration2,
      transformEl,
      allSlides: true
    });
  };
  effectInit({
    effect: "creative",
    swiper,
    on: on2,
    setTranslate: setTranslate2,
    setTransition: setTransition2,
    perspective: () => swiper.params.creativeEffect.perspective,
    overwriteParams: () => ({
      watchSlidesProgress: true,
      virtualTranslate: !swiper.params.cssMode
    })
  });
}
function EffectCards({
  swiper,
  extendParams,
  on: on2
}) {
  extendParams({
    cardsEffect: {
      slideShadows: true,
      transformEl: null,
      rotate: true,
      perSlideRotate: 2,
      perSlideOffset: 8
    }
  });
  const setTranslate2 = () => {
    const {
      slides,
      activeIndex
    } = swiper;
    const params = swiper.params.cardsEffect;
    const {
      startTranslate,
      isTouched
    } = swiper.touchEventsData;
    const currentTranslate = swiper.translate;
    for (let i = 0; i < slides.length; i += 1) {
      const $slideEl = slides.eq(i);
      const slideProgress = $slideEl[0].progress;
      const progress = Math.min(Math.max(slideProgress, -4), 4);
      let offset2 = $slideEl[0].swiperSlideOffset;
      if (swiper.params.centeredSlides && !swiper.params.cssMode) {
        swiper.$wrapperEl.transform(`translateX(${swiper.minTranslate()}px)`);
      }
      if (swiper.params.centeredSlides && swiper.params.cssMode) {
        offset2 -= slides[0].swiperSlideOffset;
      }
      let tX = swiper.params.cssMode ? -offset2 - swiper.translate : -offset2;
      let tY = 0;
      const tZ = -100 * Math.abs(progress);
      let scale = 1;
      let rotate = -params.perSlideRotate * progress;
      let tXAdd = params.perSlideOffset - Math.abs(progress) * 0.75;
      const slideIndex = swiper.virtual && swiper.params.virtual.enabled ? swiper.virtual.from + i : i;
      const isSwipeToNext = (slideIndex === activeIndex || slideIndex === activeIndex - 1) && progress > 0 && progress < 1 && (isTouched || swiper.params.cssMode) && currentTranslate < startTranslate;
      const isSwipeToPrev = (slideIndex === activeIndex || slideIndex === activeIndex + 1) && progress < 0 && progress > -1 && (isTouched || swiper.params.cssMode) && currentTranslate > startTranslate;
      if (isSwipeToNext || isSwipeToPrev) {
        const subProgress = (1 - Math.abs((Math.abs(progress) - 0.5) / 0.5)) ** 0.5;
        rotate += -28 * progress * subProgress;
        scale += -0.5 * subProgress;
        tXAdd += 96 * subProgress;
        tY = `${-25 * subProgress * Math.abs(progress)}%`;
      }
      if (progress < 0) {
        tX = `calc(${tX}px + (${tXAdd * Math.abs(progress)}%))`;
      } else if (progress > 0) {
        tX = `calc(${tX}px + (-${tXAdd * Math.abs(progress)}%))`;
      } else {
        tX = `${tX}px`;
      }
      if (!swiper.isHorizontal()) {
        const prevY = tY;
        tY = tX;
        tX = prevY;
      }
      const scaleString = progress < 0 ? `${1 + (1 - scale) * progress}` : `${1 - (1 - scale) * progress}`;
      const transform2 = `
        translate3d(${tX}, ${tY}, ${tZ}px)
        rotateZ(${params.rotate ? rotate : 0}deg)
        scale(${scaleString})
      `;
      if (params.slideShadows) {
        let $shadowEl = $slideEl.find(".swiper-slide-shadow");
        if ($shadowEl.length === 0) {
          $shadowEl = createShadow(params, $slideEl);
        }
        if ($shadowEl.length)
          $shadowEl[0].style.opacity = Math.min(Math.max((Math.abs(progress) - 0.5) / 0.5, 0), 1);
      }
      $slideEl[0].style.zIndex = -Math.abs(Math.round(slideProgress)) + slides.length;
      const $targetEl = effectTarget(params, $slideEl);
      $targetEl.transform(transform2);
    }
  };
  const setTransition2 = (duration2) => {
    const {
      transformEl
    } = swiper.params.cardsEffect;
    const $transitionElements = transformEl ? swiper.slides.find(transformEl) : swiper.slides;
    $transitionElements.transition(duration2).find(".swiper-slide-shadow").transition(duration2);
    effectVirtualTransitionEnd({
      swiper,
      duration: duration2,
      transformEl
    });
  };
  effectInit({
    effect: "cards",
    swiper,
    on: on2,
    setTranslate: setTranslate2,
    setTransition: setTransition2,
    perspective: () => true,
    overwriteParams: () => ({
      watchSlidesProgress: true,
      virtualTranslate: !swiper.params.cssMode
    })
  });
}
function isObject(o) {
  return typeof o === "object" && o !== null && o.constructor && Object.prototype.toString.call(o).slice(8, -1) === "Object";
}
function extend(target, src) {
  const noExtend = ["__proto__", "constructor", "prototype"];
  Object.keys(src).filter((key) => noExtend.indexOf(key) < 0).forEach((key) => {
    if (typeof target[key] === "undefined")
      target[key] = src[key];
    else if (isObject(src[key]) && isObject(target[key]) && Object.keys(src[key]).length > 0) {
      if (src[key].__swiper__)
        target[key] = src[key];
      else
        extend(target[key], src[key]);
    } else {
      target[key] = src[key];
    }
  });
}
function needsNavigation(params = {}) {
  return params.navigation && typeof params.navigation.nextEl === "undefined" && typeof params.navigation.prevEl === "undefined";
}
function needsPagination(params = {}) {
  return params.pagination && typeof params.pagination.el === "undefined";
}
function needsScrollbar(params = {}) {
  return params.scrollbar && typeof params.scrollbar.el === "undefined";
}
function uniqueClasses(classNames = "") {
  const classes2 = classNames.split(" ").map((c) => c.trim()).filter((c) => !!c);
  const unique = [];
  classes2.forEach((c) => {
    if (unique.indexOf(c) < 0)
      unique.push(c);
  });
  return unique.join(" ");
}
const paramsList = [
  "modules",
  "init",
  "_direction",
  "touchEventsTarget",
  "initialSlide",
  "_speed",
  "cssMode",
  "updateOnWindowResize",
  "resizeObserver",
  "nested",
  "focusableElements",
  "_enabled",
  "_width",
  "_height",
  "preventInteractionOnTransition",
  "userAgent",
  "url",
  "_edgeSwipeDetection",
  "_edgeSwipeThreshold",
  "_freeMode",
  "_autoHeight",
  "setWrapperSize",
  "virtualTranslate",
  "_effect",
  "breakpoints",
  "_spaceBetween",
  "_slidesPerView",
  "maxBackfaceHiddenSlides",
  "_grid",
  "_slidesPerGroup",
  "_slidesPerGroupSkip",
  "_slidesPerGroupAuto",
  "_centeredSlides",
  "_centeredSlidesBounds",
  "_slidesOffsetBefore",
  "_slidesOffsetAfter",
  "normalizeSlideIndex",
  "_centerInsufficientSlides",
  "_watchOverflow",
  "roundLengths",
  "touchRatio",
  "touchAngle",
  "simulateTouch",
  "_shortSwipes",
  "_longSwipes",
  "longSwipesRatio",
  "longSwipesMs",
  "_followFinger",
  "allowTouchMove",
  "_threshold",
  "touchMoveStopPropagation",
  "touchStartPreventDefault",
  "touchStartForcePreventDefault",
  "touchReleaseOnEdges",
  "uniqueNavElements",
  "_resistance",
  "_resistanceRatio",
  "_watchSlidesProgress",
  "_grabCursor",
  "preventClicks",
  "preventClicksPropagation",
  "_slideToClickedSlide",
  "_preloadImages",
  "updateOnImagesReady",
  "_loop",
  "_loopAdditionalSlides",
  "_loopedSlides",
  "_loopedSlidesLimit",
  "_loopFillGroupWithBlank",
  "loopPreventsSlide",
  "_rewind",
  "_allowSlidePrev",
  "_allowSlideNext",
  "_swipeHandler",
  "_noSwiping",
  "noSwipingClass",
  "noSwipingSelector",
  "passiveListeners",
  "containerModifierClass",
  "slideClass",
  "slideBlankClass",
  "slideActiveClass",
  "slideDuplicateActiveClass",
  "slideVisibleClass",
  "slideDuplicateClass",
  "slideNextClass",
  "slideDuplicateNextClass",
  "slidePrevClass",
  "slideDuplicatePrevClass",
  "wrapperClass",
  "runCallbacksOnInit",
  "observer",
  "observeParents",
  "observeSlideChildren",
  // modules
  "a11y",
  "_autoplay",
  "_controller",
  "coverflowEffect",
  "cubeEffect",
  "fadeEffect",
  "flipEffect",
  "creativeEffect",
  "cardsEffect",
  "hashNavigation",
  "history",
  "keyboard",
  "lazy",
  "mousewheel",
  "_navigation",
  "_pagination",
  "parallax",
  "_scrollbar",
  "_thumbs",
  "virtual",
  "zoom"
];
function getParams(obj = {}, splitEvents = true) {
  const params = {
    on: {}
  };
  const events2 = {};
  const passedParams = {};
  extend(params, Swiper$1.defaults);
  extend(params, Swiper$1.extendedDefaults);
  params._emitClasses = true;
  params.init = false;
  const rest = {};
  const allowedParams = paramsList.map((key) => key.replace(/_/, ""));
  const plainObj = Object.assign({}, obj);
  Object.keys(plainObj).forEach((key) => {
    if (typeof obj[key] === "undefined")
      return;
    if (allowedParams.indexOf(key) >= 0) {
      if (isObject(obj[key])) {
        params[key] = {};
        passedParams[key] = {};
        extend(params[key], obj[key]);
        extend(passedParams[key], obj[key]);
      } else {
        params[key] = obj[key];
        passedParams[key] = obj[key];
      }
    } else if (key.search(/on[A-Z]/) === 0 && typeof obj[key] === "function") {
      if (splitEvents) {
        events2[`${key[2].toLowerCase()}${key.substr(3)}`] = obj[key];
      } else {
        params.on[`${key[2].toLowerCase()}${key.substr(3)}`] = obj[key];
      }
    } else {
      rest[key] = obj[key];
    }
  });
  ["navigation", "pagination", "scrollbar"].forEach((key) => {
    if (params[key] === true)
      params[key] = {};
    if (params[key] === false)
      delete params[key];
  });
  return {
    params,
    passedParams,
    rest,
    events: events2
  };
}
function mountSwiper({
  el,
  nextEl,
  prevEl,
  paginationEl,
  scrollbarEl,
  swiper
}, swiperParams) {
  if (needsNavigation(swiperParams) && nextEl && prevEl) {
    swiper.params.navigation.nextEl = nextEl;
    swiper.originalParams.navigation.nextEl = nextEl;
    swiper.params.navigation.prevEl = prevEl;
    swiper.originalParams.navigation.prevEl = prevEl;
  }
  if (needsPagination(swiperParams) && paginationEl) {
    swiper.params.pagination.el = paginationEl;
    swiper.originalParams.pagination.el = paginationEl;
  }
  if (needsScrollbar(swiperParams) && scrollbarEl) {
    swiper.params.scrollbar.el = scrollbarEl;
    swiper.originalParams.scrollbar.el = scrollbarEl;
  }
  swiper.init(el);
}
const calcLoopedSlides = (slides, swiperParams) => {
  let slidesPerViewParams = swiperParams.slidesPerView;
  if (swiperParams.breakpoints) {
    const breakpoint = Swiper$1.prototype.getBreakpoint(swiperParams.breakpoints);
    const breakpointOnlyParams = breakpoint in swiperParams.breakpoints ? swiperParams.breakpoints[breakpoint] : void 0;
    if (breakpointOnlyParams && breakpointOnlyParams.slidesPerView) {
      slidesPerViewParams = breakpointOnlyParams.slidesPerView;
    }
  }
  let loopedSlides = Math.ceil(parseFloat(swiperParams.loopedSlides || slidesPerViewParams, 10));
  loopedSlides += swiperParams.loopAdditionalSlides;
  if (loopedSlides > slides.length && swiperParams.loopedSlidesLimit) {
    loopedSlides = slides.length;
  }
  return loopedSlides;
};
function renderLoop(swiperRef, slides, swiperParams) {
  const modifiedSlides = slides.map((child, index2) => {
    if (!child.props)
      child.props = {};
    child.props.swiperRef = swiperRef;
    child.props["data-swiper-slide-index"] = index2;
    return child;
  });
  function duplicateSlide(child, index2, position) {
    if (!child.props)
      child.props = {};
    return h(child.type, {
      ...child.props,
      key: `${child.key}-duplicate-${index2}-${position}`,
      class: `${child.props.className || ""} ${swiperParams.slideDuplicateClass} ${child.props.class || ""}`
    }, child.children);
  }
  if (swiperParams.loopFillGroupWithBlank) {
    const blankSlidesNum = swiperParams.slidesPerGroup - modifiedSlides.length % swiperParams.slidesPerGroup;
    if (blankSlidesNum !== swiperParams.slidesPerGroup) {
      for (let i = 0; i < blankSlidesNum; i += 1) {
        const blankSlide = h("div", {
          class: `${swiperParams.slideClass} ${swiperParams.slideBlankClass}`
        });
        modifiedSlides.push(blankSlide);
      }
    }
  }
  if (swiperParams.slidesPerView === "auto" && !swiperParams.loopedSlides) {
    swiperParams.loopedSlides = modifiedSlides.length;
  }
  const loopedSlides = calcLoopedSlides(modifiedSlides, swiperParams);
  const prependSlides = [];
  const appendSlides = [];
  for (let i = 0; i < loopedSlides; i += 1) {
    const index2 = i - Math.floor(i / modifiedSlides.length) * modifiedSlides.length;
    appendSlides.push(duplicateSlide(modifiedSlides[index2], i, "append"));
    prependSlides.unshift(duplicateSlide(modifiedSlides[modifiedSlides.length - index2 - 1], i, "prepend"));
  }
  if (swiperRef.value) {
    swiperRef.value.loopedSlides = loopedSlides;
  }
  return [...prependSlides, ...modifiedSlides, ...appendSlides];
}
function getChangedParams(swiperParams, oldParams, children2, oldChildren, getKey) {
  const keys = [];
  if (!oldParams)
    return keys;
  const addKey = (key) => {
    if (keys.indexOf(key) < 0)
      keys.push(key);
  };
  if (children2 && oldChildren) {
    const oldChildrenKeys = oldChildren.map(getKey);
    const childrenKeys = children2.map(getKey);
    if (oldChildrenKeys.join("") !== childrenKeys.join(""))
      addKey("children");
    if (oldChildren.length !== children2.length)
      addKey("children");
  }
  const watchParams = paramsList.filter((key) => key[0] === "_").map((key) => key.replace(/_/, ""));
  watchParams.forEach((key) => {
    if (key in swiperParams && key in oldParams) {
      if (isObject(swiperParams[key]) && isObject(oldParams[key])) {
        const newKeys = Object.keys(swiperParams[key]);
        const oldKeys = Object.keys(oldParams[key]);
        if (newKeys.length !== oldKeys.length) {
          addKey(key);
        } else {
          newKeys.forEach((newKey) => {
            if (swiperParams[key][newKey] !== oldParams[key][newKey]) {
              addKey(key);
            }
          });
          oldKeys.forEach((oldKey) => {
            if (swiperParams[key][oldKey] !== oldParams[key][oldKey])
              addKey(key);
          });
        }
      } else if (swiperParams[key] !== oldParams[key]) {
        addKey(key);
      }
    }
  });
  return keys;
}
function getChildren(originalSlots, slidesRef, oldSlidesRef) {
  if (originalSlots === void 0) {
    originalSlots = {};
  }
  const slides = [];
  const slots = {
    "container-start": [],
    "container-end": [],
    "wrapper-start": [],
    "wrapper-end": []
  };
  const getSlidesFromElements = (els, slotName) => {
    if (!Array.isArray(els)) {
      return;
    }
    els.forEach((vnode) => {
      const isFragment = typeof vnode.type === "symbol";
      if (slotName === "default")
        slotName = "container-end";
      if (isFragment && vnode.children) {
        getSlidesFromElements(vnode.children, "default");
      } else if (vnode.type && (vnode.type.name === "SwiperSlide" || vnode.type.name === "AsyncComponentWrapper")) {
        slides.push(vnode);
      } else if (slots[slotName]) {
        slots[slotName].push(vnode);
      }
    });
  };
  Object.keys(originalSlots).forEach((slotName) => {
    if (typeof originalSlots[slotName] !== "function")
      return;
    const els = originalSlots[slotName]();
    getSlidesFromElements(els, slotName);
  });
  oldSlidesRef.value = slidesRef.value;
  slidesRef.value = slides;
  return {
    slides,
    slots
  };
}
function updateSwiper({
  swiper,
  slides,
  passedParams,
  changedParams,
  nextEl,
  prevEl,
  scrollbarEl,
  paginationEl
}) {
  const updateParams = changedParams.filter((key) => key !== "children" && key !== "direction");
  const {
    params: currentParams,
    pagination,
    navigation,
    scrollbar,
    virtual,
    thumbs
  } = swiper;
  let needThumbsInit;
  let needControllerInit;
  let needPaginationInit;
  let needScrollbarInit;
  let needNavigationInit;
  if (changedParams.includes("thumbs") && passedParams.thumbs && passedParams.thumbs.swiper && currentParams.thumbs && !currentParams.thumbs.swiper) {
    needThumbsInit = true;
  }
  if (changedParams.includes("controller") && passedParams.controller && passedParams.controller.control && currentParams.controller && !currentParams.controller.control) {
    needControllerInit = true;
  }
  if (changedParams.includes("pagination") && passedParams.pagination && (passedParams.pagination.el || paginationEl) && (currentParams.pagination || currentParams.pagination === false) && pagination && !pagination.el) {
    needPaginationInit = true;
  }
  if (changedParams.includes("scrollbar") && passedParams.scrollbar && (passedParams.scrollbar.el || scrollbarEl) && (currentParams.scrollbar || currentParams.scrollbar === false) && scrollbar && !scrollbar.el) {
    needScrollbarInit = true;
  }
  if (changedParams.includes("navigation") && passedParams.navigation && (passedParams.navigation.prevEl || prevEl) && (passedParams.navigation.nextEl || nextEl) && (currentParams.navigation || currentParams.navigation === false) && navigation && !navigation.prevEl && !navigation.nextEl) {
    needNavigationInit = true;
  }
  const destroyModule = (mod) => {
    if (!swiper[mod])
      return;
    swiper[mod].destroy();
    if (mod === "navigation") {
      currentParams[mod].prevEl = void 0;
      currentParams[mod].nextEl = void 0;
      swiper[mod].prevEl = void 0;
      swiper[mod].nextEl = void 0;
    } else {
      currentParams[mod].el = void 0;
      swiper[mod].el = void 0;
    }
  };
  updateParams.forEach((key) => {
    if (isObject(currentParams[key]) && isObject(passedParams[key])) {
      extend(currentParams[key], passedParams[key]);
    } else {
      const newValue = passedParams[key];
      if ((newValue === true || newValue === false) && (key === "navigation" || key === "pagination" || key === "scrollbar")) {
        if (newValue === false) {
          destroyModule(key);
        }
      } else {
        currentParams[key] = passedParams[key];
      }
    }
  });
  if (updateParams.includes("controller") && !needControllerInit && swiper.controller && swiper.controller.control && currentParams.controller && currentParams.controller.control) {
    swiper.controller.control = currentParams.controller.control;
  }
  if (changedParams.includes("children") && slides && virtual && currentParams.virtual.enabled) {
    virtual.slides = slides;
    virtual.update(true);
  } else if (changedParams.includes("children") && swiper.lazy && swiper.params.lazy.enabled) {
    swiper.lazy.load();
  }
  if (needThumbsInit) {
    const initialized = thumbs.init();
    if (initialized)
      thumbs.update(true);
  }
  if (needControllerInit) {
    swiper.controller.control = currentParams.controller.control;
  }
  if (needPaginationInit) {
    if (paginationEl)
      currentParams.pagination.el = paginationEl;
    pagination.init();
    pagination.render();
    pagination.update();
  }
  if (needScrollbarInit) {
    if (scrollbarEl)
      currentParams.scrollbar.el = scrollbarEl;
    scrollbar.init();
    scrollbar.updateSize();
    scrollbar.setTranslate();
  }
  if (needNavigationInit) {
    if (nextEl)
      currentParams.navigation.nextEl = nextEl;
    if (prevEl)
      currentParams.navigation.prevEl = prevEl;
    navigation.init();
    navigation.update();
  }
  if (changedParams.includes("allowSlideNext")) {
    swiper.allowSlideNext = passedParams.allowSlideNext;
  }
  if (changedParams.includes("allowSlidePrev")) {
    swiper.allowSlidePrev = passedParams.allowSlidePrev;
  }
  if (changedParams.includes("direction")) {
    swiper.changeDirection(passedParams.direction, false);
  }
  swiper.update();
}
function renderVirtual(swiperRef, slides, virtualData) {
  if (!virtualData)
    return null;
  const style = swiperRef.value.isHorizontal() ? {
    [swiperRef.value.rtlTranslate ? "right" : "left"]: `${virtualData.offset}px`
  } : {
    top: `${virtualData.offset}px`
  };
  return slides.filter((slide2, index2) => index2 >= virtualData.from && index2 <= virtualData.to).map((slide2) => {
    if (!slide2.props)
      slide2.props = {};
    if (!slide2.props.style)
      slide2.props.style = {};
    slide2.props.swiperRef = swiperRef;
    slide2.props.style = style;
    return h(slide2.type, {
      ...slide2.props
    }, slide2.children);
  });
}
const updateOnVirtualData = (swiper) => {
  if (!swiper || swiper.destroyed || !swiper.params.virtual || swiper.params.virtual && !swiper.params.virtual.enabled)
    return;
  swiper.updateSlides();
  swiper.updateProgress();
  swiper.updateSlidesClasses();
  if (swiper.lazy && swiper.params.lazy.enabled) {
    swiper.lazy.load();
  }
  if (swiper.parallax && swiper.params.parallax && swiper.params.parallax.enabled) {
    swiper.parallax.setTranslate();
  }
};
const Swiper2 = {
  name: "Swiper",
  props: {
    tag: {
      type: String,
      default: "div"
    },
    wrapperTag: {
      type: String,
      default: "div"
    },
    modules: {
      type: Array,
      default: void 0
    },
    init: {
      type: Boolean,
      default: void 0
    },
    direction: {
      type: String,
      default: void 0
    },
    touchEventsTarget: {
      type: String,
      default: void 0
    },
    initialSlide: {
      type: Number,
      default: void 0
    },
    speed: {
      type: Number,
      default: void 0
    },
    cssMode: {
      type: Boolean,
      default: void 0
    },
    updateOnWindowResize: {
      type: Boolean,
      default: void 0
    },
    resizeObserver: {
      type: Boolean,
      default: void 0
    },
    nested: {
      type: Boolean,
      default: void 0
    },
    focusableElements: {
      type: String,
      default: void 0
    },
    width: {
      type: Number,
      default: void 0
    },
    height: {
      type: Number,
      default: void 0
    },
    preventInteractionOnTransition: {
      type: Boolean,
      default: void 0
    },
    userAgent: {
      type: String,
      default: void 0
    },
    url: {
      type: String,
      default: void 0
    },
    edgeSwipeDetection: {
      type: [Boolean, String],
      default: void 0
    },
    edgeSwipeThreshold: {
      type: Number,
      default: void 0
    },
    autoHeight: {
      type: Boolean,
      default: void 0
    },
    setWrapperSize: {
      type: Boolean,
      default: void 0
    },
    virtualTranslate: {
      type: Boolean,
      default: void 0
    },
    effect: {
      type: String,
      default: void 0
    },
    breakpoints: {
      type: Object,
      default: void 0
    },
    spaceBetween: {
      type: Number,
      default: void 0
    },
    slidesPerView: {
      type: [Number, String],
      default: void 0
    },
    maxBackfaceHiddenSlides: {
      type: Number,
      default: void 0
    },
    slidesPerGroup: {
      type: Number,
      default: void 0
    },
    slidesPerGroupSkip: {
      type: Number,
      default: void 0
    },
    slidesPerGroupAuto: {
      type: Boolean,
      default: void 0
    },
    centeredSlides: {
      type: Boolean,
      default: void 0
    },
    centeredSlidesBounds: {
      type: Boolean,
      default: void 0
    },
    slidesOffsetBefore: {
      type: Number,
      default: void 0
    },
    slidesOffsetAfter: {
      type: Number,
      default: void 0
    },
    normalizeSlideIndex: {
      type: Boolean,
      default: void 0
    },
    centerInsufficientSlides: {
      type: Boolean,
      default: void 0
    },
    watchOverflow: {
      type: Boolean,
      default: void 0
    },
    roundLengths: {
      type: Boolean,
      default: void 0
    },
    touchRatio: {
      type: Number,
      default: void 0
    },
    touchAngle: {
      type: Number,
      default: void 0
    },
    simulateTouch: {
      type: Boolean,
      default: void 0
    },
    shortSwipes: {
      type: Boolean,
      default: void 0
    },
    longSwipes: {
      type: Boolean,
      default: void 0
    },
    longSwipesRatio: {
      type: Number,
      default: void 0
    },
    longSwipesMs: {
      type: Number,
      default: void 0
    },
    followFinger: {
      type: Boolean,
      default: void 0
    },
    allowTouchMove: {
      type: Boolean,
      default: void 0
    },
    threshold: {
      type: Number,
      default: void 0
    },
    touchMoveStopPropagation: {
      type: Boolean,
      default: void 0
    },
    touchStartPreventDefault: {
      type: Boolean,
      default: void 0
    },
    touchStartForcePreventDefault: {
      type: Boolean,
      default: void 0
    },
    touchReleaseOnEdges: {
      type: Boolean,
      default: void 0
    },
    uniqueNavElements: {
      type: Boolean,
      default: void 0
    },
    resistance: {
      type: Boolean,
      default: void 0
    },
    resistanceRatio: {
      type: Number,
      default: void 0
    },
    watchSlidesProgress: {
      type: Boolean,
      default: void 0
    },
    grabCursor: {
      type: Boolean,
      default: void 0
    },
    preventClicks: {
      type: Boolean,
      default: void 0
    },
    preventClicksPropagation: {
      type: Boolean,
      default: void 0
    },
    slideToClickedSlide: {
      type: Boolean,
      default: void 0
    },
    preloadImages: {
      type: Boolean,
      default: void 0
    },
    updateOnImagesReady: {
      type: Boolean,
      default: void 0
    },
    loop: {
      type: Boolean,
      default: void 0
    },
    loopAdditionalSlides: {
      type: Number,
      default: void 0
    },
    loopedSlides: {
      type: Number,
      default: void 0
    },
    loopedSlidesLimit: {
      type: Boolean,
      default: true
    },
    loopFillGroupWithBlank: {
      type: Boolean,
      default: void 0
    },
    loopPreventsSlide: {
      type: Boolean,
      default: void 0
    },
    rewind: {
      type: Boolean,
      default: void 0
    },
    allowSlidePrev: {
      type: Boolean,
      default: void 0
    },
    allowSlideNext: {
      type: Boolean,
      default: void 0
    },
    swipeHandler: {
      type: Boolean,
      default: void 0
    },
    noSwiping: {
      type: Boolean,
      default: void 0
    },
    noSwipingClass: {
      type: String,
      default: void 0
    },
    noSwipingSelector: {
      type: String,
      default: void 0
    },
    passiveListeners: {
      type: Boolean,
      default: void 0
    },
    containerModifierClass: {
      type: String,
      default: void 0
    },
    slideClass: {
      type: String,
      default: void 0
    },
    slideBlankClass: {
      type: String,
      default: void 0
    },
    slideActiveClass: {
      type: String,
      default: void 0
    },
    slideDuplicateActiveClass: {
      type: String,
      default: void 0
    },
    slideVisibleClass: {
      type: String,
      default: void 0
    },
    slideDuplicateClass: {
      type: String,
      default: void 0
    },
    slideNextClass: {
      type: String,
      default: void 0
    },
    slideDuplicateNextClass: {
      type: String,
      default: void 0
    },
    slidePrevClass: {
      type: String,
      default: void 0
    },
    slideDuplicatePrevClass: {
      type: String,
      default: void 0
    },
    wrapperClass: {
      type: String,
      default: void 0
    },
    runCallbacksOnInit: {
      type: Boolean,
      default: void 0
    },
    observer: {
      type: Boolean,
      default: void 0
    },
    observeParents: {
      type: Boolean,
      default: void 0
    },
    observeSlideChildren: {
      type: Boolean,
      default: void 0
    },
    a11y: {
      type: [Boolean, Object],
      default: void 0
    },
    autoplay: {
      type: [Boolean, Object],
      default: void 0
    },
    controller: {
      type: Object,
      default: void 0
    },
    coverflowEffect: {
      type: Object,
      default: void 0
    },
    cubeEffect: {
      type: Object,
      default: void 0
    },
    fadeEffect: {
      type: Object,
      default: void 0
    },
    flipEffect: {
      type: Object,
      default: void 0
    },
    creativeEffect: {
      type: Object,
      default: void 0
    },
    cardsEffect: {
      type: Object,
      default: void 0
    },
    hashNavigation: {
      type: [Boolean, Object],
      default: void 0
    },
    history: {
      type: [Boolean, Object],
      default: void 0
    },
    keyboard: {
      type: [Boolean, Object],
      default: void 0
    },
    lazy: {
      type: [Boolean, Object],
      default: void 0
    },
    mousewheel: {
      type: [Boolean, Object],
      default: void 0
    },
    navigation: {
      type: [Boolean, Object],
      default: void 0
    },
    pagination: {
      type: [Boolean, Object],
      default: void 0
    },
    parallax: {
      type: [Boolean, Object],
      default: void 0
    },
    scrollbar: {
      type: [Boolean, Object],
      default: void 0
    },
    thumbs: {
      type: Object,
      default: void 0
    },
    virtual: {
      type: [Boolean, Object],
      default: void 0
    },
    zoom: {
      type: [Boolean, Object],
      default: void 0
    },
    grid: {
      type: [Object],
      default: void 0
    },
    freeMode: {
      type: [Boolean, Object],
      default: void 0
    },
    enabled: {
      type: Boolean,
      default: void 0
    }
  },
  emits: ["_beforeBreakpoint", "_containerClasses", "_slideClass", "_slideClasses", "_swiper", "_freeModeNoMomentumRelease", "activeIndexChange", "afterInit", "autoplay", "autoplayStart", "autoplayStop", "autoplayPause", "autoplayResume", "beforeDestroy", "beforeInit", "beforeLoopFix", "beforeResize", "beforeSlideChangeStart", "beforeTransitionStart", "breakpoint", "changeDirection", "click", "disable", "doubleTap", "doubleClick", "destroy", "enable", "fromEdge", "hashChange", "hashSet", "imagesReady", "init", "keyPress", "lazyImageLoad", "lazyImageReady", "lock", "loopFix", "momentumBounce", "navigationHide", "navigationShow", "navigationPrev", "navigationNext", "observerUpdate", "orientationchange", "paginationHide", "paginationRender", "paginationShow", "paginationUpdate", "progress", "reachBeginning", "reachEnd", "realIndexChange", "resize", "scroll", "scrollbarDragEnd", "scrollbarDragMove", "scrollbarDragStart", "setTransition", "setTranslate", "slideChange", "slideChangeTransitionEnd", "slideChangeTransitionStart", "slideNextTransitionEnd", "slideNextTransitionStart", "slidePrevTransitionEnd", "slidePrevTransitionStart", "slideResetTransitionStart", "slideResetTransitionEnd", "sliderMove", "sliderFirstMove", "slidesLengthChange", "slidesGridLengthChange", "snapGridLengthChange", "snapIndexChange", "swiper", "tap", "toEdge", "touchEnd", "touchMove", "touchMoveOpposite", "touchStart", "transitionEnd", "transitionStart", "unlock", "update", "virtualUpdate", "zoomChange"],
  setup(props, _ref) {
    let {
      slots: originalSlots,
      emit
    } = _ref;
    const {
      tag: Tag,
      wrapperTag: WrapperTag
    } = props;
    const containerClasses = ref("swiper");
    const virtualData = ref(null);
    const breakpointChanged = ref(false);
    const initializedRef = ref(false);
    const swiperElRef = ref(null);
    const swiperRef = ref(null);
    const oldPassedParamsRef = ref(null);
    const slidesRef = {
      value: []
    };
    const oldSlidesRef = {
      value: []
    };
    const nextElRef = ref(null);
    const prevElRef = ref(null);
    const paginationElRef = ref(null);
    const scrollbarElRef = ref(null);
    const {
      params: swiperParams,
      passedParams
    } = getParams(props, false);
    getChildren(originalSlots, slidesRef, oldSlidesRef);
    oldPassedParamsRef.value = passedParams;
    oldSlidesRef.value = slidesRef.value;
    const onBeforeBreakpoint = () => {
      getChildren(originalSlots, slidesRef, oldSlidesRef);
      breakpointChanged.value = true;
    };
    swiperParams.onAny = function(event2) {
      for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        args[_key - 1] = arguments[_key];
      }
      emit(event2, ...args);
    };
    Object.assign(swiperParams.on, {
      _beforeBreakpoint: onBeforeBreakpoint,
      _containerClasses(swiper, classes2) {
        containerClasses.value = classes2;
      }
    });
    swiperRef.value = new Swiper$1(swiperParams);
    swiperRef.value.loopCreate = () => {
    };
    swiperRef.value.loopDestroy = () => {
    };
    if (swiperParams.loop) {
      swiperRef.value.loopedSlides = calcLoopedSlides(slidesRef.value, swiperParams);
    }
    if (swiperRef.value.virtual && swiperRef.value.params.virtual.enabled) {
      swiperRef.value.virtual.slides = slidesRef.value;
      const extendWith = {
        cache: false,
        slides: slidesRef.value,
        renderExternal: (data) => {
          virtualData.value = data;
        },
        renderExternalUpdate: false
      };
      extend(swiperRef.value.params.virtual, extendWith);
      extend(swiperRef.value.originalParams.virtual, extendWith);
    }
    onUpdated(() => {
      if (!initializedRef.value && swiperRef.value) {
        swiperRef.value.emitSlidesClasses();
        initializedRef.value = true;
      }
      const {
        passedParams: newPassedParams
      } = getParams(props, false);
      const changedParams = getChangedParams(newPassedParams, oldPassedParamsRef.value, slidesRef.value, oldSlidesRef.value, (c) => c.props && c.props.key);
      oldPassedParamsRef.value = newPassedParams;
      if ((changedParams.length || breakpointChanged.value) && swiperRef.value && !swiperRef.value.destroyed) {
        updateSwiper({
          swiper: swiperRef.value,
          slides: slidesRef.value,
          passedParams: newPassedParams,
          changedParams,
          nextEl: nextElRef.value,
          prevEl: prevElRef.value,
          scrollbarEl: scrollbarElRef.value,
          paginationEl: paginationElRef.value
        });
      }
      breakpointChanged.value = false;
    });
    provide("swiper", swiperRef);
    watch(virtualData, () => {
      nextTick$1(() => {
        updateOnVirtualData(swiperRef.value);
      });
    });
    onMounted(() => {
      if (!swiperElRef.value)
        return;
      mountSwiper({
        el: swiperElRef.value,
        nextEl: nextElRef.value,
        prevEl: prevElRef.value,
        paginationEl: paginationElRef.value,
        scrollbarEl: scrollbarElRef.value,
        swiper: swiperRef.value
      }, swiperParams);
      emit("swiper", swiperRef.value);
    });
    onBeforeUnmount(() => {
      if (swiperRef.value && !swiperRef.value.destroyed) {
        swiperRef.value.destroy(true, false);
      }
    });
    function renderSlides(slides) {
      if (swiperParams.virtual) {
        return renderVirtual(swiperRef, slides, virtualData.value);
      }
      if (!swiperParams.loop || swiperRef.value && swiperRef.value.destroyed) {
        slides.forEach((slide2) => {
          if (!slide2.props)
            slide2.props = {};
          slide2.props.swiperRef = swiperRef;
        });
        return slides;
      }
      return renderLoop(swiperRef, slides, swiperParams);
    }
    return () => {
      const {
        slides,
        slots
      } = getChildren(originalSlots, slidesRef, oldSlidesRef);
      return h(Tag, {
        ref: swiperElRef,
        class: uniqueClasses(containerClasses.value)
      }, [slots["container-start"], h(WrapperTag, {
        class: "swiper-wrapper"
      }, [slots["wrapper-start"], renderSlides(slides), slots["wrapper-end"]]), needsNavigation(props) && [h("div", {
        ref: prevElRef,
        class: "swiper-button-prev"
      }), h("div", {
        ref: nextElRef,
        class: "swiper-button-next"
      })], needsScrollbar(props) && h("div", {
        ref: scrollbarElRef,
        class: "swiper-scrollbar"
      }), needsPagination(props) && h("div", {
        ref: paginationElRef,
        class: "swiper-pagination"
      }), slots["container-end"]]);
    };
  }
};
const SwiperSlide = {
  name: "SwiperSlide",
  props: {
    tag: {
      type: String,
      default: "div"
    },
    swiperRef: {
      type: Object,
      required: false
    },
    zoom: {
      type: Boolean,
      default: void 0
    },
    virtualIndex: {
      type: [String, Number],
      default: void 0
    }
  },
  setup(props, _ref) {
    let {
      slots
    } = _ref;
    let eventAttached = false;
    const {
      swiperRef
    } = props;
    const slideElRef = ref(null);
    const slideClasses = ref("swiper-slide");
    function updateClasses(swiper, el, classNames) {
      if (el === slideElRef.value) {
        slideClasses.value = classNames;
      }
    }
    onMounted(() => {
      if (!swiperRef || !swiperRef.value)
        return;
      swiperRef.value.on("_slideClass", updateClasses);
      eventAttached = true;
    });
    onBeforeUpdate(() => {
      if (eventAttached || !swiperRef || !swiperRef.value)
        return;
      swiperRef.value.on("_slideClass", updateClasses);
      eventAttached = true;
    });
    onUpdated(() => {
      if (!slideElRef.value || !swiperRef || !swiperRef.value)
        return;
      if (swiperRef.value.destroyed) {
        if (slideClasses.value !== "swiper-slide") {
          slideClasses.value = "swiper-slide";
        }
      }
    });
    onBeforeUnmount(() => {
      if (!swiperRef || !swiperRef.value)
        return;
      swiperRef.value.off("_slideClass", updateClasses);
    });
    const slideData = computed(() => ({
      isActive: slideClasses.value.indexOf("swiper-slide-active") >= 0 || slideClasses.value.indexOf("swiper-slide-duplicate-active") >= 0,
      isVisible: slideClasses.value.indexOf("swiper-slide-visible") >= 0,
      isDuplicate: slideClasses.value.indexOf("swiper-slide-duplicate") >= 0,
      isPrev: slideClasses.value.indexOf("swiper-slide-prev") >= 0 || slideClasses.value.indexOf("swiper-slide-duplicate-prev") >= 0,
      isNext: slideClasses.value.indexOf("swiper-slide-next") >= 0 || slideClasses.value.indexOf("swiper-slide-duplicate-next") >= 0
    }));
    provide("swiperSlide", slideData);
    return () => {
      return h(props.tag, {
        class: uniqueClasses(`${slideClasses.value}`),
        ref: slideElRef,
        "data-swiper-slide-index": props.virtualIndex
      }, props.zoom ? h("div", {
        class: "swiper-zoom-container",
        "data-swiper-zoom": typeof props.zoom === "number" ? props.zoom : void 0
      }, slots.default && slots.default(slideData.value)) : slots.default && slots.default(slideData.value));
    };
  }
};
const useSwiperSlide = () => {
  return inject("swiperSlide");
};
const useSwiper = () => {
  return inject("swiper");
};
const createBreakpointOptions = (propBreakpoint) => Object.keys(propBreakpoint).reduce((acc, current) => {
  acc[BREAKPOINTS[current]] = propBreakpoint[current];
  return acc;
}, {});
const _sfc_main$2 = /* @__PURE__ */ defineComponent({
  __name: "UiSwiper",
  props: {
    index: null,
    slidesPerView: { default: 1 },
    spaceBetween: null,
    scrollbar: { type: Boolean },
    pagination: { type: [Boolean, null] },
    navigation: { type: [Boolean, null] },
    loop: { type: Boolean },
    autoHeight: { type: Boolean },
    freeMode: { type: [Boolean, null] },
    breakpoints: null,
    direction: { default: "horizontal" },
    fade: { type: Boolean },
    autoplay: { type: [Boolean, null] },
    centeredSlides: { type: Boolean },
    slidesPerGroup: null,
    mousewheel: { type: Boolean }
  },
  emits: ["update:index"],
  setup(__props, { emit }) {
    const props = __props;
    const swiperRef = ref();
    const swiper = computed(() => {
      var _a, _b;
      return (_b = (_a = swiperRef.value) == null ? void 0 : _a.$el) == null ? void 0 : _b.swiper;
    });
    const currentIndex = ref();
    const setCurrentIndex = () => {
      var _a;
      currentIndex.value = (_a = swiper.value) == null ? void 0 : _a.realIndex;
    };
    const onSlideChange = () => {
      setCurrentIndex();
      emit("update:index", swiper.value.realIndex, swiper.value);
    };
    watch(
      () => props.index,
      (index2) => setTimeout(() => {
        if (swiper.value.realIndex !== index2)
          swiper.value.slideTo(index2 || 0);
      })
    );
    const autoplaying = ref();
    const setAutoPlaying = (value) => {
      autoplaying.value = value;
    };
    const breakpointOptions = props.breakpoints ? createBreakpointOptions(props.breakpoints) : void 0;
    const modules = [Mousewheel, Navigation, Pagination, Scrollbar, A11y, freeMode, EffectFade, Autoplay];
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(Swiper2), {
        ref_key: "swiperRef",
        ref: swiperRef,
        class: "ui-swiper position-relative",
        "initial-slide": __props.index,
        modules,
        loop: __props.loop,
        navigation: __props.navigation,
        pagination: __props.pagination,
        scrollbar: __props.scrollbar && { draggable: true },
        "slides-per-view": __props.slidesPerView,
        "space-between": __props.spaceBetween,
        "auto-height": __props.autoHeight,
        breakpoints: unref(breakpointOptions),
        "free-mode": __props.freeMode,
        effect: __props.fade ? "fade" : void 0,
        autoplay: __props.autoplay,
        centeredSlides: __props.centeredSlides,
        "loop-additional-slides": 30,
        "rounded-lengths": true,
        "slides-per-group": __props.slidesPerGroup,
        direction: __props.direction,
        mousewheel: __props.mousewheel,
        onSlideChange,
        onAutoplayStart: _cache[0] || (_cache[0] = ($event) => setAutoPlaying(true)),
        onAutoplayStop: _cache[1] || (_cache[1] = ($event) => setAutoPlaying(false))
      }, {
        default: withCtx(() => [
          renderSlot(_ctx.$slots, "default", normalizeProps(guardReactiveProps({ index: currentIndex.value, autoplaying: autoplaying.value, swiper: unref(swiper) }))),
          renderSlot(_ctx.$slots, "custom-pagination", normalizeProps(guardReactiveProps({ index: currentIndex.value, autoplaying: autoplaying.value, swiper: unref(swiper) })))
        ]),
        _: 3
      }, 8, ["initial-slide", "loop", "navigation", "pagination", "scrollbar", "slides-per-view", "space-between", "auto-height", "breakpoints", "free-mode", "effect", "autoplay", "centeredSlides", "slides-per-group", "direction", "mousewheel"]);
    };
  }
});
const _hoisted_1$1 = { class: "ui-timer" };
const _sfc_main$1 = /* @__PURE__ */ defineComponent({
  __name: "UiTimer",
  props: {
    startDate: null,
    endDate: null
  },
  setup(__props) {
    const props = __props;
    const timerStatus = ref();
    const updateTimerStatus = () => {
      const now2 = dayjs();
      if (now2.isBefore(props.startDate))
        timerStatus.value = "BeforeStart";
      else if (now2.isAfter(props.endDate))
        timerStatus.value = "AfterEnd";
      else
        timerStatus.value = "InProgress";
    };
    const remaining = ref();
    const updateRemaining = () => {
      const target = timerStatus.value === "BeforeStart" ? props.startDate : timerStatus.value === "InProgress" ? props.endDate : void 0;
      remaining.value = target ? dayjs(target).diff() : void 0;
    };
    let timeoutHandle = 0;
    const updateAll = () => {
      updateTimerStatus();
      updateRemaining();
      timeoutHandle = setTimeout(updateAll, 1e3);
    };
    onBeforeUnmount(() => {
      if (timeoutHandle && typeof timeoutHandle === "number")
        clearTimeout(timeoutHandle);
    });
    watch(() => [props.endDate, props.startDate], updateAll, { immediate: true });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$1, [
        timerStatus.value === "BeforeStart" && remaining.value ? renderSlot(_ctx.$slots, "beforeStart", {
          key: 0,
          remaining: remaining.value
        }) : createCommentVNode("", true),
        timerStatus.value === "InProgress" && remaining.value ? renderSlot(_ctx.$slots, "inProgress", {
          key: 1,
          remaining: remaining.value
        }) : createCommentVNode("", true),
        timerStatus.value === "AfterEnd" ? renderSlot(_ctx.$slots, "afterEnd", { key: 2 }) : createCommentVNode("", true)
      ]);
    };
  }
});
class ScrollListKey {
  constructor(params) {
    // 리스트를 강제로 갱신하는 경우 값을 하나씩 올려 사용한다.
    __publicField(this, "forceUpdate", ref(0));
    this.params = params;
  }
  setParams(params) {
    this.params = params;
  }
  forceRefresh() {
    this.forceUpdate.value++;
  }
  key() {
    var _a;
    const key = ((_a = this.params) == null ? void 0 : _a.map((param) => param.value).map((value) => value ? value.toString() : "").join("_")) || "";
    return key + (this.forceUpdate.value > 0 ? `_${this.forceUpdate.value}` : "");
  }
}
class ScrollListFilter {
  constructor(params) {
    __publicField(this, "queryRef", ref(""));
    this.params = params;
  }
  setParams(params) {
    this.params = params;
  }
  createUrlQuery(locationQuery) {
    const nonFilter = this.extractNonFilterQuery(locationQuery);
    const filter2 = this.createRequestQuery();
    return { ...nonFilter, ...filter2 };
  }
  static isQueryEqual(query1, query2) {
    return JSON.stringify(query1, Object.keys(query1).sort()) === JSON.stringify(query2, Object.keys(query2).sort());
  }
  createRequestQuery() {
    var _a;
    const query = {};
    (_a = this.params) == null ? void 0 : _a.filter((param) => param.value.value && param.value.value !== param.defaultValue).forEach((param) => {
      const queryValue = this.convertToQuery(param);
      if (queryValue)
        query[param.name] = queryValue;
    });
    return query;
  }
  extractNonFilterQuery(query) {
    var _a;
    const filterNames = ((_a = this.params) == null ? void 0 : _a.map((param) => param.name)) || [];
    return Object.keys(query || []).reduce((acc, current) => {
      if (!filterNames.includes(current))
        acc[current] = (query == null ? void 0 : query[current]) || "";
      return acc;
    }, {});
  }
  syncUrlQuery(locationQuery) {
    var _a;
    (_a = this.params) == null ? void 0 : _a.forEach((param) => {
      const queryValue = locationQuery[param.name];
      param.value.value = this.convertFromQuery(param, queryValue);
    });
    const query = this.createRequestQuery();
    this.queryRef.value = Object.keys(query).length == 0 ? "" : JSON.stringify(query);
  }
  convertToQuery(param) {
    var _a;
    const value = param.value.value;
    if (!value || JSON.stringify(value) === JSON.stringify(param.defaultValue)) {
      return void 0;
    } else if ((_a = param.queryConverter) == null ? void 0 : _a.toQueryString) {
      return param.queryConverter.toQueryString(value);
    } else {
      return value.toString();
    }
  }
  convertFromQuery(param, queryValue) {
    var _a, _b;
    if (!queryValue) {
      return param.defaultValue;
    } else if ((_a = param.queryConverter) == null ? void 0 : _a.fromQueryString) {
      return (_b = param.queryConverter) == null ? void 0 : _b.fromQueryString(queryValue);
    } else {
      return String(queryValue);
    }
  }
  createListKey() {
    return new ScrollListKey([this.queryRef]);
  }
  getParamValues() {
    var _a;
    const result = {};
    (_a = this.params) == null ? void 0 : _a.forEach((param) => result[param.name] = param.value || param.defaultValue);
    return result;
  }
}
const numberQueryConverter = {
  toQueryString(value) {
    return String(value);
  },
  fromQueryString(query) {
    const value = Array.isArray(query) ? String(query[0]) : String(query);
    return Number(value);
  }
};
const vueLoading = "";
const defaultProps = {
  color: "#3f51b5",
  loader: "spinner"
  // spinner, dots, bars
};
const inBrowser = typeof process === "undefined";
class LoadingOverlayGuard {
  constructor() {
    __publicField(this, "loadingOverlay", useLoading(defaultProps));
    __publicField(this, "showCount", 0);
    __publicField(this, "loader");
  }
  show() {
    if (inBrowser) {
      if (this.showCount <= 0) {
        this.loader = this.loadingOverlay.show();
      }
      ++this.showCount;
    }
  }
  hide() {
    if (this.showCount > 0) {
      --this.showCount;
      if (this.showCount <= 0 && this.loader) {
        this.loader.hide();
        this.loader = void 0;
      }
    }
  }
}
const defaultLoadingOverlayGuard = new LoadingOverlayGuard();
const withLoading = async (func) => {
  try {
    defaultLoadingOverlayGuard.show();
    return await func();
  } finally {
    defaultLoadingOverlayGuard.hide();
  }
};
const showLoading = () => {
  defaultLoadingOverlayGuard.show();
};
const hideLoading = () => {
  defaultLoadingOverlayGuard.hide();
};
var commonjsGlobal = typeof globalThis !== "undefined" ? globalThis : typeof window !== "undefined" ? window : typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : {};
var durationExports = {};
var duration = {
  get exports() {
    return durationExports;
  },
  set exports(v) {
    durationExports = v;
  }
};
(function(module, exports) {
  !function(t, s) {
    module.exports = s();
  }(commonjsGlobal, function() {
    var t, s, n = 1e3, i = 6e4, e = 36e5, r = 864e5, o = /\[([^\]]+)]|Y{1,4}|M{1,4}|D{1,2}|d{1,4}|H{1,2}|h{1,2}|a|A|m{1,2}|s{1,2}|Z{1,2}|SSS/g, u = 31536e6, h2 = 2592e6, a = /^(-|\+)?P(?:([-+]?[0-9,.]*)Y)?(?:([-+]?[0-9,.]*)M)?(?:([-+]?[0-9,.]*)W)?(?:([-+]?[0-9,.]*)D)?(?:T(?:([-+]?[0-9,.]*)H)?(?:([-+]?[0-9,.]*)M)?(?:([-+]?[0-9,.]*)S)?)?$/, d = { years: u, months: h2, days: r, hours: e, minutes: i, seconds: n, milliseconds: 1, weeks: 6048e5 }, c = function(t2) {
      return t2 instanceof p;
    }, f = function(t2, s2, n2) {
      return new p(t2, n2, s2.$l);
    }, m = function(t2) {
      return s.p(t2) + "s";
    }, l = function(t2) {
      return t2 < 0;
    }, $2 = function(t2) {
      return l(t2) ? Math.ceil(t2) : Math.floor(t2);
    }, y = function(t2) {
      return Math.abs(t2);
    }, g = function(t2, s2) {
      return t2 ? l(t2) ? { negative: true, format: "" + y(t2) + s2 } : { negative: false, format: "" + t2 + s2 } : { negative: false, format: "" };
    }, p = function() {
      function l2(t2, s2, n2) {
        var i2 = this;
        if (this.$d = {}, this.$l = n2, void 0 === t2 && (this.$ms = 0, this.parseFromMilliseconds()), s2)
          return f(t2 * d[m(s2)], this);
        if ("number" == typeof t2)
          return this.$ms = t2, this.parseFromMilliseconds(), this;
        if ("object" == typeof t2)
          return Object.keys(t2).forEach(function(s3) {
            i2.$d[m(s3)] = t2[s3];
          }), this.calMilliseconds(), this;
        if ("string" == typeof t2) {
          var e2 = t2.match(a);
          if (e2) {
            var r2 = e2.slice(2).map(function(t3) {
              return null != t3 ? Number(t3) : 0;
            });
            return this.$d.years = r2[0], this.$d.months = r2[1], this.$d.weeks = r2[2], this.$d.days = r2[3], this.$d.hours = r2[4], this.$d.minutes = r2[5], this.$d.seconds = r2[6], this.calMilliseconds(), this;
          }
        }
        return this;
      }
      var y2 = l2.prototype;
      return y2.calMilliseconds = function() {
        var t2 = this;
        this.$ms = Object.keys(this.$d).reduce(function(s2, n2) {
          return s2 + (t2.$d[n2] || 0) * d[n2];
        }, 0);
      }, y2.parseFromMilliseconds = function() {
        var t2 = this.$ms;
        this.$d.years = $2(t2 / u), t2 %= u, this.$d.months = $2(t2 / h2), t2 %= h2, this.$d.days = $2(t2 / r), t2 %= r, this.$d.hours = $2(t2 / e), t2 %= e, this.$d.minutes = $2(t2 / i), t2 %= i, this.$d.seconds = $2(t2 / n), t2 %= n, this.$d.milliseconds = t2;
      }, y2.toISOString = function() {
        var t2 = g(this.$d.years, "Y"), s2 = g(this.$d.months, "M"), n2 = +this.$d.days || 0;
        this.$d.weeks && (n2 += 7 * this.$d.weeks);
        var i2 = g(n2, "D"), e2 = g(this.$d.hours, "H"), r2 = g(this.$d.minutes, "M"), o2 = this.$d.seconds || 0;
        this.$d.milliseconds && (o2 += this.$d.milliseconds / 1e3);
        var u2 = g(o2, "S"), h3 = t2.negative || s2.negative || i2.negative || e2.negative || r2.negative || u2.negative, a2 = e2.format || r2.format || u2.format ? "T" : "", d2 = (h3 ? "-" : "") + "P" + t2.format + s2.format + i2.format + a2 + e2.format + r2.format + u2.format;
        return "P" === d2 || "-P" === d2 ? "P0D" : d2;
      }, y2.toJSON = function() {
        return this.toISOString();
      }, y2.format = function(t2) {
        var n2 = t2 || "YYYY-MM-DDTHH:mm:ss", i2 = { Y: this.$d.years, YY: s.s(this.$d.years, 2, "0"), YYYY: s.s(this.$d.years, 4, "0"), M: this.$d.months, MM: s.s(this.$d.months, 2, "0"), D: this.$d.days, DD: s.s(this.$d.days, 2, "0"), H: this.$d.hours, HH: s.s(this.$d.hours, 2, "0"), m: this.$d.minutes, mm: s.s(this.$d.minutes, 2, "0"), s: this.$d.seconds, ss: s.s(this.$d.seconds, 2, "0"), SSS: s.s(this.$d.milliseconds, 3, "0") };
        return n2.replace(o, function(t3, s2) {
          return s2 || String(i2[t3]);
        });
      }, y2.as = function(t2) {
        return this.$ms / d[m(t2)];
      }, y2.get = function(t2) {
        var s2 = this.$ms, n2 = m(t2);
        return "milliseconds" === n2 ? s2 %= 1e3 : s2 = "weeks" === n2 ? $2(s2 / d[n2]) : this.$d[n2], 0 === s2 ? 0 : s2;
      }, y2.add = function(t2, s2, n2) {
        var i2;
        return i2 = s2 ? t2 * d[m(s2)] : c(t2) ? t2.$ms : f(t2, this).$ms, f(this.$ms + i2 * (n2 ? -1 : 1), this);
      }, y2.subtract = function(t2, s2) {
        return this.add(t2, s2, true);
      }, y2.locale = function(t2) {
        var s2 = this.clone();
        return s2.$l = t2, s2;
      }, y2.clone = function() {
        return f(this.$ms, this);
      }, y2.humanize = function(s2) {
        return t().add(this.$ms, "ms").locale(this.$l).fromNow(!s2);
      }, y2.milliseconds = function() {
        return this.get("milliseconds");
      }, y2.asMilliseconds = function() {
        return this.as("milliseconds");
      }, y2.seconds = function() {
        return this.get("seconds");
      }, y2.asSeconds = function() {
        return this.as("seconds");
      }, y2.minutes = function() {
        return this.get("minutes");
      }, y2.asMinutes = function() {
        return this.as("minutes");
      }, y2.hours = function() {
        return this.get("hours");
      }, y2.asHours = function() {
        return this.as("hours");
      }, y2.days = function() {
        return this.get("days");
      }, y2.asDays = function() {
        return this.as("days");
      }, y2.weeks = function() {
        return this.get("weeks");
      }, y2.asWeeks = function() {
        return this.as("weeks");
      }, y2.months = function() {
        return this.get("months");
      }, y2.asMonths = function() {
        return this.as("months");
      }, y2.years = function() {
        return this.get("years");
      }, y2.asYears = function() {
        return this.as("years");
      }, l2;
    }();
    return function(n2, i2, e2) {
      t = e2, s = e2().$utils(), e2.duration = function(t2, s2) {
        var n3 = e2.locale();
        return f(t2, { $l: n3 }, s2);
      }, e2.isDuration = c;
      var r2 = i2.prototype.add, o2 = i2.prototype.subtract;
      i2.prototype.add = function(t2, s2) {
        return c(t2) && (t2 = t2.asMilliseconds()), r2.bind(this)(t2, s2);
      }, i2.prototype.subtract = function(t2, s2) {
        return c(t2) && (t2 = t2.asMilliseconds()), o2.bind(this)(t2, s2);
      };
    };
  });
})(duration);
const durationPlugin = durationExports;
dayjs.extend(durationPlugin);
const formatDuration = (timeMillis, dayFormat = "DD ", hmsFormat = "HH:mm:ss") => {
  if (!timeMillis || timeMillis < 0)
    return "";
  const days = Math.floor(timeMillis / 24 / 60 / 60 / 1e3);
  const dd = days >= 1 ? dayFormat.replace("DD", days.toFixed()) : "";
  const hms = dayjs.duration(timeMillis).format(hmsFormat);
  return `${dd}${hms}`;
};
const anchorToRouterLink = {
  mounted: (el, binding) => {
    Array.from(el.getElementsByTagName("a")).forEach((anchor) => {
      anchor.onclick = async (event2) => {
        var _a, _b;
        const router = (_a = binding.instance) == null ? void 0 : _a.$.appContext.config.globalProperties.$router;
        const href = anchor.getAttribute("href") || "";
        const isInternalLink = !!router && urlUtil.checkInternalLink(href);
        const target = (_b = anchor.getAttribute("target")) == null ? void 0 : _b.toLowerCase();
        const isTargetSelf = !target || target === "_self";
        const routerBase = location.origin + ((router == null ? void 0 : router.options.history.base) || "");
        const resultHref = isInternalLink === "SAME_ORIGIN" && isTargetSelf ? urlUtil.extractUrlDifferentPart(href, routerBase) : href;
        const useRouterLink = !event2.altKey && !event2.ctrlKey && !event2.shiftKey && isInternalLink;
        if (useRouterLink) {
          event2.preventDefault();
          await router.push(resultHref);
        }
      };
    });
  }
};
const _hoisted_1 = { class: "modal-top" };
const _hoisted_2 = {
  key: 0,
  class: "modal-title"
};
const _hoisted_3 = {
  key: 1,
  class: "modal-title"
};
const _hoisted_4 = { class: "modal-body" };
const _hoisted_5 = {
  key: 0,
  class: "modal-buttons"
};
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "UiModal",
  props: {
    title: null,
    width: null,
    height: null,
    minWidth: null,
    minHeight: null,
    maxWidth: null,
    maxHeight: null,
    drag: { type: Boolean, default: mobileDeviceType !== "IOS" },
    clickToClose: { type: Boolean },
    escToClose: { type: Boolean },
    transition: null,
    classes: null
  },
  setup(__props) {
    const slots = useSlots();
    const hasTitleSlot = computed(() => !!(slots == null ? void 0 : slots.title));
    const hasButtonsSlot = computed(() => !!(slots == null ? void 0 : slots.buttons));
    return (_ctx, _cache) => {
      const _component_Modal = resolveComponent("Modal");
      return openBlock(), createBlock(_component_Modal, {
        classes: `ui-modal ${__props.classes}`,
        "content-class": "modal-content",
        drag: __props.drag,
        "drag-selector": ".modal-top, .modal-title",
        "click-to-close": __props.clickToClose,
        "esc-to-close": __props.escToClose,
        transition: __props.transition,
        "content-style": { width: __props.width, height: __props.height, minWidth: __props.minWidth, minHeight: __props.minHeight, maxWidth: __props.maxWidth, maxHeight: __props.maxHeight }
      }, {
        default: withCtx(({ close }) => [
          createElementVNode("div", _hoisted_1, [
            unref(hasTitleSlot) ? (openBlock(), createElementBlock("span", _hoisted_2, [
              renderSlot(_ctx.$slots, "title", { close })
            ])) : (openBlock(), createElementBlock("span", _hoisted_3, toDisplayString(__props.title), 1)),
            createVNode(_sfc_main$y, {
              class: "modal-close",
              onClick: close,
              icon: "close"
            }, null, 8, ["onClick"])
          ]),
          createElementVNode("div", _hoisted_4, [
            renderSlot(_ctx.$slots, "default", { close })
          ]),
          unref(hasButtonsSlot) ? (openBlock(), createElementBlock("div", _hoisted_5, [
            renderSlot(_ctx.$slots, "buttons", { close })
          ])) : createCommentVNode("", true)
        ]),
        _: 3
      }, 8, ["classes", "drag", "click-to-close", "esc-to-close", "transition", "content-style"]);
    };
  }
});
const modalOption = {
  key: "$modal",
  componentName: "Modal",
  dynamicContainerName: "ModalsContainer"
};
const ModalPlugin = {
  install: (app) => {
    vfmPlugin().install(app, modalOption);
  },
  // $vfm object in vue-final-modal
  modal: $vfm
};
const modalProps = {
  type: Object,
  default: () => ({})
};
const useModal = () => inject("$modal");
const getModalName = (modal) => {
  var _a, _b;
  const name = typeof modal.component === "string" ? modal.component : ((_a = modal.component) == null ? void 0 : _a.name) || ((_b = modal.component) == null ? void 0 : _b.__name) || "";
  if (!name)
    throw Error(`Component name is missing. component = ${modal.component}`);
  return name;
};
const historyModalKey = Symbol("HistoryModalPluginKey");
const useHistoryModal = () => {
  const manager = inject(historyModalKey);
  if (!manager) {
    throw new Error("HistoryModalPlugin is not installed!");
  }
  return manager;
};
class HistoryModalImpl {
  constructor(modal, router) {
    __publicField(this, "unregisterRouterBeforeEach");
    __publicField(this, "openModals", /* @__PURE__ */ new Map());
    this.modal = modal;
    this.router = router;
    this.router.isReady().then(() => this.initialize());
  }
  async initialize() {
    this.unregisterRouterBeforeEach = this.router.beforeEach(
      (to, from) => {
        if (from.hash !== to.hash) {
          if (from.hash.length > 1 && to.hash.length < from.hash.length) {
            const fromFrags = this.getModalFragments(from.hash);
            const toFrags = this.getModalFragments(to.hash);
            const removed = fromFrags.filter((f) => !toFrags.includes(f));
            removed.forEach((name) => this.hide(name));
          }
        } else if (from.fullPath !== to.fullPath) {
          this.modal.hideAll();
        }
        return true;
      }
    );
    await this.removeAllModalFragments();
  }
  async removeAllModalFragments() {
    const route = this.router.currentRoute.value;
    try {
      await this.router.replace({ query: route.query, hash: "" });
    } catch (err) {
      console.log(err);
    }
  }
  getModalFragments(hash) {
    const curHash = hash.startsWith("#") ? hash.substring(1) : "";
    return curHash.length > 0 ? curHash.split(",") : [];
  }
  async removeModalFragment(modalName) {
    var _a, _b;
    const route = this.router.currentRoute.value;
    const targetModal = this.openModals.get(modalName);
    if (((_a = targetModal == null ? void 0 : targetModal.fullPathOnShow) == null ? void 0 : _a.after) === route.fullPath) {
      this.router.back();
    } else if (((_b = targetModal == null ? void 0 : targetModal.fullPathOnShow) == null ? void 0 : _b.before) === route.fullPath)
      ;
    else {
      const curFrags = this.getModalFragments(route.hash);
      const newFrags = curFrags.filter((f) => f !== modalName).join(",");
      const newHash = newFrags.length > 0 ? `#${newFrags}` : "";
      if (route.hash !== newHash) {
        await this.router.replace({ query: route.query, hash: newHash });
      }
    }
  }
  async appendModalFragment(modalName) {
    const route = this.router.currentRoute.value;
    const curFrags = this.getModalFragments(route.hash);
    if (!curFrags.includes(modalName)) {
      curFrags.push(modalName);
    }
    const newHash = "#" + curFrags.join(",");
    await this.router.push({ query: route.query, hash: newHash });
  }
  async show(option, params) {
    const modalName = getModalName(option);
    option.on = { ...option.on, closed: async () => await this.handleClose(modalName) };
    const newParams = { _modalName: modalName, ...params };
    await this.modal.show(option, newParams);
    const route = this.router.currentRoute.value;
    await this.appendModalFragment(modalName);
    this.openModals.set(modalName, {
      name: modalName,
      fullPathOnShow: {
        before: route.fullPath,
        after: this.router.currentRoute.value.fullPath
      }
    });
  }
  async hide(modalName) {
    this.modal.openedModals.filter((open) => {
      var _a, _b;
      const name = (_b = (_a = open.params) == null ? void 0 : _a.value) == null ? void 0 : _b._modalName;
      return name === modalName;
    }).forEach((toHide) => toHide.toggle());
    this.openModals.delete(modalName);
  }
  async handleClose(modalName) {
    await this.removeModalFragment(modalName);
  }
  async hideAllModals() {
    for (const modalName of this.openModals.keys()) {
      await this.hide(modalName);
    }
  }
  getOpenModalKeys() {
    return Array.from(this.openModals.keys());
  }
}
const HistoryModalPlugin = {
  install(app, option) {
    if (!option) {
      throw new Error("option (HistoryModalPluginOptions) is missing!");
    }
    if (!option.modal) {
      throw new Error("option.modal is missing!");
    }
    if (!option.router) {
      throw new Error("option.router is missing!");
    }
    const manager = new HistoryModalImpl(option.modal, option.router);
    app.provide(historyModalKey, manager);
  }
};
const closeHistoryModalAndDo = async (historyModal, router, action) => {
  const open = historyModal.getOpenModalKeys();
  if (open.length > 0) {
    await router.back();
    setTimeout(action, 100);
  } else {
    action();
  }
};
function notNull(value) {
  return value !== null && value !== void 0;
}
class CountDownTimer {
  constructor(callback) {
    __publicField(this, "targetTime");
    __publicField(this, "interval");
    this.callback = callback;
  }
  isRunning() {
    return !!this.interval;
  }
  start(targetTime) {
    this.targetTime = targetTime;
    this.countDown();
    if (!this.isRunning()) {
      this.interval = setInterval(() => {
        this.countDown();
      }, 1e3);
    }
  }
  stop() {
    if (this.interval) {
      clearInterval(this.interval);
      this.interval = void 0;
    }
  }
  countDown() {
    var _a;
    const diff = Math.max(0, ((_a = this.targetTime) == null ? void 0 : _a.diff(dayjs())) || 0);
    this.callback(diff);
    if (diff === 0) {
      this.stop();
    }
  }
}
const importCdnJs = (cdnUrl) => new Promise((resolve) => {
  const dom = document.createElement("script");
  dom.src = cdnUrl;
  dom.type = "text/javascript";
  dom.onload = () => {
    resolve();
  };
  document.head.appendChild(dom);
});
class PaginatedList {
  constructor(loading = false) {
    __publicField(this, "data", []);
    __publicField(this, "totalCount", 0);
    __publicField(this, "offset", 0);
    __publicField(this, "limit", 0);
    __publicField(this, "loading");
    this.loading = loading;
  }
  /**
   * this 뒤에 list 의 항목들을 추가한다.
   *
   * - totalCount 가 새로운 list 의 totalCount 로 변경된다.
   * - limit 이 list.length 만큼 증가한다.
   *
   * @return this 객체
   */
  append(list) {
    list.data.forEach((item) => this.data.push(item));
    this.totalCount = list.totalCount;
    this.limit += list.data.length;
    return this;
  }
  /**
   * this 앞에 list 의 항목들을 추가한다.
   *
   * - totalCount 가 새로운 list 의 totalCount 로 변경된다.
   * - offset 이 list.length 만큼 줄어든다.
   * - limit 이 list.length 만큼 증가한다.
   *
   * @return this 객체
   */
  prepend(list) {
    list.data.forEach((item) => this.data.unshift(item));
    this.totalCount = list.totalCount;
    this.offset -= list.data.length;
    this.limit += list.limit;
    return this;
  }
  /**
   * PaginatedList 의 모든 데이터를 삭제하고,
   * totalCount=0, offset=0, limit=0 으로 변경한다.
   */
  clear() {
    this.data = [];
    this.totalCount = 0;
    this.offset = 0;
    this.limit = 0;
  }
  /**
   * PaginatedList 가 로딩중인지 확인한다.
   * `PaginatedList.loading()` 으로 생성한 것만이 로딩중인 PaginatedList 이다.
   */
  isLoading() {
    return this.loading;
  }
  /**
   * @return 로딩된 데이터가 비어있으면 true
   */
  isEmpty() {
    return this.data.length === 0;
  }
  static of(data = [], totalCount = void 0, offset2 = 0, limit = void 0) {
    const paginatedList = new PaginatedList();
    paginatedList.data = data ? data.slice() : [];
    paginatedList.totalCount = Math.max(0, totalCount || paginatedList.data.length);
    paginatedList.offset = Math.max(0, offset2);
    paginatedList.limit = Math.max(0, limit || paginatedList.data.length);
    return paginatedList;
  }
  /**
   * `AxiosResponse` 등의 http response 로부터 `PaginatedList` 를 생성한다.
   * @param response
   * @param converter
   */
  static fromAxiosResponse(response, converter) {
    return PaginatedList.fromAxiosHeader(response.headers, response.data, converter);
  }
  /**
   * Axios Header 와 response data 로부터 `PaginatedList` 를 생성한다.
   * @param headers
   * @param data
   * @param converter
   */
  static fromAxiosHeader(headers, data, converter) {
    const actualConverter = converter ? converter : (item) => item;
    const convertedData = data && data.length ? data.map((item) => actualConverter(item)) : [];
    return PaginatedList.of(
      convertedData,
      Number(headers["x-total-count"]) || void 0,
      Number(headers["x-offset"]) || 0,
      Number(headers["x-limit"] || void 0)
    );
  }
  /**
   * 로딩중을 나타내는 PaginatedList 를 생성한다.
   */
  static loading() {
    return new PaginatedList(true);
  }
}
class ListCondition {
  constructor(values, defaultValue) {
    __publicField(this, "values");
    __publicField(this, "defaultValue");
    this.values = values;
    this.defaultValue = defaultValue || values[0];
  }
  toSelectItems(captionProvider) {
    return this.values.map((value) => ({ value, caption: (captionProvider == null ? void 0 : captionProvider(value)) || value }));
  }
  fromRouterQuery(queryValue) {
    const value = String(queryValue);
    return value && this.values.includes(value) ? value : this.defaultValue;
  }
}
class RouteContext {
  constructor() {
    __publicField(this, "fullPath");
    __publicField(this, "type");
    __publicField(this, "direction");
  }
  update(fullPath, type, direction) {
    this.fullPath = fullPath;
    this.type = type;
    this.direction = direction;
  }
  clearIfOtherPath(fullPath) {
    if (this.fullPath !== fullPath) {
      this.fullPath = void 0;
      this.type = void 0;
      this.direction = void 0;
    }
  }
  // 현재 route 가 back/forward 버튼으로 이동된 것이라면 true 를 리턴한다.
  fromBackOrForward() {
    return !!(this.type && this.direction);
  }
  getType() {
    return this.type === "pop" ? "pop" : this.type === "push" ? "push" : void 0;
  }
  getDirection() {
    return this.direction === "back" ? "back" : this.direction === "forward" ? "forward" : void 0;
  }
}
const routeContext = new RouteContext();
const initializeRouteContext = (router) => {
  router.options.history.listen((to, from, info) => {
    routeContext.update(to, String(info.type), String(info.direction));
  });
  router.afterEach((to) => {
    routeContext.clearIfOtherPath(to.fullPath);
  });
};
export {
  A11y,
  Autoplay,
  BREAKPOINTS,
  Controller,
  CountDownTimer,
  EffectCards,
  EffectCoverflow,
  EffectCreative,
  EffectCube,
  EffectFade,
  EffectFlip,
  freeMode as FreeMode,
  Grid,
  HashNavigation,
  History,
  HistoryModalPlugin,
  Keyboard,
  Lazy,
  ListCondition,
  MEDIA_QUERIES,
  Manipulation,
  ModalPlugin,
  Mousewheel,
  Navigation,
  PaginatedList,
  Pagination,
  Parallax,
  ScreenSizeArray,
  ScrollListFilter,
  ScrollListKey,
  Scrollbar,
  Swiper$1 as Swiper,
  Swiper2 as SwiperComponent,
  SwiperSlide,
  TAB_HANDLER,
  Thumb as Thumbs,
  TotalList,
  _sfc_main$y as UiButton,
  _sfc_main$q as UiCheckbox,
  _sfc_main$k as UiDate,
  UiField,
  UiFieldError,
  UiFieldGuide,
  _sfc_main$x as UiImage,
  _sfc_main$5 as UiInputImages,
  _sfc_main$g as UiInputPoint,
  _sfc_main$h as UiInputPrice,
  _sfc_main$e as UiInputQty,
  _sfc_main$n as UiInputText,
  _sfc_main$3 as UiLabel,
  _sfc_main$s as UiLayout,
  _sfc_main$z as UiLink,
  _sfc_main$t as UiMedia,
  _sfc_main as UiModal,
  _sfc_main$b as UiPagination,
  _sfc_main$7 as UiPeriodSearch,
  _sfc_main$w as UiPicture,
  _sfc_main$i as UiPoint,
  _sfc_main$j as UiPrice,
  _sfc_main$6 as UiProcessStep,
  _sfc_main$r as UiRadioButton,
  _sfc_main$8 as UiScrollList,
  _sfc_main$9 as UiScrollListAppend,
  _sfc_main$a as UiScrollListPage,
  _sfc_main$l as UiSelect,
  _sfc_main$2 as UiSwiper,
  _sfc_main$c as UiTab,
  _sfc_main$d as UiTabs,
  _sfc_main$m as UiTextarea,
  _sfc_main$1 as UiTimer,
  _sfc_main$f as UiTooltip,
  _sfc_main$v as UiVideo,
  _sfc_main$u as UiYoutubePlayer,
  Virtual,
  Zoom,
  anchorToRouterLink,
  browserUtil,
  closeHistoryModalAndDo,
  componentUtil,
  configureUiComponent,
  createDatePeriodByMonths,
  datePeriodConverter,
  enhanceDatePeriodObject,
  vFocusOnLoad as focusOnLoad,
  formatDuration,
  formatUtil,
  getPeriodSearchInitialValue,
  hideLoading,
  importCdnJs,
  initializeRouteContext,
  vLazy as lazy,
  mobileDeviceType,
  modalOption,
  modalProps,
  notNull,
  numberQueryConverter,
  responsiveUtil,
  routeContext,
  vSelectOnLoad as selectOnLoad,
  showLoading,
  supportIntersectionObserver,
  supportWebp,
  urlUtil,
  useHistoryModal,
  useModal,
  useRouterTab,
  useSwiper,
  useSwiperSlide,
  useTabHandler,
  withLoading
};
